Documentation
¶
Index ¶
- func GrafanaWorkspaceSamlConfiguration_IsConstruct(x interface{}) *bool
- func GrafanaWorkspaceSamlConfiguration_TfResourceType() *string
- func NewGrafanaWorkspaceSamlConfigurationTimeoutsOutputReference_Override(g GrafanaWorkspaceSamlConfigurationTimeoutsOutputReference, ...)
- func NewGrafanaWorkspaceSamlConfiguration_Override(g GrafanaWorkspaceSamlConfiguration, scope constructs.Construct, id *string, ...)
- type GrafanaWorkspaceSamlConfiguration
- type GrafanaWorkspaceSamlConfigurationConfig
- type GrafanaWorkspaceSamlConfigurationTimeouts
- type GrafanaWorkspaceSamlConfigurationTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GrafanaWorkspaceSamlConfiguration_IsConstruct ¶
func GrafanaWorkspaceSamlConfiguration_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GrafanaWorkspaceSamlConfiguration_TfResourceType ¶
func GrafanaWorkspaceSamlConfiguration_TfResourceType() *string
func NewGrafanaWorkspaceSamlConfigurationTimeoutsOutputReference_Override ¶
func NewGrafanaWorkspaceSamlConfigurationTimeoutsOutputReference_Override(g GrafanaWorkspaceSamlConfigurationTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGrafanaWorkspaceSamlConfiguration_Override ¶
func NewGrafanaWorkspaceSamlConfiguration_Override(g GrafanaWorkspaceSamlConfiguration, scope constructs.Construct, id *string, config *GrafanaWorkspaceSamlConfigurationConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration aws_grafana_workspace_saml_configuration} Resource.
Types ¶
type GrafanaWorkspaceSamlConfiguration ¶
type GrafanaWorkspaceSamlConfiguration interface {
cdktf.TerraformResource
AdminRoleValues() *[]*string
SetAdminRoleValues(val *[]*string)
AdminRoleValuesInput() *[]*string
AllowedOrganizations() *[]*string
SetAllowedOrganizations(val *[]*string)
AllowedOrganizationsInput() *[]*string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EditorRoleValues() *[]*string
SetEditorRoleValues(val *[]*string)
EditorRoleValuesInput() *[]*string
EmailAssertion() *string
SetEmailAssertion(val *string)
EmailAssertionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GroupsAssertion() *string
SetGroupsAssertion(val *string)
GroupsAssertionInput() *string
Id() *string
SetId(val *string)
IdInput() *string
IdpMetadataUrl() *string
SetIdpMetadataUrl(val *string)
IdpMetadataUrlInput() *string
IdpMetadataXml() *string
SetIdpMetadataXml(val *string)
IdpMetadataXmlInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LoginAssertion() *string
SetLoginAssertion(val *string)
LoginAssertionInput() *string
LoginValidityDuration() *float64
SetLoginValidityDuration(val *float64)
LoginValidityDurationInput() *float64
NameAssertion() *string
SetNameAssertion(val *string)
NameAssertionInput() *string
// The tree node.
Node() constructs.Node
OrgAssertion() *string
SetOrgAssertion(val *string)
OrgAssertionInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RoleAssertion() *string
SetRoleAssertion(val *string)
RoleAssertionInput() *string
Status() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GrafanaWorkspaceSamlConfigurationTimeoutsOutputReference
TimeoutsInput() interface{}
WorkspaceId() *string
SetWorkspaceId(val *string)
WorkspaceIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *GrafanaWorkspaceSamlConfigurationTimeouts)
ResetAdminRoleValues()
ResetAllowedOrganizations()
ResetEmailAssertion()
ResetGroupsAssertion()
ResetId()
ResetIdpMetadataUrl()
ResetIdpMetadataXml()
ResetLoginAssertion()
ResetLoginValidityDuration()
ResetNameAssertion()
ResetOrgAssertion()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRoleAssertion()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration aws_grafana_workspace_saml_configuration}.
func NewGrafanaWorkspaceSamlConfiguration ¶
func NewGrafanaWorkspaceSamlConfiguration(scope constructs.Construct, id *string, config *GrafanaWorkspaceSamlConfigurationConfig) GrafanaWorkspaceSamlConfiguration
Create a new {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration aws_grafana_workspace_saml_configuration} Resource.
type GrafanaWorkspaceSamlConfigurationConfig ¶
type GrafanaWorkspaceSamlConfigurationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration#editor_role_values GrafanaWorkspaceSamlConfiguration#editor_role_values}.
EditorRoleValues *[]*string `field:"required" json:"editorRoleValues" yaml:"editorRoleValues"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration#workspace_id GrafanaWorkspaceSamlConfiguration#workspace_id}.
WorkspaceId *string `field:"required" json:"workspaceId" yaml:"workspaceId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration#admin_role_values GrafanaWorkspaceSamlConfiguration#admin_role_values}.
AdminRoleValues *[]*string `field:"optional" json:"adminRoleValues" yaml:"adminRoleValues"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration#allowed_organizations GrafanaWorkspaceSamlConfiguration#allowed_organizations}.
AllowedOrganizations *[]*string `field:"optional" json:"allowedOrganizations" yaml:"allowedOrganizations"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration#email_assertion GrafanaWorkspaceSamlConfiguration#email_assertion}.
EmailAssertion *string `field:"optional" json:"emailAssertion" yaml:"emailAssertion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration#groups_assertion GrafanaWorkspaceSamlConfiguration#groups_assertion}.
GroupsAssertion *string `field:"optional" json:"groupsAssertion" yaml:"groupsAssertion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration#id GrafanaWorkspaceSamlConfiguration#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration#idp_metadata_url GrafanaWorkspaceSamlConfiguration#idp_metadata_url}.
IdpMetadataUrl *string `field:"optional" json:"idpMetadataUrl" yaml:"idpMetadataUrl"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration#idp_metadata_xml GrafanaWorkspaceSamlConfiguration#idp_metadata_xml}.
IdpMetadataXml *string `field:"optional" json:"idpMetadataXml" yaml:"idpMetadataXml"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration#login_assertion GrafanaWorkspaceSamlConfiguration#login_assertion}.
LoginAssertion *string `field:"optional" json:"loginAssertion" yaml:"loginAssertion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration#login_validity_duration GrafanaWorkspaceSamlConfiguration#login_validity_duration}.
LoginValidityDuration *float64 `field:"optional" json:"loginValidityDuration" yaml:"loginValidityDuration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration#name_assertion GrafanaWorkspaceSamlConfiguration#name_assertion}.
NameAssertion *string `field:"optional" json:"nameAssertion" yaml:"nameAssertion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration#org_assertion GrafanaWorkspaceSamlConfiguration#org_assertion}.
OrgAssertion *string `field:"optional" json:"orgAssertion" yaml:"orgAssertion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration#role_assertion GrafanaWorkspaceSamlConfiguration#role_assertion}.
RoleAssertion *string `field:"optional" json:"roleAssertion" yaml:"roleAssertion"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration#timeouts GrafanaWorkspaceSamlConfiguration#timeouts}
Timeouts *GrafanaWorkspaceSamlConfigurationTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GrafanaWorkspaceSamlConfigurationTimeouts ¶
type GrafanaWorkspaceSamlConfigurationTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration#create GrafanaWorkspaceSamlConfiguration#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_saml_configuration#delete GrafanaWorkspaceSamlConfiguration#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type GrafanaWorkspaceSamlConfigurationTimeoutsOutputReference ¶
type GrafanaWorkspaceSamlConfigurationTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGrafanaWorkspaceSamlConfigurationTimeoutsOutputReference ¶
func NewGrafanaWorkspaceSamlConfigurationTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GrafanaWorkspaceSamlConfigurationTimeoutsOutputReference
Source Files
¶
- grafanaworkspacesamlconfiguration.go
- grafanaworkspacesamlconfiguration_GrafanaWorkspaceSamlConfiguration.go
- grafanaworkspacesamlconfiguration_GrafanaWorkspaceSamlConfigurationConfig.go
- grafanaworkspacesamlconfiguration_GrafanaWorkspaceSamlConfigurationTimeouts.go
- grafanaworkspacesamlconfiguration_GrafanaWorkspaceSamlConfigurationTimeoutsOutputReference.go
- grafanaworkspacesamlconfiguration_GrafanaWorkspaceSamlConfigurationTimeoutsOutputReference__runtime_type_checks.go
- grafanaworkspacesamlconfiguration_GrafanaWorkspaceSamlConfiguration__runtime_type_checks.go