Documentation
¶
Index ¶
- func Inspector2OrganizationConfiguration_IsConstruct(x interface{}) *bool
- func Inspector2OrganizationConfiguration_TfResourceType() *string
- func NewInspector2OrganizationConfigurationAutoEnableOutputReference_Override(i Inspector2OrganizationConfigurationAutoEnableOutputReference, ...)
- func NewInspector2OrganizationConfigurationTimeoutsOutputReference_Override(i Inspector2OrganizationConfigurationTimeoutsOutputReference, ...)
- func NewInspector2OrganizationConfiguration_Override(i Inspector2OrganizationConfiguration, scope constructs.Construct, id *string, ...)
- type Inspector2OrganizationConfiguration
- type Inspector2OrganizationConfigurationAutoEnable
- type Inspector2OrganizationConfigurationAutoEnableOutputReference
- type Inspector2OrganizationConfigurationConfig
- type Inspector2OrganizationConfigurationTimeouts
- type Inspector2OrganizationConfigurationTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Inspector2OrganizationConfiguration_IsConstruct ¶
func Inspector2OrganizationConfiguration_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func Inspector2OrganizationConfiguration_TfResourceType ¶
func Inspector2OrganizationConfiguration_TfResourceType() *string
func NewInspector2OrganizationConfigurationAutoEnableOutputReference_Override ¶
func NewInspector2OrganizationConfigurationAutoEnableOutputReference_Override(i Inspector2OrganizationConfigurationAutoEnableOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewInspector2OrganizationConfigurationTimeoutsOutputReference_Override ¶
func NewInspector2OrganizationConfigurationTimeoutsOutputReference_Override(i Inspector2OrganizationConfigurationTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewInspector2OrganizationConfiguration_Override ¶
func NewInspector2OrganizationConfiguration_Override(i Inspector2OrganizationConfiguration, scope constructs.Construct, id *string, config *Inspector2OrganizationConfigurationConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/inspector2_organization_configuration aws_inspector2_organization_configuration} Resource.
Types ¶
type Inspector2OrganizationConfiguration ¶
type Inspector2OrganizationConfiguration interface {
cdktf.TerraformResource
AutoEnable() Inspector2OrganizationConfigurationAutoEnableOutputReference
AutoEnableInput() *Inspector2OrganizationConfigurationAutoEnable
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaxAccountLimitReached() cdktf.IResolvable
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() Inspector2OrganizationConfigurationTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAutoEnable(value *Inspector2OrganizationConfigurationAutoEnable)
PutTimeouts(value *Inspector2OrganizationConfigurationTimeouts)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/inspector2_organization_configuration aws_inspector2_organization_configuration}.
func NewInspector2OrganizationConfiguration ¶
func NewInspector2OrganizationConfiguration(scope constructs.Construct, id *string, config *Inspector2OrganizationConfigurationConfig) Inspector2OrganizationConfiguration
Create a new {@link https://www.terraform.io/docs/providers/aws/r/inspector2_organization_configuration aws_inspector2_organization_configuration} Resource.
type Inspector2OrganizationConfigurationAutoEnable ¶
type Inspector2OrganizationConfigurationAutoEnable struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/inspector2_organization_configuration#ec2 Inspector2OrganizationConfiguration#ec2}.
Ec2 interface{} `field:"required" json:"ec2" yaml:"ec2"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/inspector2_organization_configuration#ecr Inspector2OrganizationConfiguration#ecr}.
Ecr interface{} `field:"required" json:"ecr" yaml:"ecr"`
}
type Inspector2OrganizationConfigurationAutoEnableOutputReference ¶
type Inspector2OrganizationConfigurationAutoEnableOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Ec2() interface{}
SetEc2(val interface{})
Ec2Input() interface{}
Ecr() interface{}
SetEcr(val interface{})
EcrInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *Inspector2OrganizationConfigurationAutoEnable
SetInternalValue(val *Inspector2OrganizationConfigurationAutoEnable)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewInspector2OrganizationConfigurationAutoEnableOutputReference ¶
func NewInspector2OrganizationConfigurationAutoEnableOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Inspector2OrganizationConfigurationAutoEnableOutputReference
type Inspector2OrganizationConfigurationConfig ¶
type Inspector2OrganizationConfigurationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// auto_enable block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/inspector2_organization_configuration#auto_enable Inspector2OrganizationConfiguration#auto_enable}
AutoEnable *Inspector2OrganizationConfigurationAutoEnable `field:"required" json:"autoEnable" yaml:"autoEnable"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/inspector2_organization_configuration#id Inspector2OrganizationConfiguration#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/inspector2_organization_configuration#timeouts Inspector2OrganizationConfiguration#timeouts}
Timeouts *Inspector2OrganizationConfigurationTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type Inspector2OrganizationConfigurationTimeouts ¶
type Inspector2OrganizationConfigurationTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/inspector2_organization_configuration#create Inspector2OrganizationConfiguration#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/inspector2_organization_configuration#delete Inspector2OrganizationConfiguration#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/inspector2_organization_configuration#update Inspector2OrganizationConfiguration#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type Inspector2OrganizationConfigurationTimeoutsOutputReference ¶
type Inspector2OrganizationConfigurationTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewInspector2OrganizationConfigurationTimeoutsOutputReference ¶
func NewInspector2OrganizationConfigurationTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Inspector2OrganizationConfigurationTimeoutsOutputReference
Source Files
¶
- inspector2organizationconfiguration.go
- inspector2organizationconfiguration_Inspector2OrganizationConfiguration.go
- inspector2organizationconfiguration_Inspector2OrganizationConfigurationAutoEnable.go
- inspector2organizationconfiguration_Inspector2OrganizationConfigurationAutoEnableOutputReference.go
- inspector2organizationconfiguration_Inspector2OrganizationConfigurationAutoEnableOutputReference__runtime_type_checks.go
- inspector2organizationconfiguration_Inspector2OrganizationConfigurationConfig.go
- inspector2organizationconfiguration_Inspector2OrganizationConfigurationTimeouts.go
- inspector2organizationconfiguration_Inspector2OrganizationConfigurationTimeoutsOutputReference.go
- inspector2organizationconfiguration_Inspector2OrganizationConfigurationTimeoutsOutputReference__runtime_type_checks.go
- inspector2organizationconfiguration_Inspector2OrganizationConfiguration__runtime_type_checks.go