Documentation
¶
Index ¶
- func LambdaFunctionUrl_IsConstruct(x interface{}) *bool
- func LambdaFunctionUrl_TfResourceType() *string
- func NewLambdaFunctionUrlCorsOutputReference_Override(l LambdaFunctionUrlCorsOutputReference, ...)
- func NewLambdaFunctionUrlTimeoutsOutputReference_Override(l LambdaFunctionUrlTimeoutsOutputReference, ...)
- func NewLambdaFunctionUrl_Override(l LambdaFunctionUrl, scope constructs.Construct, id *string, ...)
- type LambdaFunctionUrl
- type LambdaFunctionUrlConfig
- type LambdaFunctionUrlCors
- type LambdaFunctionUrlCorsOutputReference
- type LambdaFunctionUrlTimeouts
- type LambdaFunctionUrlTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LambdaFunctionUrl_IsConstruct ¶
func LambdaFunctionUrl_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func LambdaFunctionUrl_TfResourceType ¶
func LambdaFunctionUrl_TfResourceType() *string
func NewLambdaFunctionUrlCorsOutputReference_Override ¶
func NewLambdaFunctionUrlCorsOutputReference_Override(l LambdaFunctionUrlCorsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLambdaFunctionUrlTimeoutsOutputReference_Override ¶
func NewLambdaFunctionUrlTimeoutsOutputReference_Override(l LambdaFunctionUrlTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLambdaFunctionUrl_Override ¶
func NewLambdaFunctionUrl_Override(l LambdaFunctionUrl, scope constructs.Construct, id *string, config *LambdaFunctionUrlConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_url aws_lambda_function_url} Resource.
Types ¶
type LambdaFunctionUrl ¶
type LambdaFunctionUrl interface {
cdktf.TerraformResource
AuthorizationType() *string
SetAuthorizationType(val *string)
AuthorizationTypeInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
Cors() LambdaFunctionUrlCorsOutputReference
CorsInput() *LambdaFunctionUrlCors
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
FunctionArn() *string
FunctionName() *string
SetFunctionName(val *string)
FunctionNameInput() *string
FunctionUrl() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
Qualifier() *string
SetQualifier(val *string)
QualifierInput() *string
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() LambdaFunctionUrlTimeoutsOutputReference
TimeoutsInput() interface{}
UrlId() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCors(value *LambdaFunctionUrlCors)
PutTimeouts(value *LambdaFunctionUrlTimeouts)
ResetCors()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetQualifier()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_url aws_lambda_function_url}.
func NewLambdaFunctionUrl ¶
func NewLambdaFunctionUrl(scope constructs.Construct, id *string, config *LambdaFunctionUrlConfig) LambdaFunctionUrl
Create a new {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_url aws_lambda_function_url} Resource.
type LambdaFunctionUrlConfig ¶
type LambdaFunctionUrlConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_url#authorization_type LambdaFunctionUrl#authorization_type}.
AuthorizationType *string `field:"required" json:"authorizationType" yaml:"authorizationType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_url#function_name LambdaFunctionUrl#function_name}.
FunctionName *string `field:"required" json:"functionName" yaml:"functionName"`
// cors block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_url#cors LambdaFunctionUrl#cors}
Cors *LambdaFunctionUrlCors `field:"optional" json:"cors" yaml:"cors"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_url#id LambdaFunctionUrl#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_url#qualifier LambdaFunctionUrl#qualifier}.
Qualifier *string `field:"optional" json:"qualifier" yaml:"qualifier"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_url#timeouts LambdaFunctionUrl#timeouts}
Timeouts *LambdaFunctionUrlTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type LambdaFunctionUrlCors ¶
type LambdaFunctionUrlCors struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_url#allow_credentials LambdaFunctionUrl#allow_credentials}.
AllowCredentials interface{} `field:"optional" json:"allowCredentials" yaml:"allowCredentials"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_url#allow_headers LambdaFunctionUrl#allow_headers}.
AllowHeaders *[]*string `field:"optional" json:"allowHeaders" yaml:"allowHeaders"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_url#allow_methods LambdaFunctionUrl#allow_methods}.
AllowMethods *[]*string `field:"optional" json:"allowMethods" yaml:"allowMethods"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_url#allow_origins LambdaFunctionUrl#allow_origins}.
AllowOrigins *[]*string `field:"optional" json:"allowOrigins" yaml:"allowOrigins"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_url#expose_headers LambdaFunctionUrl#expose_headers}.
ExposeHeaders *[]*string `field:"optional" json:"exposeHeaders" yaml:"exposeHeaders"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_url#max_age LambdaFunctionUrl#max_age}.
MaxAge *float64 `field:"optional" json:"maxAge" yaml:"maxAge"`
}
type LambdaFunctionUrlCorsOutputReference ¶
type LambdaFunctionUrlCorsOutputReference interface {
cdktf.ComplexObject
AllowCredentials() interface{}
SetAllowCredentials(val interface{})
AllowCredentialsInput() interface{}
AllowHeaders() *[]*string
SetAllowHeaders(val *[]*string)
AllowHeadersInput() *[]*string
AllowMethods() *[]*string
SetAllowMethods(val *[]*string)
AllowMethodsInput() *[]*string
AllowOrigins() *[]*string
SetAllowOrigins(val *[]*string)
AllowOriginsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
ExposeHeaders() *[]*string
SetExposeHeaders(val *[]*string)
ExposeHeadersInput() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LambdaFunctionUrlCors
SetInternalValue(val *LambdaFunctionUrlCors)
MaxAge() *float64
SetMaxAge(val *float64)
MaxAgeInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAllowCredentials()
ResetAllowHeaders()
ResetAllowMethods()
ResetAllowOrigins()
ResetExposeHeaders()
ResetMaxAge()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLambdaFunctionUrlCorsOutputReference ¶
func NewLambdaFunctionUrlCorsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LambdaFunctionUrlCorsOutputReference
type LambdaFunctionUrlTimeouts ¶
type LambdaFunctionUrlTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_url#create LambdaFunctionUrl#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
}
type LambdaFunctionUrlTimeoutsOutputReference ¶
type LambdaFunctionUrlTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLambdaFunctionUrlTimeoutsOutputReference ¶
func NewLambdaFunctionUrlTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LambdaFunctionUrlTimeoutsOutputReference
Source Files
¶
- lambdafunctionurl.go
- lambdafunctionurl_LambdaFunctionUrl.go
- lambdafunctionurl_LambdaFunctionUrlConfig.go
- lambdafunctionurl_LambdaFunctionUrlCors.go
- lambdafunctionurl_LambdaFunctionUrlCorsOutputReference.go
- lambdafunctionurl_LambdaFunctionUrlCorsOutputReference__runtime_type_checks.go
- lambdafunctionurl_LambdaFunctionUrlTimeouts.go
- lambdafunctionurl_LambdaFunctionUrlTimeoutsOutputReference.go
- lambdafunctionurl_LambdaFunctionUrlTimeoutsOutputReference__runtime_type_checks.go
- lambdafunctionurl_LambdaFunctionUrl__runtime_type_checks.go