Documentation
¶
Index ¶
- func NewRedshiftserverlessEndpointAccessVpcEndpointList_Override(r RedshiftserverlessEndpointAccessVpcEndpointList, ...)
- func NewRedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceList_Override(r RedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceList, ...)
- func NewRedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceOutputReference_Override(r RedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceOutputReference, ...)
- func NewRedshiftserverlessEndpointAccessVpcEndpointOutputReference_Override(r RedshiftserverlessEndpointAccessVpcEndpointOutputReference, ...)
- func NewRedshiftserverlessEndpointAccess_Override(r RedshiftserverlessEndpointAccess, scope constructs.Construct, id *string, ...)
- func RedshiftserverlessEndpointAccess_IsConstruct(x interface{}) *bool
- func RedshiftserverlessEndpointAccess_TfResourceType() *string
- type RedshiftserverlessEndpointAccess
- type RedshiftserverlessEndpointAccessConfig
- type RedshiftserverlessEndpointAccessVpcEndpoint
- type RedshiftserverlessEndpointAccessVpcEndpointList
- type RedshiftserverlessEndpointAccessVpcEndpointNetworkInterface
- type RedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceList
- type RedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceOutputReference
- type RedshiftserverlessEndpointAccessVpcEndpointOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRedshiftserverlessEndpointAccessVpcEndpointList_Override ¶
func NewRedshiftserverlessEndpointAccessVpcEndpointList_Override(r RedshiftserverlessEndpointAccessVpcEndpointList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewRedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceList_Override ¶
func NewRedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceList_Override(r RedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewRedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceOutputReference_Override ¶
func NewRedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceOutputReference_Override(r RedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewRedshiftserverlessEndpointAccessVpcEndpointOutputReference_Override ¶
func NewRedshiftserverlessEndpointAccessVpcEndpointOutputReference_Override(r RedshiftserverlessEndpointAccessVpcEndpointOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewRedshiftserverlessEndpointAccess_Override ¶
func NewRedshiftserverlessEndpointAccess_Override(r RedshiftserverlessEndpointAccess, scope constructs.Construct, id *string, config *RedshiftserverlessEndpointAccessConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/redshiftserverless_endpoint_access aws_redshiftserverless_endpoint_access} Resource.
func RedshiftserverlessEndpointAccess_IsConstruct ¶
func RedshiftserverlessEndpointAccess_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func RedshiftserverlessEndpointAccess_TfResourceType ¶
func RedshiftserverlessEndpointAccess_TfResourceType() *string
Types ¶
type RedshiftserverlessEndpointAccess ¶
type RedshiftserverlessEndpointAccess interface {
cdktf.TerraformResource
Address() *string
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EndpointName() *string
SetEndpointName(val *string)
EndpointNameInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
Port() *float64
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SubnetIds() *[]*string
SetSubnetIds(val *[]*string)
SubnetIdsInput() *[]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
VpcEndpoint() RedshiftserverlessEndpointAccessVpcEndpointList
VpcSecurityGroupIds() *[]*string
SetVpcSecurityGroupIds(val *[]*string)
VpcSecurityGroupIdsInput() *[]*string
WorkgroupName() *string
SetWorkgroupName(val *string)
WorkgroupNameInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetVpcSecurityGroupIds()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/redshiftserverless_endpoint_access aws_redshiftserverless_endpoint_access}.
func NewRedshiftserverlessEndpointAccess ¶
func NewRedshiftserverlessEndpointAccess(scope constructs.Construct, id *string, config *RedshiftserverlessEndpointAccessConfig) RedshiftserverlessEndpointAccess
Create a new {@link https://www.terraform.io/docs/providers/aws/r/redshiftserverless_endpoint_access aws_redshiftserverless_endpoint_access} Resource.
type RedshiftserverlessEndpointAccessConfig ¶
type RedshiftserverlessEndpointAccessConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/redshiftserverless_endpoint_access#endpoint_name RedshiftserverlessEndpointAccess#endpoint_name}.
EndpointName *string `field:"required" json:"endpointName" yaml:"endpointName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/redshiftserverless_endpoint_access#subnet_ids RedshiftserverlessEndpointAccess#subnet_ids}.
SubnetIds *[]*string `field:"required" json:"subnetIds" yaml:"subnetIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/redshiftserverless_endpoint_access#workgroup_name RedshiftserverlessEndpointAccess#workgroup_name}.
WorkgroupName *string `field:"required" json:"workgroupName" yaml:"workgroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/redshiftserverless_endpoint_access#id RedshiftserverlessEndpointAccess#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/redshiftserverless_endpoint_access#vpc_security_group_ids RedshiftserverlessEndpointAccess#vpc_security_group_ids}.
VpcSecurityGroupIds *[]*string `field:"optional" json:"vpcSecurityGroupIds" yaml:"vpcSecurityGroupIds"`
}
type RedshiftserverlessEndpointAccessVpcEndpoint ¶
type RedshiftserverlessEndpointAccessVpcEndpoint struct {
}
type RedshiftserverlessEndpointAccessVpcEndpointList ¶
type RedshiftserverlessEndpointAccessVpcEndpointList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) RedshiftserverlessEndpointAccessVpcEndpointOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRedshiftserverlessEndpointAccessVpcEndpointList ¶
func NewRedshiftserverlessEndpointAccessVpcEndpointList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) RedshiftserverlessEndpointAccessVpcEndpointList
type RedshiftserverlessEndpointAccessVpcEndpointNetworkInterface ¶
type RedshiftserverlessEndpointAccessVpcEndpointNetworkInterface struct {
}
type RedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceList ¶
type RedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) RedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceList ¶
func NewRedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) RedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceList
type RedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceOutputReference ¶
type RedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceOutputReference interface {
cdktf.ComplexObject
AvailabilityZone() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *RedshiftserverlessEndpointAccessVpcEndpointNetworkInterface
SetInternalValue(val *RedshiftserverlessEndpointAccessVpcEndpointNetworkInterface)
NetworkInterfaceId() *string
PrivateIpAddress() *string
SubnetId() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceOutputReference ¶
func NewRedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) RedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceOutputReference
type RedshiftserverlessEndpointAccessVpcEndpointOutputReference ¶
type RedshiftserverlessEndpointAccessVpcEndpointOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *RedshiftserverlessEndpointAccessVpcEndpoint
SetInternalValue(val *RedshiftserverlessEndpointAccessVpcEndpoint)
NetworkInterface() RedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VpcEndpointId() *string
VpcId() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRedshiftserverlessEndpointAccessVpcEndpointOutputReference ¶
func NewRedshiftserverlessEndpointAccessVpcEndpointOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) RedshiftserverlessEndpointAccessVpcEndpointOutputReference
Source Files
¶
- redshiftserverlessendpointaccess.go
- redshiftserverlessendpointaccess_RedshiftserverlessEndpointAccess.go
- redshiftserverlessendpointaccess_RedshiftserverlessEndpointAccessConfig.go
- redshiftserverlessendpointaccess_RedshiftserverlessEndpointAccessVpcEndpoint.go
- redshiftserverlessendpointaccess_RedshiftserverlessEndpointAccessVpcEndpointList.go
- redshiftserverlessendpointaccess_RedshiftserverlessEndpointAccessVpcEndpointList__runtime_type_checks.go
- redshiftserverlessendpointaccess_RedshiftserverlessEndpointAccessVpcEndpointNetworkInterface.go
- redshiftserverlessendpointaccess_RedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceList.go
- redshiftserverlessendpointaccess_RedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceList__runtime_type_checks.go
- redshiftserverlessendpointaccess_RedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceOutputReference.go
- redshiftserverlessendpointaccess_RedshiftserverlessEndpointAccessVpcEndpointNetworkInterfaceOutputReference__runtime_type_checks.go
- redshiftserverlessendpointaccess_RedshiftserverlessEndpointAccessVpcEndpointOutputReference.go
- redshiftserverlessendpointaccess_RedshiftserverlessEndpointAccessVpcEndpointOutputReference__runtime_type_checks.go
- redshiftserverlessendpointaccess_RedshiftserverlessEndpointAccess__runtime_type_checks.go