Documentation
¶
Index ¶
- func NewRoute53RecordAliasList_Override(r Route53RecordAliasList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewRoute53RecordAliasOutputReference_Override(r Route53RecordAliasOutputReference, ...)
- func NewRoute53RecordFailoverRoutingPolicyList_Override(r Route53RecordFailoverRoutingPolicyList, ...)
- func NewRoute53RecordFailoverRoutingPolicyOutputReference_Override(r Route53RecordFailoverRoutingPolicyOutputReference, ...)
- func NewRoute53RecordGeolocationRoutingPolicyList_Override(r Route53RecordGeolocationRoutingPolicyList, ...)
- func NewRoute53RecordGeolocationRoutingPolicyOutputReference_Override(r Route53RecordGeolocationRoutingPolicyOutputReference, ...)
- func NewRoute53RecordLatencyRoutingPolicyList_Override(r Route53RecordLatencyRoutingPolicyList, ...)
- func NewRoute53RecordLatencyRoutingPolicyOutputReference_Override(r Route53RecordLatencyRoutingPolicyOutputReference, ...)
- func NewRoute53RecordWeightedRoutingPolicyList_Override(r Route53RecordWeightedRoutingPolicyList, ...)
- func NewRoute53RecordWeightedRoutingPolicyOutputReference_Override(r Route53RecordWeightedRoutingPolicyOutputReference, ...)
- func NewRoute53Record_Override(r Route53Record, scope constructs.Construct, id *string, ...)
- func Route53Record_IsConstruct(x interface{}) *bool
- func Route53Record_TfResourceType() *string
- type Route53Record
- type Route53RecordAlias
- type Route53RecordAliasList
- type Route53RecordAliasOutputReference
- type Route53RecordConfig
- type Route53RecordFailoverRoutingPolicy
- type Route53RecordFailoverRoutingPolicyList
- type Route53RecordFailoverRoutingPolicyOutputReference
- type Route53RecordGeolocationRoutingPolicy
- type Route53RecordGeolocationRoutingPolicyList
- type Route53RecordGeolocationRoutingPolicyOutputReference
- type Route53RecordLatencyRoutingPolicy
- type Route53RecordLatencyRoutingPolicyList
- type Route53RecordLatencyRoutingPolicyOutputReference
- type Route53RecordWeightedRoutingPolicy
- type Route53RecordWeightedRoutingPolicyList
- type Route53RecordWeightedRoutingPolicyOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRoute53RecordAliasList_Override ¶
func NewRoute53RecordAliasList_Override(r Route53RecordAliasList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewRoute53RecordAliasOutputReference_Override ¶
func NewRoute53RecordAliasOutputReference_Override(r Route53RecordAliasOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewRoute53RecordFailoverRoutingPolicyList_Override ¶
func NewRoute53RecordFailoverRoutingPolicyList_Override(r Route53RecordFailoverRoutingPolicyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewRoute53RecordFailoverRoutingPolicyOutputReference_Override ¶
func NewRoute53RecordFailoverRoutingPolicyOutputReference_Override(r Route53RecordFailoverRoutingPolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewRoute53RecordGeolocationRoutingPolicyList_Override ¶
func NewRoute53RecordGeolocationRoutingPolicyList_Override(r Route53RecordGeolocationRoutingPolicyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewRoute53RecordGeolocationRoutingPolicyOutputReference_Override ¶
func NewRoute53RecordGeolocationRoutingPolicyOutputReference_Override(r Route53RecordGeolocationRoutingPolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewRoute53RecordLatencyRoutingPolicyList_Override ¶
func NewRoute53RecordLatencyRoutingPolicyList_Override(r Route53RecordLatencyRoutingPolicyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewRoute53RecordLatencyRoutingPolicyOutputReference_Override ¶
func NewRoute53RecordLatencyRoutingPolicyOutputReference_Override(r Route53RecordLatencyRoutingPolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewRoute53RecordWeightedRoutingPolicyList_Override ¶
func NewRoute53RecordWeightedRoutingPolicyList_Override(r Route53RecordWeightedRoutingPolicyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewRoute53RecordWeightedRoutingPolicyOutputReference_Override ¶
func NewRoute53RecordWeightedRoutingPolicyOutputReference_Override(r Route53RecordWeightedRoutingPolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewRoute53Record_Override ¶
func NewRoute53Record_Override(r Route53Record, scope constructs.Construct, id *string, config *Route53RecordConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/route53_record aws_route53_record} Resource.
func Route53Record_IsConstruct ¶
func Route53Record_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func Route53Record_TfResourceType ¶
func Route53Record_TfResourceType() *string
Types ¶
type Route53Record ¶
type Route53Record interface {
cdktf.TerraformResource
Alias() Route53RecordAliasList
AliasInput() interface{}
AllowOverwrite() interface{}
SetAllowOverwrite(val interface{})
AllowOverwriteInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
FailoverRoutingPolicy() Route53RecordFailoverRoutingPolicyList
FailoverRoutingPolicyInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
Fqdn() *string
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GeolocationRoutingPolicy() Route53RecordGeolocationRoutingPolicyList
GeolocationRoutingPolicyInput() interface{}
HealthCheckId() *string
SetHealthCheckId(val *string)
HealthCheckIdInput() *string
Id() *string
SetId(val *string)
IdInput() *string
LatencyRoutingPolicy() Route53RecordLatencyRoutingPolicyList
LatencyRoutingPolicyInput() interface{}
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MultivalueAnswerRoutingPolicy() interface{}
SetMultivalueAnswerRoutingPolicy(val interface{})
MultivalueAnswerRoutingPolicyInput() interface{}
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Records() *[]*string
SetRecords(val *[]*string)
RecordsInput() *[]*string
SetIdentifier() *string
SetSetIdentifier(val *string)
SetIdentifierInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Ttl() *float64
SetTtl(val *float64)
TtlInput() *float64
Type() *string
SetType(val *string)
TypeInput() *string
WeightedRoutingPolicy() Route53RecordWeightedRoutingPolicyList
WeightedRoutingPolicyInput() interface{}
ZoneId() *string
SetZoneId(val *string)
ZoneIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAlias(value interface{})
PutFailoverRoutingPolicy(value interface{})
PutGeolocationRoutingPolicy(value interface{})
PutLatencyRoutingPolicy(value interface{})
PutWeightedRoutingPolicy(value interface{})
ResetAlias()
ResetAllowOverwrite()
ResetFailoverRoutingPolicy()
ResetGeolocationRoutingPolicy()
ResetHealthCheckId()
ResetId()
ResetLatencyRoutingPolicy()
ResetMultivalueAnswerRoutingPolicy()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRecords()
ResetSetIdentifier()
ResetTtl()
ResetWeightedRoutingPolicy()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/route53_record aws_route53_record}.
func NewRoute53Record ¶
func NewRoute53Record(scope constructs.Construct, id *string, config *Route53RecordConfig) Route53Record
Create a new {@link https://www.terraform.io/docs/providers/aws/r/route53_record aws_route53_record} Resource.
type Route53RecordAlias ¶
type Route53RecordAlias struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#evaluate_target_health Route53Record#evaluate_target_health}.
EvaluateTargetHealth interface{} `field:"required" json:"evaluateTargetHealth" yaml:"evaluateTargetHealth"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#name Route53Record#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#zone_id Route53Record#zone_id}.
ZoneId *string `field:"required" json:"zoneId" yaml:"zoneId"`
}
type Route53RecordAliasList ¶
type Route53RecordAliasList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) Route53RecordAliasOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRoute53RecordAliasList ¶
func NewRoute53RecordAliasList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) Route53RecordAliasList
type Route53RecordAliasOutputReference ¶
type Route53RecordAliasOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EvaluateTargetHealth() interface{}
SetEvaluateTargetHealth(val interface{})
EvaluateTargetHealthInput() interface{}
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ZoneId() *string
SetZoneId(val *string)
ZoneIdInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRoute53RecordAliasOutputReference ¶
func NewRoute53RecordAliasOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) Route53RecordAliasOutputReference
type Route53RecordConfig ¶
type Route53RecordConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#name Route53Record#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#type Route53Record#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#zone_id Route53Record#zone_id}.
ZoneId *string `field:"required" json:"zoneId" yaml:"zoneId"`
// alias block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#alias Route53Record#alias}
Alias interface{} `field:"optional" json:"alias" yaml:"alias"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#allow_overwrite Route53Record#allow_overwrite}.
AllowOverwrite interface{} `field:"optional" json:"allowOverwrite" yaml:"allowOverwrite"`
// failover_routing_policy block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#failover_routing_policy Route53Record#failover_routing_policy}
FailoverRoutingPolicy interface{} `field:"optional" json:"failoverRoutingPolicy" yaml:"failoverRoutingPolicy"`
// geolocation_routing_policy block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#geolocation_routing_policy Route53Record#geolocation_routing_policy}
GeolocationRoutingPolicy interface{} `field:"optional" json:"geolocationRoutingPolicy" yaml:"geolocationRoutingPolicy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#health_check_id Route53Record#health_check_id}.
HealthCheckId *string `field:"optional" json:"healthCheckId" yaml:"healthCheckId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#id Route53Record#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// latency_routing_policy block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#latency_routing_policy Route53Record#latency_routing_policy}
LatencyRoutingPolicy interface{} `field:"optional" json:"latencyRoutingPolicy" yaml:"latencyRoutingPolicy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#multivalue_answer_routing_policy Route53Record#multivalue_answer_routing_policy}.
MultivalueAnswerRoutingPolicy interface{} `field:"optional" json:"multivalueAnswerRoutingPolicy" yaml:"multivalueAnswerRoutingPolicy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#records Route53Record#records}.
Records *[]*string `field:"optional" json:"records" yaml:"records"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#set_identifier Route53Record#set_identifier}.
SetIdentifier *string `field:"optional" json:"setIdentifier" yaml:"setIdentifier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#ttl Route53Record#ttl}.
Ttl *float64 `field:"optional" json:"ttl" yaml:"ttl"`
// weighted_routing_policy block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#weighted_routing_policy Route53Record#weighted_routing_policy}
WeightedRoutingPolicy interface{} `field:"optional" json:"weightedRoutingPolicy" yaml:"weightedRoutingPolicy"`
}
type Route53RecordFailoverRoutingPolicy ¶
type Route53RecordFailoverRoutingPolicy struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#type Route53Record#type}.
Type *string `field:"required" json:"type" yaml:"type"`
}
type Route53RecordFailoverRoutingPolicyList ¶
type Route53RecordFailoverRoutingPolicyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) Route53RecordFailoverRoutingPolicyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRoute53RecordFailoverRoutingPolicyList ¶
func NewRoute53RecordFailoverRoutingPolicyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) Route53RecordFailoverRoutingPolicyList
type Route53RecordFailoverRoutingPolicyOutputReference ¶
type Route53RecordFailoverRoutingPolicyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRoute53RecordFailoverRoutingPolicyOutputReference ¶
func NewRoute53RecordFailoverRoutingPolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) Route53RecordFailoverRoutingPolicyOutputReference
type Route53RecordGeolocationRoutingPolicy ¶
type Route53RecordGeolocationRoutingPolicy struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#continent Route53Record#continent}.
Continent *string `field:"optional" json:"continent" yaml:"continent"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#country Route53Record#country}.
Country *string `field:"optional" json:"country" yaml:"country"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#subdivision Route53Record#subdivision}.
Subdivision *string `field:"optional" json:"subdivision" yaml:"subdivision"`
}
type Route53RecordGeolocationRoutingPolicyList ¶
type Route53RecordGeolocationRoutingPolicyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) Route53RecordGeolocationRoutingPolicyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRoute53RecordGeolocationRoutingPolicyList ¶
func NewRoute53RecordGeolocationRoutingPolicyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) Route53RecordGeolocationRoutingPolicyList
type Route53RecordGeolocationRoutingPolicyOutputReference ¶
type Route53RecordGeolocationRoutingPolicyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Continent() *string
SetContinent(val *string)
ContinentInput() *string
Country() *string
SetCountry(val *string)
CountryInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Subdivision() *string
SetSubdivision(val *string)
SubdivisionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetContinent()
ResetCountry()
ResetSubdivision()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRoute53RecordGeolocationRoutingPolicyOutputReference ¶
func NewRoute53RecordGeolocationRoutingPolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) Route53RecordGeolocationRoutingPolicyOutputReference
type Route53RecordLatencyRoutingPolicy ¶
type Route53RecordLatencyRoutingPolicy struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#region Route53Record#region}.
Region *string `field:"required" json:"region" yaml:"region"`
}
type Route53RecordLatencyRoutingPolicyList ¶
type Route53RecordLatencyRoutingPolicyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) Route53RecordLatencyRoutingPolicyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRoute53RecordLatencyRoutingPolicyList ¶
func NewRoute53RecordLatencyRoutingPolicyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) Route53RecordLatencyRoutingPolicyList
type Route53RecordLatencyRoutingPolicyOutputReference ¶
type Route53RecordLatencyRoutingPolicyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Region() *string
SetRegion(val *string)
RegionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRoute53RecordLatencyRoutingPolicyOutputReference ¶
func NewRoute53RecordLatencyRoutingPolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) Route53RecordLatencyRoutingPolicyOutputReference
type Route53RecordWeightedRoutingPolicy ¶
type Route53RecordWeightedRoutingPolicy struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_record#weight Route53Record#weight}.
Weight *float64 `field:"required" json:"weight" yaml:"weight"`
}
type Route53RecordWeightedRoutingPolicyList ¶
type Route53RecordWeightedRoutingPolicyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) Route53RecordWeightedRoutingPolicyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRoute53RecordWeightedRoutingPolicyList ¶
func NewRoute53RecordWeightedRoutingPolicyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) Route53RecordWeightedRoutingPolicyList
type Route53RecordWeightedRoutingPolicyOutputReference ¶
type Route53RecordWeightedRoutingPolicyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Weight() *float64
SetWeight(val *float64)
WeightInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRoute53RecordWeightedRoutingPolicyOutputReference ¶
func NewRoute53RecordWeightedRoutingPolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) Route53RecordWeightedRoutingPolicyOutputReference
Source Files
¶
- route53record.go
- route53record_Route53Record.go
- route53record_Route53RecordAlias.go
- route53record_Route53RecordAliasList.go
- route53record_Route53RecordAliasList__runtime_type_checks.go
- route53record_Route53RecordAliasOutputReference.go
- route53record_Route53RecordAliasOutputReference__runtime_type_checks.go
- route53record_Route53RecordConfig.go
- route53record_Route53RecordFailoverRoutingPolicy.go
- route53record_Route53RecordFailoverRoutingPolicyList.go
- route53record_Route53RecordFailoverRoutingPolicyList__runtime_type_checks.go
- route53record_Route53RecordFailoverRoutingPolicyOutputReference.go
- route53record_Route53RecordFailoverRoutingPolicyOutputReference__runtime_type_checks.go
- route53record_Route53RecordGeolocationRoutingPolicy.go
- route53record_Route53RecordGeolocationRoutingPolicyList.go
- route53record_Route53RecordGeolocationRoutingPolicyList__runtime_type_checks.go
- route53record_Route53RecordGeolocationRoutingPolicyOutputReference.go
- route53record_Route53RecordGeolocationRoutingPolicyOutputReference__runtime_type_checks.go
- route53record_Route53RecordLatencyRoutingPolicy.go
- route53record_Route53RecordLatencyRoutingPolicyList.go
- route53record_Route53RecordLatencyRoutingPolicyList__runtime_type_checks.go
- route53record_Route53RecordLatencyRoutingPolicyOutputReference.go
- route53record_Route53RecordLatencyRoutingPolicyOutputReference__runtime_type_checks.go
- route53record_Route53RecordWeightedRoutingPolicy.go
- route53record_Route53RecordWeightedRoutingPolicyList.go
- route53record_Route53RecordWeightedRoutingPolicyList__runtime_type_checks.go
- route53record_Route53RecordWeightedRoutingPolicyOutputReference.go
- route53record_Route53RecordWeightedRoutingPolicyOutputReference__runtime_type_checks.go
- route53record_Route53Record__runtime_type_checks.go