Documentation
¶
Index ¶
- func NewS3BucketAclAccessControlPolicyGrantGranteeOutputReference_Override(s S3BucketAclAccessControlPolicyGrantGranteeOutputReference, ...)
- func NewS3BucketAclAccessControlPolicyGrantList_Override(s S3BucketAclAccessControlPolicyGrantList, ...)
- func NewS3BucketAclAccessControlPolicyGrantOutputReference_Override(s S3BucketAclAccessControlPolicyGrantOutputReference, ...)
- func NewS3BucketAclAccessControlPolicyOutputReference_Override(s S3BucketAclAccessControlPolicyOutputReference, ...)
- func NewS3BucketAclAccessControlPolicyOwnerOutputReference_Override(s S3BucketAclAccessControlPolicyOwnerOutputReference, ...)
- func NewS3BucketAcl_Override(s S3BucketAcl, scope constructs.Construct, id *string, ...)
- func S3BucketAcl_IsConstruct(x interface{}) *bool
- func S3BucketAcl_TfResourceType() *string
- type S3BucketAcl
- type S3BucketAclAccessControlPolicy
- type S3BucketAclAccessControlPolicyGrant
- type S3BucketAclAccessControlPolicyGrantGrantee
- type S3BucketAclAccessControlPolicyGrantGranteeOutputReference
- type S3BucketAclAccessControlPolicyGrantList
- type S3BucketAclAccessControlPolicyGrantOutputReference
- type S3BucketAclAccessControlPolicyOutputReference
- type S3BucketAclAccessControlPolicyOwner
- type S3BucketAclAccessControlPolicyOwnerOutputReference
- type S3BucketAclConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewS3BucketAclAccessControlPolicyGrantGranteeOutputReference_Override ¶
func NewS3BucketAclAccessControlPolicyGrantGranteeOutputReference_Override(s S3BucketAclAccessControlPolicyGrantGranteeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketAclAccessControlPolicyGrantList_Override ¶
func NewS3BucketAclAccessControlPolicyGrantList_Override(s S3BucketAclAccessControlPolicyGrantList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewS3BucketAclAccessControlPolicyGrantOutputReference_Override ¶
func NewS3BucketAclAccessControlPolicyGrantOutputReference_Override(s S3BucketAclAccessControlPolicyGrantOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewS3BucketAclAccessControlPolicyOutputReference_Override ¶
func NewS3BucketAclAccessControlPolicyOutputReference_Override(s S3BucketAclAccessControlPolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketAclAccessControlPolicyOwnerOutputReference_Override ¶
func NewS3BucketAclAccessControlPolicyOwnerOutputReference_Override(s S3BucketAclAccessControlPolicyOwnerOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketAcl_Override ¶
func NewS3BucketAcl_Override(s S3BucketAcl, scope constructs.Construct, id *string, config *S3BucketAclConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl aws_s3_bucket_acl} Resource.
func S3BucketAcl_IsConstruct ¶
func S3BucketAcl_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func S3BucketAcl_TfResourceType ¶
func S3BucketAcl_TfResourceType() *string
Types ¶
type S3BucketAcl ¶
type S3BucketAcl interface {
cdktf.TerraformResource
AccessControlPolicy() S3BucketAclAccessControlPolicyOutputReference
AccessControlPolicyInput() *S3BucketAclAccessControlPolicy
Acl() *string
SetAcl(val *string)
AclInput() *string
Bucket() *string
SetBucket(val *string)
BucketInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
ExpectedBucketOwner() *string
SetExpectedBucketOwner(val *string)
ExpectedBucketOwnerInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAccessControlPolicy(value *S3BucketAclAccessControlPolicy)
ResetAccessControlPolicy()
ResetAcl()
ResetExpectedBucketOwner()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl aws_s3_bucket_acl}.
func NewS3BucketAcl ¶
func NewS3BucketAcl(scope constructs.Construct, id *string, config *S3BucketAclConfig) S3BucketAcl
Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl aws_s3_bucket_acl} Resource.
type S3BucketAclAccessControlPolicy ¶
type S3BucketAclAccessControlPolicy struct {
// owner block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl#owner S3BucketAcl#owner}
Owner *S3BucketAclAccessControlPolicyOwner `field:"required" json:"owner" yaml:"owner"`
// grant block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl#grant S3BucketAcl#grant}
Grant interface{} `field:"optional" json:"grant" yaml:"grant"`
}
type S3BucketAclAccessControlPolicyGrant ¶
type S3BucketAclAccessControlPolicyGrant struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl#permission S3BucketAcl#permission}.
Permission *string `field:"required" json:"permission" yaml:"permission"`
// grantee block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl#grantee S3BucketAcl#grantee}
Grantee *S3BucketAclAccessControlPolicyGrantGrantee `field:"optional" json:"grantee" yaml:"grantee"`
}
type S3BucketAclAccessControlPolicyGrantGrantee ¶
type S3BucketAclAccessControlPolicyGrantGrantee struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl#type S3BucketAcl#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl#email_address S3BucketAcl#email_address}.
EmailAddress *string `field:"optional" json:"emailAddress" yaml:"emailAddress"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl#id S3BucketAcl#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl#uri S3BucketAcl#uri}.
Uri *string `field:"optional" json:"uri" yaml:"uri"`
}
type S3BucketAclAccessControlPolicyGrantGranteeOutputReference ¶
type S3BucketAclAccessControlPolicyGrantGranteeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DisplayName() *string
EmailAddress() *string
SetEmailAddress(val *string)
EmailAddressInput() *string
// Experimental.
Fqn() *string
Id() *string
SetId(val *string)
IdInput() *string
InternalValue() *S3BucketAclAccessControlPolicyGrantGrantee
SetInternalValue(val *S3BucketAclAccessControlPolicyGrantGrantee)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
Uri() *string
SetUri(val *string)
UriInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEmailAddress()
ResetId()
ResetUri()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketAclAccessControlPolicyGrantGranteeOutputReference ¶
func NewS3BucketAclAccessControlPolicyGrantGranteeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketAclAccessControlPolicyGrantGranteeOutputReference
type S3BucketAclAccessControlPolicyGrantList ¶
type S3BucketAclAccessControlPolicyGrantList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) S3BucketAclAccessControlPolicyGrantOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketAclAccessControlPolicyGrantList ¶
func NewS3BucketAclAccessControlPolicyGrantList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) S3BucketAclAccessControlPolicyGrantList
type S3BucketAclAccessControlPolicyGrantOutputReference ¶
type S3BucketAclAccessControlPolicyGrantOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Grantee() S3BucketAclAccessControlPolicyGrantGranteeOutputReference
GranteeInput() *S3BucketAclAccessControlPolicyGrantGrantee
InternalValue() interface{}
SetInternalValue(val interface{})
Permission() *string
SetPermission(val *string)
PermissionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutGrantee(value *S3BucketAclAccessControlPolicyGrantGrantee)
ResetGrantee()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketAclAccessControlPolicyGrantOutputReference ¶
func NewS3BucketAclAccessControlPolicyGrantOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) S3BucketAclAccessControlPolicyGrantOutputReference
type S3BucketAclAccessControlPolicyOutputReference ¶
type S3BucketAclAccessControlPolicyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Grant() S3BucketAclAccessControlPolicyGrantList
GrantInput() interface{}
InternalValue() *S3BucketAclAccessControlPolicy
SetInternalValue(val *S3BucketAclAccessControlPolicy)
Owner() S3BucketAclAccessControlPolicyOwnerOutputReference
OwnerInput() *S3BucketAclAccessControlPolicyOwner
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutGrant(value interface{})
PutOwner(value *S3BucketAclAccessControlPolicyOwner)
ResetGrant()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketAclAccessControlPolicyOutputReference ¶
func NewS3BucketAclAccessControlPolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketAclAccessControlPolicyOutputReference
type S3BucketAclAccessControlPolicyOwner ¶
type S3BucketAclAccessControlPolicyOwner struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl#id S3BucketAcl#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"required" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl#display_name S3BucketAcl#display_name}.
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
}
type S3BucketAclAccessControlPolicyOwnerOutputReference ¶
type S3BucketAclAccessControlPolicyOwnerOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
// Experimental.
Fqn() *string
Id() *string
SetId(val *string)
IdInput() *string
InternalValue() *S3BucketAclAccessControlPolicyOwner
SetInternalValue(val *S3BucketAclAccessControlPolicyOwner)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDisplayName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketAclAccessControlPolicyOwnerOutputReference ¶
func NewS3BucketAclAccessControlPolicyOwnerOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketAclAccessControlPolicyOwnerOutputReference
type S3BucketAclConfig ¶
type S3BucketAclConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl#bucket S3BucketAcl#bucket}.
Bucket *string `field:"required" json:"bucket" yaml:"bucket"`
// access_control_policy block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl#access_control_policy S3BucketAcl#access_control_policy}
AccessControlPolicy *S3BucketAclAccessControlPolicy `field:"optional" json:"accessControlPolicy" yaml:"accessControlPolicy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl#acl S3BucketAcl#acl}.
Acl *string `field:"optional" json:"acl" yaml:"acl"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl#expected_bucket_owner S3BucketAcl#expected_bucket_owner}.
ExpectedBucketOwner *string `field:"optional" json:"expectedBucketOwner" yaml:"expectedBucketOwner"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_acl#id S3BucketAcl#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
Source Files
¶
- s3bucketacl.go
- s3bucketacl_S3BucketAcl.go
- s3bucketacl_S3BucketAclAccessControlPolicy.go
- s3bucketacl_S3BucketAclAccessControlPolicyGrant.go
- s3bucketacl_S3BucketAclAccessControlPolicyGrantGrantee.go
- s3bucketacl_S3BucketAclAccessControlPolicyGrantGranteeOutputReference.go
- s3bucketacl_S3BucketAclAccessControlPolicyGrantGranteeOutputReference__runtime_type_checks.go
- s3bucketacl_S3BucketAclAccessControlPolicyGrantList.go
- s3bucketacl_S3BucketAclAccessControlPolicyGrantList__runtime_type_checks.go
- s3bucketacl_S3BucketAclAccessControlPolicyGrantOutputReference.go
- s3bucketacl_S3BucketAclAccessControlPolicyGrantOutputReference__runtime_type_checks.go
- s3bucketacl_S3BucketAclAccessControlPolicyOutputReference.go
- s3bucketacl_S3BucketAclAccessControlPolicyOutputReference__runtime_type_checks.go
- s3bucketacl_S3BucketAclAccessControlPolicyOwner.go
- s3bucketacl_S3BucketAclAccessControlPolicyOwnerOutputReference.go
- s3bucketacl_S3BucketAclAccessControlPolicyOwnerOutputReference__runtime_type_checks.go
- s3bucketacl_S3BucketAclConfig.go
- s3bucketacl_S3BucketAcl__runtime_type_checks.go