Documentation
¶
Index ¶
- func NewSagemakerModelContainerImageConfigOutputReference_Override(s SagemakerModelContainerImageConfigOutputReference, ...)
- func NewSagemakerModelContainerImageConfigRepositoryAuthConfigOutputReference_Override(s SagemakerModelContainerImageConfigRepositoryAuthConfigOutputReference, ...)
- func NewSagemakerModelContainerList_Override(s SagemakerModelContainerList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewSagemakerModelContainerOutputReference_Override(s SagemakerModelContainerOutputReference, ...)
- func NewSagemakerModelInferenceExecutionConfigOutputReference_Override(s SagemakerModelInferenceExecutionConfigOutputReference, ...)
- func NewSagemakerModelPrimaryContainerImageConfigOutputReference_Override(s SagemakerModelPrimaryContainerImageConfigOutputReference, ...)
- func NewSagemakerModelPrimaryContainerImageConfigRepositoryAuthConfigOutputReference_Override(s SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfigOutputReference, ...)
- func NewSagemakerModelPrimaryContainerOutputReference_Override(s SagemakerModelPrimaryContainerOutputReference, ...)
- func NewSagemakerModelVpcConfigOutputReference_Override(s SagemakerModelVpcConfigOutputReference, ...)
- func NewSagemakerModel_Override(s SagemakerModel, scope constructs.Construct, id *string, ...)
- func SagemakerModel_IsConstruct(x interface{}) *bool
- func SagemakerModel_TfResourceType() *string
- type SagemakerModel
- type SagemakerModelConfig
- type SagemakerModelContainer
- type SagemakerModelContainerImageConfig
- type SagemakerModelContainerImageConfigOutputReference
- type SagemakerModelContainerImageConfigRepositoryAuthConfig
- type SagemakerModelContainerImageConfigRepositoryAuthConfigOutputReference
- type SagemakerModelContainerList
- type SagemakerModelContainerOutputReference
- type SagemakerModelInferenceExecutionConfig
- type SagemakerModelInferenceExecutionConfigOutputReference
- type SagemakerModelPrimaryContainer
- type SagemakerModelPrimaryContainerImageConfig
- type SagemakerModelPrimaryContainerImageConfigOutputReference
- type SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig
- type SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfigOutputReference
- type SagemakerModelPrimaryContainerOutputReference
- type SagemakerModelVpcConfig
- type SagemakerModelVpcConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSagemakerModelContainerImageConfigOutputReference_Override ¶
func NewSagemakerModelContainerImageConfigOutputReference_Override(s SagemakerModelContainerImageConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerModelContainerImageConfigRepositoryAuthConfigOutputReference_Override ¶
func NewSagemakerModelContainerImageConfigRepositoryAuthConfigOutputReference_Override(s SagemakerModelContainerImageConfigRepositoryAuthConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerModelContainerList_Override ¶
func NewSagemakerModelContainerList_Override(s SagemakerModelContainerList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSagemakerModelContainerOutputReference_Override ¶
func NewSagemakerModelContainerOutputReference_Override(s SagemakerModelContainerOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSagemakerModelInferenceExecutionConfigOutputReference_Override ¶
func NewSagemakerModelInferenceExecutionConfigOutputReference_Override(s SagemakerModelInferenceExecutionConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerModelPrimaryContainerImageConfigOutputReference_Override ¶
func NewSagemakerModelPrimaryContainerImageConfigOutputReference_Override(s SagemakerModelPrimaryContainerImageConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerModelPrimaryContainerImageConfigRepositoryAuthConfigOutputReference_Override ¶
func NewSagemakerModelPrimaryContainerImageConfigRepositoryAuthConfigOutputReference_Override(s SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerModelPrimaryContainerOutputReference_Override ¶
func NewSagemakerModelPrimaryContainerOutputReference_Override(s SagemakerModelPrimaryContainerOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerModelVpcConfigOutputReference_Override ¶
func NewSagemakerModelVpcConfigOutputReference_Override(s SagemakerModelVpcConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerModel_Override ¶
func NewSagemakerModel_Override(s SagemakerModel, scope constructs.Construct, id *string, config *SagemakerModelConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model aws_sagemaker_model} Resource.
func SagemakerModel_IsConstruct ¶
func SagemakerModel_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SagemakerModel_TfResourceType ¶
func SagemakerModel_TfResourceType() *string
Types ¶
type SagemakerModel ¶
type SagemakerModel interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
Container() SagemakerModelContainerList
ContainerInput() interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EnableNetworkIsolation() interface{}
SetEnableNetworkIsolation(val interface{})
EnableNetworkIsolationInput() interface{}
ExecutionRoleArn() *string
SetExecutionRoleArn(val *string)
ExecutionRoleArnInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InferenceExecutionConfig() SagemakerModelInferenceExecutionConfigOutputReference
InferenceExecutionConfigInput() *SagemakerModelInferenceExecutionConfig
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
PrimaryContainer() SagemakerModelPrimaryContainerOutputReference
PrimaryContainerInput() *SagemakerModelPrimaryContainer
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
VpcConfig() SagemakerModelVpcConfigOutputReference
VpcConfigInput() *SagemakerModelVpcConfig
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutContainer(value interface{})
PutInferenceExecutionConfig(value *SagemakerModelInferenceExecutionConfig)
PutPrimaryContainer(value *SagemakerModelPrimaryContainer)
PutVpcConfig(value *SagemakerModelVpcConfig)
ResetContainer()
ResetEnableNetworkIsolation()
ResetId()
ResetInferenceExecutionConfig()
ResetName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPrimaryContainer()
ResetTags()
ResetTagsAll()
ResetVpcConfig()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model aws_sagemaker_model}.
func NewSagemakerModel ¶
func NewSagemakerModel(scope constructs.Construct, id *string, config *SagemakerModelConfig) SagemakerModel
Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model aws_sagemaker_model} Resource.
type SagemakerModelConfig ¶
type SagemakerModelConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#execution_role_arn SagemakerModel#execution_role_arn}.
ExecutionRoleArn *string `field:"required" json:"executionRoleArn" yaml:"executionRoleArn"`
// container block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#container SagemakerModel#container}
Container interface{} `field:"optional" json:"container" yaml:"container"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#enable_network_isolation SagemakerModel#enable_network_isolation}.
EnableNetworkIsolation interface{} `field:"optional" json:"enableNetworkIsolation" yaml:"enableNetworkIsolation"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#id SagemakerModel#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// inference_execution_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#inference_execution_config SagemakerModel#inference_execution_config}
InferenceExecutionConfig *SagemakerModelInferenceExecutionConfig `field:"optional" json:"inferenceExecutionConfig" yaml:"inferenceExecutionConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#name SagemakerModel#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// primary_container block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#primary_container SagemakerModel#primary_container}
PrimaryContainer *SagemakerModelPrimaryContainer `field:"optional" json:"primaryContainer" yaml:"primaryContainer"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#tags SagemakerModel#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#tags_all SagemakerModel#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// vpc_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#vpc_config SagemakerModel#vpc_config}
VpcConfig *SagemakerModelVpcConfig `field:"optional" json:"vpcConfig" yaml:"vpcConfig"`
}
type SagemakerModelContainer ¶
type SagemakerModelContainer struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#image SagemakerModel#image}.
Image *string `field:"required" json:"image" yaml:"image"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#container_hostname SagemakerModel#container_hostname}.
ContainerHostname *string `field:"optional" json:"containerHostname" yaml:"containerHostname"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#environment SagemakerModel#environment}.
Environment *map[string]*string `field:"optional" json:"environment" yaml:"environment"`
// image_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#image_config SagemakerModel#image_config}
ImageConfig *SagemakerModelContainerImageConfig `field:"optional" json:"imageConfig" yaml:"imageConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#mode SagemakerModel#mode}.
Mode *string `field:"optional" json:"mode" yaml:"mode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#model_data_url SagemakerModel#model_data_url}.
ModelDataUrl *string `field:"optional" json:"modelDataUrl" yaml:"modelDataUrl"`
}
type SagemakerModelContainerImageConfig ¶
type SagemakerModelContainerImageConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#repository_access_mode SagemakerModel#repository_access_mode}.
RepositoryAccessMode *string `field:"required" json:"repositoryAccessMode" yaml:"repositoryAccessMode"`
// repository_auth_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#repository_auth_config SagemakerModel#repository_auth_config}
RepositoryAuthConfig *SagemakerModelContainerImageConfigRepositoryAuthConfig `field:"optional" json:"repositoryAuthConfig" yaml:"repositoryAuthConfig"`
}
type SagemakerModelContainerImageConfigOutputReference ¶
type SagemakerModelContainerImageConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SagemakerModelContainerImageConfig
SetInternalValue(val *SagemakerModelContainerImageConfig)
RepositoryAccessMode() *string
SetRepositoryAccessMode(val *string)
RepositoryAccessModeInput() *string
RepositoryAuthConfig() SagemakerModelContainerImageConfigRepositoryAuthConfigOutputReference
RepositoryAuthConfigInput() *SagemakerModelContainerImageConfigRepositoryAuthConfig
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutRepositoryAuthConfig(value *SagemakerModelContainerImageConfigRepositoryAuthConfig)
ResetRepositoryAuthConfig()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerModelContainerImageConfigOutputReference ¶
func NewSagemakerModelContainerImageConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerModelContainerImageConfigOutputReference
type SagemakerModelContainerImageConfigRepositoryAuthConfig ¶
type SagemakerModelContainerImageConfigRepositoryAuthConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#repository_credentials_provider_arn SagemakerModel#repository_credentials_provider_arn}.
RepositoryCredentialsProviderArn *string `field:"required" json:"repositoryCredentialsProviderArn" yaml:"repositoryCredentialsProviderArn"`
}
type SagemakerModelContainerImageConfigRepositoryAuthConfigOutputReference ¶
type SagemakerModelContainerImageConfigRepositoryAuthConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SagemakerModelContainerImageConfigRepositoryAuthConfig
SetInternalValue(val *SagemakerModelContainerImageConfigRepositoryAuthConfig)
RepositoryCredentialsProviderArn() *string
SetRepositoryCredentialsProviderArn(val *string)
RepositoryCredentialsProviderArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerModelContainerImageConfigRepositoryAuthConfigOutputReference ¶
func NewSagemakerModelContainerImageConfigRepositoryAuthConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerModelContainerImageConfigRepositoryAuthConfigOutputReference
type SagemakerModelContainerList ¶
type SagemakerModelContainerList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SagemakerModelContainerOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerModelContainerList ¶
func NewSagemakerModelContainerList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SagemakerModelContainerList
type SagemakerModelContainerOutputReference ¶
type SagemakerModelContainerOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ContainerHostname() *string
SetContainerHostname(val *string)
ContainerHostnameInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Environment() *map[string]*string
SetEnvironment(val *map[string]*string)
EnvironmentInput() *map[string]*string
// Experimental.
Fqn() *string
Image() *string
SetImage(val *string)
ImageConfig() SagemakerModelContainerImageConfigOutputReference
ImageConfigInput() *SagemakerModelContainerImageConfig
ImageInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Mode() *string
SetMode(val *string)
ModeInput() *string
ModelDataUrl() *string
SetModelDataUrl(val *string)
ModelDataUrlInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutImageConfig(value *SagemakerModelContainerImageConfig)
ResetContainerHostname()
ResetEnvironment()
ResetImageConfig()
ResetMode()
ResetModelDataUrl()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerModelContainerOutputReference ¶
func NewSagemakerModelContainerOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SagemakerModelContainerOutputReference
type SagemakerModelInferenceExecutionConfig ¶
type SagemakerModelInferenceExecutionConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#mode SagemakerModel#mode}.
Mode *string `field:"required" json:"mode" yaml:"mode"`
}
type SagemakerModelInferenceExecutionConfigOutputReference ¶
type SagemakerModelInferenceExecutionConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SagemakerModelInferenceExecutionConfig
SetInternalValue(val *SagemakerModelInferenceExecutionConfig)
Mode() *string
SetMode(val *string)
ModeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerModelInferenceExecutionConfigOutputReference ¶
func NewSagemakerModelInferenceExecutionConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerModelInferenceExecutionConfigOutputReference
type SagemakerModelPrimaryContainer ¶
type SagemakerModelPrimaryContainer struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#image SagemakerModel#image}.
Image *string `field:"required" json:"image" yaml:"image"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#container_hostname SagemakerModel#container_hostname}.
ContainerHostname *string `field:"optional" json:"containerHostname" yaml:"containerHostname"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#environment SagemakerModel#environment}.
Environment *map[string]*string `field:"optional" json:"environment" yaml:"environment"`
// image_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#image_config SagemakerModel#image_config}
ImageConfig *SagemakerModelPrimaryContainerImageConfig `field:"optional" json:"imageConfig" yaml:"imageConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#mode SagemakerModel#mode}.
Mode *string `field:"optional" json:"mode" yaml:"mode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#model_data_url SagemakerModel#model_data_url}.
ModelDataUrl *string `field:"optional" json:"modelDataUrl" yaml:"modelDataUrl"`
}
type SagemakerModelPrimaryContainerImageConfig ¶
type SagemakerModelPrimaryContainerImageConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#repository_access_mode SagemakerModel#repository_access_mode}.
RepositoryAccessMode *string `field:"required" json:"repositoryAccessMode" yaml:"repositoryAccessMode"`
// repository_auth_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#repository_auth_config SagemakerModel#repository_auth_config}
RepositoryAuthConfig *SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig `field:"optional" json:"repositoryAuthConfig" yaml:"repositoryAuthConfig"`
}
type SagemakerModelPrimaryContainerImageConfigOutputReference ¶
type SagemakerModelPrimaryContainerImageConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SagemakerModelPrimaryContainerImageConfig
SetInternalValue(val *SagemakerModelPrimaryContainerImageConfig)
RepositoryAccessMode() *string
SetRepositoryAccessMode(val *string)
RepositoryAccessModeInput() *string
RepositoryAuthConfig() SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfigOutputReference
RepositoryAuthConfigInput() *SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutRepositoryAuthConfig(value *SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig)
ResetRepositoryAuthConfig()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerModelPrimaryContainerImageConfigOutputReference ¶
func NewSagemakerModelPrimaryContainerImageConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerModelPrimaryContainerImageConfigOutputReference
type SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig ¶
type SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#repository_credentials_provider_arn SagemakerModel#repository_credentials_provider_arn}.
RepositoryCredentialsProviderArn *string `field:"required" json:"repositoryCredentialsProviderArn" yaml:"repositoryCredentialsProviderArn"`
}
type SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfigOutputReference ¶
type SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig
SetInternalValue(val *SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig)
RepositoryCredentialsProviderArn() *string
SetRepositoryCredentialsProviderArn(val *string)
RepositoryCredentialsProviderArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerModelPrimaryContainerImageConfigRepositoryAuthConfigOutputReference ¶
func NewSagemakerModelPrimaryContainerImageConfigRepositoryAuthConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfigOutputReference
type SagemakerModelPrimaryContainerOutputReference ¶
type SagemakerModelPrimaryContainerOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ContainerHostname() *string
SetContainerHostname(val *string)
ContainerHostnameInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Environment() *map[string]*string
SetEnvironment(val *map[string]*string)
EnvironmentInput() *map[string]*string
// Experimental.
Fqn() *string
Image() *string
SetImage(val *string)
ImageConfig() SagemakerModelPrimaryContainerImageConfigOutputReference
ImageConfigInput() *SagemakerModelPrimaryContainerImageConfig
ImageInput() *string
InternalValue() *SagemakerModelPrimaryContainer
SetInternalValue(val *SagemakerModelPrimaryContainer)
Mode() *string
SetMode(val *string)
ModeInput() *string
ModelDataUrl() *string
SetModelDataUrl(val *string)
ModelDataUrlInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutImageConfig(value *SagemakerModelPrimaryContainerImageConfig)
ResetContainerHostname()
ResetEnvironment()
ResetImageConfig()
ResetMode()
ResetModelDataUrl()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerModelPrimaryContainerOutputReference ¶
func NewSagemakerModelPrimaryContainerOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerModelPrimaryContainerOutputReference
type SagemakerModelVpcConfig ¶
type SagemakerModelVpcConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#security_group_ids SagemakerModel#security_group_ids}.
SecurityGroupIds *[]*string `field:"required" json:"securityGroupIds" yaml:"securityGroupIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model#subnets SagemakerModel#subnets}.
Subnets *[]*string `field:"required" json:"subnets" yaml:"subnets"`
}
type SagemakerModelVpcConfigOutputReference ¶
type SagemakerModelVpcConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SagemakerModelVpcConfig
SetInternalValue(val *SagemakerModelVpcConfig)
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
Subnets() *[]*string
SetSubnets(val *[]*string)
SubnetsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerModelVpcConfigOutputReference ¶
func NewSagemakerModelVpcConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerModelVpcConfigOutputReference
Source Files
¶
- sagemakermodel.go
- sagemakermodel_SagemakerModel.go
- sagemakermodel_SagemakerModelConfig.go
- sagemakermodel_SagemakerModelContainer.go
- sagemakermodel_SagemakerModelContainerImageConfig.go
- sagemakermodel_SagemakerModelContainerImageConfigOutputReference.go
- sagemakermodel_SagemakerModelContainerImageConfigOutputReference__runtime_type_checks.go
- sagemakermodel_SagemakerModelContainerImageConfigRepositoryAuthConfig.go
- sagemakermodel_SagemakerModelContainerImageConfigRepositoryAuthConfigOutputReference.go
- sagemakermodel_SagemakerModelContainerImageConfigRepositoryAuthConfigOutputReference__runtime_type_checks.go
- sagemakermodel_SagemakerModelContainerList.go
- sagemakermodel_SagemakerModelContainerList__runtime_type_checks.go
- sagemakermodel_SagemakerModelContainerOutputReference.go
- sagemakermodel_SagemakerModelContainerOutputReference__runtime_type_checks.go
- sagemakermodel_SagemakerModelInferenceExecutionConfig.go
- sagemakermodel_SagemakerModelInferenceExecutionConfigOutputReference.go
- sagemakermodel_SagemakerModelInferenceExecutionConfigOutputReference__runtime_type_checks.go
- sagemakermodel_SagemakerModelPrimaryContainer.go
- sagemakermodel_SagemakerModelPrimaryContainerImageConfig.go
- sagemakermodel_SagemakerModelPrimaryContainerImageConfigOutputReference.go
- sagemakermodel_SagemakerModelPrimaryContainerImageConfigOutputReference__runtime_type_checks.go
- sagemakermodel_SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfig.go
- sagemakermodel_SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfigOutputReference.go
- sagemakermodel_SagemakerModelPrimaryContainerImageConfigRepositoryAuthConfigOutputReference__runtime_type_checks.go
- sagemakermodel_SagemakerModelPrimaryContainerOutputReference.go
- sagemakermodel_SagemakerModelPrimaryContainerOutputReference__runtime_type_checks.go
- sagemakermodel_SagemakerModelVpcConfig.go
- sagemakermodel_SagemakerModelVpcConfigOutputReference.go
- sagemakermodel_SagemakerModelVpcConfigOutputReference__runtime_type_checks.go
- sagemakermodel_SagemakerModel__runtime_type_checks.go