Documentation
¶
Index ¶
- func NewServiceDiscoveryServiceDnsConfigDnsRecordsList_Override(s ServiceDiscoveryServiceDnsConfigDnsRecordsList, ...)
- func NewServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference_Override(s ServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference, ...)
- func NewServiceDiscoveryServiceDnsConfigOutputReference_Override(s ServiceDiscoveryServiceDnsConfigOutputReference, ...)
- func NewServiceDiscoveryServiceHealthCheckConfigOutputReference_Override(s ServiceDiscoveryServiceHealthCheckConfigOutputReference, ...)
- func NewServiceDiscoveryServiceHealthCheckCustomConfigOutputReference_Override(s ServiceDiscoveryServiceHealthCheckCustomConfigOutputReference, ...)
- func NewServiceDiscoveryService_Override(s ServiceDiscoveryService, scope constructs.Construct, id *string, ...)
- func ServiceDiscoveryService_IsConstruct(x interface{}) *bool
- func ServiceDiscoveryService_TfResourceType() *string
- type ServiceDiscoveryService
- type ServiceDiscoveryServiceConfig
- type ServiceDiscoveryServiceDnsConfig
- type ServiceDiscoveryServiceDnsConfigDnsRecords
- type ServiceDiscoveryServiceDnsConfigDnsRecordsList
- type ServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference
- type ServiceDiscoveryServiceDnsConfigOutputReference
- type ServiceDiscoveryServiceHealthCheckConfig
- type ServiceDiscoveryServiceHealthCheckConfigOutputReference
- type ServiceDiscoveryServiceHealthCheckCustomConfig
- type ServiceDiscoveryServiceHealthCheckCustomConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewServiceDiscoveryServiceDnsConfigDnsRecordsList_Override ¶
func NewServiceDiscoveryServiceDnsConfigDnsRecordsList_Override(s ServiceDiscoveryServiceDnsConfigDnsRecordsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference_Override ¶
func NewServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference_Override(s ServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewServiceDiscoveryServiceDnsConfigOutputReference_Override ¶
func NewServiceDiscoveryServiceDnsConfigOutputReference_Override(s ServiceDiscoveryServiceDnsConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewServiceDiscoveryServiceHealthCheckConfigOutputReference_Override ¶
func NewServiceDiscoveryServiceHealthCheckConfigOutputReference_Override(s ServiceDiscoveryServiceHealthCheckConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewServiceDiscoveryServiceHealthCheckCustomConfigOutputReference_Override ¶
func NewServiceDiscoveryServiceHealthCheckCustomConfigOutputReference_Override(s ServiceDiscoveryServiceHealthCheckCustomConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewServiceDiscoveryService_Override ¶
func NewServiceDiscoveryService_Override(s ServiceDiscoveryService, scope constructs.Construct, id *string, config *ServiceDiscoveryServiceConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service aws_service_discovery_service} Resource.
func ServiceDiscoveryService_IsConstruct ¶
func ServiceDiscoveryService_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ServiceDiscoveryService_TfResourceType ¶
func ServiceDiscoveryService_TfResourceType() *string
Types ¶
type ServiceDiscoveryService ¶
type ServiceDiscoveryService interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DnsConfig() ServiceDiscoveryServiceDnsConfigOutputReference
DnsConfigInput() *ServiceDiscoveryServiceDnsConfig
ForceDestroy() interface{}
SetForceDestroy(val interface{})
ForceDestroyInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HealthCheckConfig() ServiceDiscoveryServiceHealthCheckConfigOutputReference
HealthCheckConfigInput() *ServiceDiscoveryServiceHealthCheckConfig
HealthCheckCustomConfig() ServiceDiscoveryServiceHealthCheckCustomConfigOutputReference
HealthCheckCustomConfigInput() *ServiceDiscoveryServiceHealthCheckCustomConfig
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
NamespaceId() *string
SetNamespaceId(val *string)
NamespaceIdInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDnsConfig(value *ServiceDiscoveryServiceDnsConfig)
PutHealthCheckConfig(value *ServiceDiscoveryServiceHealthCheckConfig)
PutHealthCheckCustomConfig(value *ServiceDiscoveryServiceHealthCheckCustomConfig)
ResetDescription()
ResetDnsConfig()
ResetForceDestroy()
ResetHealthCheckConfig()
ResetHealthCheckCustomConfig()
ResetId()
ResetNamespaceId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service aws_service_discovery_service}.
func NewServiceDiscoveryService ¶
func NewServiceDiscoveryService(scope constructs.Construct, id *string, config *ServiceDiscoveryServiceConfig) ServiceDiscoveryService
Create a new {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service aws_service_discovery_service} Resource.
type ServiceDiscoveryServiceConfig ¶
type ServiceDiscoveryServiceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#name ServiceDiscoveryService#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#description ServiceDiscoveryService#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// dns_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#dns_config ServiceDiscoveryService#dns_config}
DnsConfig *ServiceDiscoveryServiceDnsConfig `field:"optional" json:"dnsConfig" yaml:"dnsConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#force_destroy ServiceDiscoveryService#force_destroy}.
ForceDestroy interface{} `field:"optional" json:"forceDestroy" yaml:"forceDestroy"`
// health_check_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#health_check_config ServiceDiscoveryService#health_check_config}
HealthCheckConfig *ServiceDiscoveryServiceHealthCheckConfig `field:"optional" json:"healthCheckConfig" yaml:"healthCheckConfig"`
// health_check_custom_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#health_check_custom_config ServiceDiscoveryService#health_check_custom_config}
HealthCheckCustomConfig *ServiceDiscoveryServiceHealthCheckCustomConfig `field:"optional" json:"healthCheckCustomConfig" yaml:"healthCheckCustomConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#id ServiceDiscoveryService#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#namespace_id ServiceDiscoveryService#namespace_id}.
NamespaceId *string `field:"optional" json:"namespaceId" yaml:"namespaceId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#tags ServiceDiscoveryService#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#tags_all ServiceDiscoveryService#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type ServiceDiscoveryServiceDnsConfig ¶
type ServiceDiscoveryServiceDnsConfig struct {
// dns_records block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#dns_records ServiceDiscoveryService#dns_records}
DnsRecords interface{} `field:"required" json:"dnsRecords" yaml:"dnsRecords"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#namespace_id ServiceDiscoveryService#namespace_id}.
NamespaceId *string `field:"required" json:"namespaceId" yaml:"namespaceId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#routing_policy ServiceDiscoveryService#routing_policy}.
RoutingPolicy *string `field:"optional" json:"routingPolicy" yaml:"routingPolicy"`
}
type ServiceDiscoveryServiceDnsConfigDnsRecords ¶
type ServiceDiscoveryServiceDnsConfigDnsRecords struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#ttl ServiceDiscoveryService#ttl}.
Ttl *float64 `field:"required" json:"ttl" yaml:"ttl"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#type ServiceDiscoveryService#type}.
Type *string `field:"required" json:"type" yaml:"type"`
}
type ServiceDiscoveryServiceDnsConfigDnsRecordsList ¶
type ServiceDiscoveryServiceDnsConfigDnsRecordsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewServiceDiscoveryServiceDnsConfigDnsRecordsList ¶
func NewServiceDiscoveryServiceDnsConfigDnsRecordsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ServiceDiscoveryServiceDnsConfigDnsRecordsList
type ServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference ¶
type ServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Ttl() *float64
SetTtl(val *float64)
TtlInput() *float64
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference ¶
func NewServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference
type ServiceDiscoveryServiceDnsConfigOutputReference ¶
type ServiceDiscoveryServiceDnsConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DnsRecords() ServiceDiscoveryServiceDnsConfigDnsRecordsList
DnsRecordsInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *ServiceDiscoveryServiceDnsConfig
SetInternalValue(val *ServiceDiscoveryServiceDnsConfig)
NamespaceId() *string
SetNamespaceId(val *string)
NamespaceIdInput() *string
RoutingPolicy() *string
SetRoutingPolicy(val *string)
RoutingPolicyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutDnsRecords(value interface{})
ResetRoutingPolicy()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewServiceDiscoveryServiceDnsConfigOutputReference ¶
func NewServiceDiscoveryServiceDnsConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ServiceDiscoveryServiceDnsConfigOutputReference
type ServiceDiscoveryServiceHealthCheckConfig ¶
type ServiceDiscoveryServiceHealthCheckConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#failure_threshold ServiceDiscoveryService#failure_threshold}.
FailureThreshold *float64 `field:"optional" json:"failureThreshold" yaml:"failureThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#resource_path ServiceDiscoveryService#resource_path}.
ResourcePath *string `field:"optional" json:"resourcePath" yaml:"resourcePath"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#type ServiceDiscoveryService#type}.
Type *string `field:"optional" json:"type" yaml:"type"`
}
type ServiceDiscoveryServiceHealthCheckConfigOutputReference ¶
type ServiceDiscoveryServiceHealthCheckConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FailureThreshold() *float64
SetFailureThreshold(val *float64)
FailureThresholdInput() *float64
// Experimental.
Fqn() *string
InternalValue() *ServiceDiscoveryServiceHealthCheckConfig
SetInternalValue(val *ServiceDiscoveryServiceHealthCheckConfig)
ResourcePath() *string
SetResourcePath(val *string)
ResourcePathInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetFailureThreshold()
ResetResourcePath()
ResetType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewServiceDiscoveryServiceHealthCheckConfigOutputReference ¶
func NewServiceDiscoveryServiceHealthCheckConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ServiceDiscoveryServiceHealthCheckConfigOutputReference
type ServiceDiscoveryServiceHealthCheckCustomConfig ¶
type ServiceDiscoveryServiceHealthCheckCustomConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service#failure_threshold ServiceDiscoveryService#failure_threshold}.
FailureThreshold *float64 `field:"optional" json:"failureThreshold" yaml:"failureThreshold"`
}
type ServiceDiscoveryServiceHealthCheckCustomConfigOutputReference ¶
type ServiceDiscoveryServiceHealthCheckCustomConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FailureThreshold() *float64
SetFailureThreshold(val *float64)
FailureThresholdInput() *float64
// Experimental.
Fqn() *string
InternalValue() *ServiceDiscoveryServiceHealthCheckCustomConfig
SetInternalValue(val *ServiceDiscoveryServiceHealthCheckCustomConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetFailureThreshold()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewServiceDiscoveryServiceHealthCheckCustomConfigOutputReference ¶
func NewServiceDiscoveryServiceHealthCheckCustomConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ServiceDiscoveryServiceHealthCheckCustomConfigOutputReference
Source Files
¶
- servicediscoveryservice.go
- servicediscoveryservice_ServiceDiscoveryService.go
- servicediscoveryservice_ServiceDiscoveryServiceConfig.go
- servicediscoveryservice_ServiceDiscoveryServiceDnsConfig.go
- servicediscoveryservice_ServiceDiscoveryServiceDnsConfigDnsRecords.go
- servicediscoveryservice_ServiceDiscoveryServiceDnsConfigDnsRecordsList.go
- servicediscoveryservice_ServiceDiscoveryServiceDnsConfigDnsRecordsList__runtime_type_checks.go
- servicediscoveryservice_ServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference.go
- servicediscoveryservice_ServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference__runtime_type_checks.go
- servicediscoveryservice_ServiceDiscoveryServiceDnsConfigOutputReference.go
- servicediscoveryservice_ServiceDiscoveryServiceDnsConfigOutputReference__runtime_type_checks.go
- servicediscoveryservice_ServiceDiscoveryServiceHealthCheckConfig.go
- servicediscoveryservice_ServiceDiscoveryServiceHealthCheckConfigOutputReference.go
- servicediscoveryservice_ServiceDiscoveryServiceHealthCheckConfigOutputReference__runtime_type_checks.go
- servicediscoveryservice_ServiceDiscoveryServiceHealthCheckCustomConfig.go
- servicediscoveryservice_ServiceDiscoveryServiceHealthCheckCustomConfigOutputReference.go
- servicediscoveryservice_ServiceDiscoveryServiceHealthCheckCustomConfigOutputReference__runtime_type_checks.go
- servicediscoveryservice_ServiceDiscoveryService__runtime_type_checks.go