Documentation
¶
Index ¶
- func NewSignerSigningJobDestinationOutputReference_Override(s SignerSigningJobDestinationOutputReference, ...)
- func NewSignerSigningJobDestinationS3OutputReference_Override(s SignerSigningJobDestinationS3OutputReference, ...)
- func NewSignerSigningJobRevocationRecordList_Override(s SignerSigningJobRevocationRecordList, ...)
- func NewSignerSigningJobRevocationRecordOutputReference_Override(s SignerSigningJobRevocationRecordOutputReference, ...)
- func NewSignerSigningJobSignedObjectList_Override(s SignerSigningJobSignedObjectList, ...)
- func NewSignerSigningJobSignedObjectOutputReference_Override(s SignerSigningJobSignedObjectOutputReference, ...)
- func NewSignerSigningJobSignedObjectS3List_Override(s SignerSigningJobSignedObjectS3List, ...)
- func NewSignerSigningJobSignedObjectS3OutputReference_Override(s SignerSigningJobSignedObjectS3OutputReference, ...)
- func NewSignerSigningJobSourceOutputReference_Override(s SignerSigningJobSourceOutputReference, ...)
- func NewSignerSigningJobSourceS3OutputReference_Override(s SignerSigningJobSourceS3OutputReference, ...)
- func NewSignerSigningJob_Override(s SignerSigningJob, scope constructs.Construct, id *string, ...)
- func SignerSigningJob_IsConstruct(x interface{}) *bool
- func SignerSigningJob_TfResourceType() *string
- type SignerSigningJob
- type SignerSigningJobConfig
- type SignerSigningJobDestination
- type SignerSigningJobDestinationOutputReference
- type SignerSigningJobDestinationS3
- type SignerSigningJobDestinationS3OutputReference
- type SignerSigningJobRevocationRecord
- type SignerSigningJobRevocationRecordList
- type SignerSigningJobRevocationRecordOutputReference
- type SignerSigningJobSignedObject
- type SignerSigningJobSignedObjectList
- type SignerSigningJobSignedObjectOutputReference
- type SignerSigningJobSignedObjectS3
- type SignerSigningJobSignedObjectS3List
- type SignerSigningJobSignedObjectS3OutputReference
- type SignerSigningJobSource
- type SignerSigningJobSourceOutputReference
- type SignerSigningJobSourceS3
- type SignerSigningJobSourceS3OutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSignerSigningJobDestinationOutputReference_Override ¶
func NewSignerSigningJobDestinationOutputReference_Override(s SignerSigningJobDestinationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSignerSigningJobDestinationS3OutputReference_Override ¶
func NewSignerSigningJobDestinationS3OutputReference_Override(s SignerSigningJobDestinationS3OutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSignerSigningJobRevocationRecordList_Override ¶
func NewSignerSigningJobRevocationRecordList_Override(s SignerSigningJobRevocationRecordList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSignerSigningJobRevocationRecordOutputReference_Override ¶
func NewSignerSigningJobRevocationRecordOutputReference_Override(s SignerSigningJobRevocationRecordOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSignerSigningJobSignedObjectList_Override ¶
func NewSignerSigningJobSignedObjectList_Override(s SignerSigningJobSignedObjectList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSignerSigningJobSignedObjectOutputReference_Override ¶
func NewSignerSigningJobSignedObjectOutputReference_Override(s SignerSigningJobSignedObjectOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSignerSigningJobSignedObjectS3List_Override ¶
func NewSignerSigningJobSignedObjectS3List_Override(s SignerSigningJobSignedObjectS3List, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSignerSigningJobSignedObjectS3OutputReference_Override ¶
func NewSignerSigningJobSignedObjectS3OutputReference_Override(s SignerSigningJobSignedObjectS3OutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSignerSigningJobSourceOutputReference_Override ¶
func NewSignerSigningJobSourceOutputReference_Override(s SignerSigningJobSourceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSignerSigningJobSourceS3OutputReference_Override ¶
func NewSignerSigningJobSourceS3OutputReference_Override(s SignerSigningJobSourceS3OutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSignerSigningJob_Override ¶
func NewSignerSigningJob_Override(s SignerSigningJob, scope constructs.Construct, id *string, config *SignerSigningJobConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job aws_signer_signing_job} Resource.
func SignerSigningJob_IsConstruct ¶
func SignerSigningJob_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SignerSigningJob_TfResourceType ¶
func SignerSigningJob_TfResourceType() *string
Types ¶
type SignerSigningJob ¶
type SignerSigningJob interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
CompletedAt() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreatedAt() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Destination() SignerSigningJobDestinationOutputReference
DestinationInput() *SignerSigningJobDestination
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IgnoreSigningJobFailure() interface{}
SetIgnoreSigningJobFailure(val interface{})
IgnoreSigningJobFailureInput() interface{}
JobId() *string
JobInvoker() *string
JobOwner() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
PlatformDisplayName() *string
PlatformId() *string
ProfileName() *string
SetProfileName(val *string)
ProfileNameInput() *string
ProfileVersion() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RequestedBy() *string
RevocationRecord() SignerSigningJobRevocationRecordList
SignatureExpiresAt() *string
SignedObject() SignerSigningJobSignedObjectList
Source() SignerSigningJobSourceOutputReference
SourceInput() *SignerSigningJobSource
Status() *string
StatusReason() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDestination(value *SignerSigningJobDestination)
PutSource(value *SignerSigningJobSource)
ResetId()
ResetIgnoreSigningJobFailure()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job aws_signer_signing_job}.
func NewSignerSigningJob ¶
func NewSignerSigningJob(scope constructs.Construct, id *string, config *SignerSigningJobConfig) SignerSigningJob
Create a new {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job aws_signer_signing_job} Resource.
type SignerSigningJobConfig ¶
type SignerSigningJobConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// destination block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#destination SignerSigningJob#destination}
Destination *SignerSigningJobDestination `field:"required" json:"destination" yaml:"destination"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#profile_name SignerSigningJob#profile_name}.
ProfileName *string `field:"required" json:"profileName" yaml:"profileName"`
// source block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#source SignerSigningJob#source}
Source *SignerSigningJobSource `field:"required" json:"source" yaml:"source"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#id SignerSigningJob#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#ignore_signing_job_failure SignerSigningJob#ignore_signing_job_failure}.
IgnoreSigningJobFailure interface{} `field:"optional" json:"ignoreSigningJobFailure" yaml:"ignoreSigningJobFailure"`
}
type SignerSigningJobDestination ¶
type SignerSigningJobDestination struct {
// s3 block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#s3 SignerSigningJob#s3}
S3 *SignerSigningJobDestinationS3 `field:"required" json:"s3" yaml:"s3"`
}
type SignerSigningJobDestinationOutputReference ¶
type SignerSigningJobDestinationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SignerSigningJobDestination
SetInternalValue(val *SignerSigningJobDestination)
S3() SignerSigningJobDestinationS3OutputReference
S3Input() *SignerSigningJobDestinationS3
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutS3(value *SignerSigningJobDestinationS3)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSignerSigningJobDestinationOutputReference ¶
func NewSignerSigningJobDestinationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SignerSigningJobDestinationOutputReference
type SignerSigningJobDestinationS3 ¶
type SignerSigningJobDestinationS3 struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#bucket SignerSigningJob#bucket}.
Bucket *string `field:"required" json:"bucket" yaml:"bucket"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#prefix SignerSigningJob#prefix}.
Prefix *string `field:"optional" json:"prefix" yaml:"prefix"`
}
type SignerSigningJobDestinationS3OutputReference ¶
type SignerSigningJobDestinationS3OutputReference interface {
cdktf.ComplexObject
Bucket() *string
SetBucket(val *string)
BucketInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SignerSigningJobDestinationS3
SetInternalValue(val *SignerSigningJobDestinationS3)
Prefix() *string
SetPrefix(val *string)
PrefixInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetPrefix()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSignerSigningJobDestinationS3OutputReference ¶
func NewSignerSigningJobDestinationS3OutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SignerSigningJobDestinationS3OutputReference
type SignerSigningJobRevocationRecord ¶
type SignerSigningJobRevocationRecord struct {
}
type SignerSigningJobRevocationRecordList ¶
type SignerSigningJobRevocationRecordList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SignerSigningJobRevocationRecordOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSignerSigningJobRevocationRecordList ¶
func NewSignerSigningJobRevocationRecordList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SignerSigningJobRevocationRecordList
type SignerSigningJobRevocationRecordOutputReference ¶
type SignerSigningJobRevocationRecordOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SignerSigningJobRevocationRecord
SetInternalValue(val *SignerSigningJobRevocationRecord)
Reason() *string
RevokedAt() *string
RevokedBy() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSignerSigningJobRevocationRecordOutputReference ¶
func NewSignerSigningJobRevocationRecordOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SignerSigningJobRevocationRecordOutputReference
type SignerSigningJobSignedObject ¶
type SignerSigningJobSignedObject struct {
}
type SignerSigningJobSignedObjectList ¶
type SignerSigningJobSignedObjectList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SignerSigningJobSignedObjectOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSignerSigningJobSignedObjectList ¶
func NewSignerSigningJobSignedObjectList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SignerSigningJobSignedObjectList
type SignerSigningJobSignedObjectOutputReference ¶
type SignerSigningJobSignedObjectOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SignerSigningJobSignedObject
SetInternalValue(val *SignerSigningJobSignedObject)
S3() SignerSigningJobSignedObjectS3List
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSignerSigningJobSignedObjectOutputReference ¶
func NewSignerSigningJobSignedObjectOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SignerSigningJobSignedObjectOutputReference
type SignerSigningJobSignedObjectS3 ¶
type SignerSigningJobSignedObjectS3 struct {
}
type SignerSigningJobSignedObjectS3List ¶
type SignerSigningJobSignedObjectS3List interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SignerSigningJobSignedObjectS3OutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSignerSigningJobSignedObjectS3List ¶
func NewSignerSigningJobSignedObjectS3List(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SignerSigningJobSignedObjectS3List
type SignerSigningJobSignedObjectS3OutputReference ¶
type SignerSigningJobSignedObjectS3OutputReference interface {
cdktf.ComplexObject
Bucket() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SignerSigningJobSignedObjectS3
SetInternalValue(val *SignerSigningJobSignedObjectS3)
Key() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSignerSigningJobSignedObjectS3OutputReference ¶
func NewSignerSigningJobSignedObjectS3OutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SignerSigningJobSignedObjectS3OutputReference
type SignerSigningJobSource ¶
type SignerSigningJobSource struct {
// s3 block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#s3 SignerSigningJob#s3}
S3 *SignerSigningJobSourceS3 `field:"required" json:"s3" yaml:"s3"`
}
type SignerSigningJobSourceOutputReference ¶
type SignerSigningJobSourceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SignerSigningJobSource
SetInternalValue(val *SignerSigningJobSource)
S3() SignerSigningJobSourceS3OutputReference
S3Input() *SignerSigningJobSourceS3
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutS3(value *SignerSigningJobSourceS3)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSignerSigningJobSourceOutputReference ¶
func NewSignerSigningJobSourceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SignerSigningJobSourceOutputReference
type SignerSigningJobSourceS3 ¶
type SignerSigningJobSourceS3 struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#bucket SignerSigningJob#bucket}.
Bucket *string `field:"required" json:"bucket" yaml:"bucket"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#key SignerSigningJob#key}.
Key *string `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#version SignerSigningJob#version}.
Version *string `field:"required" json:"version" yaml:"version"`
}
type SignerSigningJobSourceS3OutputReference ¶
type SignerSigningJobSourceS3OutputReference interface {
cdktf.ComplexObject
Bucket() *string
SetBucket(val *string)
BucketInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SignerSigningJobSourceS3
SetInternalValue(val *SignerSigningJobSourceS3)
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Version() *string
SetVersion(val *string)
VersionInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSignerSigningJobSourceS3OutputReference ¶
func NewSignerSigningJobSourceS3OutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SignerSigningJobSourceS3OutputReference
Source Files
¶
- signersigningjob.go
- signersigningjob_SignerSigningJob.go
- signersigningjob_SignerSigningJobConfig.go
- signersigningjob_SignerSigningJobDestination.go
- signersigningjob_SignerSigningJobDestinationOutputReference.go
- signersigningjob_SignerSigningJobDestinationOutputReference__runtime_type_checks.go
- signersigningjob_SignerSigningJobDestinationS3.go
- signersigningjob_SignerSigningJobDestinationS3OutputReference.go
- signersigningjob_SignerSigningJobDestinationS3OutputReference__runtime_type_checks.go
- signersigningjob_SignerSigningJobRevocationRecord.go
- signersigningjob_SignerSigningJobRevocationRecordList.go
- signersigningjob_SignerSigningJobRevocationRecordList__runtime_type_checks.go
- signersigningjob_SignerSigningJobRevocationRecordOutputReference.go
- signersigningjob_SignerSigningJobRevocationRecordOutputReference__runtime_type_checks.go
- signersigningjob_SignerSigningJobSignedObject.go
- signersigningjob_SignerSigningJobSignedObjectList.go
- signersigningjob_SignerSigningJobSignedObjectList__runtime_type_checks.go
- signersigningjob_SignerSigningJobSignedObjectOutputReference.go
- signersigningjob_SignerSigningJobSignedObjectOutputReference__runtime_type_checks.go
- signersigningjob_SignerSigningJobSignedObjectS3.go
- signersigningjob_SignerSigningJobSignedObjectS3List.go
- signersigningjob_SignerSigningJobSignedObjectS3List__runtime_type_checks.go
- signersigningjob_SignerSigningJobSignedObjectS3OutputReference.go
- signersigningjob_SignerSigningJobSignedObjectS3OutputReference__runtime_type_checks.go
- signersigningjob_SignerSigningJobSource.go
- signersigningjob_SignerSigningJobSourceOutputReference.go
- signersigningjob_SignerSigningJobSourceOutputReference__runtime_type_checks.go
- signersigningjob_SignerSigningJobSourceS3.go
- signersigningjob_SignerSigningJobSourceS3OutputReference.go
- signersigningjob_SignerSigningJobSourceS3OutputReference__runtime_type_checks.go
- signersigningjob_SignerSigningJob__runtime_type_checks.go