Documentation
¶
Index ¶
- func NewWafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatchOutputReference_Override(...)
- func NewWafregionalSqlInjectionMatchSetSqlInjectionMatchTupleList_Override(w WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleList, ...)
- func NewWafregionalSqlInjectionMatchSetSqlInjectionMatchTupleOutputReference_Override(w WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleOutputReference, ...)
- func NewWafregionalSqlInjectionMatchSet_Override(w WafregionalSqlInjectionMatchSet, scope constructs.Construct, id *string, ...)
- func WafregionalSqlInjectionMatchSet_IsConstruct(x interface{}) *bool
- func WafregionalSqlInjectionMatchSet_TfResourceType() *string
- type WafregionalSqlInjectionMatchSet
- type WafregionalSqlInjectionMatchSetConfig
- type WafregionalSqlInjectionMatchSetSqlInjectionMatchTuple
- type WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatch
- type WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatchOutputReference
- type WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleList
- type WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewWafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatchOutputReference_Override ¶
func NewWafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatchOutputReference_Override(w WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatchOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewWafregionalSqlInjectionMatchSetSqlInjectionMatchTupleList_Override ¶
func NewWafregionalSqlInjectionMatchSetSqlInjectionMatchTupleList_Override(w WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewWafregionalSqlInjectionMatchSetSqlInjectionMatchTupleOutputReference_Override ¶
func NewWafregionalSqlInjectionMatchSetSqlInjectionMatchTupleOutputReference_Override(w WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewWafregionalSqlInjectionMatchSet_Override ¶
func NewWafregionalSqlInjectionMatchSet_Override(w WafregionalSqlInjectionMatchSet, scope constructs.Construct, id *string, config *WafregionalSqlInjectionMatchSetConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/wafregional_sql_injection_match_set aws_wafregional_sql_injection_match_set} Resource.
func WafregionalSqlInjectionMatchSet_IsConstruct ¶
func WafregionalSqlInjectionMatchSet_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func WafregionalSqlInjectionMatchSet_TfResourceType ¶
func WafregionalSqlInjectionMatchSet_TfResourceType() *string
Types ¶
type WafregionalSqlInjectionMatchSet ¶
type WafregionalSqlInjectionMatchSet interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SqlInjectionMatchTuple() WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleList
SqlInjectionMatchTupleInput() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutSqlInjectionMatchTuple(value interface{})
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSqlInjectionMatchTuple()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/wafregional_sql_injection_match_set aws_wafregional_sql_injection_match_set}.
func NewWafregionalSqlInjectionMatchSet ¶
func NewWafregionalSqlInjectionMatchSet(scope constructs.Construct, id *string, config *WafregionalSqlInjectionMatchSetConfig) WafregionalSqlInjectionMatchSet
Create a new {@link https://www.terraform.io/docs/providers/aws/r/wafregional_sql_injection_match_set aws_wafregional_sql_injection_match_set} Resource.
type WafregionalSqlInjectionMatchSetConfig ¶
type WafregionalSqlInjectionMatchSetConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafregional_sql_injection_match_set#name WafregionalSqlInjectionMatchSet#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafregional_sql_injection_match_set#id WafregionalSqlInjectionMatchSet#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// sql_injection_match_tuple block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafregional_sql_injection_match_set#sql_injection_match_tuple WafregionalSqlInjectionMatchSet#sql_injection_match_tuple}
SqlInjectionMatchTuple interface{} `field:"optional" json:"sqlInjectionMatchTuple" yaml:"sqlInjectionMatchTuple"`
}
type WafregionalSqlInjectionMatchSetSqlInjectionMatchTuple ¶
type WafregionalSqlInjectionMatchSetSqlInjectionMatchTuple struct {
// field_to_match block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafregional_sql_injection_match_set#field_to_match WafregionalSqlInjectionMatchSet#field_to_match}
FieldToMatch *WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatch `field:"required" json:"fieldToMatch" yaml:"fieldToMatch"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafregional_sql_injection_match_set#text_transformation WafregionalSqlInjectionMatchSet#text_transformation}.
TextTransformation *string `field:"required" json:"textTransformation" yaml:"textTransformation"`
}
type WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatch ¶
type WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatch struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafregional_sql_injection_match_set#type WafregionalSqlInjectionMatchSet#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafregional_sql_injection_match_set#data WafregionalSqlInjectionMatchSet#data}.
Data *string `field:"optional" json:"data" yaml:"data"`
}
type WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatchOutputReference ¶
type WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatchOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Data() *string
SetData(val *string)
DataInput() *string
// Experimental.
Fqn() *string
InternalValue() *WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatch
SetInternalValue(val *WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatch)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetData()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewWafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatchOutputReference ¶
func NewWafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatchOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatchOutputReference
type WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleList ¶
type WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewWafregionalSqlInjectionMatchSetSqlInjectionMatchTupleList ¶
func NewWafregionalSqlInjectionMatchSetSqlInjectionMatchTupleList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleList
type WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleOutputReference ¶
type WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FieldToMatch() WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatchOutputReference
FieldToMatchInput() *WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatch
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TextTransformation() *string
SetTextTransformation(val *string)
TextTransformationInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutFieldToMatch(value *WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatch)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewWafregionalSqlInjectionMatchSetSqlInjectionMatchTupleOutputReference ¶
func NewWafregionalSqlInjectionMatchSetSqlInjectionMatchTupleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleOutputReference
Source Files
¶
- wafregionalsqlinjectionmatchset.go
- wafregionalsqlinjectionmatchset_WafregionalSqlInjectionMatchSet.go
- wafregionalsqlinjectionmatchset_WafregionalSqlInjectionMatchSetConfig.go
- wafregionalsqlinjectionmatchset_WafregionalSqlInjectionMatchSetSqlInjectionMatchTuple.go
- wafregionalsqlinjectionmatchset_WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatch.go
- wafregionalsqlinjectionmatchset_WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatchOutputReference.go
- wafregionalsqlinjectionmatchset_WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatchOutputReference__runtime_type_checks.go
- wafregionalsqlinjectionmatchset_WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleList.go
- wafregionalsqlinjectionmatchset_WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleList__runtime_type_checks.go
- wafregionalsqlinjectionmatchset_WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleOutputReference.go
- wafregionalsqlinjectionmatchset_WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleOutputReference__runtime_type_checks.go
- wafregionalsqlinjectionmatchset_WafregionalSqlInjectionMatchSet__runtime_type_checks.go