Documentation
¶
Index ¶
- func NewWorkspacesDirectorySelfServicePermissionsOutputReference_Override(w WorkspacesDirectorySelfServicePermissionsOutputReference, ...)
- func NewWorkspacesDirectoryWorkspaceAccessPropertiesOutputReference_Override(w WorkspacesDirectoryWorkspaceAccessPropertiesOutputReference, ...)
- func NewWorkspacesDirectoryWorkspaceCreationPropertiesOutputReference_Override(w WorkspacesDirectoryWorkspaceCreationPropertiesOutputReference, ...)
- func NewWorkspacesDirectory_Override(w WorkspacesDirectory, scope constructs.Construct, id *string, ...)
- func WorkspacesDirectory_IsConstruct(x interface{}) *bool
- func WorkspacesDirectory_TfResourceType() *string
- type WorkspacesDirectory
- type WorkspacesDirectoryConfig
- type WorkspacesDirectorySelfServicePermissions
- type WorkspacesDirectorySelfServicePermissionsOutputReference
- type WorkspacesDirectoryWorkspaceAccessProperties
- type WorkspacesDirectoryWorkspaceAccessPropertiesOutputReference
- type WorkspacesDirectoryWorkspaceCreationProperties
- type WorkspacesDirectoryWorkspaceCreationPropertiesOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewWorkspacesDirectorySelfServicePermissionsOutputReference_Override ¶
func NewWorkspacesDirectorySelfServicePermissionsOutputReference_Override(w WorkspacesDirectorySelfServicePermissionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewWorkspacesDirectoryWorkspaceAccessPropertiesOutputReference_Override ¶
func NewWorkspacesDirectoryWorkspaceAccessPropertiesOutputReference_Override(w WorkspacesDirectoryWorkspaceAccessPropertiesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewWorkspacesDirectoryWorkspaceCreationPropertiesOutputReference_Override ¶
func NewWorkspacesDirectoryWorkspaceCreationPropertiesOutputReference_Override(w WorkspacesDirectoryWorkspaceCreationPropertiesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewWorkspacesDirectory_Override ¶
func NewWorkspacesDirectory_Override(w WorkspacesDirectory, scope constructs.Construct, id *string, config *WorkspacesDirectoryConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory aws_workspaces_directory} Resource.
func WorkspacesDirectory_IsConstruct ¶
func WorkspacesDirectory_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func WorkspacesDirectory_TfResourceType ¶
func WorkspacesDirectory_TfResourceType() *string
Types ¶
type WorkspacesDirectory ¶
type WorkspacesDirectory interface {
cdktf.TerraformResource
Alias() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CustomerUserName() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DirectoryId() *string
SetDirectoryId(val *string)
DirectoryIdInput() *string
DirectoryName() *string
DirectoryType() *string
DnsIpAddresses() *[]*string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
IamRoleId() *string
Id() *string
SetId(val *string)
IdInput() *string
IpGroupIds() *[]*string
SetIpGroupIds(val *[]*string)
IpGroupIdsInput() *[]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RegistrationCode() *string
SelfServicePermissions() WorkspacesDirectorySelfServicePermissionsOutputReference
SelfServicePermissionsInput() *WorkspacesDirectorySelfServicePermissions
SubnetIds() *[]*string
SetSubnetIds(val *[]*string)
SubnetIdsInput() *[]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
WorkspaceAccessProperties() WorkspacesDirectoryWorkspaceAccessPropertiesOutputReference
WorkspaceAccessPropertiesInput() *WorkspacesDirectoryWorkspaceAccessProperties
WorkspaceCreationProperties() WorkspacesDirectoryWorkspaceCreationPropertiesOutputReference
WorkspaceCreationPropertiesInput() *WorkspacesDirectoryWorkspaceCreationProperties
WorkspaceSecurityGroupId() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutSelfServicePermissions(value *WorkspacesDirectorySelfServicePermissions)
PutWorkspaceAccessProperties(value *WorkspacesDirectoryWorkspaceAccessProperties)
PutWorkspaceCreationProperties(value *WorkspacesDirectoryWorkspaceCreationProperties)
ResetId()
ResetIpGroupIds()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSelfServicePermissions()
ResetSubnetIds()
ResetTags()
ResetTagsAll()
ResetWorkspaceAccessProperties()
ResetWorkspaceCreationProperties()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory aws_workspaces_directory}.
func NewWorkspacesDirectory ¶
func NewWorkspacesDirectory(scope constructs.Construct, id *string, config *WorkspacesDirectoryConfig) WorkspacesDirectory
Create a new {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory aws_workspaces_directory} Resource.
type WorkspacesDirectoryConfig ¶
type WorkspacesDirectoryConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#directory_id WorkspacesDirectory#directory_id}.
DirectoryId *string `field:"required" json:"directoryId" yaml:"directoryId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#id WorkspacesDirectory#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#ip_group_ids WorkspacesDirectory#ip_group_ids}.
IpGroupIds *[]*string `field:"optional" json:"ipGroupIds" yaml:"ipGroupIds"`
// self_service_permissions block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#self_service_permissions WorkspacesDirectory#self_service_permissions}
SelfServicePermissions *WorkspacesDirectorySelfServicePermissions `field:"optional" json:"selfServicePermissions" yaml:"selfServicePermissions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#subnet_ids WorkspacesDirectory#subnet_ids}.
SubnetIds *[]*string `field:"optional" json:"subnetIds" yaml:"subnetIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#tags WorkspacesDirectory#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#tags_all WorkspacesDirectory#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// workspace_access_properties block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#workspace_access_properties WorkspacesDirectory#workspace_access_properties}
WorkspaceAccessProperties *WorkspacesDirectoryWorkspaceAccessProperties `field:"optional" json:"workspaceAccessProperties" yaml:"workspaceAccessProperties"`
// workspace_creation_properties block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#workspace_creation_properties WorkspacesDirectory#workspace_creation_properties}
WorkspaceCreationProperties *WorkspacesDirectoryWorkspaceCreationProperties `field:"optional" json:"workspaceCreationProperties" yaml:"workspaceCreationProperties"`
}
type WorkspacesDirectorySelfServicePermissions ¶
type WorkspacesDirectorySelfServicePermissions struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#change_compute_type WorkspacesDirectory#change_compute_type}.
ChangeComputeType interface{} `field:"optional" json:"changeComputeType" yaml:"changeComputeType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#increase_volume_size WorkspacesDirectory#increase_volume_size}.
IncreaseVolumeSize interface{} `field:"optional" json:"increaseVolumeSize" yaml:"increaseVolumeSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#rebuild_workspace WorkspacesDirectory#rebuild_workspace}.
RebuildWorkspace interface{} `field:"optional" json:"rebuildWorkspace" yaml:"rebuildWorkspace"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#restart_workspace WorkspacesDirectory#restart_workspace}.
RestartWorkspace interface{} `field:"optional" json:"restartWorkspace" yaml:"restartWorkspace"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#switch_running_mode WorkspacesDirectory#switch_running_mode}.
SwitchRunningMode interface{} `field:"optional" json:"switchRunningMode" yaml:"switchRunningMode"`
}
type WorkspacesDirectorySelfServicePermissionsOutputReference ¶
type WorkspacesDirectorySelfServicePermissionsOutputReference interface {
cdktf.ComplexObject
ChangeComputeType() interface{}
SetChangeComputeType(val interface{})
ChangeComputeTypeInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IncreaseVolumeSize() interface{}
SetIncreaseVolumeSize(val interface{})
IncreaseVolumeSizeInput() interface{}
InternalValue() *WorkspacesDirectorySelfServicePermissions
SetInternalValue(val *WorkspacesDirectorySelfServicePermissions)
RebuildWorkspace() interface{}
SetRebuildWorkspace(val interface{})
RebuildWorkspaceInput() interface{}
RestartWorkspace() interface{}
SetRestartWorkspace(val interface{})
RestartWorkspaceInput() interface{}
SwitchRunningMode() interface{}
SetSwitchRunningMode(val interface{})
SwitchRunningModeInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetChangeComputeType()
ResetIncreaseVolumeSize()
ResetRebuildWorkspace()
ResetRestartWorkspace()
ResetSwitchRunningMode()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewWorkspacesDirectorySelfServicePermissionsOutputReference ¶
func NewWorkspacesDirectorySelfServicePermissionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) WorkspacesDirectorySelfServicePermissionsOutputReference
type WorkspacesDirectoryWorkspaceAccessProperties ¶
type WorkspacesDirectoryWorkspaceAccessProperties struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#device_type_android WorkspacesDirectory#device_type_android}.
DeviceTypeAndroid *string `field:"optional" json:"deviceTypeAndroid" yaml:"deviceTypeAndroid"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#device_type_chromeos WorkspacesDirectory#device_type_chromeos}.
DeviceTypeChromeos *string `field:"optional" json:"deviceTypeChromeos" yaml:"deviceTypeChromeos"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#device_type_ios WorkspacesDirectory#device_type_ios}.
DeviceTypeIos *string `field:"optional" json:"deviceTypeIos" yaml:"deviceTypeIos"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#device_type_linux WorkspacesDirectory#device_type_linux}.
DeviceTypeLinux *string `field:"optional" json:"deviceTypeLinux" yaml:"deviceTypeLinux"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#device_type_osx WorkspacesDirectory#device_type_osx}.
DeviceTypeOsx *string `field:"optional" json:"deviceTypeOsx" yaml:"deviceTypeOsx"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#device_type_web WorkspacesDirectory#device_type_web}.
DeviceTypeWeb *string `field:"optional" json:"deviceTypeWeb" yaml:"deviceTypeWeb"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#device_type_windows WorkspacesDirectory#device_type_windows}.
DeviceTypeWindows *string `field:"optional" json:"deviceTypeWindows" yaml:"deviceTypeWindows"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#device_type_zeroclient WorkspacesDirectory#device_type_zeroclient}.
DeviceTypeZeroclient *string `field:"optional" json:"deviceTypeZeroclient" yaml:"deviceTypeZeroclient"`
}
type WorkspacesDirectoryWorkspaceAccessPropertiesOutputReference ¶
type WorkspacesDirectoryWorkspaceAccessPropertiesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeviceTypeAndroid() *string
SetDeviceTypeAndroid(val *string)
DeviceTypeAndroidInput() *string
DeviceTypeChromeos() *string
SetDeviceTypeChromeos(val *string)
DeviceTypeChromeosInput() *string
DeviceTypeIos() *string
SetDeviceTypeIos(val *string)
DeviceTypeIosInput() *string
DeviceTypeLinux() *string
SetDeviceTypeLinux(val *string)
DeviceTypeLinuxInput() *string
DeviceTypeOsx() *string
SetDeviceTypeOsx(val *string)
DeviceTypeOsxInput() *string
DeviceTypeWeb() *string
SetDeviceTypeWeb(val *string)
DeviceTypeWebInput() *string
DeviceTypeWindows() *string
SetDeviceTypeWindows(val *string)
DeviceTypeWindowsInput() *string
DeviceTypeZeroclient() *string
SetDeviceTypeZeroclient(val *string)
DeviceTypeZeroclientInput() *string
// Experimental.
Fqn() *string
InternalValue() *WorkspacesDirectoryWorkspaceAccessProperties
SetInternalValue(val *WorkspacesDirectoryWorkspaceAccessProperties)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDeviceTypeAndroid()
ResetDeviceTypeChromeos()
ResetDeviceTypeIos()
ResetDeviceTypeLinux()
ResetDeviceTypeOsx()
ResetDeviceTypeWeb()
ResetDeviceTypeWindows()
ResetDeviceTypeZeroclient()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewWorkspacesDirectoryWorkspaceAccessPropertiesOutputReference ¶
func NewWorkspacesDirectoryWorkspaceAccessPropertiesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) WorkspacesDirectoryWorkspaceAccessPropertiesOutputReference
type WorkspacesDirectoryWorkspaceCreationProperties ¶
type WorkspacesDirectoryWorkspaceCreationProperties struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#custom_security_group_id WorkspacesDirectory#custom_security_group_id}.
CustomSecurityGroupId *string `field:"optional" json:"customSecurityGroupId" yaml:"customSecurityGroupId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#default_ou WorkspacesDirectory#default_ou}.
DefaultOu *string `field:"optional" json:"defaultOu" yaml:"defaultOu"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#enable_internet_access WorkspacesDirectory#enable_internet_access}.
EnableInternetAccess interface{} `field:"optional" json:"enableInternetAccess" yaml:"enableInternetAccess"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#enable_maintenance_mode WorkspacesDirectory#enable_maintenance_mode}.
EnableMaintenanceMode interface{} `field:"optional" json:"enableMaintenanceMode" yaml:"enableMaintenanceMode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#user_enabled_as_local_administrator WorkspacesDirectory#user_enabled_as_local_administrator}.
UserEnabledAsLocalAdministrator interface{} `field:"optional" json:"userEnabledAsLocalAdministrator" yaml:"userEnabledAsLocalAdministrator"`
}
type WorkspacesDirectoryWorkspaceCreationPropertiesOutputReference ¶
type WorkspacesDirectoryWorkspaceCreationPropertiesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
CustomSecurityGroupId() *string
SetCustomSecurityGroupId(val *string)
CustomSecurityGroupIdInput() *string
DefaultOu() *string
SetDefaultOu(val *string)
DefaultOuInput() *string
EnableInternetAccess() interface{}
SetEnableInternetAccess(val interface{})
EnableInternetAccessInput() interface{}
EnableMaintenanceMode() interface{}
SetEnableMaintenanceMode(val interface{})
EnableMaintenanceModeInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *WorkspacesDirectoryWorkspaceCreationProperties
SetInternalValue(val *WorkspacesDirectoryWorkspaceCreationProperties)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UserEnabledAsLocalAdministrator() interface{}
SetUserEnabledAsLocalAdministrator(val interface{})
UserEnabledAsLocalAdministratorInput() interface{}
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCustomSecurityGroupId()
ResetDefaultOu()
ResetEnableInternetAccess()
ResetEnableMaintenanceMode()
ResetUserEnabledAsLocalAdministrator()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewWorkspacesDirectoryWorkspaceCreationPropertiesOutputReference ¶
func NewWorkspacesDirectoryWorkspaceCreationPropertiesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) WorkspacesDirectoryWorkspaceCreationPropertiesOutputReference
Source Files
¶
- workspacesdirectory.go
- workspacesdirectory_WorkspacesDirectory.go
- workspacesdirectory_WorkspacesDirectoryConfig.go
- workspacesdirectory_WorkspacesDirectorySelfServicePermissions.go
- workspacesdirectory_WorkspacesDirectorySelfServicePermissionsOutputReference.go
- workspacesdirectory_WorkspacesDirectorySelfServicePermissionsOutputReference__runtime_type_checks.go
- workspacesdirectory_WorkspacesDirectoryWorkspaceAccessProperties.go
- workspacesdirectory_WorkspacesDirectoryWorkspaceAccessPropertiesOutputReference.go
- workspacesdirectory_WorkspacesDirectoryWorkspaceAccessPropertiesOutputReference__runtime_type_checks.go
- workspacesdirectory_WorkspacesDirectoryWorkspaceCreationProperties.go
- workspacesdirectory_WorkspacesDirectoryWorkspaceCreationPropertiesOutputReference.go
- workspacesdirectory_WorkspacesDirectoryWorkspaceCreationPropertiesOutputReference__runtime_type_checks.go
- workspacesdirectory_WorkspacesDirectory__runtime_type_checks.go