Documentation
¶
Index ¶
- func Ami_IsConstruct(x interface{}) *bool
- func Ami_IsTerraformElement(x interface{}) *bool
- func Ami_IsTerraformResource(x interface{}) *bool
- func Ami_TfResourceType() *string
- func NewAmiEbsBlockDeviceList_Override(a AmiEbsBlockDeviceList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewAmiEbsBlockDeviceOutputReference_Override(a AmiEbsBlockDeviceOutputReference, ...)
- func NewAmiEphemeralBlockDeviceList_Override(a AmiEphemeralBlockDeviceList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewAmiEphemeralBlockDeviceOutputReference_Override(a AmiEphemeralBlockDeviceOutputReference, ...)
- func NewAmiTimeoutsOutputReference_Override(a AmiTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, ...)
- func NewAmi_Override(a Ami, scope constructs.Construct, id *string, config *AmiConfig)
- type Ami
- type AmiConfig
- type AmiEbsBlockDevice
- type AmiEbsBlockDeviceList
- type AmiEbsBlockDeviceOutputReference
- type AmiEphemeralBlockDevice
- type AmiEphemeralBlockDeviceList
- type AmiEphemeralBlockDeviceOutputReference
- type AmiTimeouts
- type AmiTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Ami_IsConstruct ¶
func Ami_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func Ami_TfResourceType ¶
func Ami_TfResourceType() *string
func NewAmiEbsBlockDeviceList_Override ¶
func NewAmiEbsBlockDeviceList_Override(a AmiEbsBlockDeviceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAmiEbsBlockDeviceOutputReference_Override ¶
func NewAmiEbsBlockDeviceOutputReference_Override(a AmiEbsBlockDeviceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAmiEphemeralBlockDeviceList_Override ¶
func NewAmiEphemeralBlockDeviceList_Override(a AmiEphemeralBlockDeviceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAmiEphemeralBlockDeviceOutputReference_Override ¶
func NewAmiEphemeralBlockDeviceOutputReference_Override(a AmiEphemeralBlockDeviceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAmiTimeoutsOutputReference_Override ¶
func NewAmiTimeoutsOutputReference_Override(a AmiTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAmi_Override ¶
func NewAmi_Override(a Ami, scope constructs.Construct, id *string, config *AmiConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ami aws_ami} Resource.
Types ¶
type Ami ¶
type Ami interface {
cdktf.TerraformResource
Architecture() *string
SetArchitecture(val *string)
ArchitectureInput() *string
Arn() *string
BootMode() *string
SetBootMode(val *string)
BootModeInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeprecationTime() *string
SetDeprecationTime(val *string)
DeprecationTimeInput() *string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
EbsBlockDevice() AmiEbsBlockDeviceList
EbsBlockDeviceInput() interface{}
EnaSupport() interface{}
SetEnaSupport(val interface{})
EnaSupportInput() interface{}
EphemeralBlockDevice() AmiEphemeralBlockDeviceList
EphemeralBlockDeviceInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Hypervisor() *string
Id() *string
SetId(val *string)
IdInput() *string
ImageLocation() *string
SetImageLocation(val *string)
ImageLocationInput() *string
ImageOwnerAlias() *string
ImageType() *string
ImdsSupport() *string
SetImdsSupport(val *string)
ImdsSupportInput() *string
KernelId() *string
SetKernelId(val *string)
KernelIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
ManageEbsSnapshots() cdktf.IResolvable
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
OwnerId() *string
Platform() *string
PlatformDetails() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
Public() cdktf.IResolvable
RamdiskId() *string
SetRamdiskId(val *string)
RamdiskIdInput() *string
// Experimental.
RawOverrides() interface{}
RootDeviceName() *string
SetRootDeviceName(val *string)
RootDeviceNameInput() *string
RootSnapshotId() *string
SriovNetSupport() *string
SetSriovNetSupport(val *string)
SriovNetSupportInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() AmiTimeoutsOutputReference
TimeoutsInput() interface{}
TpmSupport() *string
SetTpmSupport(val *string)
TpmSupportInput() *string
UsageOperation() *string
VirtualizationType() *string
SetVirtualizationType(val *string)
VirtualizationTypeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutEbsBlockDevice(value interface{})
PutEphemeralBlockDevice(value interface{})
PutTimeouts(value *AmiTimeouts)
ResetArchitecture()
ResetBootMode()
ResetDeprecationTime()
ResetDescription()
ResetEbsBlockDevice()
ResetEnaSupport()
ResetEphemeralBlockDevice()
ResetId()
ResetImageLocation()
ResetImdsSupport()
ResetKernelId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRamdiskId()
ResetRootDeviceName()
ResetSriovNetSupport()
ResetTags()
ResetTagsAll()
ResetTimeouts()
ResetTpmSupport()
ResetVirtualizationType()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/ami aws_ami}.
func NewAmi ¶
func NewAmi(scope constructs.Construct, id *string, config *AmiConfig) Ami
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ami aws_ami} Resource.
type AmiConfig ¶
type AmiConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#name Ami#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#architecture Ami#architecture}.
Architecture *string `field:"optional" json:"architecture" yaml:"architecture"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#boot_mode Ami#boot_mode}.
BootMode *string `field:"optional" json:"bootMode" yaml:"bootMode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#deprecation_time Ami#deprecation_time}.
DeprecationTime *string `field:"optional" json:"deprecationTime" yaml:"deprecationTime"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#description Ami#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// ebs_block_device block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#ebs_block_device Ami#ebs_block_device}
EbsBlockDevice interface{} `field:"optional" json:"ebsBlockDevice" yaml:"ebsBlockDevice"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#ena_support Ami#ena_support}.
EnaSupport interface{} `field:"optional" json:"enaSupport" yaml:"enaSupport"`
// ephemeral_block_device block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#ephemeral_block_device Ami#ephemeral_block_device}
EphemeralBlockDevice interface{} `field:"optional" json:"ephemeralBlockDevice" yaml:"ephemeralBlockDevice"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#id Ami#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#image_location Ami#image_location}.
ImageLocation *string `field:"optional" json:"imageLocation" yaml:"imageLocation"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#imds_support Ami#imds_support}.
ImdsSupport *string `field:"optional" json:"imdsSupport" yaml:"imdsSupport"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#kernel_id Ami#kernel_id}.
KernelId *string `field:"optional" json:"kernelId" yaml:"kernelId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#ramdisk_id Ami#ramdisk_id}.
RamdiskId *string `field:"optional" json:"ramdiskId" yaml:"ramdiskId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#root_device_name Ami#root_device_name}.
RootDeviceName *string `field:"optional" json:"rootDeviceName" yaml:"rootDeviceName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#sriov_net_support Ami#sriov_net_support}.
SriovNetSupport *string `field:"optional" json:"sriovNetSupport" yaml:"sriovNetSupport"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#tags Ami#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#tags_all Ami#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#timeouts Ami#timeouts}
Timeouts *AmiTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#tpm_support Ami#tpm_support}.
TpmSupport *string `field:"optional" json:"tpmSupport" yaml:"tpmSupport"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#virtualization_type Ami#virtualization_type}.
VirtualizationType *string `field:"optional" json:"virtualizationType" yaml:"virtualizationType"`
}
type AmiEbsBlockDevice ¶
type AmiEbsBlockDevice struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#device_name Ami#device_name}.
DeviceName *string `field:"required" json:"deviceName" yaml:"deviceName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#delete_on_termination Ami#delete_on_termination}.
DeleteOnTermination interface{} `field:"optional" json:"deleteOnTermination" yaml:"deleteOnTermination"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#encrypted Ami#encrypted}.
Encrypted interface{} `field:"optional" json:"encrypted" yaml:"encrypted"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#iops Ami#iops}.
Iops *float64 `field:"optional" json:"iops" yaml:"iops"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#outpost_arn Ami#outpost_arn}.
OutpostArn *string `field:"optional" json:"outpostArn" yaml:"outpostArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#snapshot_id Ami#snapshot_id}.
SnapshotId *string `field:"optional" json:"snapshotId" yaml:"snapshotId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#throughput Ami#throughput}.
Throughput *float64 `field:"optional" json:"throughput" yaml:"throughput"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#volume_size Ami#volume_size}.
VolumeSize *float64 `field:"optional" json:"volumeSize" yaml:"volumeSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#volume_type Ami#volume_type}.
VolumeType *string `field:"optional" json:"volumeType" yaml:"volumeType"`
}
type AmiEbsBlockDeviceList ¶
type AmiEbsBlockDeviceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) AmiEbsBlockDeviceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAmiEbsBlockDeviceList ¶
func NewAmiEbsBlockDeviceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AmiEbsBlockDeviceList
type AmiEbsBlockDeviceOutputReference ¶
type AmiEbsBlockDeviceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeleteOnTermination() interface{}
SetDeleteOnTermination(val interface{})
DeleteOnTerminationInput() interface{}
DeviceName() *string
SetDeviceName(val *string)
DeviceNameInput() *string
Encrypted() interface{}
SetEncrypted(val interface{})
EncryptedInput() interface{}
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Iops() *float64
SetIops(val *float64)
IopsInput() *float64
OutpostArn() *string
SetOutpostArn(val *string)
OutpostArnInput() *string
SnapshotId() *string
SetSnapshotId(val *string)
SnapshotIdInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Throughput() *float64
SetThroughput(val *float64)
ThroughputInput() *float64
VolumeSize() *float64
SetVolumeSize(val *float64)
VolumeSizeInput() *float64
VolumeType() *string
SetVolumeType(val *string)
VolumeTypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDeleteOnTermination()
ResetEncrypted()
ResetIops()
ResetOutpostArn()
ResetSnapshotId()
ResetThroughput()
ResetVolumeSize()
ResetVolumeType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAmiEbsBlockDeviceOutputReference ¶
func NewAmiEbsBlockDeviceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AmiEbsBlockDeviceOutputReference
type AmiEphemeralBlockDevice ¶
type AmiEphemeralBlockDevice struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#device_name Ami#device_name}.
DeviceName *string `field:"required" json:"deviceName" yaml:"deviceName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#virtual_name Ami#virtual_name}.
VirtualName *string `field:"required" json:"virtualName" yaml:"virtualName"`
}
type AmiEphemeralBlockDeviceList ¶
type AmiEphemeralBlockDeviceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) AmiEphemeralBlockDeviceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAmiEphemeralBlockDeviceList ¶
func NewAmiEphemeralBlockDeviceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AmiEphemeralBlockDeviceList
type AmiEphemeralBlockDeviceOutputReference ¶
type AmiEphemeralBlockDeviceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeviceName() *string
SetDeviceName(val *string)
DeviceNameInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VirtualName() *string
SetVirtualName(val *string)
VirtualNameInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAmiEphemeralBlockDeviceOutputReference ¶
func NewAmiEphemeralBlockDeviceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AmiEphemeralBlockDeviceOutputReference
type AmiTimeouts ¶
type AmiTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#create Ami#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#delete Ami#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami#update Ami#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type AmiTimeoutsOutputReference ¶
type AmiTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAmiTimeoutsOutputReference ¶
func NewAmiTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AmiTimeoutsOutputReference
Source Files
¶
- ami.go
- ami_Ami.go
- ami_AmiConfig.go
- ami_AmiEbsBlockDevice.go
- ami_AmiEbsBlockDeviceList.go
- ami_AmiEbsBlockDeviceList__runtime_type_checks.go
- ami_AmiEbsBlockDeviceOutputReference.go
- ami_AmiEbsBlockDeviceOutputReference__runtime_type_checks.go
- ami_AmiEphemeralBlockDevice.go
- ami_AmiEphemeralBlockDeviceList.go
- ami_AmiEphemeralBlockDeviceList__runtime_type_checks.go
- ami_AmiEphemeralBlockDeviceOutputReference.go
- ami_AmiEphemeralBlockDeviceOutputReference__runtime_type_checks.go
- ami_AmiTimeouts.go
- ami_AmiTimeoutsOutputReference.go
- ami_AmiTimeoutsOutputReference__runtime_type_checks.go
- ami_Ami__runtime_type_checks.go