Documentation
¶
Index ¶
- func Apigatewayv2Integration_IsConstruct(x interface{}) *bool
- func Apigatewayv2Integration_IsTerraformElement(x interface{}) *bool
- func Apigatewayv2Integration_IsTerraformResource(x interface{}) *bool
- func Apigatewayv2Integration_TfResourceType() *string
- func NewApigatewayv2IntegrationResponseParametersList_Override(a Apigatewayv2IntegrationResponseParametersList, ...)
- func NewApigatewayv2IntegrationResponseParametersOutputReference_Override(a Apigatewayv2IntegrationResponseParametersOutputReference, ...)
- func NewApigatewayv2IntegrationTlsConfigOutputReference_Override(a Apigatewayv2IntegrationTlsConfigOutputReference, ...)
- func NewApigatewayv2Integration_Override(a Apigatewayv2Integration, scope constructs.Construct, id *string, ...)
- type Apigatewayv2Integration
- type Apigatewayv2IntegrationConfig
- type Apigatewayv2IntegrationResponseParameters
- type Apigatewayv2IntegrationResponseParametersList
- type Apigatewayv2IntegrationResponseParametersOutputReference
- type Apigatewayv2IntegrationTlsConfig
- type Apigatewayv2IntegrationTlsConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Apigatewayv2Integration_IsConstruct ¶
func Apigatewayv2Integration_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func Apigatewayv2Integration_IsTerraformElement ¶
func Apigatewayv2Integration_IsTerraformElement(x interface{}) *bool
Experimental.
func Apigatewayv2Integration_IsTerraformResource ¶
func Apigatewayv2Integration_IsTerraformResource(x interface{}) *bool
Experimental.
func Apigatewayv2Integration_TfResourceType ¶
func Apigatewayv2Integration_TfResourceType() *string
func NewApigatewayv2IntegrationResponseParametersList_Override ¶
func NewApigatewayv2IntegrationResponseParametersList_Override(a Apigatewayv2IntegrationResponseParametersList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewApigatewayv2IntegrationResponseParametersOutputReference_Override ¶
func NewApigatewayv2IntegrationResponseParametersOutputReference_Override(a Apigatewayv2IntegrationResponseParametersOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewApigatewayv2IntegrationTlsConfigOutputReference_Override ¶
func NewApigatewayv2IntegrationTlsConfigOutputReference_Override(a Apigatewayv2IntegrationTlsConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewApigatewayv2Integration_Override ¶
func NewApigatewayv2Integration_Override(a Apigatewayv2Integration, scope constructs.Construct, id *string, config *Apigatewayv2IntegrationConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration aws_apigatewayv2_integration} Resource.
Types ¶
type Apigatewayv2Integration ¶
type Apigatewayv2Integration interface {
cdktf.TerraformResource
ApiId() *string
SetApiId(val *string)
ApiIdInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
ConnectionId() *string
SetConnectionId(val *string)
ConnectionIdInput() *string
ConnectionType() *string
SetConnectionType(val *string)
ConnectionTypeInput() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ContentHandlingStrategy() *string
SetContentHandlingStrategy(val *string)
ContentHandlingStrategyInput() *string
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CredentialsArn() *string
SetCredentialsArn(val *string)
CredentialsArnInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IntegrationMethod() *string
SetIntegrationMethod(val *string)
IntegrationMethodInput() *string
IntegrationResponseSelectionExpression() *string
IntegrationSubtype() *string
SetIntegrationSubtype(val *string)
IntegrationSubtypeInput() *string
IntegrationType() *string
SetIntegrationType(val *string)
IntegrationTypeInput() *string
IntegrationUri() *string
SetIntegrationUri(val *string)
IntegrationUriInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
PassthroughBehavior() *string
SetPassthroughBehavior(val *string)
PassthroughBehaviorInput() *string
PayloadFormatVersion() *string
SetPayloadFormatVersion(val *string)
PayloadFormatVersionInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RequestParameters() *map[string]*string
SetRequestParameters(val *map[string]*string)
RequestParametersInput() *map[string]*string
RequestTemplates() *map[string]*string
SetRequestTemplates(val *map[string]*string)
RequestTemplatesInput() *map[string]*string
ResponseParameters() Apigatewayv2IntegrationResponseParametersList
ResponseParametersInput() interface{}
TemplateSelectionExpression() *string
SetTemplateSelectionExpression(val *string)
TemplateSelectionExpressionInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
TimeoutMilliseconds() *float64
SetTimeoutMilliseconds(val *float64)
TimeoutMillisecondsInput() *float64
TlsConfig() Apigatewayv2IntegrationTlsConfigOutputReference
TlsConfigInput() *Apigatewayv2IntegrationTlsConfig
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutResponseParameters(value interface{})
PutTlsConfig(value *Apigatewayv2IntegrationTlsConfig)
ResetConnectionId()
ResetConnectionType()
ResetContentHandlingStrategy()
ResetCredentialsArn()
ResetDescription()
ResetId()
ResetIntegrationMethod()
ResetIntegrationSubtype()
ResetIntegrationUri()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPassthroughBehavior()
ResetPayloadFormatVersion()
ResetRequestParameters()
ResetRequestTemplates()
ResetResponseParameters()
ResetTemplateSelectionExpression()
ResetTimeoutMilliseconds()
ResetTlsConfig()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration aws_apigatewayv2_integration}.
func NewApigatewayv2Integration ¶
func NewApigatewayv2Integration(scope constructs.Construct, id *string, config *Apigatewayv2IntegrationConfig) Apigatewayv2Integration
Create a new {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration aws_apigatewayv2_integration} Resource.
type Apigatewayv2IntegrationConfig ¶
type Apigatewayv2IntegrationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#api_id Apigatewayv2Integration#api_id}.
ApiId *string `field:"required" json:"apiId" yaml:"apiId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#integration_type Apigatewayv2Integration#integration_type}.
IntegrationType *string `field:"required" json:"integrationType" yaml:"integrationType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#connection_id Apigatewayv2Integration#connection_id}.
ConnectionId *string `field:"optional" json:"connectionId" yaml:"connectionId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#connection_type Apigatewayv2Integration#connection_type}.
ConnectionType *string `field:"optional" json:"connectionType" yaml:"connectionType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#content_handling_strategy Apigatewayv2Integration#content_handling_strategy}.
ContentHandlingStrategy *string `field:"optional" json:"contentHandlingStrategy" yaml:"contentHandlingStrategy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#credentials_arn Apigatewayv2Integration#credentials_arn}.
CredentialsArn *string `field:"optional" json:"credentialsArn" yaml:"credentialsArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#description Apigatewayv2Integration#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#id Apigatewayv2Integration#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#integration_method Apigatewayv2Integration#integration_method}.
IntegrationMethod *string `field:"optional" json:"integrationMethod" yaml:"integrationMethod"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#integration_subtype Apigatewayv2Integration#integration_subtype}.
IntegrationSubtype *string `field:"optional" json:"integrationSubtype" yaml:"integrationSubtype"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#integration_uri Apigatewayv2Integration#integration_uri}.
IntegrationUri *string `field:"optional" json:"integrationUri" yaml:"integrationUri"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#passthrough_behavior Apigatewayv2Integration#passthrough_behavior}.
PassthroughBehavior *string `field:"optional" json:"passthroughBehavior" yaml:"passthroughBehavior"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#payload_format_version Apigatewayv2Integration#payload_format_version}.
PayloadFormatVersion *string `field:"optional" json:"payloadFormatVersion" yaml:"payloadFormatVersion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#request_parameters Apigatewayv2Integration#request_parameters}.
RequestParameters *map[string]*string `field:"optional" json:"requestParameters" yaml:"requestParameters"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#request_templates Apigatewayv2Integration#request_templates}.
RequestTemplates *map[string]*string `field:"optional" json:"requestTemplates" yaml:"requestTemplates"`
// response_parameters block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#response_parameters Apigatewayv2Integration#response_parameters}
ResponseParameters interface{} `field:"optional" json:"responseParameters" yaml:"responseParameters"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#template_selection_expression Apigatewayv2Integration#template_selection_expression}.
TemplateSelectionExpression *string `field:"optional" json:"templateSelectionExpression" yaml:"templateSelectionExpression"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#timeout_milliseconds Apigatewayv2Integration#timeout_milliseconds}.
TimeoutMilliseconds *float64 `field:"optional" json:"timeoutMilliseconds" yaml:"timeoutMilliseconds"`
// tls_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#tls_config Apigatewayv2Integration#tls_config}
TlsConfig *Apigatewayv2IntegrationTlsConfig `field:"optional" json:"tlsConfig" yaml:"tlsConfig"`
}
type Apigatewayv2IntegrationResponseParameters ¶
type Apigatewayv2IntegrationResponseParameters struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#mappings Apigatewayv2Integration#mappings}.
Mappings *map[string]*string `field:"required" json:"mappings" yaml:"mappings"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#status_code Apigatewayv2Integration#status_code}.
StatusCode *string `field:"required" json:"statusCode" yaml:"statusCode"`
}
type Apigatewayv2IntegrationResponseParametersList ¶
type Apigatewayv2IntegrationResponseParametersList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) Apigatewayv2IntegrationResponseParametersOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApigatewayv2IntegrationResponseParametersList ¶
func NewApigatewayv2IntegrationResponseParametersList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) Apigatewayv2IntegrationResponseParametersList
type Apigatewayv2IntegrationResponseParametersOutputReference ¶
type Apigatewayv2IntegrationResponseParametersOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Mappings() *map[string]*string
SetMappings(val *map[string]*string)
MappingsInput() *map[string]*string
StatusCode() *string
SetStatusCode(val *string)
StatusCodeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApigatewayv2IntegrationResponseParametersOutputReference ¶
func NewApigatewayv2IntegrationResponseParametersOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) Apigatewayv2IntegrationResponseParametersOutputReference
type Apigatewayv2IntegrationTlsConfig ¶
type Apigatewayv2IntegrationTlsConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_integration#server_name_to_verify Apigatewayv2Integration#server_name_to_verify}.
ServerNameToVerify *string `field:"optional" json:"serverNameToVerify" yaml:"serverNameToVerify"`
}
type Apigatewayv2IntegrationTlsConfigOutputReference ¶
type Apigatewayv2IntegrationTlsConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *Apigatewayv2IntegrationTlsConfig
SetInternalValue(val *Apigatewayv2IntegrationTlsConfig)
ServerNameToVerify() *string
SetServerNameToVerify(val *string)
ServerNameToVerifyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetServerNameToVerify()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApigatewayv2IntegrationTlsConfigOutputReference ¶
func NewApigatewayv2IntegrationTlsConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Apigatewayv2IntegrationTlsConfigOutputReference
Source Files
¶
- apigatewayv2integration.go
- apigatewayv2integration_Apigatewayv2Integration.go
- apigatewayv2integration_Apigatewayv2IntegrationConfig.go
- apigatewayv2integration_Apigatewayv2IntegrationResponseParameters.go
- apigatewayv2integration_Apigatewayv2IntegrationResponseParametersList.go
- apigatewayv2integration_Apigatewayv2IntegrationResponseParametersList__runtime_type_checks.go
- apigatewayv2integration_Apigatewayv2IntegrationResponseParametersOutputReference.go
- apigatewayv2integration_Apigatewayv2IntegrationResponseParametersOutputReference__runtime_type_checks.go
- apigatewayv2integration_Apigatewayv2IntegrationTlsConfig.go
- apigatewayv2integration_Apigatewayv2IntegrationTlsConfigOutputReference.go
- apigatewayv2integration_Apigatewayv2IntegrationTlsConfigOutputReference__runtime_type_checks.go
- apigatewayv2integration_Apigatewayv2Integration__runtime_type_checks.go