Documentation
¶
Index ¶
- func ApprunnerVpcIngressConnection_IsConstruct(x interface{}) *bool
- func ApprunnerVpcIngressConnection_IsTerraformElement(x interface{}) *bool
- func ApprunnerVpcIngressConnection_IsTerraformResource(x interface{}) *bool
- func ApprunnerVpcIngressConnection_TfResourceType() *string
- func NewApprunnerVpcIngressConnectionIngressVpcConfigurationOutputReference_Override(a ApprunnerVpcIngressConnectionIngressVpcConfigurationOutputReference, ...)
- func NewApprunnerVpcIngressConnection_Override(a ApprunnerVpcIngressConnection, scope constructs.Construct, id *string, ...)
- type ApprunnerVpcIngressConnection
- type ApprunnerVpcIngressConnectionConfig
- type ApprunnerVpcIngressConnectionIngressVpcConfiguration
- type ApprunnerVpcIngressConnectionIngressVpcConfigurationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ApprunnerVpcIngressConnection_IsConstruct ¶
func ApprunnerVpcIngressConnection_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ApprunnerVpcIngressConnection_IsTerraformElement ¶
func ApprunnerVpcIngressConnection_IsTerraformElement(x interface{}) *bool
Experimental.
func ApprunnerVpcIngressConnection_IsTerraformResource ¶
func ApprunnerVpcIngressConnection_IsTerraformResource(x interface{}) *bool
Experimental.
func ApprunnerVpcIngressConnection_TfResourceType ¶
func ApprunnerVpcIngressConnection_TfResourceType() *string
func NewApprunnerVpcIngressConnectionIngressVpcConfigurationOutputReference_Override ¶
func NewApprunnerVpcIngressConnectionIngressVpcConfigurationOutputReference_Override(a ApprunnerVpcIngressConnectionIngressVpcConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewApprunnerVpcIngressConnection_Override ¶
func NewApprunnerVpcIngressConnection_Override(a ApprunnerVpcIngressConnection, scope constructs.Construct, id *string, config *ApprunnerVpcIngressConnectionConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/apprunner_vpc_ingress_connection aws_apprunner_vpc_ingress_connection} Resource.
Types ¶
type ApprunnerVpcIngressConnection ¶
type ApprunnerVpcIngressConnection interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DomainName() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IngressVpcConfiguration() ApprunnerVpcIngressConnectionIngressVpcConfigurationOutputReference
IngressVpcConfigurationInput() *ApprunnerVpcIngressConnectionIngressVpcConfiguration
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ServiceArn() *string
SetServiceArn(val *string)
ServiceArnInput() *string
Status() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutIngressVpcConfiguration(value *ApprunnerVpcIngressConnectionIngressVpcConfiguration)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/apprunner_vpc_ingress_connection aws_apprunner_vpc_ingress_connection}.
func NewApprunnerVpcIngressConnection ¶
func NewApprunnerVpcIngressConnection(scope constructs.Construct, id *string, config *ApprunnerVpcIngressConnectionConfig) ApprunnerVpcIngressConnection
Create a new {@link https://www.terraform.io/docs/providers/aws/r/apprunner_vpc_ingress_connection aws_apprunner_vpc_ingress_connection} Resource.
type ApprunnerVpcIngressConnectionConfig ¶
type ApprunnerVpcIngressConnectionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// ingress_vpc_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_vpc_ingress_connection#ingress_vpc_configuration ApprunnerVpcIngressConnection#ingress_vpc_configuration}
IngressVpcConfiguration *ApprunnerVpcIngressConnectionIngressVpcConfiguration `field:"required" json:"ingressVpcConfiguration" yaml:"ingressVpcConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_vpc_ingress_connection#name ApprunnerVpcIngressConnection#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_vpc_ingress_connection#service_arn ApprunnerVpcIngressConnection#service_arn}.
ServiceArn *string `field:"required" json:"serviceArn" yaml:"serviceArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_vpc_ingress_connection#id ApprunnerVpcIngressConnection#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_vpc_ingress_connection#tags ApprunnerVpcIngressConnection#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_vpc_ingress_connection#tags_all ApprunnerVpcIngressConnection#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type ApprunnerVpcIngressConnectionIngressVpcConfiguration ¶
type ApprunnerVpcIngressConnectionIngressVpcConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_vpc_ingress_connection#vpc_endpoint_id ApprunnerVpcIngressConnection#vpc_endpoint_id}.
VpcEndpointId *string `field:"optional" json:"vpcEndpointId" yaml:"vpcEndpointId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_vpc_ingress_connection#vpc_id ApprunnerVpcIngressConnection#vpc_id}.
VpcId *string `field:"optional" json:"vpcId" yaml:"vpcId"`
}
type ApprunnerVpcIngressConnectionIngressVpcConfigurationOutputReference ¶
type ApprunnerVpcIngressConnectionIngressVpcConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ApprunnerVpcIngressConnectionIngressVpcConfiguration
SetInternalValue(val *ApprunnerVpcIngressConnectionIngressVpcConfiguration)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VpcEndpointId() *string
SetVpcEndpointId(val *string)
VpcEndpointIdInput() *string
VpcId() *string
SetVpcId(val *string)
VpcIdInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetVpcEndpointId()
ResetVpcId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApprunnerVpcIngressConnectionIngressVpcConfigurationOutputReference ¶
func NewApprunnerVpcIngressConnectionIngressVpcConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ApprunnerVpcIngressConnectionIngressVpcConfigurationOutputReference
Source Files
¶
- apprunnervpcingressconnection.go
- apprunnervpcingressconnection_ApprunnerVpcIngressConnection.go
- apprunnervpcingressconnection_ApprunnerVpcIngressConnectionConfig.go
- apprunnervpcingressconnection_ApprunnerVpcIngressConnectionIngressVpcConfiguration.go
- apprunnervpcingressconnection_ApprunnerVpcIngressConnectionIngressVpcConfigurationOutputReference.go
- apprunnervpcingressconnection_ApprunnerVpcIngressConnectionIngressVpcConfigurationOutputReference__runtime_type_checks.go
- apprunnervpcingressconnection_ApprunnerVpcIngressConnection__runtime_type_checks.go