Documentation
¶
Index ¶
- func AppstreamFleet_IsConstruct(x interface{}) *bool
- func AppstreamFleet_IsTerraformElement(x interface{}) *bool
- func AppstreamFleet_IsTerraformResource(x interface{}) *bool
- func AppstreamFleet_TfResourceType() *string
- func NewAppstreamFleetComputeCapacityOutputReference_Override(a AppstreamFleetComputeCapacityOutputReference, ...)
- func NewAppstreamFleetDomainJoinInfoOutputReference_Override(a AppstreamFleetDomainJoinInfoOutputReference, ...)
- func NewAppstreamFleetVpcConfigOutputReference_Override(a AppstreamFleetVpcConfigOutputReference, ...)
- func NewAppstreamFleet_Override(a AppstreamFleet, scope constructs.Construct, id *string, ...)
- type AppstreamFleet
- type AppstreamFleetComputeCapacity
- type AppstreamFleetComputeCapacityOutputReference
- type AppstreamFleetConfig
- type AppstreamFleetDomainJoinInfo
- type AppstreamFleetDomainJoinInfoOutputReference
- type AppstreamFleetVpcConfig
- type AppstreamFleetVpcConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AppstreamFleet_IsConstruct ¶
func AppstreamFleet_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AppstreamFleet_IsTerraformElement ¶
func AppstreamFleet_IsTerraformElement(x interface{}) *bool
Experimental.
func AppstreamFleet_IsTerraformResource ¶
func AppstreamFleet_IsTerraformResource(x interface{}) *bool
Experimental.
func AppstreamFleet_TfResourceType ¶
func AppstreamFleet_TfResourceType() *string
func NewAppstreamFleetComputeCapacityOutputReference_Override ¶
func NewAppstreamFleetComputeCapacityOutputReference_Override(a AppstreamFleetComputeCapacityOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppstreamFleetDomainJoinInfoOutputReference_Override ¶
func NewAppstreamFleetDomainJoinInfoOutputReference_Override(a AppstreamFleetDomainJoinInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppstreamFleetVpcConfigOutputReference_Override ¶
func NewAppstreamFleetVpcConfigOutputReference_Override(a AppstreamFleetVpcConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppstreamFleet_Override ¶
func NewAppstreamFleet_Override(a AppstreamFleet, scope constructs.Construct, id *string, config *AppstreamFleetConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet aws_appstream_fleet} Resource.
Types ¶
type AppstreamFleet ¶
type AppstreamFleet interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ComputeCapacity() AppstreamFleetComputeCapacityOutputReference
ComputeCapacityInput() *AppstreamFleetComputeCapacity
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreatedTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DisconnectTimeoutInSeconds() *float64
SetDisconnectTimeoutInSeconds(val *float64)
DisconnectTimeoutInSecondsInput() *float64
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
DomainJoinInfo() AppstreamFleetDomainJoinInfoOutputReference
DomainJoinInfoInput() *AppstreamFleetDomainJoinInfo
EnableDefaultInternetAccess() interface{}
SetEnableDefaultInternetAccess(val interface{})
EnableDefaultInternetAccessInput() interface{}
FleetType() *string
SetFleetType(val *string)
FleetTypeInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
IamRoleArn() *string
SetIamRoleArn(val *string)
IamRoleArnInput() *string
Id() *string
SetId(val *string)
IdInput() *string
IdleDisconnectTimeoutInSeconds() *float64
SetIdleDisconnectTimeoutInSeconds(val *float64)
IdleDisconnectTimeoutInSecondsInput() *float64
ImageArn() *string
SetImageArn(val *string)
ImageArnInput() *string
ImageName() *string
SetImageName(val *string)
ImageNameInput() *string
InstanceType() *string
SetInstanceType(val *string)
InstanceTypeInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaxUserDurationInSeconds() *float64
SetMaxUserDurationInSeconds(val *float64)
MaxUserDurationInSecondsInput() *float64
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
State() *string
StreamView() *string
SetStreamView(val *string)
StreamViewInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
VpcConfig() AppstreamFleetVpcConfigOutputReference
VpcConfigInput() *AppstreamFleetVpcConfig
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutComputeCapacity(value *AppstreamFleetComputeCapacity)
PutDomainJoinInfo(value *AppstreamFleetDomainJoinInfo)
PutVpcConfig(value *AppstreamFleetVpcConfig)
ResetDescription()
ResetDisconnectTimeoutInSeconds()
ResetDisplayName()
ResetDomainJoinInfo()
ResetEnableDefaultInternetAccess()
ResetFleetType()
ResetIamRoleArn()
ResetId()
ResetIdleDisconnectTimeoutInSeconds()
ResetImageArn()
ResetImageName()
ResetMaxUserDurationInSeconds()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetStreamView()
ResetTags()
ResetTagsAll()
ResetVpcConfig()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet aws_appstream_fleet}.
func NewAppstreamFleet ¶
func NewAppstreamFleet(scope constructs.Construct, id *string, config *AppstreamFleetConfig) AppstreamFleet
Create a new {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet aws_appstream_fleet} Resource.
type AppstreamFleetComputeCapacity ¶
type AppstreamFleetComputeCapacity struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#desired_instances AppstreamFleet#desired_instances}.
DesiredInstances *float64 `field:"required" json:"desiredInstances" yaml:"desiredInstances"`
}
type AppstreamFleetComputeCapacityOutputReference ¶
type AppstreamFleetComputeCapacityOutputReference interface {
cdktf.ComplexObject
Available() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DesiredInstances() *float64
SetDesiredInstances(val *float64)
DesiredInstancesInput() *float64
// Experimental.
Fqn() *string
InternalValue() *AppstreamFleetComputeCapacity
SetInternalValue(val *AppstreamFleetComputeCapacity)
InUse() *float64
Running() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppstreamFleetComputeCapacityOutputReference ¶
func NewAppstreamFleetComputeCapacityOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppstreamFleetComputeCapacityOutputReference
type AppstreamFleetConfig ¶
type AppstreamFleetConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// compute_capacity block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#compute_capacity AppstreamFleet#compute_capacity}
ComputeCapacity *AppstreamFleetComputeCapacity `field:"required" json:"computeCapacity" yaml:"computeCapacity"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#instance_type AppstreamFleet#instance_type}.
InstanceType *string `field:"required" json:"instanceType" yaml:"instanceType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#name AppstreamFleet#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#description AppstreamFleet#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#disconnect_timeout_in_seconds AppstreamFleet#disconnect_timeout_in_seconds}.
DisconnectTimeoutInSeconds *float64 `field:"optional" json:"disconnectTimeoutInSeconds" yaml:"disconnectTimeoutInSeconds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#display_name AppstreamFleet#display_name}.
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// domain_join_info block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#domain_join_info AppstreamFleet#domain_join_info}
DomainJoinInfo *AppstreamFleetDomainJoinInfo `field:"optional" json:"domainJoinInfo" yaml:"domainJoinInfo"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#enable_default_internet_access AppstreamFleet#enable_default_internet_access}.
EnableDefaultInternetAccess interface{} `field:"optional" json:"enableDefaultInternetAccess" yaml:"enableDefaultInternetAccess"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#fleet_type AppstreamFleet#fleet_type}.
FleetType *string `field:"optional" json:"fleetType" yaml:"fleetType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#iam_role_arn AppstreamFleet#iam_role_arn}.
IamRoleArn *string `field:"optional" json:"iamRoleArn" yaml:"iamRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#id AppstreamFleet#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#idle_disconnect_timeout_in_seconds AppstreamFleet#idle_disconnect_timeout_in_seconds}.
IdleDisconnectTimeoutInSeconds *float64 `field:"optional" json:"idleDisconnectTimeoutInSeconds" yaml:"idleDisconnectTimeoutInSeconds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#image_arn AppstreamFleet#image_arn}.
ImageArn *string `field:"optional" json:"imageArn" yaml:"imageArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#image_name AppstreamFleet#image_name}.
ImageName *string `field:"optional" json:"imageName" yaml:"imageName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#max_user_duration_in_seconds AppstreamFleet#max_user_duration_in_seconds}.
MaxUserDurationInSeconds *float64 `field:"optional" json:"maxUserDurationInSeconds" yaml:"maxUserDurationInSeconds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#stream_view AppstreamFleet#stream_view}.
StreamView *string `field:"optional" json:"streamView" yaml:"streamView"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#tags AppstreamFleet#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#tags_all AppstreamFleet#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// vpc_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#vpc_config AppstreamFleet#vpc_config}
VpcConfig *AppstreamFleetVpcConfig `field:"optional" json:"vpcConfig" yaml:"vpcConfig"`
}
type AppstreamFleetDomainJoinInfo ¶
type AppstreamFleetDomainJoinInfo struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#directory_name AppstreamFleet#directory_name}.
DirectoryName *string `field:"optional" json:"directoryName" yaml:"directoryName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#organizational_unit_distinguished_name AppstreamFleet#organizational_unit_distinguished_name}.
OrganizationalUnitDistinguishedName *string `field:"optional" json:"organizationalUnitDistinguishedName" yaml:"organizationalUnitDistinguishedName"`
}
type AppstreamFleetDomainJoinInfoOutputReference ¶
type AppstreamFleetDomainJoinInfoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DirectoryName() *string
SetDirectoryName(val *string)
DirectoryNameInput() *string
// Experimental.
Fqn() *string
InternalValue() *AppstreamFleetDomainJoinInfo
SetInternalValue(val *AppstreamFleetDomainJoinInfo)
OrganizationalUnitDistinguishedName() *string
SetOrganizationalUnitDistinguishedName(val *string)
OrganizationalUnitDistinguishedNameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDirectoryName()
ResetOrganizationalUnitDistinguishedName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppstreamFleetDomainJoinInfoOutputReference ¶
func NewAppstreamFleetDomainJoinInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppstreamFleetDomainJoinInfoOutputReference
type AppstreamFleetVpcConfig ¶
type AppstreamFleetVpcConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#security_group_ids AppstreamFleet#security_group_ids}.
SecurityGroupIds *[]*string `field:"optional" json:"securityGroupIds" yaml:"securityGroupIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appstream_fleet#subnet_ids AppstreamFleet#subnet_ids}.
SubnetIds *[]*string `field:"optional" json:"subnetIds" yaml:"subnetIds"`
}
type AppstreamFleetVpcConfigOutputReference ¶
type AppstreamFleetVpcConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AppstreamFleetVpcConfig
SetInternalValue(val *AppstreamFleetVpcConfig)
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
SubnetIds() *[]*string
SetSubnetIds(val *[]*string)
SubnetIdsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetSecurityGroupIds()
ResetSubnetIds()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppstreamFleetVpcConfigOutputReference ¶
func NewAppstreamFleetVpcConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppstreamFleetVpcConfigOutputReference
Source Files
¶
- appstreamfleet.go
- appstreamfleet_AppstreamFleet.go
- appstreamfleet_AppstreamFleetComputeCapacity.go
- appstreamfleet_AppstreamFleetComputeCapacityOutputReference.go
- appstreamfleet_AppstreamFleetComputeCapacityOutputReference__runtime_type_checks.go
- appstreamfleet_AppstreamFleetConfig.go
- appstreamfleet_AppstreamFleetDomainJoinInfo.go
- appstreamfleet_AppstreamFleetDomainJoinInfoOutputReference.go
- appstreamfleet_AppstreamFleetDomainJoinInfoOutputReference__runtime_type_checks.go
- appstreamfleet_AppstreamFleetVpcConfig.go
- appstreamfleet_AppstreamFleetVpcConfigOutputReference.go
- appstreamfleet_AppstreamFleetVpcConfigOutputReference__runtime_type_checks.go
- appstreamfleet_AppstreamFleet__runtime_type_checks.go