Documentation
¶
Index ¶
- func AppsyncResolver_IsConstruct(x interface{}) *bool
- func AppsyncResolver_IsTerraformElement(x interface{}) *bool
- func AppsyncResolver_IsTerraformResource(x interface{}) *bool
- func AppsyncResolver_TfResourceType() *string
- func NewAppsyncResolverCachingConfigOutputReference_Override(a AppsyncResolverCachingConfigOutputReference, ...)
- func NewAppsyncResolverPipelineConfigOutputReference_Override(a AppsyncResolverPipelineConfigOutputReference, ...)
- func NewAppsyncResolverRuntimeOutputReference_Override(a AppsyncResolverRuntimeOutputReference, ...)
- func NewAppsyncResolverSyncConfigLambdaConflictHandlerConfigOutputReference_Override(a AppsyncResolverSyncConfigLambdaConflictHandlerConfigOutputReference, ...)
- func NewAppsyncResolverSyncConfigOutputReference_Override(a AppsyncResolverSyncConfigOutputReference, ...)
- func NewAppsyncResolver_Override(a AppsyncResolver, scope constructs.Construct, id *string, ...)
- type AppsyncResolver
- type AppsyncResolverCachingConfig
- type AppsyncResolverCachingConfigOutputReference
- type AppsyncResolverConfig
- type AppsyncResolverPipelineConfig
- type AppsyncResolverPipelineConfigOutputReference
- type AppsyncResolverRuntime
- type AppsyncResolverRuntimeOutputReference
- type AppsyncResolverSyncConfig
- type AppsyncResolverSyncConfigLambdaConflictHandlerConfig
- type AppsyncResolverSyncConfigLambdaConflictHandlerConfigOutputReference
- type AppsyncResolverSyncConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AppsyncResolver_IsConstruct ¶
func AppsyncResolver_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AppsyncResolver_IsTerraformElement ¶
func AppsyncResolver_IsTerraformElement(x interface{}) *bool
Experimental.
func AppsyncResolver_IsTerraformResource ¶
func AppsyncResolver_IsTerraformResource(x interface{}) *bool
Experimental.
func AppsyncResolver_TfResourceType ¶
func AppsyncResolver_TfResourceType() *string
func NewAppsyncResolverCachingConfigOutputReference_Override ¶
func NewAppsyncResolverCachingConfigOutputReference_Override(a AppsyncResolverCachingConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppsyncResolverPipelineConfigOutputReference_Override ¶
func NewAppsyncResolverPipelineConfigOutputReference_Override(a AppsyncResolverPipelineConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppsyncResolverRuntimeOutputReference_Override ¶ added in v11.0.9
func NewAppsyncResolverRuntimeOutputReference_Override(a AppsyncResolverRuntimeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppsyncResolverSyncConfigLambdaConflictHandlerConfigOutputReference_Override ¶
func NewAppsyncResolverSyncConfigLambdaConflictHandlerConfigOutputReference_Override(a AppsyncResolverSyncConfigLambdaConflictHandlerConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppsyncResolverSyncConfigOutputReference_Override ¶
func NewAppsyncResolverSyncConfigOutputReference_Override(a AppsyncResolverSyncConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppsyncResolver_Override ¶
func NewAppsyncResolver_Override(a AppsyncResolver, scope constructs.Construct, id *string, config *AppsyncResolverConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver aws_appsync_resolver} Resource.
Types ¶
type AppsyncResolver ¶
type AppsyncResolver interface {
cdktf.TerraformResource
ApiId() *string
SetApiId(val *string)
ApiIdInput() *string
Arn() *string
CachingConfig() AppsyncResolverCachingConfigOutputReference
CachingConfigInput() *AppsyncResolverCachingConfig
// Experimental.
CdktfStack() cdktf.TerraformStack
Code() *string
SetCode(val *string)
CodeInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DataSource() *string
SetDataSource(val *string)
DataSourceInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Field() *string
SetField(val *string)
FieldInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Kind() *string
SetKind(val *string)
KindInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaxBatchSize() *float64
SetMaxBatchSize(val *float64)
MaxBatchSizeInput() *float64
// The tree node.
Node() constructs.Node
PipelineConfig() AppsyncResolverPipelineConfigOutputReference
PipelineConfigInput() *AppsyncResolverPipelineConfig
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RequestTemplate() *string
SetRequestTemplate(val *string)
RequestTemplateInput() *string
ResponseTemplate() *string
SetResponseTemplate(val *string)
ResponseTemplateInput() *string
Runtime() AppsyncResolverRuntimeOutputReference
RuntimeInput() *AppsyncResolverRuntime
SyncConfig() AppsyncResolverSyncConfigOutputReference
SyncConfigInput() *AppsyncResolverSyncConfig
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCachingConfig(value *AppsyncResolverCachingConfig)
PutPipelineConfig(value *AppsyncResolverPipelineConfig)
PutRuntime(value *AppsyncResolverRuntime)
PutSyncConfig(value *AppsyncResolverSyncConfig)
ResetCachingConfig()
ResetCode()
ResetDataSource()
ResetId()
ResetKind()
ResetMaxBatchSize()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPipelineConfig()
ResetRequestTemplate()
ResetResponseTemplate()
ResetRuntime()
ResetSyncConfig()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver aws_appsync_resolver}.
func NewAppsyncResolver ¶
func NewAppsyncResolver(scope constructs.Construct, id *string, config *AppsyncResolverConfig) AppsyncResolver
Create a new {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver aws_appsync_resolver} Resource.
type AppsyncResolverCachingConfig ¶
type AppsyncResolverCachingConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#caching_keys AppsyncResolver#caching_keys}.
CachingKeys *[]*string `field:"optional" json:"cachingKeys" yaml:"cachingKeys"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#ttl AppsyncResolver#ttl}.
Ttl *float64 `field:"optional" json:"ttl" yaml:"ttl"`
}
type AppsyncResolverCachingConfigOutputReference ¶
type AppsyncResolverCachingConfigOutputReference interface {
cdktf.ComplexObject
CachingKeys() *[]*string
SetCachingKeys(val *[]*string)
CachingKeysInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AppsyncResolverCachingConfig
SetInternalValue(val *AppsyncResolverCachingConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Ttl() *float64
SetTtl(val *float64)
TtlInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCachingKeys()
ResetTtl()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppsyncResolverCachingConfigOutputReference ¶
func NewAppsyncResolverCachingConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppsyncResolverCachingConfigOutputReference
type AppsyncResolverConfig ¶
type AppsyncResolverConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#api_id AppsyncResolver#api_id}.
ApiId *string `field:"required" json:"apiId" yaml:"apiId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#field AppsyncResolver#field}.
Field *string `field:"required" json:"field" yaml:"field"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#type AppsyncResolver#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// caching_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#caching_config AppsyncResolver#caching_config}
CachingConfig *AppsyncResolverCachingConfig `field:"optional" json:"cachingConfig" yaml:"cachingConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#code AppsyncResolver#code}.
Code *string `field:"optional" json:"code" yaml:"code"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#data_source AppsyncResolver#data_source}.
DataSource *string `field:"optional" json:"dataSource" yaml:"dataSource"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#id AppsyncResolver#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#kind AppsyncResolver#kind}.
Kind *string `field:"optional" json:"kind" yaml:"kind"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#max_batch_size AppsyncResolver#max_batch_size}.
MaxBatchSize *float64 `field:"optional" json:"maxBatchSize" yaml:"maxBatchSize"`
// pipeline_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#pipeline_config AppsyncResolver#pipeline_config}
PipelineConfig *AppsyncResolverPipelineConfig `field:"optional" json:"pipelineConfig" yaml:"pipelineConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#request_template AppsyncResolver#request_template}.
RequestTemplate *string `field:"optional" json:"requestTemplate" yaml:"requestTemplate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#response_template AppsyncResolver#response_template}.
ResponseTemplate *string `field:"optional" json:"responseTemplate" yaml:"responseTemplate"`
// runtime block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#runtime AppsyncResolver#runtime}
Runtime *AppsyncResolverRuntime `field:"optional" json:"runtime" yaml:"runtime"`
// sync_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#sync_config AppsyncResolver#sync_config}
SyncConfig *AppsyncResolverSyncConfig `field:"optional" json:"syncConfig" yaml:"syncConfig"`
}
type AppsyncResolverPipelineConfig ¶
type AppsyncResolverPipelineConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#functions AppsyncResolver#functions}.
Functions *[]*string `field:"optional" json:"functions" yaml:"functions"`
}
type AppsyncResolverPipelineConfigOutputReference ¶
type AppsyncResolverPipelineConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Functions() *[]*string
SetFunctions(val *[]*string)
FunctionsInput() *[]*string
InternalValue() *AppsyncResolverPipelineConfig
SetInternalValue(val *AppsyncResolverPipelineConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetFunctions()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppsyncResolverPipelineConfigOutputReference ¶
func NewAppsyncResolverPipelineConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppsyncResolverPipelineConfigOutputReference
type AppsyncResolverRuntime ¶ added in v11.0.9
type AppsyncResolverRuntime struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#name AppsyncResolver#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#runtime_version AppsyncResolver#runtime_version}.
RuntimeVersion *string `field:"required" json:"runtimeVersion" yaml:"runtimeVersion"`
}
type AppsyncResolverRuntimeOutputReference ¶ added in v11.0.9
type AppsyncResolverRuntimeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AppsyncResolverRuntime
SetInternalValue(val *AppsyncResolverRuntime)
Name() *string
SetName(val *string)
NameInput() *string
RuntimeVersion() *string
SetRuntimeVersion(val *string)
RuntimeVersionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppsyncResolverRuntimeOutputReference ¶ added in v11.0.9
func NewAppsyncResolverRuntimeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppsyncResolverRuntimeOutputReference
type AppsyncResolverSyncConfig ¶
type AppsyncResolverSyncConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#conflict_detection AppsyncResolver#conflict_detection}.
ConflictDetection *string `field:"optional" json:"conflictDetection" yaml:"conflictDetection"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#conflict_handler AppsyncResolver#conflict_handler}.
ConflictHandler *string `field:"optional" json:"conflictHandler" yaml:"conflictHandler"`
// lambda_conflict_handler_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#lambda_conflict_handler_config AppsyncResolver#lambda_conflict_handler_config}
LambdaConflictHandlerConfig *AppsyncResolverSyncConfigLambdaConflictHandlerConfig `field:"optional" json:"lambdaConflictHandlerConfig" yaml:"lambdaConflictHandlerConfig"`
}
type AppsyncResolverSyncConfigLambdaConflictHandlerConfig ¶
type AppsyncResolverSyncConfigLambdaConflictHandlerConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver#lambda_conflict_handler_arn AppsyncResolver#lambda_conflict_handler_arn}.
LambdaConflictHandlerArn *string `field:"optional" json:"lambdaConflictHandlerArn" yaml:"lambdaConflictHandlerArn"`
}
type AppsyncResolverSyncConfigLambdaConflictHandlerConfigOutputReference ¶
type AppsyncResolverSyncConfigLambdaConflictHandlerConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AppsyncResolverSyncConfigLambdaConflictHandlerConfig
SetInternalValue(val *AppsyncResolverSyncConfigLambdaConflictHandlerConfig)
LambdaConflictHandlerArn() *string
SetLambdaConflictHandlerArn(val *string)
LambdaConflictHandlerArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetLambdaConflictHandlerArn()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppsyncResolverSyncConfigLambdaConflictHandlerConfigOutputReference ¶
func NewAppsyncResolverSyncConfigLambdaConflictHandlerConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppsyncResolverSyncConfigLambdaConflictHandlerConfigOutputReference
type AppsyncResolverSyncConfigOutputReference ¶
type AppsyncResolverSyncConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ConflictDetection() *string
SetConflictDetection(val *string)
ConflictDetectionInput() *string
ConflictHandler() *string
SetConflictHandler(val *string)
ConflictHandlerInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AppsyncResolverSyncConfig
SetInternalValue(val *AppsyncResolverSyncConfig)
LambdaConflictHandlerConfig() AppsyncResolverSyncConfigLambdaConflictHandlerConfigOutputReference
LambdaConflictHandlerConfigInput() *AppsyncResolverSyncConfigLambdaConflictHandlerConfig
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutLambdaConflictHandlerConfig(value *AppsyncResolverSyncConfigLambdaConflictHandlerConfig)
ResetConflictDetection()
ResetConflictHandler()
ResetLambdaConflictHandlerConfig()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppsyncResolverSyncConfigOutputReference ¶
func NewAppsyncResolverSyncConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppsyncResolverSyncConfigOutputReference
Source Files
¶
- appsyncresolver.go
- appsyncresolver_AppsyncResolver.go
- appsyncresolver_AppsyncResolverCachingConfig.go
- appsyncresolver_AppsyncResolverCachingConfigOutputReference.go
- appsyncresolver_AppsyncResolverCachingConfigOutputReference__runtime_type_checks.go
- appsyncresolver_AppsyncResolverConfig.go
- appsyncresolver_AppsyncResolverPipelineConfig.go
- appsyncresolver_AppsyncResolverPipelineConfigOutputReference.go
- appsyncresolver_AppsyncResolverPipelineConfigOutputReference__runtime_type_checks.go
- appsyncresolver_AppsyncResolverRuntime.go
- appsyncresolver_AppsyncResolverRuntimeOutputReference.go
- appsyncresolver_AppsyncResolverRuntimeOutputReference__runtime_type_checks.go
- appsyncresolver_AppsyncResolverSyncConfig.go
- appsyncresolver_AppsyncResolverSyncConfigLambdaConflictHandlerConfig.go
- appsyncresolver_AppsyncResolverSyncConfigLambdaConflictHandlerConfigOutputReference.go
- appsyncresolver_AppsyncResolverSyncConfigLambdaConflictHandlerConfigOutputReference__runtime_type_checks.go
- appsyncresolver_AppsyncResolverSyncConfigOutputReference.go
- appsyncresolver_AppsyncResolverSyncConfigOutputReference__runtime_type_checks.go
- appsyncresolver_AppsyncResolver__runtime_type_checks.go