Documentation
¶
Index ¶
- func CloudfrontFieldLevelEncryptionProfile_IsConstruct(x interface{}) *bool
- func CloudfrontFieldLevelEncryptionProfile_IsTerraformElement(x interface{}) *bool
- func CloudfrontFieldLevelEncryptionProfile_IsTerraformResource(x interface{}) *bool
- func CloudfrontFieldLevelEncryptionProfile_TfResourceType() *string
- func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatternsOutputReference_Override(...)
- func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsList_Override(c CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsList, ...)
- func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsOutputReference_Override(c CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsOutputReference, ...)
- func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesOutputReference_Override(c CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesOutputReference, ...)
- func NewCloudfrontFieldLevelEncryptionProfile_Override(c CloudfrontFieldLevelEncryptionProfile, scope constructs.Construct, ...)
- type CloudfrontFieldLevelEncryptionProfile
- type CloudfrontFieldLevelEncryptionProfileConfig
- type CloudfrontFieldLevelEncryptionProfileEncryptionEntities
- type CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItems
- type CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatterns
- type CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatternsOutputReference
- type CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsList
- type CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsOutputReference
- type CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CloudfrontFieldLevelEncryptionProfile_IsConstruct ¶
func CloudfrontFieldLevelEncryptionProfile_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func CloudfrontFieldLevelEncryptionProfile_IsTerraformElement ¶
func CloudfrontFieldLevelEncryptionProfile_IsTerraformElement(x interface{}) *bool
Experimental.
func CloudfrontFieldLevelEncryptionProfile_IsTerraformResource ¶
func CloudfrontFieldLevelEncryptionProfile_IsTerraformResource(x interface{}) *bool
Experimental.
func CloudfrontFieldLevelEncryptionProfile_TfResourceType ¶
func CloudfrontFieldLevelEncryptionProfile_TfResourceType() *string
func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatternsOutputReference_Override ¶
func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatternsOutputReference_Override(c CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatternsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsList_Override ¶
func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsList_Override(c CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsOutputReference_Override ¶
func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsOutputReference_Override(c CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesOutputReference_Override ¶
func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesOutputReference_Override(c CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCloudfrontFieldLevelEncryptionProfile_Override ¶
func NewCloudfrontFieldLevelEncryptionProfile_Override(c CloudfrontFieldLevelEncryptionProfile, scope constructs.Construct, id *string, config *CloudfrontFieldLevelEncryptionProfileConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_field_level_encryption_profile aws_cloudfront_field_level_encryption_profile} Resource.
Types ¶
type CloudfrontFieldLevelEncryptionProfile ¶
type CloudfrontFieldLevelEncryptionProfile interface {
cdktf.TerraformResource
CallerReference() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
Comment() *string
SetComment(val *string)
CommentInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EncryptionEntities() CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesOutputReference
EncryptionEntitiesInput() *CloudfrontFieldLevelEncryptionProfileEncryptionEntities
Etag() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutEncryptionEntities(value *CloudfrontFieldLevelEncryptionProfileEncryptionEntities)
ResetComment()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_field_level_encryption_profile aws_cloudfront_field_level_encryption_profile}.
func NewCloudfrontFieldLevelEncryptionProfile ¶
func NewCloudfrontFieldLevelEncryptionProfile(scope constructs.Construct, id *string, config *CloudfrontFieldLevelEncryptionProfileConfig) CloudfrontFieldLevelEncryptionProfile
Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_field_level_encryption_profile aws_cloudfront_field_level_encryption_profile} Resource.
type CloudfrontFieldLevelEncryptionProfileConfig ¶
type CloudfrontFieldLevelEncryptionProfileConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// encryption_entities block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_field_level_encryption_profile#encryption_entities CloudfrontFieldLevelEncryptionProfile#encryption_entities}
EncryptionEntities *CloudfrontFieldLevelEncryptionProfileEncryptionEntities `field:"required" json:"encryptionEntities" yaml:"encryptionEntities"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_field_level_encryption_profile#name CloudfrontFieldLevelEncryptionProfile#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_field_level_encryption_profile#comment CloudfrontFieldLevelEncryptionProfile#comment}.
Comment *string `field:"optional" json:"comment" yaml:"comment"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_field_level_encryption_profile#id CloudfrontFieldLevelEncryptionProfile#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type CloudfrontFieldLevelEncryptionProfileEncryptionEntities ¶
type CloudfrontFieldLevelEncryptionProfileEncryptionEntities struct {
// items block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_field_level_encryption_profile#items CloudfrontFieldLevelEncryptionProfile#items}
Items interface{} `field:"optional" json:"items" yaml:"items"`
}
type CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItems ¶
type CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItems struct {
// field_patterns block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_field_level_encryption_profile#field_patterns CloudfrontFieldLevelEncryptionProfile#field_patterns}
FieldPatterns *CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatterns `field:"required" json:"fieldPatterns" yaml:"fieldPatterns"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_field_level_encryption_profile#provider_id CloudfrontFieldLevelEncryptionProfile#provider_id}.
ProviderId *string `field:"required" json:"providerId" yaml:"providerId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_field_level_encryption_profile#public_key_id CloudfrontFieldLevelEncryptionProfile#public_key_id}.
PublicKeyId *string `field:"required" json:"publicKeyId" yaml:"publicKeyId"`
}
type CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatterns ¶
type CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatterns struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_field_level_encryption_profile#items CloudfrontFieldLevelEncryptionProfile#items}.
Items *[]*string `field:"optional" json:"items" yaml:"items"`
}
type CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatternsOutputReference ¶
type CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatternsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatterns
SetInternalValue(val *CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatterns)
Items() *[]*string
SetItems(val *[]*string)
ItemsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetItems()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatternsOutputReference ¶
func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatternsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatternsOutputReference
type CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsList ¶
type CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsList ¶
func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsList
type CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsOutputReference ¶
type CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FieldPatterns() CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatternsOutputReference
FieldPatternsInput() *CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatterns
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
ProviderId() *string
SetProviderId(val *string)
ProviderIdInput() *string
PublicKeyId() *string
SetPublicKeyId(val *string)
PublicKeyIdInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutFieldPatterns(value *CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatterns)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsOutputReference ¶
func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsOutputReference
type CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesOutputReference ¶
type CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *CloudfrontFieldLevelEncryptionProfileEncryptionEntities
SetInternalValue(val *CloudfrontFieldLevelEncryptionProfileEncryptionEntities)
Items() CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsList
ItemsInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutItems(value interface{})
ResetItems()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesOutputReference ¶
func NewCloudfrontFieldLevelEncryptionProfileEncryptionEntitiesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesOutputReference
Source Files
¶
- cloudfrontfieldlevelencryptionprofile.go
- cloudfrontfieldlevelencryptionprofile_CloudfrontFieldLevelEncryptionProfile.go
- cloudfrontfieldlevelencryptionprofile_CloudfrontFieldLevelEncryptionProfileConfig.go
- cloudfrontfieldlevelencryptionprofile_CloudfrontFieldLevelEncryptionProfileEncryptionEntities.go
- cloudfrontfieldlevelencryptionprofile_CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItems.go
- cloudfrontfieldlevelencryptionprofile_CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatterns.go
- cloudfrontfieldlevelencryptionprofile_CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatternsOutputReference.go
- cloudfrontfieldlevelencryptionprofile_CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsFieldPatternsOutputReference__runtime_type_checks.go
- cloudfrontfieldlevelencryptionprofile_CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsList.go
- cloudfrontfieldlevelencryptionprofile_CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsList__runtime_type_checks.go
- cloudfrontfieldlevelencryptionprofile_CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsOutputReference.go
- cloudfrontfieldlevelencryptionprofile_CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesItemsOutputReference__runtime_type_checks.go
- cloudfrontfieldlevelencryptionprofile_CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesOutputReference.go
- cloudfrontfieldlevelencryptionprofile_CloudfrontFieldLevelEncryptionProfileEncryptionEntitiesOutputReference__runtime_type_checks.go
- cloudfrontfieldlevelencryptionprofile_CloudfrontFieldLevelEncryptionProfile__runtime_type_checks.go