Documentation
¶
Index ¶
- func ConfigConfigurationAggregator_IsConstruct(x interface{}) *bool
- func ConfigConfigurationAggregator_IsTerraformElement(x interface{}) *bool
- func ConfigConfigurationAggregator_IsTerraformResource(x interface{}) *bool
- func ConfigConfigurationAggregator_TfResourceType() *string
- func NewConfigConfigurationAggregatorAccountAggregationSourceOutputReference_Override(c ConfigConfigurationAggregatorAccountAggregationSourceOutputReference, ...)
- func NewConfigConfigurationAggregatorOrganizationAggregationSourceOutputReference_Override(c ConfigConfigurationAggregatorOrganizationAggregationSourceOutputReference, ...)
- func NewConfigConfigurationAggregator_Override(c ConfigConfigurationAggregator, scope constructs.Construct, id *string, ...)
- type ConfigConfigurationAggregator
- type ConfigConfigurationAggregatorAccountAggregationSource
- type ConfigConfigurationAggregatorAccountAggregationSourceOutputReference
- type ConfigConfigurationAggregatorConfig
- type ConfigConfigurationAggregatorOrganizationAggregationSource
- type ConfigConfigurationAggregatorOrganizationAggregationSourceOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConfigConfigurationAggregator_IsConstruct ¶
func ConfigConfigurationAggregator_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ConfigConfigurationAggregator_IsTerraformElement ¶
func ConfigConfigurationAggregator_IsTerraformElement(x interface{}) *bool
Experimental.
func ConfigConfigurationAggregator_IsTerraformResource ¶
func ConfigConfigurationAggregator_IsTerraformResource(x interface{}) *bool
Experimental.
func ConfigConfigurationAggregator_TfResourceType ¶
func ConfigConfigurationAggregator_TfResourceType() *string
func NewConfigConfigurationAggregatorAccountAggregationSourceOutputReference_Override ¶
func NewConfigConfigurationAggregatorAccountAggregationSourceOutputReference_Override(c ConfigConfigurationAggregatorAccountAggregationSourceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewConfigConfigurationAggregatorOrganizationAggregationSourceOutputReference_Override ¶
func NewConfigConfigurationAggregatorOrganizationAggregationSourceOutputReference_Override(c ConfigConfigurationAggregatorOrganizationAggregationSourceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewConfigConfigurationAggregator_Override ¶
func NewConfigConfigurationAggregator_Override(c ConfigConfigurationAggregator, scope constructs.Construct, id *string, config *ConfigConfigurationAggregatorConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator aws_config_configuration_aggregator} Resource.
Types ¶
type ConfigConfigurationAggregator ¶
type ConfigConfigurationAggregator interface {
cdktf.TerraformResource
AccountAggregationSource() ConfigConfigurationAggregatorAccountAggregationSourceOutputReference
AccountAggregationSourceInput() *ConfigConfigurationAggregatorAccountAggregationSource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
OrganizationAggregationSource() ConfigConfigurationAggregatorOrganizationAggregationSourceOutputReference
OrganizationAggregationSourceInput() *ConfigConfigurationAggregatorOrganizationAggregationSource
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAccountAggregationSource(value *ConfigConfigurationAggregatorAccountAggregationSource)
PutOrganizationAggregationSource(value *ConfigConfigurationAggregatorOrganizationAggregationSource)
ResetAccountAggregationSource()
ResetId()
ResetOrganizationAggregationSource()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator aws_config_configuration_aggregator}.
func NewConfigConfigurationAggregator ¶
func NewConfigConfigurationAggregator(scope constructs.Construct, id *string, config *ConfigConfigurationAggregatorConfig) ConfigConfigurationAggregator
Create a new {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator aws_config_configuration_aggregator} Resource.
type ConfigConfigurationAggregatorAccountAggregationSource ¶
type ConfigConfigurationAggregatorAccountAggregationSource struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator#account_ids ConfigConfigurationAggregator#account_ids}.
AccountIds *[]*string `field:"required" json:"accountIds" yaml:"accountIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator#all_regions ConfigConfigurationAggregator#all_regions}.
AllRegions interface{} `field:"optional" json:"allRegions" yaml:"allRegions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator#regions ConfigConfigurationAggregator#regions}.
Regions *[]*string `field:"optional" json:"regions" yaml:"regions"`
}
type ConfigConfigurationAggregatorAccountAggregationSourceOutputReference ¶
type ConfigConfigurationAggregatorAccountAggregationSourceOutputReference interface {
cdktf.ComplexObject
AccountIds() *[]*string
SetAccountIds(val *[]*string)
AccountIdsInput() *[]*string
AllRegions() interface{}
SetAllRegions(val interface{})
AllRegionsInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ConfigConfigurationAggregatorAccountAggregationSource
SetInternalValue(val *ConfigConfigurationAggregatorAccountAggregationSource)
Regions() *[]*string
SetRegions(val *[]*string)
RegionsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAllRegions()
ResetRegions()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConfigConfigurationAggregatorAccountAggregationSourceOutputReference ¶
func NewConfigConfigurationAggregatorAccountAggregationSourceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ConfigConfigurationAggregatorAccountAggregationSourceOutputReference
type ConfigConfigurationAggregatorConfig ¶
type ConfigConfigurationAggregatorConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator#name ConfigConfigurationAggregator#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// account_aggregation_source block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator#account_aggregation_source ConfigConfigurationAggregator#account_aggregation_source}
AccountAggregationSource *ConfigConfigurationAggregatorAccountAggregationSource `field:"optional" json:"accountAggregationSource" yaml:"accountAggregationSource"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator#id ConfigConfigurationAggregator#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// organization_aggregation_source block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator#organization_aggregation_source ConfigConfigurationAggregator#organization_aggregation_source}
OrganizationAggregationSource *ConfigConfigurationAggregatorOrganizationAggregationSource `field:"optional" json:"organizationAggregationSource" yaml:"organizationAggregationSource"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator#tags ConfigConfigurationAggregator#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator#tags_all ConfigConfigurationAggregator#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type ConfigConfigurationAggregatorOrganizationAggregationSource ¶
type ConfigConfigurationAggregatorOrganizationAggregationSource struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator#role_arn ConfigConfigurationAggregator#role_arn}.
RoleArn *string `field:"required" json:"roleArn" yaml:"roleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator#all_regions ConfigConfigurationAggregator#all_regions}.
AllRegions interface{} `field:"optional" json:"allRegions" yaml:"allRegions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_configuration_aggregator#regions ConfigConfigurationAggregator#regions}.
Regions *[]*string `field:"optional" json:"regions" yaml:"regions"`
}
type ConfigConfigurationAggregatorOrganizationAggregationSourceOutputReference ¶
type ConfigConfigurationAggregatorOrganizationAggregationSourceOutputReference interface {
cdktf.ComplexObject
AllRegions() interface{}
SetAllRegions(val interface{})
AllRegionsInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ConfigConfigurationAggregatorOrganizationAggregationSource
SetInternalValue(val *ConfigConfigurationAggregatorOrganizationAggregationSource)
Regions() *[]*string
SetRegions(val *[]*string)
RegionsInput() *[]*string
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAllRegions()
ResetRegions()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConfigConfigurationAggregatorOrganizationAggregationSourceOutputReference ¶
func NewConfigConfigurationAggregatorOrganizationAggregationSourceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ConfigConfigurationAggregatorOrganizationAggregationSourceOutputReference
Source Files
¶
- configconfigurationaggregator.go
- configconfigurationaggregator_ConfigConfigurationAggregator.go
- configconfigurationaggregator_ConfigConfigurationAggregatorAccountAggregationSource.go
- configconfigurationaggregator_ConfigConfigurationAggregatorAccountAggregationSourceOutputReference.go
- configconfigurationaggregator_ConfigConfigurationAggregatorAccountAggregationSourceOutputReference__runtime_type_checks.go
- configconfigurationaggregator_ConfigConfigurationAggregatorConfig.go
- configconfigurationaggregator_ConfigConfigurationAggregatorOrganizationAggregationSource.go
- configconfigurationaggregator_ConfigConfigurationAggregatorOrganizationAggregationSourceOutputReference.go
- configconfigurationaggregator_ConfigConfigurationAggregatorOrganizationAggregationSourceOutputReference__runtime_type_checks.go
- configconfigurationaggregator_ConfigConfigurationAggregator__runtime_type_checks.go