Documentation
¶
Index ¶
- func DataAwsAlbTargetGroup_IsConstruct(x interface{}) *bool
- func DataAwsAlbTargetGroup_IsTerraformDataSource(x interface{}) *bool
- func DataAwsAlbTargetGroup_IsTerraformElement(x interface{}) *bool
- func DataAwsAlbTargetGroup_TfResourceType() *string
- func NewDataAwsAlbTargetGroupHealthCheckList_Override(d DataAwsAlbTargetGroupHealthCheckList, ...)
- func NewDataAwsAlbTargetGroupHealthCheckOutputReference_Override(d DataAwsAlbTargetGroupHealthCheckOutputReference, ...)
- func NewDataAwsAlbTargetGroupStickinessList_Override(d DataAwsAlbTargetGroupStickinessList, ...)
- func NewDataAwsAlbTargetGroupStickinessOutputReference_Override(d DataAwsAlbTargetGroupStickinessOutputReference, ...)
- func NewDataAwsAlbTargetGroupTimeoutsOutputReference_Override(d DataAwsAlbTargetGroupTimeoutsOutputReference, ...)
- func NewDataAwsAlbTargetGroup_Override(d DataAwsAlbTargetGroup, scope constructs.Construct, id *string, ...)
- type DataAwsAlbTargetGroup
- type DataAwsAlbTargetGroupConfig
- type DataAwsAlbTargetGroupHealthCheck
- type DataAwsAlbTargetGroupHealthCheckList
- type DataAwsAlbTargetGroupHealthCheckOutputReference
- type DataAwsAlbTargetGroupStickiness
- type DataAwsAlbTargetGroupStickinessList
- type DataAwsAlbTargetGroupStickinessOutputReference
- type DataAwsAlbTargetGroupTimeouts
- type DataAwsAlbTargetGroupTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsAlbTargetGroup_IsConstruct ¶
func DataAwsAlbTargetGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsAlbTargetGroup_IsTerraformDataSource ¶
func DataAwsAlbTargetGroup_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsAlbTargetGroup_IsTerraformElement ¶
func DataAwsAlbTargetGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsAlbTargetGroup_TfResourceType ¶
func DataAwsAlbTargetGroup_TfResourceType() *string
func NewDataAwsAlbTargetGroupHealthCheckList_Override ¶
func NewDataAwsAlbTargetGroupHealthCheckList_Override(d DataAwsAlbTargetGroupHealthCheckList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsAlbTargetGroupHealthCheckOutputReference_Override ¶
func NewDataAwsAlbTargetGroupHealthCheckOutputReference_Override(d DataAwsAlbTargetGroupHealthCheckOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsAlbTargetGroupStickinessList_Override ¶
func NewDataAwsAlbTargetGroupStickinessList_Override(d DataAwsAlbTargetGroupStickinessList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsAlbTargetGroupStickinessOutputReference_Override ¶
func NewDataAwsAlbTargetGroupStickinessOutputReference_Override(d DataAwsAlbTargetGroupStickinessOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsAlbTargetGroupTimeoutsOutputReference_Override ¶
func NewDataAwsAlbTargetGroupTimeoutsOutputReference_Override(d DataAwsAlbTargetGroupTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsAlbTargetGroup_Override ¶
func NewDataAwsAlbTargetGroup_Override(d DataAwsAlbTargetGroup, scope constructs.Construct, id *string, config *DataAwsAlbTargetGroupConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/alb_target_group aws_alb_target_group} Data Source.
Types ¶
type DataAwsAlbTargetGroup ¶
type DataAwsAlbTargetGroup interface {
cdktf.TerraformDataSource
Arn() *string
SetArn(val *string)
ArnInput() *string
ArnSuffix() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ConnectionTermination() cdktf.IResolvable
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeregistrationDelay() *float64
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HealthCheck() DataAwsAlbTargetGroupHealthCheckList
Id() *string
SetId(val *string)
IdInput() *string
LambdaMultiValueHeadersEnabled() cdktf.IResolvable
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LoadBalancingAlgorithmType() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Port() *float64
PreserveClientIp() *string
Protocol() *string
ProtocolVersion() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
ProxyProtocolV2() cdktf.IResolvable
// Experimental.
RawOverrides() interface{}
SlowStart() *float64
Stickiness() DataAwsAlbTargetGroupStickinessList
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
TargetType() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DataAwsAlbTargetGroupTimeoutsOutputReference
TimeoutsInput() interface{}
VpcId() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *DataAwsAlbTargetGroupTimeouts)
ResetArn()
ResetId()
ResetName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/alb_target_group aws_alb_target_group}.
func NewDataAwsAlbTargetGroup ¶
func NewDataAwsAlbTargetGroup(scope constructs.Construct, id *string, config *DataAwsAlbTargetGroupConfig) DataAwsAlbTargetGroup
Create a new {@link https://www.terraform.io/docs/providers/aws/d/alb_target_group aws_alb_target_group} Data Source.
type DataAwsAlbTargetGroupConfig ¶
type DataAwsAlbTargetGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/alb_target_group#arn DataAwsAlbTargetGroup#arn}.
Arn *string `field:"optional" json:"arn" yaml:"arn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/alb_target_group#id DataAwsAlbTargetGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/alb_target_group#name DataAwsAlbTargetGroup#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/alb_target_group#tags DataAwsAlbTargetGroup#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/alb_target_group#timeouts DataAwsAlbTargetGroup#timeouts}
Timeouts *DataAwsAlbTargetGroupTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type DataAwsAlbTargetGroupHealthCheck ¶
type DataAwsAlbTargetGroupHealthCheck struct {
}
type DataAwsAlbTargetGroupHealthCheckList ¶
type DataAwsAlbTargetGroupHealthCheckList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsAlbTargetGroupHealthCheckOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbTargetGroupHealthCheckList ¶
func NewDataAwsAlbTargetGroupHealthCheckList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsAlbTargetGroupHealthCheckList
type DataAwsAlbTargetGroupHealthCheckOutputReference ¶
type DataAwsAlbTargetGroupHealthCheckOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() cdktf.IResolvable
// Experimental.
Fqn() *string
HealthyThreshold() *float64
InternalValue() *DataAwsAlbTargetGroupHealthCheck
SetInternalValue(val *DataAwsAlbTargetGroupHealthCheck)
Interval() *float64
Matcher() *string
Path() *string
Port() *string
Protocol() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Timeout() *float64
UnhealthyThreshold() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbTargetGroupHealthCheckOutputReference ¶
func NewDataAwsAlbTargetGroupHealthCheckOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsAlbTargetGroupHealthCheckOutputReference
type DataAwsAlbTargetGroupStickiness ¶
type DataAwsAlbTargetGroupStickiness struct {
}
type DataAwsAlbTargetGroupStickinessList ¶
type DataAwsAlbTargetGroupStickinessList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsAlbTargetGroupStickinessOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbTargetGroupStickinessList ¶
func NewDataAwsAlbTargetGroupStickinessList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsAlbTargetGroupStickinessList
type DataAwsAlbTargetGroupStickinessOutputReference ¶
type DataAwsAlbTargetGroupStickinessOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CookieDuration() *float64
CookieName() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() cdktf.IResolvable
// Experimental.
Fqn() *string
InternalValue() *DataAwsAlbTargetGroupStickiness
SetInternalValue(val *DataAwsAlbTargetGroupStickiness)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbTargetGroupStickinessOutputReference ¶
func NewDataAwsAlbTargetGroupStickinessOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsAlbTargetGroupStickinessOutputReference
type DataAwsAlbTargetGroupTimeouts ¶
type DataAwsAlbTargetGroupTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/alb_target_group#read DataAwsAlbTargetGroup#read}.
Read *string `field:"optional" json:"read" yaml:"read"`
}
type DataAwsAlbTargetGroupTimeoutsOutputReference ¶
type DataAwsAlbTargetGroupTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Read() *string
SetRead(val *string)
ReadInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetRead()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbTargetGroupTimeoutsOutputReference ¶
func NewDataAwsAlbTargetGroupTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsAlbTargetGroupTimeoutsOutputReference
Source Files
¶
- dataawsalbtargetgroup.go
- dataawsalbtargetgroup_DataAwsAlbTargetGroup.go
- dataawsalbtargetgroup_DataAwsAlbTargetGroupConfig.go
- dataawsalbtargetgroup_DataAwsAlbTargetGroupHealthCheck.go
- dataawsalbtargetgroup_DataAwsAlbTargetGroupHealthCheckList.go
- dataawsalbtargetgroup_DataAwsAlbTargetGroupHealthCheckList__runtime_type_checks.go
- dataawsalbtargetgroup_DataAwsAlbTargetGroupHealthCheckOutputReference.go
- dataawsalbtargetgroup_DataAwsAlbTargetGroupHealthCheckOutputReference__runtime_type_checks.go
- dataawsalbtargetgroup_DataAwsAlbTargetGroupStickiness.go
- dataawsalbtargetgroup_DataAwsAlbTargetGroupStickinessList.go
- dataawsalbtargetgroup_DataAwsAlbTargetGroupStickinessList__runtime_type_checks.go
- dataawsalbtargetgroup_DataAwsAlbTargetGroupStickinessOutputReference.go
- dataawsalbtargetgroup_DataAwsAlbTargetGroupStickinessOutputReference__runtime_type_checks.go
- dataawsalbtargetgroup_DataAwsAlbTargetGroupTimeouts.go
- dataawsalbtargetgroup_DataAwsAlbTargetGroupTimeoutsOutputReference.go
- dataawsalbtargetgroup_DataAwsAlbTargetGroupTimeoutsOutputReference__runtime_type_checks.go
- dataawsalbtargetgroup_DataAwsAlbTargetGroup__runtime_type_checks.go