Documentation
¶
Index ¶
- func DataAwsAmi_IsConstruct(x interface{}) *bool
- func DataAwsAmi_IsTerraformDataSource(x interface{}) *bool
- func DataAwsAmi_IsTerraformElement(x interface{}) *bool
- func DataAwsAmi_TfResourceType() *string
- func NewDataAwsAmiBlockDeviceMappingsList_Override(d DataAwsAmiBlockDeviceMappingsList, ...)
- func NewDataAwsAmiBlockDeviceMappingsOutputReference_Override(d DataAwsAmiBlockDeviceMappingsOutputReference, ...)
- func NewDataAwsAmiFilterList_Override(d DataAwsAmiFilterList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewDataAwsAmiFilterOutputReference_Override(d DataAwsAmiFilterOutputReference, ...)
- func NewDataAwsAmiProductCodesList_Override(d DataAwsAmiProductCodesList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewDataAwsAmiProductCodesOutputReference_Override(d DataAwsAmiProductCodesOutputReference, ...)
- func NewDataAwsAmiTimeoutsOutputReference_Override(d DataAwsAmiTimeoutsOutputReference, ...)
- func NewDataAwsAmi_Override(d DataAwsAmi, scope constructs.Construct, id *string, config *DataAwsAmiConfig)
- type DataAwsAmi
- type DataAwsAmiBlockDeviceMappings
- type DataAwsAmiBlockDeviceMappingsList
- type DataAwsAmiBlockDeviceMappingsOutputReference
- type DataAwsAmiConfig
- type DataAwsAmiFilter
- type DataAwsAmiFilterList
- type DataAwsAmiFilterOutputReference
- type DataAwsAmiProductCodes
- type DataAwsAmiProductCodesList
- type DataAwsAmiProductCodesOutputReference
- type DataAwsAmiTimeouts
- type DataAwsAmiTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsAmi_IsConstruct ¶
func DataAwsAmi_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsAmi_IsTerraformDataSource ¶
func DataAwsAmi_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsAmi_IsTerraformElement ¶
func DataAwsAmi_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsAmi_TfResourceType ¶
func DataAwsAmi_TfResourceType() *string
func NewDataAwsAmiBlockDeviceMappingsList_Override ¶
func NewDataAwsAmiBlockDeviceMappingsList_Override(d DataAwsAmiBlockDeviceMappingsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsAmiBlockDeviceMappingsOutputReference_Override ¶
func NewDataAwsAmiBlockDeviceMappingsOutputReference_Override(d DataAwsAmiBlockDeviceMappingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsAmiFilterList_Override ¶
func NewDataAwsAmiFilterList_Override(d DataAwsAmiFilterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsAmiFilterOutputReference_Override ¶
func NewDataAwsAmiFilterOutputReference_Override(d DataAwsAmiFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsAmiProductCodesList_Override ¶
func NewDataAwsAmiProductCodesList_Override(d DataAwsAmiProductCodesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsAmiProductCodesOutputReference_Override ¶
func NewDataAwsAmiProductCodesOutputReference_Override(d DataAwsAmiProductCodesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsAmiTimeoutsOutputReference_Override ¶
func NewDataAwsAmiTimeoutsOutputReference_Override(d DataAwsAmiTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsAmi_Override ¶
func NewDataAwsAmi_Override(d DataAwsAmi, scope constructs.Construct, id *string, config *DataAwsAmiConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/ami aws_ami} Data Source.
Types ¶
type DataAwsAmi ¶
type DataAwsAmi interface {
cdktf.TerraformDataSource
Architecture() *string
Arn() *string
BlockDeviceMappings() DataAwsAmiBlockDeviceMappingsList
BootMode() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreationDate() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeprecationTime() *string
Description() *string
EnaSupport() cdktf.IResolvable
ExecutableUsers() *[]*string
SetExecutableUsers(val *[]*string)
ExecutableUsersInput() *[]*string
Filter() DataAwsAmiFilterList
FilterInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Hypervisor() *string
Id() *string
SetId(val *string)
IdInput() *string
ImageId() *string
ImageLocation() *string
ImageOwnerAlias() *string
ImageType() *string
ImdsSupport() *string
IncludeDeprecated() interface{}
SetIncludeDeprecated(val interface{})
IncludeDeprecatedInput() interface{}
KernelId() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MostRecent() interface{}
SetMostRecent(val interface{})
MostRecentInput() interface{}
Name() *string
NameRegex() *string
SetNameRegex(val *string)
NameRegexInput() *string
// The tree node.
Node() constructs.Node
OwnerId() *string
Owners() *[]*string
SetOwners(val *[]*string)
OwnersInput() *[]*string
Platform() *string
PlatformDetails() *string
ProductCodes() DataAwsAmiProductCodesList
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
Public() cdktf.IResolvable
RamdiskId() *string
// Experimental.
RawOverrides() interface{}
RootDeviceName() *string
RootDeviceType() *string
RootSnapshotId() *string
SriovNetSupport() *string
State() *string
StateReason() cdktf.StringMap
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DataAwsAmiTimeoutsOutputReference
TimeoutsInput() interface{}
TpmSupport() *string
UsageOperation() *string
VirtualizationType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutFilter(value interface{})
PutTimeouts(value *DataAwsAmiTimeouts)
ResetExecutableUsers()
ResetFilter()
ResetId()
ResetIncludeDeprecated()
ResetMostRecent()
ResetNameRegex()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetOwners()
ResetTags()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/ami aws_ami}.
func NewDataAwsAmi ¶
func NewDataAwsAmi(scope constructs.Construct, id *string, config *DataAwsAmiConfig) DataAwsAmi
Create a new {@link https://www.terraform.io/docs/providers/aws/d/ami aws_ami} Data Source.
type DataAwsAmiBlockDeviceMappings ¶
type DataAwsAmiBlockDeviceMappings struct {
}
type DataAwsAmiBlockDeviceMappingsList ¶
type DataAwsAmiBlockDeviceMappingsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsAmiBlockDeviceMappingsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAmiBlockDeviceMappingsList ¶
func NewDataAwsAmiBlockDeviceMappingsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsAmiBlockDeviceMappingsList
type DataAwsAmiBlockDeviceMappingsOutputReference ¶
type DataAwsAmiBlockDeviceMappingsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeviceName() *string
Ebs() cdktf.StringMap
// Experimental.
Fqn() *string
InternalValue() *DataAwsAmiBlockDeviceMappings
SetInternalValue(val *DataAwsAmiBlockDeviceMappings)
NoDevice() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VirtualName() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAmiBlockDeviceMappingsOutputReference ¶
func NewDataAwsAmiBlockDeviceMappingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsAmiBlockDeviceMappingsOutputReference
type DataAwsAmiConfig ¶
type DataAwsAmiConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ami#executable_users DataAwsAmi#executable_users}.
ExecutableUsers *[]*string `field:"optional" json:"executableUsers" yaml:"executableUsers"`
// filter block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ami#filter DataAwsAmi#filter}
Filter interface{} `field:"optional" json:"filter" yaml:"filter"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ami#id DataAwsAmi#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ami#include_deprecated DataAwsAmi#include_deprecated}.
IncludeDeprecated interface{} `field:"optional" json:"includeDeprecated" yaml:"includeDeprecated"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ami#most_recent DataAwsAmi#most_recent}.
MostRecent interface{} `field:"optional" json:"mostRecent" yaml:"mostRecent"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ami#name_regex DataAwsAmi#name_regex}.
NameRegex *string `field:"optional" json:"nameRegex" yaml:"nameRegex"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ami#owners DataAwsAmi#owners}.
Owners *[]*string `field:"optional" json:"owners" yaml:"owners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ami#tags DataAwsAmi#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ami#timeouts DataAwsAmi#timeouts}
Timeouts *DataAwsAmiTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type DataAwsAmiFilter ¶
type DataAwsAmiFilter struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ami#name DataAwsAmi#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ami#values DataAwsAmi#values}.
Values *[]*string `field:"required" json:"values" yaml:"values"`
}
type DataAwsAmiFilterList ¶
type DataAwsAmiFilterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsAmiFilterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAmiFilterList ¶
func NewDataAwsAmiFilterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsAmiFilterList
type DataAwsAmiFilterOutputReference ¶
type DataAwsAmiFilterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
SetValues(val *[]*string)
ValuesInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAmiFilterOutputReference ¶
func NewDataAwsAmiFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsAmiFilterOutputReference
type DataAwsAmiProductCodes ¶
type DataAwsAmiProductCodes struct {
}
type DataAwsAmiProductCodesList ¶
type DataAwsAmiProductCodesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsAmiProductCodesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAmiProductCodesList ¶
func NewDataAwsAmiProductCodesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsAmiProductCodesList
type DataAwsAmiProductCodesOutputReference ¶
type DataAwsAmiProductCodesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsAmiProductCodes
SetInternalValue(val *DataAwsAmiProductCodes)
ProductCodeId() *string
ProductCodeType() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAmiProductCodesOutputReference ¶
func NewDataAwsAmiProductCodesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsAmiProductCodesOutputReference
type DataAwsAmiTimeouts ¶
type DataAwsAmiTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ami#read DataAwsAmi#read}.
Read *string `field:"optional" json:"read" yaml:"read"`
}
type DataAwsAmiTimeoutsOutputReference ¶
type DataAwsAmiTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Read() *string
SetRead(val *string)
ReadInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetRead()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAmiTimeoutsOutputReference ¶
func NewDataAwsAmiTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsAmiTimeoutsOutputReference
Source Files
¶
- dataawsami.go
- dataawsami_DataAwsAmi.go
- dataawsami_DataAwsAmiBlockDeviceMappings.go
- dataawsami_DataAwsAmiBlockDeviceMappingsList.go
- dataawsami_DataAwsAmiBlockDeviceMappingsList__runtime_type_checks.go
- dataawsami_DataAwsAmiBlockDeviceMappingsOutputReference.go
- dataawsami_DataAwsAmiBlockDeviceMappingsOutputReference__runtime_type_checks.go
- dataawsami_DataAwsAmiConfig.go
- dataawsami_DataAwsAmiFilter.go
- dataawsami_DataAwsAmiFilterList.go
- dataawsami_DataAwsAmiFilterList__runtime_type_checks.go
- dataawsami_DataAwsAmiFilterOutputReference.go
- dataawsami_DataAwsAmiFilterOutputReference__runtime_type_checks.go
- dataawsami_DataAwsAmiProductCodes.go
- dataawsami_DataAwsAmiProductCodesList.go
- dataawsami_DataAwsAmiProductCodesList__runtime_type_checks.go
- dataawsami_DataAwsAmiProductCodesOutputReference.go
- dataawsami_DataAwsAmiProductCodesOutputReference__runtime_type_checks.go
- dataawsami_DataAwsAmiTimeouts.go
- dataawsami_DataAwsAmiTimeoutsOutputReference.go
- dataawsami_DataAwsAmiTimeoutsOutputReference__runtime_type_checks.go
- dataawsami_DataAwsAmi__runtime_type_checks.go