Documentation
¶
Index ¶
- func DataAwsApigatewayv2Api_IsConstruct(x interface{}) *bool
- func DataAwsApigatewayv2Api_IsTerraformDataSource(x interface{}) *bool
- func DataAwsApigatewayv2Api_IsTerraformElement(x interface{}) *bool
- func DataAwsApigatewayv2Api_TfResourceType() *string
- func NewDataAwsApigatewayv2ApiCorsConfigurationList_Override(d DataAwsApigatewayv2ApiCorsConfigurationList, ...)
- func NewDataAwsApigatewayv2ApiCorsConfigurationOutputReference_Override(d DataAwsApigatewayv2ApiCorsConfigurationOutputReference, ...)
- func NewDataAwsApigatewayv2Api_Override(d DataAwsApigatewayv2Api, scope constructs.Construct, id *string, ...)
- type DataAwsApigatewayv2Api
- type DataAwsApigatewayv2ApiConfig
- type DataAwsApigatewayv2ApiCorsConfiguration
- type DataAwsApigatewayv2ApiCorsConfigurationList
- type DataAwsApigatewayv2ApiCorsConfigurationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsApigatewayv2Api_IsConstruct ¶
func DataAwsApigatewayv2Api_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsApigatewayv2Api_IsTerraformDataSource ¶
func DataAwsApigatewayv2Api_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsApigatewayv2Api_IsTerraformElement ¶
func DataAwsApigatewayv2Api_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsApigatewayv2Api_TfResourceType ¶
func DataAwsApigatewayv2Api_TfResourceType() *string
func NewDataAwsApigatewayv2ApiCorsConfigurationList_Override ¶
func NewDataAwsApigatewayv2ApiCorsConfigurationList_Override(d DataAwsApigatewayv2ApiCorsConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsApigatewayv2ApiCorsConfigurationOutputReference_Override ¶
func NewDataAwsApigatewayv2ApiCorsConfigurationOutputReference_Override(d DataAwsApigatewayv2ApiCorsConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsApigatewayv2Api_Override ¶
func NewDataAwsApigatewayv2Api_Override(d DataAwsApigatewayv2Api, scope constructs.Construct, id *string, config *DataAwsApigatewayv2ApiConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/apigatewayv2_api aws_apigatewayv2_api} Data Source.
Types ¶
type DataAwsApigatewayv2Api ¶
type DataAwsApigatewayv2Api interface {
cdktf.TerraformDataSource
ApiEndpoint() *string
ApiId() *string
SetApiId(val *string)
ApiIdInput() *string
ApiKeySelectionExpression() *string
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
CorsConfiguration() DataAwsApigatewayv2ApiCorsConfigurationList
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
DisableExecuteApiEndpoint() cdktf.IResolvable
ExecutionArn() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
ProtocolType() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
RouteSelectionExpression() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Version() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/apigatewayv2_api aws_apigatewayv2_api}.
func NewDataAwsApigatewayv2Api ¶
func NewDataAwsApigatewayv2Api(scope constructs.Construct, id *string, config *DataAwsApigatewayv2ApiConfig) DataAwsApigatewayv2Api
Create a new {@link https://www.terraform.io/docs/providers/aws/d/apigatewayv2_api aws_apigatewayv2_api} Data Source.
type DataAwsApigatewayv2ApiConfig ¶
type DataAwsApigatewayv2ApiConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/apigatewayv2_api#api_id DataAwsApigatewayv2Api#api_id}.
ApiId *string `field:"required" json:"apiId" yaml:"apiId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/apigatewayv2_api#id DataAwsApigatewayv2Api#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/apigatewayv2_api#tags DataAwsApigatewayv2Api#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsApigatewayv2ApiCorsConfiguration ¶
type DataAwsApigatewayv2ApiCorsConfiguration struct {
}
type DataAwsApigatewayv2ApiCorsConfigurationList ¶
type DataAwsApigatewayv2ApiCorsConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsApigatewayv2ApiCorsConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsApigatewayv2ApiCorsConfigurationList ¶
func NewDataAwsApigatewayv2ApiCorsConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsApigatewayv2ApiCorsConfigurationList
type DataAwsApigatewayv2ApiCorsConfigurationOutputReference ¶
type DataAwsApigatewayv2ApiCorsConfigurationOutputReference interface {
cdktf.ComplexObject
AllowCredentials() cdktf.IResolvable
AllowHeaders() *[]*string
AllowMethods() *[]*string
AllowOrigins() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
ExposeHeaders() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsApigatewayv2ApiCorsConfiguration
SetInternalValue(val *DataAwsApigatewayv2ApiCorsConfiguration)
MaxAge() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsApigatewayv2ApiCorsConfigurationOutputReference ¶
func NewDataAwsApigatewayv2ApiCorsConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsApigatewayv2ApiCorsConfigurationOutputReference
Source Files
¶
- dataawsapigatewayv2api.go
- dataawsapigatewayv2api_DataAwsApigatewayv2Api.go
- dataawsapigatewayv2api_DataAwsApigatewayv2ApiConfig.go
- dataawsapigatewayv2api_DataAwsApigatewayv2ApiCorsConfiguration.go
- dataawsapigatewayv2api_DataAwsApigatewayv2ApiCorsConfigurationList.go
- dataawsapigatewayv2api_DataAwsApigatewayv2ApiCorsConfigurationList__runtime_type_checks.go
- dataawsapigatewayv2api_DataAwsApigatewayv2ApiCorsConfigurationOutputReference.go
- dataawsapigatewayv2api_DataAwsApigatewayv2ApiCorsConfigurationOutputReference__runtime_type_checks.go
- dataawsapigatewayv2api_DataAwsApigatewayv2Api__runtime_type_checks.go