Documentation
¶
Index ¶
- func DataAwsBatchSchedulingPolicy_IsConstruct(x interface{}) *bool
- func DataAwsBatchSchedulingPolicy_IsTerraformDataSource(x interface{}) *bool
- func DataAwsBatchSchedulingPolicy_IsTerraformElement(x interface{}) *bool
- func DataAwsBatchSchedulingPolicy_TfResourceType() *string
- func NewDataAwsBatchSchedulingPolicyFairSharePolicyList_Override(d DataAwsBatchSchedulingPolicyFairSharePolicyList, ...)
- func NewDataAwsBatchSchedulingPolicyFairSharePolicyOutputReference_Override(d DataAwsBatchSchedulingPolicyFairSharePolicyOutputReference, ...)
- func NewDataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionList_Override(d DataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionList, ...)
- func NewDataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference_Override(d DataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference, ...)
- func NewDataAwsBatchSchedulingPolicy_Override(d DataAwsBatchSchedulingPolicy, scope constructs.Construct, id *string, ...)
- type DataAwsBatchSchedulingPolicy
- type DataAwsBatchSchedulingPolicyConfig
- type DataAwsBatchSchedulingPolicyFairSharePolicy
- type DataAwsBatchSchedulingPolicyFairSharePolicyList
- type DataAwsBatchSchedulingPolicyFairSharePolicyOutputReference
- type DataAwsBatchSchedulingPolicyFairSharePolicyShareDistribution
- type DataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionList
- type DataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsBatchSchedulingPolicy_IsConstruct ¶
func DataAwsBatchSchedulingPolicy_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsBatchSchedulingPolicy_IsTerraformDataSource ¶
func DataAwsBatchSchedulingPolicy_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsBatchSchedulingPolicy_IsTerraformElement ¶
func DataAwsBatchSchedulingPolicy_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsBatchSchedulingPolicy_TfResourceType ¶
func DataAwsBatchSchedulingPolicy_TfResourceType() *string
func NewDataAwsBatchSchedulingPolicyFairSharePolicyList_Override ¶
func NewDataAwsBatchSchedulingPolicyFairSharePolicyList_Override(d DataAwsBatchSchedulingPolicyFairSharePolicyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsBatchSchedulingPolicyFairSharePolicyOutputReference_Override ¶
func NewDataAwsBatchSchedulingPolicyFairSharePolicyOutputReference_Override(d DataAwsBatchSchedulingPolicyFairSharePolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionList_Override ¶
func NewDataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionList_Override(d DataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference_Override ¶
func NewDataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference_Override(d DataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsBatchSchedulingPolicy_Override ¶
func NewDataAwsBatchSchedulingPolicy_Override(d DataAwsBatchSchedulingPolicy, scope constructs.Construct, id *string, config *DataAwsBatchSchedulingPolicyConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/batch_scheduling_policy aws_batch_scheduling_policy} Data Source.
Types ¶
type DataAwsBatchSchedulingPolicy ¶
type DataAwsBatchSchedulingPolicy interface {
cdktf.TerraformDataSource
Arn() *string
SetArn(val *string)
ArnInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/batch_scheduling_policy aws_batch_scheduling_policy}.
func NewDataAwsBatchSchedulingPolicy ¶
func NewDataAwsBatchSchedulingPolicy(scope constructs.Construct, id *string, config *DataAwsBatchSchedulingPolicyConfig) DataAwsBatchSchedulingPolicy
Create a new {@link https://www.terraform.io/docs/providers/aws/d/batch_scheduling_policy aws_batch_scheduling_policy} Data Source.
type DataAwsBatchSchedulingPolicyConfig ¶
type DataAwsBatchSchedulingPolicyConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/batch_scheduling_policy#arn DataAwsBatchSchedulingPolicy#arn}.
Arn *string `field:"required" json:"arn" yaml:"arn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/batch_scheduling_policy#id DataAwsBatchSchedulingPolicy#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/batch_scheduling_policy#tags DataAwsBatchSchedulingPolicy#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsBatchSchedulingPolicyFairSharePolicy ¶
type DataAwsBatchSchedulingPolicyFairSharePolicy struct {
}
type DataAwsBatchSchedulingPolicyFairSharePolicyList ¶
type DataAwsBatchSchedulingPolicyFairSharePolicyList interface {
cdktf.ComplexList
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Fqn() *string
// The attribute on the parent resource this class is referencing.
// The parent resource.
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsBatchSchedulingPolicyFairSharePolicyList ¶
func NewDataAwsBatchSchedulingPolicyFairSharePolicyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsBatchSchedulingPolicyFairSharePolicyList
type DataAwsBatchSchedulingPolicyFairSharePolicyOutputReference ¶
type DataAwsBatchSchedulingPolicyFairSharePolicyOutputReference interface {
cdktf.ComplexObject
// Experimental.
ComplexObjectIndex() interface{}
SetComplexObjectIndex(val interface{})
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
ComputeFqn() *string
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationAsList() cdktf.IResolvable
InterpolationForAttribute(property *string) cdktf.IResolvable
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsBatchSchedulingPolicyFairSharePolicyOutputReference ¶
func NewDataAwsBatchSchedulingPolicyFairSharePolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsBatchSchedulingPolicyFairSharePolicyOutputReference
type DataAwsBatchSchedulingPolicyFairSharePolicyShareDistribution ¶
type DataAwsBatchSchedulingPolicyFairSharePolicyShareDistribution struct {
}
type DataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionList ¶
type DataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionList interface {
cdktf.ComplexList
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Fqn() *string
// The attribute on the parent resource this class is referencing.
// The parent resource.
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionList ¶
func NewDataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionList
type DataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference ¶
type DataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference interface {
cdktf.ComplexObject
// Experimental.
ComplexObjectIndex() interface{}
SetComplexObjectIndex(val interface{})
// Experimental.
ComplexObjectIsFromSet() *bool
SetComplexObjectIsFromSet(val *bool)
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
ComputeFqn() *string
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationAsList() cdktf.IResolvable
InterpolationForAttribute(property *string) cdktf.IResolvable
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference ¶
func NewDataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference
Source Files
¶
- dataawsbatchschedulingpolicy.go
- dataawsbatchschedulingpolicy_DataAwsBatchSchedulingPolicy.go
- dataawsbatchschedulingpolicy_DataAwsBatchSchedulingPolicyConfig.go
- dataawsbatchschedulingpolicy_DataAwsBatchSchedulingPolicyFairSharePolicy.go
- dataawsbatchschedulingpolicy_DataAwsBatchSchedulingPolicyFairSharePolicyList.go
- dataawsbatchschedulingpolicy_DataAwsBatchSchedulingPolicyFairSharePolicyList__runtime_type_checks.go
- dataawsbatchschedulingpolicy_DataAwsBatchSchedulingPolicyFairSharePolicyOutputReference.go
- dataawsbatchschedulingpolicy_DataAwsBatchSchedulingPolicyFairSharePolicyOutputReference__runtime_type_checks.go
- dataawsbatchschedulingpolicy_DataAwsBatchSchedulingPolicyFairSharePolicyShareDistribution.go
- dataawsbatchschedulingpolicy_DataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionList.go
- dataawsbatchschedulingpolicy_DataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionList__runtime_type_checks.go
- dataawsbatchschedulingpolicy_DataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference.go
- dataawsbatchschedulingpolicy_DataAwsBatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference__runtime_type_checks.go
- dataawsbatchschedulingpolicy_DataAwsBatchSchedulingPolicy__runtime_type_checks.go