Documentation
¶
Index ¶
- func DataAwsConnectUserHierarchyGroup_IsConstruct(x interface{}) *bool
- func DataAwsConnectUserHierarchyGroup_IsTerraformDataSource(x interface{}) *bool
- func DataAwsConnectUserHierarchyGroup_IsTerraformElement(x interface{}) *bool
- func DataAwsConnectUserHierarchyGroup_TfResourceType() *string
- func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveList_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveList, ...)
- func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference, ...)
- func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFourList_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelFourList, ...)
- func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference, ...)
- func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelOneList_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelOneList, ...)
- func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference, ...)
- func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeList_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeList, ...)
- func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference, ...)
- func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoList_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoList, ...)
- func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference, ...)
- func NewDataAwsConnectUserHierarchyGroupHierarchyPathList_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathList, ...)
- func NewDataAwsConnectUserHierarchyGroupHierarchyPathOutputReference_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathOutputReference, ...)
- func NewDataAwsConnectUserHierarchyGroup_Override(d DataAwsConnectUserHierarchyGroup, scope constructs.Construct, id *string, ...)
- type DataAwsConnectUserHierarchyGroup
- type DataAwsConnectUserHierarchyGroupConfig
- type DataAwsConnectUserHierarchyGroupHierarchyPath
- type DataAwsConnectUserHierarchyGroupHierarchyPathLevelFive
- type DataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveList
- type DataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference
- type DataAwsConnectUserHierarchyGroupHierarchyPathLevelFour
- type DataAwsConnectUserHierarchyGroupHierarchyPathLevelFourList
- type DataAwsConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference
- type DataAwsConnectUserHierarchyGroupHierarchyPathLevelOne
- type DataAwsConnectUserHierarchyGroupHierarchyPathLevelOneList
- type DataAwsConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference
- type DataAwsConnectUserHierarchyGroupHierarchyPathLevelThree
- type DataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeList
- type DataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference
- type DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwo
- type DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoList
- type DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference
- type DataAwsConnectUserHierarchyGroupHierarchyPathList
- type DataAwsConnectUserHierarchyGroupHierarchyPathOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsConnectUserHierarchyGroup_IsConstruct ¶
func DataAwsConnectUserHierarchyGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsConnectUserHierarchyGroup_IsTerraformDataSource ¶
func DataAwsConnectUserHierarchyGroup_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsConnectUserHierarchyGroup_IsTerraformElement ¶
func DataAwsConnectUserHierarchyGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsConnectUserHierarchyGroup_TfResourceType ¶
func DataAwsConnectUserHierarchyGroup_TfResourceType() *string
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveList_Override ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveList_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference_Override ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFourList_Override ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFourList_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelFourList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference_Override ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelOneList_Override ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelOneList_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelOneList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference_Override ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeList_Override ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeList_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference_Override ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoList_Override ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoList_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference_Override ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsConnectUserHierarchyGroupHierarchyPathList_Override ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathList_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsConnectUserHierarchyGroupHierarchyPathOutputReference_Override ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathOutputReference_Override(d DataAwsConnectUserHierarchyGroupHierarchyPathOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsConnectUserHierarchyGroup_Override ¶
func NewDataAwsConnectUserHierarchyGroup_Override(d DataAwsConnectUserHierarchyGroup, scope constructs.Construct, id *string, config *DataAwsConnectUserHierarchyGroupConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/connect_user_hierarchy_group aws_connect_user_hierarchy_group} Data Source.
Types ¶
type DataAwsConnectUserHierarchyGroup ¶
type DataAwsConnectUserHierarchyGroup interface {
cdktf.TerraformDataSource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HierarchyGroupId() *string
SetHierarchyGroupId(val *string)
HierarchyGroupIdInput() *string
HierarchyPath() DataAwsConnectUserHierarchyGroupHierarchyPathList
Id() *string
SetId(val *string)
IdInput() *string
InstanceId() *string
SetInstanceId(val *string)
InstanceIdInput() *string
LevelId() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetHierarchyGroupId()
ResetId()
ResetName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/connect_user_hierarchy_group aws_connect_user_hierarchy_group}.
func NewDataAwsConnectUserHierarchyGroup ¶
func NewDataAwsConnectUserHierarchyGroup(scope constructs.Construct, id *string, config *DataAwsConnectUserHierarchyGroupConfig) DataAwsConnectUserHierarchyGroup
Create a new {@link https://www.terraform.io/docs/providers/aws/d/connect_user_hierarchy_group aws_connect_user_hierarchy_group} Data Source.
type DataAwsConnectUserHierarchyGroupConfig ¶
type DataAwsConnectUserHierarchyGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/connect_user_hierarchy_group#instance_id DataAwsConnectUserHierarchyGroup#instance_id}.
InstanceId *string `field:"required" json:"instanceId" yaml:"instanceId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/connect_user_hierarchy_group#hierarchy_group_id DataAwsConnectUserHierarchyGroup#hierarchy_group_id}.
HierarchyGroupId *string `field:"optional" json:"hierarchyGroupId" yaml:"hierarchyGroupId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/connect_user_hierarchy_group#id DataAwsConnectUserHierarchyGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/connect_user_hierarchy_group#name DataAwsConnectUserHierarchyGroup#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/connect_user_hierarchy_group#tags DataAwsConnectUserHierarchyGroup#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsConnectUserHierarchyGroupHierarchyPath ¶
type DataAwsConnectUserHierarchyGroupHierarchyPath struct {
}
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelFive ¶
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelFive struct {
}
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveList ¶
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveList ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveList
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference ¶
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *DataAwsConnectUserHierarchyGroupHierarchyPathLevelFive
SetInternalValue(val *DataAwsConnectUserHierarchyGroupHierarchyPathLevelFive)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelFour ¶
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelFour struct {
}
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelFourList ¶
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelFourList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFourList ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFourList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsConnectUserHierarchyGroupHierarchyPathLevelFourList
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference ¶
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *DataAwsConnectUserHierarchyGroupHierarchyPathLevelFour
SetInternalValue(val *DataAwsConnectUserHierarchyGroupHierarchyPathLevelFour)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelOne ¶
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelOne struct {
}
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelOneList ¶
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelOneList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelOneList ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelOneList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsConnectUserHierarchyGroupHierarchyPathLevelOneList
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference ¶
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *DataAwsConnectUserHierarchyGroupHierarchyPathLevelOne
SetInternalValue(val *DataAwsConnectUserHierarchyGroupHierarchyPathLevelOne)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelThree ¶
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelThree struct {
}
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeList ¶
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeList ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeList
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference ¶
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *DataAwsConnectUserHierarchyGroupHierarchyPathLevelThree
SetInternalValue(val *DataAwsConnectUserHierarchyGroupHierarchyPathLevelThree)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwo ¶
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwo struct {
}
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoList ¶
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoList ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoList
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference ¶
type DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwo
SetInternalValue(val *DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwo)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference
type DataAwsConnectUserHierarchyGroupHierarchyPathList ¶
type DataAwsConnectUserHierarchyGroupHierarchyPathList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsConnectUserHierarchyGroupHierarchyPathOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyGroupHierarchyPathList ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsConnectUserHierarchyGroupHierarchyPathList
type DataAwsConnectUserHierarchyGroupHierarchyPathOutputReference ¶
type DataAwsConnectUserHierarchyGroupHierarchyPathOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsConnectUserHierarchyGroupHierarchyPath
SetInternalValue(val *DataAwsConnectUserHierarchyGroupHierarchyPath)
LevelFive() DataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveList
LevelFour() DataAwsConnectUserHierarchyGroupHierarchyPathLevelFourList
LevelOne() DataAwsConnectUserHierarchyGroupHierarchyPathLevelOneList
LevelThree() DataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeList
LevelTwo() DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyGroupHierarchyPathOutputReference ¶
func NewDataAwsConnectUserHierarchyGroupHierarchyPathOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsConnectUserHierarchyGroupHierarchyPathOutputReference
Source Files
¶
- dataawsconnectuserhierarchygroup.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroup.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupConfig.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPath.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelFive.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveList.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveList__runtime_type_checks.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference__runtime_type_checks.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelFour.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelFourList.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelFourList__runtime_type_checks.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference__runtime_type_checks.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelOne.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelOneList.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelOneList__runtime_type_checks.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference__runtime_type_checks.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelThree.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeList.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeList__runtime_type_checks.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference__runtime_type_checks.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwo.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoList.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoList__runtime_type_checks.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference__runtime_type_checks.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathList.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathList__runtime_type_checks.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathOutputReference.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroupHierarchyPathOutputReference__runtime_type_checks.go
- dataawsconnectuserhierarchygroup_DataAwsConnectUserHierarchyGroup__runtime_type_checks.go