Documentation
¶
Index ¶
- func DataAwsDirectoryServiceDirectory_IsConstruct(x interface{}) *bool
- func DataAwsDirectoryServiceDirectory_IsTerraformDataSource(x interface{}) *bool
- func DataAwsDirectoryServiceDirectory_IsTerraformElement(x interface{}) *bool
- func DataAwsDirectoryServiceDirectory_TfResourceType() *string
- func NewDataAwsDirectoryServiceDirectoryConnectSettingsList_Override(d DataAwsDirectoryServiceDirectoryConnectSettingsList, ...)
- func NewDataAwsDirectoryServiceDirectoryConnectSettingsOutputReference_Override(d DataAwsDirectoryServiceDirectoryConnectSettingsOutputReference, ...)
- func NewDataAwsDirectoryServiceDirectoryRadiusSettingsList_Override(d DataAwsDirectoryServiceDirectoryRadiusSettingsList, ...)
- func NewDataAwsDirectoryServiceDirectoryRadiusSettingsOutputReference_Override(d DataAwsDirectoryServiceDirectoryRadiusSettingsOutputReference, ...)
- func NewDataAwsDirectoryServiceDirectoryVpcSettingsList_Override(d DataAwsDirectoryServiceDirectoryVpcSettingsList, ...)
- func NewDataAwsDirectoryServiceDirectoryVpcSettingsOutputReference_Override(d DataAwsDirectoryServiceDirectoryVpcSettingsOutputReference, ...)
- func NewDataAwsDirectoryServiceDirectory_Override(d DataAwsDirectoryServiceDirectory, scope constructs.Construct, id *string, ...)
- type DataAwsDirectoryServiceDirectory
- type DataAwsDirectoryServiceDirectoryConfig
- type DataAwsDirectoryServiceDirectoryConnectSettings
- type DataAwsDirectoryServiceDirectoryConnectSettingsList
- type DataAwsDirectoryServiceDirectoryConnectSettingsOutputReference
- type DataAwsDirectoryServiceDirectoryRadiusSettings
- type DataAwsDirectoryServiceDirectoryRadiusSettingsList
- type DataAwsDirectoryServiceDirectoryRadiusSettingsOutputReference
- type DataAwsDirectoryServiceDirectoryVpcSettings
- type DataAwsDirectoryServiceDirectoryVpcSettingsList
- type DataAwsDirectoryServiceDirectoryVpcSettingsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsDirectoryServiceDirectory_IsConstruct ¶
func DataAwsDirectoryServiceDirectory_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsDirectoryServiceDirectory_IsTerraformDataSource ¶
func DataAwsDirectoryServiceDirectory_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsDirectoryServiceDirectory_IsTerraformElement ¶
func DataAwsDirectoryServiceDirectory_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsDirectoryServiceDirectory_TfResourceType ¶
func DataAwsDirectoryServiceDirectory_TfResourceType() *string
func NewDataAwsDirectoryServiceDirectoryConnectSettingsList_Override ¶
func NewDataAwsDirectoryServiceDirectoryConnectSettingsList_Override(d DataAwsDirectoryServiceDirectoryConnectSettingsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsDirectoryServiceDirectoryConnectSettingsOutputReference_Override ¶
func NewDataAwsDirectoryServiceDirectoryConnectSettingsOutputReference_Override(d DataAwsDirectoryServiceDirectoryConnectSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsDirectoryServiceDirectoryRadiusSettingsList_Override ¶
func NewDataAwsDirectoryServiceDirectoryRadiusSettingsList_Override(d DataAwsDirectoryServiceDirectoryRadiusSettingsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsDirectoryServiceDirectoryRadiusSettingsOutputReference_Override ¶
func NewDataAwsDirectoryServiceDirectoryRadiusSettingsOutputReference_Override(d DataAwsDirectoryServiceDirectoryRadiusSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsDirectoryServiceDirectoryVpcSettingsList_Override ¶
func NewDataAwsDirectoryServiceDirectoryVpcSettingsList_Override(d DataAwsDirectoryServiceDirectoryVpcSettingsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsDirectoryServiceDirectoryVpcSettingsOutputReference_Override ¶
func NewDataAwsDirectoryServiceDirectoryVpcSettingsOutputReference_Override(d DataAwsDirectoryServiceDirectoryVpcSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsDirectoryServiceDirectory_Override ¶
func NewDataAwsDirectoryServiceDirectory_Override(d DataAwsDirectoryServiceDirectory, scope constructs.Construct, id *string, config *DataAwsDirectoryServiceDirectoryConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/directory_service_directory aws_directory_service_directory} Data Source.
Types ¶
type DataAwsDirectoryServiceDirectory ¶
type DataAwsDirectoryServiceDirectory interface {
cdktf.TerraformDataSource
AccessUrl() *string
Alias() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ConnectSettings() DataAwsDirectoryServiceDirectoryConnectSettingsList
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
DirectoryId() *string
SetDirectoryId(val *string)
DirectoryIdInput() *string
DnsIpAddresses() *[]*string
Edition() *string
EnableSso() cdktf.IResolvable
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
RadiusSettings() DataAwsDirectoryServiceDirectoryRadiusSettingsList
// Experimental.
RawOverrides() interface{}
SecurityGroupId() *string
ShortName() *string
Size() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Type() *string
VpcSettings() DataAwsDirectoryServiceDirectoryVpcSettingsList
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/directory_service_directory aws_directory_service_directory}.
func NewDataAwsDirectoryServiceDirectory ¶
func NewDataAwsDirectoryServiceDirectory(scope constructs.Construct, id *string, config *DataAwsDirectoryServiceDirectoryConfig) DataAwsDirectoryServiceDirectory
Create a new {@link https://www.terraform.io/docs/providers/aws/d/directory_service_directory aws_directory_service_directory} Data Source.
type DataAwsDirectoryServiceDirectoryConfig ¶
type DataAwsDirectoryServiceDirectoryConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/directory_service_directory#directory_id DataAwsDirectoryServiceDirectory#directory_id}.
DirectoryId *string `field:"required" json:"directoryId" yaml:"directoryId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/directory_service_directory#id DataAwsDirectoryServiceDirectory#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/directory_service_directory#tags DataAwsDirectoryServiceDirectory#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsDirectoryServiceDirectoryConnectSettings ¶
type DataAwsDirectoryServiceDirectoryConnectSettings struct {
}
type DataAwsDirectoryServiceDirectoryConnectSettingsList ¶
type DataAwsDirectoryServiceDirectoryConnectSettingsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsDirectoryServiceDirectoryConnectSettingsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDirectoryServiceDirectoryConnectSettingsList ¶
func NewDataAwsDirectoryServiceDirectoryConnectSettingsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsDirectoryServiceDirectoryConnectSettingsList
type DataAwsDirectoryServiceDirectoryConnectSettingsOutputReference ¶
type DataAwsDirectoryServiceDirectoryConnectSettingsOutputReference interface {
cdktf.ComplexObject
AvailabilityZones() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ConnectIps() *[]*string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
CustomerDnsIps() *[]*string
CustomerUsername() *string
// Experimental.
Fqn() *string
InternalValue() *DataAwsDirectoryServiceDirectoryConnectSettings
SetInternalValue(val *DataAwsDirectoryServiceDirectoryConnectSettings)
SubnetIds() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VpcId() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDirectoryServiceDirectoryConnectSettingsOutputReference ¶
func NewDataAwsDirectoryServiceDirectoryConnectSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsDirectoryServiceDirectoryConnectSettingsOutputReference
type DataAwsDirectoryServiceDirectoryRadiusSettings ¶
type DataAwsDirectoryServiceDirectoryRadiusSettings struct {
}
type DataAwsDirectoryServiceDirectoryRadiusSettingsList ¶
type DataAwsDirectoryServiceDirectoryRadiusSettingsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsDirectoryServiceDirectoryRadiusSettingsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDirectoryServiceDirectoryRadiusSettingsList ¶
func NewDataAwsDirectoryServiceDirectoryRadiusSettingsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsDirectoryServiceDirectoryRadiusSettingsList
type DataAwsDirectoryServiceDirectoryRadiusSettingsOutputReference ¶
type DataAwsDirectoryServiceDirectoryRadiusSettingsOutputReference interface {
cdktf.ComplexObject
AuthenticationProtocol() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DisplayLabel() *string
// Experimental.
Fqn() *string
InternalValue() *DataAwsDirectoryServiceDirectoryRadiusSettings
SetInternalValue(val *DataAwsDirectoryServiceDirectoryRadiusSettings)
RadiusPort() *float64
RadiusRetries() *float64
RadiusServers() *[]*string
RadiusTimeout() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UseSameUsername() cdktf.IResolvable
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDirectoryServiceDirectoryRadiusSettingsOutputReference ¶
func NewDataAwsDirectoryServiceDirectoryRadiusSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsDirectoryServiceDirectoryRadiusSettingsOutputReference
type DataAwsDirectoryServiceDirectoryVpcSettings ¶
type DataAwsDirectoryServiceDirectoryVpcSettings struct {
}
type DataAwsDirectoryServiceDirectoryVpcSettingsList ¶
type DataAwsDirectoryServiceDirectoryVpcSettingsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsDirectoryServiceDirectoryVpcSettingsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDirectoryServiceDirectoryVpcSettingsList ¶
func NewDataAwsDirectoryServiceDirectoryVpcSettingsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsDirectoryServiceDirectoryVpcSettingsList
type DataAwsDirectoryServiceDirectoryVpcSettingsOutputReference ¶
type DataAwsDirectoryServiceDirectoryVpcSettingsOutputReference interface {
cdktf.ComplexObject
AvailabilityZones() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsDirectoryServiceDirectoryVpcSettings
SetInternalValue(val *DataAwsDirectoryServiceDirectoryVpcSettings)
SubnetIds() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VpcId() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDirectoryServiceDirectoryVpcSettingsOutputReference ¶
func NewDataAwsDirectoryServiceDirectoryVpcSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsDirectoryServiceDirectoryVpcSettingsOutputReference
Source Files
¶
- dataawsdirectoryservicedirectory.go
- dataawsdirectoryservicedirectory_DataAwsDirectoryServiceDirectory.go
- dataawsdirectoryservicedirectory_DataAwsDirectoryServiceDirectoryConfig.go
- dataawsdirectoryservicedirectory_DataAwsDirectoryServiceDirectoryConnectSettings.go
- dataawsdirectoryservicedirectory_DataAwsDirectoryServiceDirectoryConnectSettingsList.go
- dataawsdirectoryservicedirectory_DataAwsDirectoryServiceDirectoryConnectSettingsList__runtime_type_checks.go
- dataawsdirectoryservicedirectory_DataAwsDirectoryServiceDirectoryConnectSettingsOutputReference.go
- dataawsdirectoryservicedirectory_DataAwsDirectoryServiceDirectoryConnectSettingsOutputReference__runtime_type_checks.go
- dataawsdirectoryservicedirectory_DataAwsDirectoryServiceDirectoryRadiusSettings.go
- dataawsdirectoryservicedirectory_DataAwsDirectoryServiceDirectoryRadiusSettingsList.go
- dataawsdirectoryservicedirectory_DataAwsDirectoryServiceDirectoryRadiusSettingsList__runtime_type_checks.go
- dataawsdirectoryservicedirectory_DataAwsDirectoryServiceDirectoryRadiusSettingsOutputReference.go
- dataawsdirectoryservicedirectory_DataAwsDirectoryServiceDirectoryRadiusSettingsOutputReference__runtime_type_checks.go
- dataawsdirectoryservicedirectory_DataAwsDirectoryServiceDirectoryVpcSettings.go
- dataawsdirectoryservicedirectory_DataAwsDirectoryServiceDirectoryVpcSettingsList.go
- dataawsdirectoryservicedirectory_DataAwsDirectoryServiceDirectoryVpcSettingsList__runtime_type_checks.go
- dataawsdirectoryservicedirectory_DataAwsDirectoryServiceDirectoryVpcSettingsOutputReference.go
- dataawsdirectoryservicedirectory_DataAwsDirectoryServiceDirectoryVpcSettingsOutputReference__runtime_type_checks.go
- dataawsdirectoryservicedirectory_DataAwsDirectoryServiceDirectory__runtime_type_checks.go