Documentation
¶
Index ¶
- func DataAwsEc2InstanceType_IsConstruct(x interface{}) *bool
- func DataAwsEc2InstanceType_IsTerraformDataSource(x interface{}) *bool
- func DataAwsEc2InstanceType_IsTerraformElement(x interface{}) *bool
- func DataAwsEc2InstanceType_TfResourceType() *string
- func NewDataAwsEc2InstanceTypeFpgasList_Override(d DataAwsEc2InstanceTypeFpgasList, ...)
- func NewDataAwsEc2InstanceTypeFpgasOutputReference_Override(d DataAwsEc2InstanceTypeFpgasOutputReference, ...)
- func NewDataAwsEc2InstanceTypeGpusList_Override(d DataAwsEc2InstanceTypeGpusList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewDataAwsEc2InstanceTypeGpusOutputReference_Override(d DataAwsEc2InstanceTypeGpusOutputReference, ...)
- func NewDataAwsEc2InstanceTypeInferenceAcceleratorsList_Override(d DataAwsEc2InstanceTypeInferenceAcceleratorsList, ...)
- func NewDataAwsEc2InstanceTypeInferenceAcceleratorsOutputReference_Override(d DataAwsEc2InstanceTypeInferenceAcceleratorsOutputReference, ...)
- func NewDataAwsEc2InstanceTypeInstanceDisksList_Override(d DataAwsEc2InstanceTypeInstanceDisksList, ...)
- func NewDataAwsEc2InstanceTypeInstanceDisksOutputReference_Override(d DataAwsEc2InstanceTypeInstanceDisksOutputReference, ...)
- func NewDataAwsEc2InstanceTypeTimeoutsOutputReference_Override(d DataAwsEc2InstanceTypeTimeoutsOutputReference, ...)
- func NewDataAwsEc2InstanceType_Override(d DataAwsEc2InstanceType, scope constructs.Construct, id *string, ...)
- type DataAwsEc2InstanceType
- type DataAwsEc2InstanceTypeConfig
- type DataAwsEc2InstanceTypeFpgas
- type DataAwsEc2InstanceTypeFpgasList
- type DataAwsEc2InstanceTypeFpgasOutputReference
- type DataAwsEc2InstanceTypeGpus
- type DataAwsEc2InstanceTypeGpusList
- type DataAwsEc2InstanceTypeGpusOutputReference
- type DataAwsEc2InstanceTypeInferenceAccelerators
- type DataAwsEc2InstanceTypeInferenceAcceleratorsList
- type DataAwsEc2InstanceTypeInferenceAcceleratorsOutputReference
- type DataAwsEc2InstanceTypeInstanceDisks
- type DataAwsEc2InstanceTypeInstanceDisksList
- type DataAwsEc2InstanceTypeInstanceDisksOutputReference
- type DataAwsEc2InstanceTypeTimeouts
- type DataAwsEc2InstanceTypeTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsEc2InstanceType_IsConstruct ¶
func DataAwsEc2InstanceType_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsEc2InstanceType_IsTerraformDataSource ¶
func DataAwsEc2InstanceType_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsEc2InstanceType_IsTerraformElement ¶
func DataAwsEc2InstanceType_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsEc2InstanceType_TfResourceType ¶
func DataAwsEc2InstanceType_TfResourceType() *string
func NewDataAwsEc2InstanceTypeFpgasList_Override ¶
func NewDataAwsEc2InstanceTypeFpgasList_Override(d DataAwsEc2InstanceTypeFpgasList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEc2InstanceTypeFpgasOutputReference_Override ¶
func NewDataAwsEc2InstanceTypeFpgasOutputReference_Override(d DataAwsEc2InstanceTypeFpgasOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEc2InstanceTypeGpusList_Override ¶
func NewDataAwsEc2InstanceTypeGpusList_Override(d DataAwsEc2InstanceTypeGpusList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEc2InstanceTypeGpusOutputReference_Override ¶
func NewDataAwsEc2InstanceTypeGpusOutputReference_Override(d DataAwsEc2InstanceTypeGpusOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEc2InstanceTypeInferenceAcceleratorsList_Override ¶
func NewDataAwsEc2InstanceTypeInferenceAcceleratorsList_Override(d DataAwsEc2InstanceTypeInferenceAcceleratorsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEc2InstanceTypeInferenceAcceleratorsOutputReference_Override ¶
func NewDataAwsEc2InstanceTypeInferenceAcceleratorsOutputReference_Override(d DataAwsEc2InstanceTypeInferenceAcceleratorsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEc2InstanceTypeInstanceDisksList_Override ¶
func NewDataAwsEc2InstanceTypeInstanceDisksList_Override(d DataAwsEc2InstanceTypeInstanceDisksList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEc2InstanceTypeInstanceDisksOutputReference_Override ¶
func NewDataAwsEc2InstanceTypeInstanceDisksOutputReference_Override(d DataAwsEc2InstanceTypeInstanceDisksOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEc2InstanceTypeTimeoutsOutputReference_Override ¶
func NewDataAwsEc2InstanceTypeTimeoutsOutputReference_Override(d DataAwsEc2InstanceTypeTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsEc2InstanceType_Override ¶
func NewDataAwsEc2InstanceType_Override(d DataAwsEc2InstanceType, scope constructs.Construct, id *string, config *DataAwsEc2InstanceTypeConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type aws_ec2_instance_type} Data Source.
Types ¶
type DataAwsEc2InstanceType ¶
type DataAwsEc2InstanceType interface {
cdktf.TerraformDataSource
AutoRecoverySupported() cdktf.IResolvable
BareMetal() cdktf.IResolvable
BurstablePerformanceSupported() cdktf.IResolvable
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CurrentGeneration() cdktf.IResolvable
DedicatedHostsSupported() cdktf.IResolvable
DefaultCores() *float64
DefaultThreadsPerCore() *float64
DefaultVcpus() *float64
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EbsEncryptionSupport() *string
EbsNvmeSupport() *string
EbsOptimizedSupport() *string
EbsPerformanceBaselineBandwidth() *float64
EbsPerformanceBaselineIops() *float64
EbsPerformanceBaselineThroughput() *float64
EbsPerformanceMaximumBandwidth() *float64
EbsPerformanceMaximumIops() *float64
EbsPerformanceMaximumThroughput() *float64
EfaSupported() cdktf.IResolvable
EnaSupport() *string
EncryptionInTransitSupported() cdktf.IResolvable
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
Fpgas() DataAwsEc2InstanceTypeFpgasList
// Experimental.
Fqn() *string
FreeTierEligible() cdktf.IResolvable
// Experimental.
FriendlyUniqueId() *string
Gpus() DataAwsEc2InstanceTypeGpusList
HibernationSupported() cdktf.IResolvable
Hypervisor() *string
Id() *string
SetId(val *string)
IdInput() *string
InferenceAccelerators() DataAwsEc2InstanceTypeInferenceAcceleratorsList
InstanceDisks() DataAwsEc2InstanceTypeInstanceDisksList
InstanceStorageSupported() cdktf.IResolvable
InstanceType() *string
SetInstanceType(val *string)
InstanceTypeInput() *string
Ipv6Supported() cdktf.IResolvable
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaximumIpv4AddressesPerInterface() *float64
MaximumIpv6AddressesPerInterface() *float64
MaximumNetworkInterfaces() *float64
MemorySize() *float64
NetworkPerformance() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
SupportedArchitectures() *[]*string
SupportedPlacementStrategies() *[]*string
SupportedRootDeviceTypes() *[]*string
SupportedUsagesClasses() *[]*string
SupportedVirtualizationTypes() *[]*string
SustainedClockSpeed() *float64
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DataAwsEc2InstanceTypeTimeoutsOutputReference
TimeoutsInput() interface{}
TotalFpgaMemory() *float64
TotalGpuMemory() *float64
TotalInstanceStorage() *float64
ValidCores() *[]*float64
ValidThreadsPerCore() *[]*float64
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *DataAwsEc2InstanceTypeTimeouts)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type aws_ec2_instance_type}.
func NewDataAwsEc2InstanceType ¶
func NewDataAwsEc2InstanceType(scope constructs.Construct, id *string, config *DataAwsEc2InstanceTypeConfig) DataAwsEc2InstanceType
Create a new {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type aws_ec2_instance_type} Data Source.
type DataAwsEc2InstanceTypeConfig ¶
type DataAwsEc2InstanceTypeConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type#instance_type DataAwsEc2InstanceType#instance_type}.
InstanceType *string `field:"required" json:"instanceType" yaml:"instanceType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type#id DataAwsEc2InstanceType#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type#timeouts DataAwsEc2InstanceType#timeouts}
Timeouts *DataAwsEc2InstanceTypeTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type DataAwsEc2InstanceTypeFpgas ¶
type DataAwsEc2InstanceTypeFpgas struct {
}
type DataAwsEc2InstanceTypeFpgasList ¶
type DataAwsEc2InstanceTypeFpgasList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEc2InstanceTypeFpgasOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2InstanceTypeFpgasList ¶
func NewDataAwsEc2InstanceTypeFpgasList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEc2InstanceTypeFpgasList
type DataAwsEc2InstanceTypeFpgasOutputReference ¶
type DataAwsEc2InstanceTypeFpgasOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Count() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsEc2InstanceTypeFpgas
SetInternalValue(val *DataAwsEc2InstanceTypeFpgas)
Manufacturer() *string
MemorySize() *float64
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2InstanceTypeFpgasOutputReference ¶
func NewDataAwsEc2InstanceTypeFpgasOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEc2InstanceTypeFpgasOutputReference
type DataAwsEc2InstanceTypeGpus ¶
type DataAwsEc2InstanceTypeGpus struct {
}
type DataAwsEc2InstanceTypeGpusList ¶
type DataAwsEc2InstanceTypeGpusList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEc2InstanceTypeGpusOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2InstanceTypeGpusList ¶
func NewDataAwsEc2InstanceTypeGpusList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEc2InstanceTypeGpusList
type DataAwsEc2InstanceTypeGpusOutputReference ¶
type DataAwsEc2InstanceTypeGpusOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Count() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsEc2InstanceTypeGpus
SetInternalValue(val *DataAwsEc2InstanceTypeGpus)
Manufacturer() *string
MemorySize() *float64
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2InstanceTypeGpusOutputReference ¶
func NewDataAwsEc2InstanceTypeGpusOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEc2InstanceTypeGpusOutputReference
type DataAwsEc2InstanceTypeInferenceAccelerators ¶
type DataAwsEc2InstanceTypeInferenceAccelerators struct {
}
type DataAwsEc2InstanceTypeInferenceAcceleratorsList ¶
type DataAwsEc2InstanceTypeInferenceAcceleratorsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEc2InstanceTypeInferenceAcceleratorsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2InstanceTypeInferenceAcceleratorsList ¶
func NewDataAwsEc2InstanceTypeInferenceAcceleratorsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEc2InstanceTypeInferenceAcceleratorsList
type DataAwsEc2InstanceTypeInferenceAcceleratorsOutputReference ¶
type DataAwsEc2InstanceTypeInferenceAcceleratorsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Count() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsEc2InstanceTypeInferenceAccelerators
SetInternalValue(val *DataAwsEc2InstanceTypeInferenceAccelerators)
Manufacturer() *string
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2InstanceTypeInferenceAcceleratorsOutputReference ¶
func NewDataAwsEc2InstanceTypeInferenceAcceleratorsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEc2InstanceTypeInferenceAcceleratorsOutputReference
type DataAwsEc2InstanceTypeInstanceDisks ¶
type DataAwsEc2InstanceTypeInstanceDisks struct {
}
type DataAwsEc2InstanceTypeInstanceDisksList ¶
type DataAwsEc2InstanceTypeInstanceDisksList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEc2InstanceTypeInstanceDisksOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2InstanceTypeInstanceDisksList ¶
func NewDataAwsEc2InstanceTypeInstanceDisksList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEc2InstanceTypeInstanceDisksList
type DataAwsEc2InstanceTypeInstanceDisksOutputReference ¶
type DataAwsEc2InstanceTypeInstanceDisksOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Count() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsEc2InstanceTypeInstanceDisks
SetInternalValue(val *DataAwsEc2InstanceTypeInstanceDisks)
Size() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2InstanceTypeInstanceDisksOutputReference ¶
func NewDataAwsEc2InstanceTypeInstanceDisksOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEc2InstanceTypeInstanceDisksOutputReference
type DataAwsEc2InstanceTypeTimeouts ¶
type DataAwsEc2InstanceTypeTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type#read DataAwsEc2InstanceType#read}.
Read *string `field:"optional" json:"read" yaml:"read"`
}
type DataAwsEc2InstanceTypeTimeoutsOutputReference ¶
type DataAwsEc2InstanceTypeTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Read() *string
SetRead(val *string)
ReadInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetRead()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2InstanceTypeTimeoutsOutputReference ¶
func NewDataAwsEc2InstanceTypeTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsEc2InstanceTypeTimeoutsOutputReference
Source Files
¶
- dataawsec2instancetype.go
- dataawsec2instancetype_DataAwsEc2InstanceType.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeConfig.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeFpgas.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeFpgasList.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeFpgasList__runtime_type_checks.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeFpgasOutputReference.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeFpgasOutputReference__runtime_type_checks.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeGpus.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeGpusList.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeGpusList__runtime_type_checks.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeGpusOutputReference.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeGpusOutputReference__runtime_type_checks.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeInferenceAccelerators.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeInferenceAcceleratorsList.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeInferenceAcceleratorsList__runtime_type_checks.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeInferenceAcceleratorsOutputReference.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeInferenceAcceleratorsOutputReference__runtime_type_checks.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeInstanceDisks.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeInstanceDisksList.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeInstanceDisksList__runtime_type_checks.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeInstanceDisksOutputReference.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeInstanceDisksOutputReference__runtime_type_checks.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeTimeouts.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeTimeoutsOutputReference.go
- dataawsec2instancetype_DataAwsEc2InstanceTypeTimeoutsOutputReference__runtime_type_checks.go
- dataawsec2instancetype_DataAwsEc2InstanceType__runtime_type_checks.go