Documentation
¶
Index ¶
- func DataAwsEksNodeGroup_IsConstruct(x interface{}) *bool
- func DataAwsEksNodeGroup_IsTerraformDataSource(x interface{}) *bool
- func DataAwsEksNodeGroup_IsTerraformElement(x interface{}) *bool
- func DataAwsEksNodeGroup_TfResourceType() *string
- func NewDataAwsEksNodeGroupRemoteAccessList_Override(d DataAwsEksNodeGroupRemoteAccessList, ...)
- func NewDataAwsEksNodeGroupRemoteAccessOutputReference_Override(d DataAwsEksNodeGroupRemoteAccessOutputReference, ...)
- func NewDataAwsEksNodeGroupResourcesAutoscalingGroupsList_Override(d DataAwsEksNodeGroupResourcesAutoscalingGroupsList, ...)
- func NewDataAwsEksNodeGroupResourcesAutoscalingGroupsOutputReference_Override(d DataAwsEksNodeGroupResourcesAutoscalingGroupsOutputReference, ...)
- func NewDataAwsEksNodeGroupResourcesList_Override(d DataAwsEksNodeGroupResourcesList, ...)
- func NewDataAwsEksNodeGroupResourcesOutputReference_Override(d DataAwsEksNodeGroupResourcesOutputReference, ...)
- func NewDataAwsEksNodeGroupScalingConfigList_Override(d DataAwsEksNodeGroupScalingConfigList, ...)
- func NewDataAwsEksNodeGroupScalingConfigOutputReference_Override(d DataAwsEksNodeGroupScalingConfigOutputReference, ...)
- func NewDataAwsEksNodeGroupTaintsList_Override(d DataAwsEksNodeGroupTaintsList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewDataAwsEksNodeGroupTaintsOutputReference_Override(d DataAwsEksNodeGroupTaintsOutputReference, ...)
- func NewDataAwsEksNodeGroup_Override(d DataAwsEksNodeGroup, scope constructs.Construct, id *string, ...)
- type DataAwsEksNodeGroup
- type DataAwsEksNodeGroupConfig
- type DataAwsEksNodeGroupRemoteAccess
- type DataAwsEksNodeGroupRemoteAccessList
- type DataAwsEksNodeGroupRemoteAccessOutputReference
- type DataAwsEksNodeGroupResources
- type DataAwsEksNodeGroupResourcesAutoscalingGroups
- type DataAwsEksNodeGroupResourcesAutoscalingGroupsList
- type DataAwsEksNodeGroupResourcesAutoscalingGroupsOutputReference
- type DataAwsEksNodeGroupResourcesList
- type DataAwsEksNodeGroupResourcesOutputReference
- type DataAwsEksNodeGroupScalingConfig
- type DataAwsEksNodeGroupScalingConfigList
- type DataAwsEksNodeGroupScalingConfigOutputReference
- type DataAwsEksNodeGroupTaints
- type DataAwsEksNodeGroupTaintsList
- type DataAwsEksNodeGroupTaintsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsEksNodeGroup_IsConstruct ¶
func DataAwsEksNodeGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsEksNodeGroup_IsTerraformDataSource ¶
func DataAwsEksNodeGroup_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsEksNodeGroup_IsTerraformElement ¶
func DataAwsEksNodeGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsEksNodeGroup_TfResourceType ¶
func DataAwsEksNodeGroup_TfResourceType() *string
func NewDataAwsEksNodeGroupRemoteAccessList_Override ¶
func NewDataAwsEksNodeGroupRemoteAccessList_Override(d DataAwsEksNodeGroupRemoteAccessList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEksNodeGroupRemoteAccessOutputReference_Override ¶
func NewDataAwsEksNodeGroupRemoteAccessOutputReference_Override(d DataAwsEksNodeGroupRemoteAccessOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEksNodeGroupResourcesAutoscalingGroupsList_Override ¶
func NewDataAwsEksNodeGroupResourcesAutoscalingGroupsList_Override(d DataAwsEksNodeGroupResourcesAutoscalingGroupsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEksNodeGroupResourcesAutoscalingGroupsOutputReference_Override ¶
func NewDataAwsEksNodeGroupResourcesAutoscalingGroupsOutputReference_Override(d DataAwsEksNodeGroupResourcesAutoscalingGroupsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEksNodeGroupResourcesList_Override ¶
func NewDataAwsEksNodeGroupResourcesList_Override(d DataAwsEksNodeGroupResourcesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEksNodeGroupResourcesOutputReference_Override ¶
func NewDataAwsEksNodeGroupResourcesOutputReference_Override(d DataAwsEksNodeGroupResourcesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEksNodeGroupScalingConfigList_Override ¶
func NewDataAwsEksNodeGroupScalingConfigList_Override(d DataAwsEksNodeGroupScalingConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEksNodeGroupScalingConfigOutputReference_Override ¶
func NewDataAwsEksNodeGroupScalingConfigOutputReference_Override(d DataAwsEksNodeGroupScalingConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEksNodeGroupTaintsList_Override ¶
func NewDataAwsEksNodeGroupTaintsList_Override(d DataAwsEksNodeGroupTaintsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEksNodeGroupTaintsOutputReference_Override ¶
func NewDataAwsEksNodeGroupTaintsOutputReference_Override(d DataAwsEksNodeGroupTaintsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEksNodeGroup_Override ¶
func NewDataAwsEksNodeGroup_Override(d DataAwsEksNodeGroup, scope constructs.Construct, id *string, config *DataAwsEksNodeGroupConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/eks_node_group aws_eks_node_group} Data Source.
Types ¶
type DataAwsEksNodeGroup ¶
type DataAwsEksNodeGroup interface {
cdktf.TerraformDataSource
AmiType() *string
Arn() *string
CapacityType() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterName() *string
SetClusterName(val *string)
ClusterNameInput() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DiskSize() *float64
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InstanceTypes() *[]*string
Labels() cdktf.StringMap
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
NodeGroupName() *string
SetNodeGroupName(val *string)
NodeGroupNameInput() *string
NodeRoleArn() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
ReleaseVersion() *string
RemoteAccess() DataAwsEksNodeGroupRemoteAccessList
Resources() DataAwsEksNodeGroupResourcesList
ScalingConfig() DataAwsEksNodeGroupScalingConfigList
Status() *string
SubnetIds() *[]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
Taints() DataAwsEksNodeGroupTaintsList
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Version() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/eks_node_group aws_eks_node_group}.
func NewDataAwsEksNodeGroup ¶
func NewDataAwsEksNodeGroup(scope constructs.Construct, id *string, config *DataAwsEksNodeGroupConfig) DataAwsEksNodeGroup
Create a new {@link https://www.terraform.io/docs/providers/aws/d/eks_node_group aws_eks_node_group} Data Source.
type DataAwsEksNodeGroupConfig ¶
type DataAwsEksNodeGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/eks_node_group#cluster_name DataAwsEksNodeGroup#cluster_name}.
ClusterName *string `field:"required" json:"clusterName" yaml:"clusterName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/eks_node_group#node_group_name DataAwsEksNodeGroup#node_group_name}.
NodeGroupName *string `field:"required" json:"nodeGroupName" yaml:"nodeGroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/eks_node_group#id DataAwsEksNodeGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/eks_node_group#tags DataAwsEksNodeGroup#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsEksNodeGroupRemoteAccess ¶
type DataAwsEksNodeGroupRemoteAccess struct {
}
type DataAwsEksNodeGroupRemoteAccessList ¶
type DataAwsEksNodeGroupRemoteAccessList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEksNodeGroupRemoteAccessOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEksNodeGroupRemoteAccessList ¶
func NewDataAwsEksNodeGroupRemoteAccessList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEksNodeGroupRemoteAccessList
type DataAwsEksNodeGroupRemoteAccessOutputReference ¶
type DataAwsEksNodeGroupRemoteAccessOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Ec2SshKey() *string
// Experimental.
Fqn() *string
InternalValue() *DataAwsEksNodeGroupRemoteAccess
SetInternalValue(val *DataAwsEksNodeGroupRemoteAccess)
SourceSecurityGroupIds() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEksNodeGroupRemoteAccessOutputReference ¶
func NewDataAwsEksNodeGroupRemoteAccessOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEksNodeGroupRemoteAccessOutputReference
type DataAwsEksNodeGroupResources ¶
type DataAwsEksNodeGroupResources struct {
}
type DataAwsEksNodeGroupResourcesAutoscalingGroups ¶
type DataAwsEksNodeGroupResourcesAutoscalingGroups struct {
}
type DataAwsEksNodeGroupResourcesAutoscalingGroupsList ¶
type DataAwsEksNodeGroupResourcesAutoscalingGroupsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEksNodeGroupResourcesAutoscalingGroupsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEksNodeGroupResourcesAutoscalingGroupsList ¶
func NewDataAwsEksNodeGroupResourcesAutoscalingGroupsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEksNodeGroupResourcesAutoscalingGroupsList
type DataAwsEksNodeGroupResourcesAutoscalingGroupsOutputReference ¶
type DataAwsEksNodeGroupResourcesAutoscalingGroupsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsEksNodeGroupResourcesAutoscalingGroups
SetInternalValue(val *DataAwsEksNodeGroupResourcesAutoscalingGroups)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEksNodeGroupResourcesAutoscalingGroupsOutputReference ¶
func NewDataAwsEksNodeGroupResourcesAutoscalingGroupsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEksNodeGroupResourcesAutoscalingGroupsOutputReference
type DataAwsEksNodeGroupResourcesList ¶
type DataAwsEksNodeGroupResourcesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEksNodeGroupResourcesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEksNodeGroupResourcesList ¶
func NewDataAwsEksNodeGroupResourcesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEksNodeGroupResourcesList
type DataAwsEksNodeGroupResourcesOutputReference ¶
type DataAwsEksNodeGroupResourcesOutputReference interface {
cdktf.ComplexObject
AutoscalingGroups() DataAwsEksNodeGroupResourcesAutoscalingGroupsList
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsEksNodeGroupResources
SetInternalValue(val *DataAwsEksNodeGroupResources)
RemoteAccessSecurityGroupId() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEksNodeGroupResourcesOutputReference ¶
func NewDataAwsEksNodeGroupResourcesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEksNodeGroupResourcesOutputReference
type DataAwsEksNodeGroupScalingConfig ¶
type DataAwsEksNodeGroupScalingConfig struct {
}
type DataAwsEksNodeGroupScalingConfigList ¶
type DataAwsEksNodeGroupScalingConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEksNodeGroupScalingConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEksNodeGroupScalingConfigList ¶
func NewDataAwsEksNodeGroupScalingConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEksNodeGroupScalingConfigList
type DataAwsEksNodeGroupScalingConfigOutputReference ¶
type DataAwsEksNodeGroupScalingConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DesiredSize() *float64
// Experimental.
Fqn() *string
InternalValue() *DataAwsEksNodeGroupScalingConfig
SetInternalValue(val *DataAwsEksNodeGroupScalingConfig)
MaxSize() *float64
MinSize() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEksNodeGroupScalingConfigOutputReference ¶
func NewDataAwsEksNodeGroupScalingConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEksNodeGroupScalingConfigOutputReference
type DataAwsEksNodeGroupTaints ¶
type DataAwsEksNodeGroupTaints struct {
}
type DataAwsEksNodeGroupTaintsList ¶
type DataAwsEksNodeGroupTaintsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEksNodeGroupTaintsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEksNodeGroupTaintsList ¶
func NewDataAwsEksNodeGroupTaintsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEksNodeGroupTaintsList
type DataAwsEksNodeGroupTaintsOutputReference ¶
type DataAwsEksNodeGroupTaintsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Effect() *string
// Experimental.
Fqn() *string
InternalValue() *DataAwsEksNodeGroupTaints
SetInternalValue(val *DataAwsEksNodeGroupTaints)
Key() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEksNodeGroupTaintsOutputReference ¶
func NewDataAwsEksNodeGroupTaintsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEksNodeGroupTaintsOutputReference
Source Files
¶
- dataawseksnodegroup.go
- dataawseksnodegroup_DataAwsEksNodeGroup.go
- dataawseksnodegroup_DataAwsEksNodeGroupConfig.go
- dataawseksnodegroup_DataAwsEksNodeGroupRemoteAccess.go
- dataawseksnodegroup_DataAwsEksNodeGroupRemoteAccessList.go
- dataawseksnodegroup_DataAwsEksNodeGroupRemoteAccessList__runtime_type_checks.go
- dataawseksnodegroup_DataAwsEksNodeGroupRemoteAccessOutputReference.go
- dataawseksnodegroup_DataAwsEksNodeGroupRemoteAccessOutputReference__runtime_type_checks.go
- dataawseksnodegroup_DataAwsEksNodeGroupResources.go
- dataawseksnodegroup_DataAwsEksNodeGroupResourcesAutoscalingGroups.go
- dataawseksnodegroup_DataAwsEksNodeGroupResourcesAutoscalingGroupsList.go
- dataawseksnodegroup_DataAwsEksNodeGroupResourcesAutoscalingGroupsList__runtime_type_checks.go
- dataawseksnodegroup_DataAwsEksNodeGroupResourcesAutoscalingGroupsOutputReference.go
- dataawseksnodegroup_DataAwsEksNodeGroupResourcesAutoscalingGroupsOutputReference__runtime_type_checks.go
- dataawseksnodegroup_DataAwsEksNodeGroupResourcesList.go
- dataawseksnodegroup_DataAwsEksNodeGroupResourcesList__runtime_type_checks.go
- dataawseksnodegroup_DataAwsEksNodeGroupResourcesOutputReference.go
- dataawseksnodegroup_DataAwsEksNodeGroupResourcesOutputReference__runtime_type_checks.go
- dataawseksnodegroup_DataAwsEksNodeGroupScalingConfig.go
- dataawseksnodegroup_DataAwsEksNodeGroupScalingConfigList.go
- dataawseksnodegroup_DataAwsEksNodeGroupScalingConfigList__runtime_type_checks.go
- dataawseksnodegroup_DataAwsEksNodeGroupScalingConfigOutputReference.go
- dataawseksnodegroup_DataAwsEksNodeGroupScalingConfigOutputReference__runtime_type_checks.go
- dataawseksnodegroup_DataAwsEksNodeGroupTaints.go
- dataawseksnodegroup_DataAwsEksNodeGroupTaintsList.go
- dataawseksnodegroup_DataAwsEksNodeGroupTaintsList__runtime_type_checks.go
- dataawseksnodegroup_DataAwsEksNodeGroupTaintsOutputReference.go
- dataawseksnodegroup_DataAwsEksNodeGroupTaintsOutputReference__runtime_type_checks.go
- dataawseksnodegroup_DataAwsEksNodeGroup__runtime_type_checks.go