Documentation
¶
Index ¶
- func DataAwsFsxOpenzfsSnapshot_IsConstruct(x interface{}) *bool
- func DataAwsFsxOpenzfsSnapshot_IsTerraformDataSource(x interface{}) *bool
- func DataAwsFsxOpenzfsSnapshot_IsTerraformElement(x interface{}) *bool
- func DataAwsFsxOpenzfsSnapshot_TfResourceType() *string
- func NewDataAwsFsxOpenzfsSnapshotFilterList_Override(d DataAwsFsxOpenzfsSnapshotFilterList, ...)
- func NewDataAwsFsxOpenzfsSnapshotFilterOutputReference_Override(d DataAwsFsxOpenzfsSnapshotFilterOutputReference, ...)
- func NewDataAwsFsxOpenzfsSnapshot_Override(d DataAwsFsxOpenzfsSnapshot, scope constructs.Construct, id *string, ...)
- type DataAwsFsxOpenzfsSnapshot
- type DataAwsFsxOpenzfsSnapshotConfig
- type DataAwsFsxOpenzfsSnapshotFilter
- type DataAwsFsxOpenzfsSnapshotFilterList
- type DataAwsFsxOpenzfsSnapshotFilterOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsFsxOpenzfsSnapshot_IsConstruct ¶
func DataAwsFsxOpenzfsSnapshot_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsFsxOpenzfsSnapshot_IsTerraformDataSource ¶
func DataAwsFsxOpenzfsSnapshot_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsFsxOpenzfsSnapshot_IsTerraformElement ¶
func DataAwsFsxOpenzfsSnapshot_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsFsxOpenzfsSnapshot_TfResourceType ¶
func DataAwsFsxOpenzfsSnapshot_TfResourceType() *string
func NewDataAwsFsxOpenzfsSnapshotFilterList_Override ¶
func NewDataAwsFsxOpenzfsSnapshotFilterList_Override(d DataAwsFsxOpenzfsSnapshotFilterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsFsxOpenzfsSnapshotFilterOutputReference_Override ¶
func NewDataAwsFsxOpenzfsSnapshotFilterOutputReference_Override(d DataAwsFsxOpenzfsSnapshotFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsFsxOpenzfsSnapshot_Override ¶
func NewDataAwsFsxOpenzfsSnapshot_Override(d DataAwsFsxOpenzfsSnapshot, scope constructs.Construct, id *string, config *DataAwsFsxOpenzfsSnapshotConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/fsx_openzfs_snapshot aws_fsx_openzfs_snapshot} Data Source.
Types ¶
type DataAwsFsxOpenzfsSnapshot ¶
type DataAwsFsxOpenzfsSnapshot interface {
cdktf.TerraformDataSource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreationTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Filter() DataAwsFsxOpenzfsSnapshotFilterList
FilterInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MostRecent() interface{}
SetMostRecent(val interface{})
MostRecentInput() interface{}
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
SnapshotId() *string
SnapshotIds() *[]*string
SetSnapshotIds(val *[]*string)
SnapshotIdsInput() *[]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
VolumeId() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutFilter(value interface{})
ResetFilter()
ResetId()
ResetMostRecent()
ResetName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSnapshotIds()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/fsx_openzfs_snapshot aws_fsx_openzfs_snapshot}.
func NewDataAwsFsxOpenzfsSnapshot ¶
func NewDataAwsFsxOpenzfsSnapshot(scope constructs.Construct, id *string, config *DataAwsFsxOpenzfsSnapshotConfig) DataAwsFsxOpenzfsSnapshot
Create a new {@link https://www.terraform.io/docs/providers/aws/d/fsx_openzfs_snapshot aws_fsx_openzfs_snapshot} Data Source.
type DataAwsFsxOpenzfsSnapshotConfig ¶
type DataAwsFsxOpenzfsSnapshotConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// filter block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/fsx_openzfs_snapshot#filter DataAwsFsxOpenzfsSnapshot#filter}
Filter interface{} `field:"optional" json:"filter" yaml:"filter"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/fsx_openzfs_snapshot#id DataAwsFsxOpenzfsSnapshot#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/fsx_openzfs_snapshot#most_recent DataAwsFsxOpenzfsSnapshot#most_recent}.
MostRecent interface{} `field:"optional" json:"mostRecent" yaml:"mostRecent"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/fsx_openzfs_snapshot#name DataAwsFsxOpenzfsSnapshot#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/fsx_openzfs_snapshot#snapshot_ids DataAwsFsxOpenzfsSnapshot#snapshot_ids}.
SnapshotIds *[]*string `field:"optional" json:"snapshotIds" yaml:"snapshotIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/fsx_openzfs_snapshot#tags DataAwsFsxOpenzfsSnapshot#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsFsxOpenzfsSnapshotFilter ¶
type DataAwsFsxOpenzfsSnapshotFilter struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/fsx_openzfs_snapshot#name DataAwsFsxOpenzfsSnapshot#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/fsx_openzfs_snapshot#values DataAwsFsxOpenzfsSnapshot#values}.
Values *[]*string `field:"required" json:"values" yaml:"values"`
}
type DataAwsFsxOpenzfsSnapshotFilterList ¶
type DataAwsFsxOpenzfsSnapshotFilterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsFsxOpenzfsSnapshotFilterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsFsxOpenzfsSnapshotFilterList ¶
func NewDataAwsFsxOpenzfsSnapshotFilterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsFsxOpenzfsSnapshotFilterList
type DataAwsFsxOpenzfsSnapshotFilterOutputReference ¶
type DataAwsFsxOpenzfsSnapshotFilterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
SetValues(val *[]*string)
ValuesInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsFsxOpenzfsSnapshotFilterOutputReference ¶
func NewDataAwsFsxOpenzfsSnapshotFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsFsxOpenzfsSnapshotFilterOutputReference
Source Files
¶
- dataawsfsxopenzfssnapshot.go
- dataawsfsxopenzfssnapshot_DataAwsFsxOpenzfsSnapshot.go
- dataawsfsxopenzfssnapshot_DataAwsFsxOpenzfsSnapshotConfig.go
- dataawsfsxopenzfssnapshot_DataAwsFsxOpenzfsSnapshotFilter.go
- dataawsfsxopenzfssnapshot_DataAwsFsxOpenzfsSnapshotFilterList.go
- dataawsfsxopenzfssnapshot_DataAwsFsxOpenzfsSnapshotFilterList__runtime_type_checks.go
- dataawsfsxopenzfssnapshot_DataAwsFsxOpenzfsSnapshotFilterOutputReference.go
- dataawsfsxopenzfssnapshot_DataAwsFsxOpenzfsSnapshotFilterOutputReference__runtime_type_checks.go
- dataawsfsxopenzfssnapshot_DataAwsFsxOpenzfsSnapshot__runtime_type_checks.go