Documentation
¶
Index ¶
- func DataAwsIdentitystoreGroup_IsConstruct(x interface{}) *bool
- func DataAwsIdentitystoreGroup_IsTerraformDataSource(x interface{}) *bool
- func DataAwsIdentitystoreGroup_IsTerraformElement(x interface{}) *bool
- func DataAwsIdentitystoreGroup_TfResourceType() *string
- func NewDataAwsIdentitystoreGroupAlternateIdentifierExternalIdOutputReference_Override(d DataAwsIdentitystoreGroupAlternateIdentifierExternalIdOutputReference, ...)
- func NewDataAwsIdentitystoreGroupAlternateIdentifierOutputReference_Override(d DataAwsIdentitystoreGroupAlternateIdentifierOutputReference, ...)
- func NewDataAwsIdentitystoreGroupAlternateIdentifierUniqueAttributeOutputReference_Override(d DataAwsIdentitystoreGroupAlternateIdentifierUniqueAttributeOutputReference, ...)
- func NewDataAwsIdentitystoreGroupExternalIdsList_Override(d DataAwsIdentitystoreGroupExternalIdsList, ...)
- func NewDataAwsIdentitystoreGroupExternalIdsOutputReference_Override(d DataAwsIdentitystoreGroupExternalIdsOutputReference, ...)
- func NewDataAwsIdentitystoreGroupFilterOutputReference_Override(d DataAwsIdentitystoreGroupFilterOutputReference, ...)
- func NewDataAwsIdentitystoreGroup_Override(d DataAwsIdentitystoreGroup, scope constructs.Construct, id *string, ...)
- type DataAwsIdentitystoreGroup
- type DataAwsIdentitystoreGroupAlternateIdentifier
- type DataAwsIdentitystoreGroupAlternateIdentifierExternalId
- type DataAwsIdentitystoreGroupAlternateIdentifierExternalIdOutputReference
- type DataAwsIdentitystoreGroupAlternateIdentifierOutputReference
- type DataAwsIdentitystoreGroupAlternateIdentifierUniqueAttribute
- type DataAwsIdentitystoreGroupAlternateIdentifierUniqueAttributeOutputReference
- type DataAwsIdentitystoreGroupConfig
- type DataAwsIdentitystoreGroupExternalIds
- type DataAwsIdentitystoreGroupExternalIdsList
- type DataAwsIdentitystoreGroupExternalIdsOutputReference
- type DataAwsIdentitystoreGroupFilter
- type DataAwsIdentitystoreGroupFilterOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsIdentitystoreGroup_IsConstruct ¶
func DataAwsIdentitystoreGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsIdentitystoreGroup_IsTerraformDataSource ¶
func DataAwsIdentitystoreGroup_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsIdentitystoreGroup_IsTerraformElement ¶
func DataAwsIdentitystoreGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsIdentitystoreGroup_TfResourceType ¶
func DataAwsIdentitystoreGroup_TfResourceType() *string
func NewDataAwsIdentitystoreGroupAlternateIdentifierExternalIdOutputReference_Override ¶ added in v11.0.1
func NewDataAwsIdentitystoreGroupAlternateIdentifierExternalIdOutputReference_Override(d DataAwsIdentitystoreGroupAlternateIdentifierExternalIdOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsIdentitystoreGroupAlternateIdentifierOutputReference_Override ¶ added in v11.0.1
func NewDataAwsIdentitystoreGroupAlternateIdentifierOutputReference_Override(d DataAwsIdentitystoreGroupAlternateIdentifierOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsIdentitystoreGroupAlternateIdentifierUniqueAttributeOutputReference_Override ¶ added in v11.0.1
func NewDataAwsIdentitystoreGroupAlternateIdentifierUniqueAttributeOutputReference_Override(d DataAwsIdentitystoreGroupAlternateIdentifierUniqueAttributeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsIdentitystoreGroupExternalIdsList_Override ¶ added in v11.0.1
func NewDataAwsIdentitystoreGroupExternalIdsList_Override(d DataAwsIdentitystoreGroupExternalIdsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsIdentitystoreGroupExternalIdsOutputReference_Override ¶ added in v11.0.1
func NewDataAwsIdentitystoreGroupExternalIdsOutputReference_Override(d DataAwsIdentitystoreGroupExternalIdsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsIdentitystoreGroupFilterOutputReference_Override ¶
func NewDataAwsIdentitystoreGroupFilterOutputReference_Override(d DataAwsIdentitystoreGroupFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsIdentitystoreGroup_Override ¶
func NewDataAwsIdentitystoreGroup_Override(d DataAwsIdentitystoreGroup, scope constructs.Construct, id *string, config *DataAwsIdentitystoreGroupConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/identitystore_group aws_identitystore_group} Data Source.
Types ¶
type DataAwsIdentitystoreGroup ¶
type DataAwsIdentitystoreGroup interface {
cdktf.TerraformDataSource
AlternateIdentifier() DataAwsIdentitystoreGroupAlternateIdentifierOutputReference
AlternateIdentifierInput() *DataAwsIdentitystoreGroupAlternateIdentifier
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
DisplayName() *string
ExternalIds() DataAwsIdentitystoreGroupExternalIdsList
Filter() DataAwsIdentitystoreGroupFilterOutputReference
FilterInput() *DataAwsIdentitystoreGroupFilter
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GroupId() *string
SetGroupId(val *string)
GroupIdInput() *string
Id() *string
SetId(val *string)
IdentityStoreId() *string
SetIdentityStoreId(val *string)
IdentityStoreIdInput() *string
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAlternateIdentifier(value *DataAwsIdentitystoreGroupAlternateIdentifier)
PutFilter(value *DataAwsIdentitystoreGroupFilter)
ResetAlternateIdentifier()
ResetFilter()
ResetGroupId()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/identitystore_group aws_identitystore_group}.
func NewDataAwsIdentitystoreGroup ¶
func NewDataAwsIdentitystoreGroup(scope constructs.Construct, id *string, config *DataAwsIdentitystoreGroupConfig) DataAwsIdentitystoreGroup
Create a new {@link https://www.terraform.io/docs/providers/aws/d/identitystore_group aws_identitystore_group} Data Source.
type DataAwsIdentitystoreGroupAlternateIdentifier ¶ added in v11.0.1
type DataAwsIdentitystoreGroupAlternateIdentifier struct {
// external_id block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/identitystore_group#external_id DataAwsIdentitystoreGroup#external_id}
ExternalId *DataAwsIdentitystoreGroupAlternateIdentifierExternalId `field:"optional" json:"externalId" yaml:"externalId"`
// unique_attribute block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/identitystore_group#unique_attribute DataAwsIdentitystoreGroup#unique_attribute}
UniqueAttribute *DataAwsIdentitystoreGroupAlternateIdentifierUniqueAttribute `field:"optional" json:"uniqueAttribute" yaml:"uniqueAttribute"`
}
type DataAwsIdentitystoreGroupAlternateIdentifierExternalId ¶ added in v11.0.1
type DataAwsIdentitystoreGroupAlternateIdentifierExternalId struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/identitystore_group#id DataAwsIdentitystoreGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"required" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/identitystore_group#issuer DataAwsIdentitystoreGroup#issuer}.
Issuer *string `field:"required" json:"issuer" yaml:"issuer"`
}
type DataAwsIdentitystoreGroupAlternateIdentifierExternalIdOutputReference ¶ added in v11.0.1
type DataAwsIdentitystoreGroupAlternateIdentifierExternalIdOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
SetId(val *string)
IdInput() *string
InternalValue() *DataAwsIdentitystoreGroupAlternateIdentifierExternalId
SetInternalValue(val *DataAwsIdentitystoreGroupAlternateIdentifierExternalId)
Issuer() *string
SetIssuer(val *string)
IssuerInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsIdentitystoreGroupAlternateIdentifierExternalIdOutputReference ¶ added in v11.0.1
func NewDataAwsIdentitystoreGroupAlternateIdentifierExternalIdOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsIdentitystoreGroupAlternateIdentifierExternalIdOutputReference
type DataAwsIdentitystoreGroupAlternateIdentifierOutputReference ¶ added in v11.0.1
type DataAwsIdentitystoreGroupAlternateIdentifierOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
ExternalId() DataAwsIdentitystoreGroupAlternateIdentifierExternalIdOutputReference
ExternalIdInput() *DataAwsIdentitystoreGroupAlternateIdentifierExternalId
// Experimental.
Fqn() *string
InternalValue() *DataAwsIdentitystoreGroupAlternateIdentifier
SetInternalValue(val *DataAwsIdentitystoreGroupAlternateIdentifier)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UniqueAttribute() DataAwsIdentitystoreGroupAlternateIdentifierUniqueAttributeOutputReference
UniqueAttributeInput() *DataAwsIdentitystoreGroupAlternateIdentifierUniqueAttribute
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutExternalId(value *DataAwsIdentitystoreGroupAlternateIdentifierExternalId)
PutUniqueAttribute(value *DataAwsIdentitystoreGroupAlternateIdentifierUniqueAttribute)
ResetExternalId()
ResetUniqueAttribute()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsIdentitystoreGroupAlternateIdentifierOutputReference ¶ added in v11.0.1
func NewDataAwsIdentitystoreGroupAlternateIdentifierOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsIdentitystoreGroupAlternateIdentifierOutputReference
type DataAwsIdentitystoreGroupAlternateIdentifierUniqueAttribute ¶ added in v11.0.1
type DataAwsIdentitystoreGroupAlternateIdentifierUniqueAttribute struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/identitystore_group#attribute_path DataAwsIdentitystoreGroup#attribute_path}.
AttributePath *string `field:"required" json:"attributePath" yaml:"attributePath"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/identitystore_group#attribute_value DataAwsIdentitystoreGroup#attribute_value}.
AttributeValue *string `field:"required" json:"attributeValue" yaml:"attributeValue"`
}
type DataAwsIdentitystoreGroupAlternateIdentifierUniqueAttributeOutputReference ¶ added in v11.0.1
type DataAwsIdentitystoreGroupAlternateIdentifierUniqueAttributeOutputReference interface {
cdktf.ComplexObject
AttributePath() *string
SetAttributePath(val *string)
AttributePathInput() *string
AttributeValue() *string
SetAttributeValue(val *string)
AttributeValueInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsIdentitystoreGroupAlternateIdentifierUniqueAttribute
SetInternalValue(val *DataAwsIdentitystoreGroupAlternateIdentifierUniqueAttribute)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsIdentitystoreGroupAlternateIdentifierUniqueAttributeOutputReference ¶ added in v11.0.1
func NewDataAwsIdentitystoreGroupAlternateIdentifierUniqueAttributeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsIdentitystoreGroupAlternateIdentifierUniqueAttributeOutputReference
type DataAwsIdentitystoreGroupConfig ¶
type DataAwsIdentitystoreGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/identitystore_group#identity_store_id DataAwsIdentitystoreGroup#identity_store_id}.
IdentityStoreId *string `field:"required" json:"identityStoreId" yaml:"identityStoreId"`
// alternate_identifier block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/identitystore_group#alternate_identifier DataAwsIdentitystoreGroup#alternate_identifier}
AlternateIdentifier *DataAwsIdentitystoreGroupAlternateIdentifier `field:"optional" json:"alternateIdentifier" yaml:"alternateIdentifier"`
// filter block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/identitystore_group#filter DataAwsIdentitystoreGroup#filter}
Filter *DataAwsIdentitystoreGroupFilter `field:"optional" json:"filter" yaml:"filter"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/identitystore_group#group_id DataAwsIdentitystoreGroup#group_id}.
GroupId *string `field:"optional" json:"groupId" yaml:"groupId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/identitystore_group#id DataAwsIdentitystoreGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type DataAwsIdentitystoreGroupExternalIds ¶ added in v11.0.1
type DataAwsIdentitystoreGroupExternalIds struct {
}
type DataAwsIdentitystoreGroupExternalIdsList ¶ added in v11.0.1
type DataAwsIdentitystoreGroupExternalIdsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsIdentitystoreGroupExternalIdsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsIdentitystoreGroupExternalIdsList ¶ added in v11.0.1
func NewDataAwsIdentitystoreGroupExternalIdsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsIdentitystoreGroupExternalIdsList
type DataAwsIdentitystoreGroupExternalIdsOutputReference ¶ added in v11.0.1
type DataAwsIdentitystoreGroupExternalIdsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *DataAwsIdentitystoreGroupExternalIds
SetInternalValue(val *DataAwsIdentitystoreGroupExternalIds)
Issuer() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsIdentitystoreGroupExternalIdsOutputReference ¶ added in v11.0.1
func NewDataAwsIdentitystoreGroupExternalIdsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsIdentitystoreGroupExternalIdsOutputReference
type DataAwsIdentitystoreGroupFilter ¶
type DataAwsIdentitystoreGroupFilter struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/identitystore_group#attribute_path DataAwsIdentitystoreGroup#attribute_path}.
AttributePath *string `field:"required" json:"attributePath" yaml:"attributePath"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/identitystore_group#attribute_value DataAwsIdentitystoreGroup#attribute_value}.
AttributeValue *string `field:"required" json:"attributeValue" yaml:"attributeValue"`
}
type DataAwsIdentitystoreGroupFilterOutputReference ¶
type DataAwsIdentitystoreGroupFilterOutputReference interface {
cdktf.ComplexObject
AttributePath() *string
SetAttributePath(val *string)
AttributePathInput() *string
AttributeValue() *string
SetAttributeValue(val *string)
AttributeValueInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsIdentitystoreGroupFilter
SetInternalValue(val *DataAwsIdentitystoreGroupFilter)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsIdentitystoreGroupFilterOutputReference ¶
func NewDataAwsIdentitystoreGroupFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsIdentitystoreGroupFilterOutputReference
Source Files
¶
- dataawsidentitystoregroup.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroup.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroupAlternateIdentifier.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroupAlternateIdentifierExternalId.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroupAlternateIdentifierExternalIdOutputReference.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroupAlternateIdentifierExternalIdOutputReference__runtime_type_checks.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroupAlternateIdentifierOutputReference.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroupAlternateIdentifierOutputReference__runtime_type_checks.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroupAlternateIdentifierUniqueAttribute.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroupAlternateIdentifierUniqueAttributeOutputReference.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroupAlternateIdentifierUniqueAttributeOutputReference__runtime_type_checks.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroupConfig.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroupExternalIds.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroupExternalIdsList.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroupExternalIdsList__runtime_type_checks.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroupExternalIdsOutputReference.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroupExternalIdsOutputReference__runtime_type_checks.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroupFilter.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroupFilterOutputReference.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroupFilterOutputReference__runtime_type_checks.go
- dataawsidentitystoregroup_DataAwsIdentitystoreGroup__runtime_type_checks.go