Documentation
¶
Index ¶
- func DataAwsLambdaCodeSigningConfig_IsConstruct(x interface{}) *bool
- func DataAwsLambdaCodeSigningConfig_IsTerraformDataSource(x interface{}) *bool
- func DataAwsLambdaCodeSigningConfig_IsTerraformElement(x interface{}) *bool
- func DataAwsLambdaCodeSigningConfig_TfResourceType() *string
- func NewDataAwsLambdaCodeSigningConfigAllowedPublishersList_Override(d DataAwsLambdaCodeSigningConfigAllowedPublishersList, ...)
- func NewDataAwsLambdaCodeSigningConfigAllowedPublishersOutputReference_Override(d DataAwsLambdaCodeSigningConfigAllowedPublishersOutputReference, ...)
- func NewDataAwsLambdaCodeSigningConfigPoliciesList_Override(d DataAwsLambdaCodeSigningConfigPoliciesList, ...)
- func NewDataAwsLambdaCodeSigningConfigPoliciesOutputReference_Override(d DataAwsLambdaCodeSigningConfigPoliciesOutputReference, ...)
- func NewDataAwsLambdaCodeSigningConfig_Override(d DataAwsLambdaCodeSigningConfig, scope constructs.Construct, id *string, ...)
- type DataAwsLambdaCodeSigningConfig
- type DataAwsLambdaCodeSigningConfigAllowedPublishers
- type DataAwsLambdaCodeSigningConfigAllowedPublishersList
- type DataAwsLambdaCodeSigningConfigAllowedPublishersOutputReference
- type DataAwsLambdaCodeSigningConfigConfig
- type DataAwsLambdaCodeSigningConfigPolicies
- type DataAwsLambdaCodeSigningConfigPoliciesList
- type DataAwsLambdaCodeSigningConfigPoliciesOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsLambdaCodeSigningConfig_IsConstruct ¶
func DataAwsLambdaCodeSigningConfig_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsLambdaCodeSigningConfig_IsTerraformDataSource ¶
func DataAwsLambdaCodeSigningConfig_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsLambdaCodeSigningConfig_IsTerraformElement ¶
func DataAwsLambdaCodeSigningConfig_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsLambdaCodeSigningConfig_TfResourceType ¶
func DataAwsLambdaCodeSigningConfig_TfResourceType() *string
func NewDataAwsLambdaCodeSigningConfigAllowedPublishersList_Override ¶
func NewDataAwsLambdaCodeSigningConfigAllowedPublishersList_Override(d DataAwsLambdaCodeSigningConfigAllowedPublishersList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLambdaCodeSigningConfigAllowedPublishersOutputReference_Override ¶
func NewDataAwsLambdaCodeSigningConfigAllowedPublishersOutputReference_Override(d DataAwsLambdaCodeSigningConfigAllowedPublishersOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLambdaCodeSigningConfigPoliciesList_Override ¶
func NewDataAwsLambdaCodeSigningConfigPoliciesList_Override(d DataAwsLambdaCodeSigningConfigPoliciesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLambdaCodeSigningConfigPoliciesOutputReference_Override ¶
func NewDataAwsLambdaCodeSigningConfigPoliciesOutputReference_Override(d DataAwsLambdaCodeSigningConfigPoliciesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLambdaCodeSigningConfig_Override ¶
func NewDataAwsLambdaCodeSigningConfig_Override(d DataAwsLambdaCodeSigningConfig, scope constructs.Construct, id *string, config *DataAwsLambdaCodeSigningConfigConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/lambda_code_signing_config aws_lambda_code_signing_config} Data Source.
Types ¶
type DataAwsLambdaCodeSigningConfig ¶
type DataAwsLambdaCodeSigningConfig interface {
cdktf.TerraformDataSource
AllowedPublishers() DataAwsLambdaCodeSigningConfigAllowedPublishersList
Arn() *string
SetArn(val *string)
ArnInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ConfigId() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
LastModified() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
Policies() DataAwsLambdaCodeSigningConfigPoliciesList
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/lambda_code_signing_config aws_lambda_code_signing_config}.
func NewDataAwsLambdaCodeSigningConfig ¶
func NewDataAwsLambdaCodeSigningConfig(scope constructs.Construct, id *string, config *DataAwsLambdaCodeSigningConfigConfig) DataAwsLambdaCodeSigningConfig
Create a new {@link https://www.terraform.io/docs/providers/aws/d/lambda_code_signing_config aws_lambda_code_signing_config} Data Source.
type DataAwsLambdaCodeSigningConfigAllowedPublishers ¶
type DataAwsLambdaCodeSigningConfigAllowedPublishers struct {
}
type DataAwsLambdaCodeSigningConfigAllowedPublishersList ¶
type DataAwsLambdaCodeSigningConfigAllowedPublishersList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLambdaCodeSigningConfigAllowedPublishersOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLambdaCodeSigningConfigAllowedPublishersList ¶
func NewDataAwsLambdaCodeSigningConfigAllowedPublishersList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLambdaCodeSigningConfigAllowedPublishersList
type DataAwsLambdaCodeSigningConfigAllowedPublishersOutputReference ¶
type DataAwsLambdaCodeSigningConfigAllowedPublishersOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLambdaCodeSigningConfigAllowedPublishers
SetInternalValue(val *DataAwsLambdaCodeSigningConfigAllowedPublishers)
SigningProfileVersionArns() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLambdaCodeSigningConfigAllowedPublishersOutputReference ¶
func NewDataAwsLambdaCodeSigningConfigAllowedPublishersOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLambdaCodeSigningConfigAllowedPublishersOutputReference
type DataAwsLambdaCodeSigningConfigConfig ¶
type DataAwsLambdaCodeSigningConfigConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lambda_code_signing_config#arn DataAwsLambdaCodeSigningConfig#arn}.
Arn *string `field:"required" json:"arn" yaml:"arn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lambda_code_signing_config#id DataAwsLambdaCodeSigningConfig#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type DataAwsLambdaCodeSigningConfigPolicies ¶
type DataAwsLambdaCodeSigningConfigPolicies struct {
}
type DataAwsLambdaCodeSigningConfigPoliciesList ¶
type DataAwsLambdaCodeSigningConfigPoliciesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLambdaCodeSigningConfigPoliciesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLambdaCodeSigningConfigPoliciesList ¶
func NewDataAwsLambdaCodeSigningConfigPoliciesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLambdaCodeSigningConfigPoliciesList
type DataAwsLambdaCodeSigningConfigPoliciesOutputReference ¶
type DataAwsLambdaCodeSigningConfigPoliciesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLambdaCodeSigningConfigPolicies
SetInternalValue(val *DataAwsLambdaCodeSigningConfigPolicies)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UntrustedArtifactOnDeployment() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLambdaCodeSigningConfigPoliciesOutputReference ¶
func NewDataAwsLambdaCodeSigningConfigPoliciesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLambdaCodeSigningConfigPoliciesOutputReference
Source Files
¶
- dataawslambdacodesigningconfig.go
- dataawslambdacodesigningconfig_DataAwsLambdaCodeSigningConfig.go
- dataawslambdacodesigningconfig_DataAwsLambdaCodeSigningConfigAllowedPublishers.go
- dataawslambdacodesigningconfig_DataAwsLambdaCodeSigningConfigAllowedPublishersList.go
- dataawslambdacodesigningconfig_DataAwsLambdaCodeSigningConfigAllowedPublishersList__runtime_type_checks.go
- dataawslambdacodesigningconfig_DataAwsLambdaCodeSigningConfigAllowedPublishersOutputReference.go
- dataawslambdacodesigningconfig_DataAwsLambdaCodeSigningConfigAllowedPublishersOutputReference__runtime_type_checks.go
- dataawslambdacodesigningconfig_DataAwsLambdaCodeSigningConfigConfig.go
- dataawslambdacodesigningconfig_DataAwsLambdaCodeSigningConfigPolicies.go
- dataawslambdacodesigningconfig_DataAwsLambdaCodeSigningConfigPoliciesList.go
- dataawslambdacodesigningconfig_DataAwsLambdaCodeSigningConfigPoliciesList__runtime_type_checks.go
- dataawslambdacodesigningconfig_DataAwsLambdaCodeSigningConfigPoliciesOutputReference.go
- dataawslambdacodesigningconfig_DataAwsLambdaCodeSigningConfigPoliciesOutputReference__runtime_type_checks.go
- dataawslambdacodesigningconfig_DataAwsLambdaCodeSigningConfig__runtime_type_checks.go