Documentation
¶
Index ¶
- func DataAwsLaunchConfiguration_IsConstruct(x interface{}) *bool
- func DataAwsLaunchConfiguration_IsTerraformDataSource(x interface{}) *bool
- func DataAwsLaunchConfiguration_IsTerraformElement(x interface{}) *bool
- func DataAwsLaunchConfiguration_TfResourceType() *string
- func NewDataAwsLaunchConfigurationEbsBlockDeviceList_Override(d DataAwsLaunchConfigurationEbsBlockDeviceList, ...)
- func NewDataAwsLaunchConfigurationEbsBlockDeviceOutputReference_Override(d DataAwsLaunchConfigurationEbsBlockDeviceOutputReference, ...)
- func NewDataAwsLaunchConfigurationEphemeralBlockDeviceList_Override(d DataAwsLaunchConfigurationEphemeralBlockDeviceList, ...)
- func NewDataAwsLaunchConfigurationEphemeralBlockDeviceOutputReference_Override(d DataAwsLaunchConfigurationEphemeralBlockDeviceOutputReference, ...)
- func NewDataAwsLaunchConfigurationMetadataOptionsList_Override(d DataAwsLaunchConfigurationMetadataOptionsList, ...)
- func NewDataAwsLaunchConfigurationMetadataOptionsOutputReference_Override(d DataAwsLaunchConfigurationMetadataOptionsOutputReference, ...)
- func NewDataAwsLaunchConfigurationRootBlockDeviceList_Override(d DataAwsLaunchConfigurationRootBlockDeviceList, ...)
- func NewDataAwsLaunchConfigurationRootBlockDeviceOutputReference_Override(d DataAwsLaunchConfigurationRootBlockDeviceOutputReference, ...)
- func NewDataAwsLaunchConfiguration_Override(d DataAwsLaunchConfiguration, scope constructs.Construct, id *string, ...)
- type DataAwsLaunchConfiguration
- type DataAwsLaunchConfigurationConfig
- type DataAwsLaunchConfigurationEbsBlockDevice
- type DataAwsLaunchConfigurationEbsBlockDeviceList
- type DataAwsLaunchConfigurationEbsBlockDeviceOutputReference
- type DataAwsLaunchConfigurationEphemeralBlockDevice
- type DataAwsLaunchConfigurationEphemeralBlockDeviceList
- type DataAwsLaunchConfigurationEphemeralBlockDeviceOutputReference
- type DataAwsLaunchConfigurationMetadataOptions
- type DataAwsLaunchConfigurationMetadataOptionsList
- type DataAwsLaunchConfigurationMetadataOptionsOutputReference
- type DataAwsLaunchConfigurationRootBlockDevice
- type DataAwsLaunchConfigurationRootBlockDeviceList
- type DataAwsLaunchConfigurationRootBlockDeviceOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsLaunchConfiguration_IsConstruct ¶
func DataAwsLaunchConfiguration_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsLaunchConfiguration_IsTerraformDataSource ¶
func DataAwsLaunchConfiguration_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsLaunchConfiguration_IsTerraformElement ¶
func DataAwsLaunchConfiguration_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsLaunchConfiguration_TfResourceType ¶
func DataAwsLaunchConfiguration_TfResourceType() *string
func NewDataAwsLaunchConfigurationEbsBlockDeviceList_Override ¶
func NewDataAwsLaunchConfigurationEbsBlockDeviceList_Override(d DataAwsLaunchConfigurationEbsBlockDeviceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLaunchConfigurationEbsBlockDeviceOutputReference_Override ¶
func NewDataAwsLaunchConfigurationEbsBlockDeviceOutputReference_Override(d DataAwsLaunchConfigurationEbsBlockDeviceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLaunchConfigurationEphemeralBlockDeviceList_Override ¶
func NewDataAwsLaunchConfigurationEphemeralBlockDeviceList_Override(d DataAwsLaunchConfigurationEphemeralBlockDeviceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLaunchConfigurationEphemeralBlockDeviceOutputReference_Override ¶
func NewDataAwsLaunchConfigurationEphemeralBlockDeviceOutputReference_Override(d DataAwsLaunchConfigurationEphemeralBlockDeviceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLaunchConfigurationMetadataOptionsList_Override ¶
func NewDataAwsLaunchConfigurationMetadataOptionsList_Override(d DataAwsLaunchConfigurationMetadataOptionsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLaunchConfigurationMetadataOptionsOutputReference_Override ¶
func NewDataAwsLaunchConfigurationMetadataOptionsOutputReference_Override(d DataAwsLaunchConfigurationMetadataOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLaunchConfigurationRootBlockDeviceList_Override ¶
func NewDataAwsLaunchConfigurationRootBlockDeviceList_Override(d DataAwsLaunchConfigurationRootBlockDeviceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLaunchConfigurationRootBlockDeviceOutputReference_Override ¶
func NewDataAwsLaunchConfigurationRootBlockDeviceOutputReference_Override(d DataAwsLaunchConfigurationRootBlockDeviceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLaunchConfiguration_Override ¶
func NewDataAwsLaunchConfiguration_Override(d DataAwsLaunchConfiguration, scope constructs.Construct, id *string, config *DataAwsLaunchConfigurationConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/launch_configuration aws_launch_configuration} Data Source.
Types ¶
type DataAwsLaunchConfiguration ¶
type DataAwsLaunchConfiguration interface {
cdktf.TerraformDataSource
Arn() *string
AssociatePublicIpAddress() cdktf.IResolvable
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EbsBlockDevice() DataAwsLaunchConfigurationEbsBlockDeviceList
EbsOptimized() cdktf.IResolvable
EnableMonitoring() cdktf.IResolvable
EphemeralBlockDevice() DataAwsLaunchConfigurationEphemeralBlockDeviceList
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
IamInstanceProfile() *string
Id() *string
SetId(val *string)
IdInput() *string
ImageId() *string
InstanceType() *string
KeyName() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MetadataOptions() DataAwsLaunchConfigurationMetadataOptionsList
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
PlacementTenancy() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
RootBlockDevice() DataAwsLaunchConfigurationRootBlockDeviceList
SecurityGroups() *[]*string
SpotPrice() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
UserData() *string
VpcClassicLinkId() *string
VpcClassicLinkSecurityGroups() *[]*string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/launch_configuration aws_launch_configuration}.
func NewDataAwsLaunchConfiguration ¶
func NewDataAwsLaunchConfiguration(scope constructs.Construct, id *string, config *DataAwsLaunchConfigurationConfig) DataAwsLaunchConfiguration
Create a new {@link https://www.terraform.io/docs/providers/aws/d/launch_configuration aws_launch_configuration} Data Source.
type DataAwsLaunchConfigurationConfig ¶
type DataAwsLaunchConfigurationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/launch_configuration#name DataAwsLaunchConfiguration#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/launch_configuration#id DataAwsLaunchConfiguration#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type DataAwsLaunchConfigurationEbsBlockDevice ¶
type DataAwsLaunchConfigurationEbsBlockDevice struct {
}
type DataAwsLaunchConfigurationEbsBlockDeviceList ¶
type DataAwsLaunchConfigurationEbsBlockDeviceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLaunchConfigurationEbsBlockDeviceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLaunchConfigurationEbsBlockDeviceList ¶
func NewDataAwsLaunchConfigurationEbsBlockDeviceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLaunchConfigurationEbsBlockDeviceList
type DataAwsLaunchConfigurationEbsBlockDeviceOutputReference ¶
type DataAwsLaunchConfigurationEbsBlockDeviceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeleteOnTermination() cdktf.IResolvable
DeviceName() *string
Encrypted() cdktf.IResolvable
// Experimental.
Fqn() *string
InternalValue() *DataAwsLaunchConfigurationEbsBlockDevice
SetInternalValue(val *DataAwsLaunchConfigurationEbsBlockDevice)
Iops() *float64
NoDevice() cdktf.IResolvable
SnapshotId() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Throughput() *float64
VolumeSize() *float64
VolumeType() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLaunchConfigurationEbsBlockDeviceOutputReference ¶
func NewDataAwsLaunchConfigurationEbsBlockDeviceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLaunchConfigurationEbsBlockDeviceOutputReference
type DataAwsLaunchConfigurationEphemeralBlockDevice ¶
type DataAwsLaunchConfigurationEphemeralBlockDevice struct {
}
type DataAwsLaunchConfigurationEphemeralBlockDeviceList ¶
type DataAwsLaunchConfigurationEphemeralBlockDeviceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLaunchConfigurationEphemeralBlockDeviceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLaunchConfigurationEphemeralBlockDeviceList ¶
func NewDataAwsLaunchConfigurationEphemeralBlockDeviceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLaunchConfigurationEphemeralBlockDeviceList
type DataAwsLaunchConfigurationEphemeralBlockDeviceOutputReference ¶
type DataAwsLaunchConfigurationEphemeralBlockDeviceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeviceName() *string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLaunchConfigurationEphemeralBlockDevice
SetInternalValue(val *DataAwsLaunchConfigurationEphemeralBlockDevice)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VirtualName() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLaunchConfigurationEphemeralBlockDeviceOutputReference ¶
func NewDataAwsLaunchConfigurationEphemeralBlockDeviceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLaunchConfigurationEphemeralBlockDeviceOutputReference
type DataAwsLaunchConfigurationMetadataOptions ¶
type DataAwsLaunchConfigurationMetadataOptions struct {
}
type DataAwsLaunchConfigurationMetadataOptionsList ¶
type DataAwsLaunchConfigurationMetadataOptionsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLaunchConfigurationMetadataOptionsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLaunchConfigurationMetadataOptionsList ¶
func NewDataAwsLaunchConfigurationMetadataOptionsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLaunchConfigurationMetadataOptionsList
type DataAwsLaunchConfigurationMetadataOptionsOutputReference ¶
type DataAwsLaunchConfigurationMetadataOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HttpEndpoint() *string
HttpPutResponseHopLimit() *float64
HttpTokens() *string
InternalValue() *DataAwsLaunchConfigurationMetadataOptions
SetInternalValue(val *DataAwsLaunchConfigurationMetadataOptions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLaunchConfigurationMetadataOptionsOutputReference ¶
func NewDataAwsLaunchConfigurationMetadataOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLaunchConfigurationMetadataOptionsOutputReference
type DataAwsLaunchConfigurationRootBlockDevice ¶
type DataAwsLaunchConfigurationRootBlockDevice struct {
}
type DataAwsLaunchConfigurationRootBlockDeviceList ¶
type DataAwsLaunchConfigurationRootBlockDeviceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLaunchConfigurationRootBlockDeviceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLaunchConfigurationRootBlockDeviceList ¶
func NewDataAwsLaunchConfigurationRootBlockDeviceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLaunchConfigurationRootBlockDeviceList
type DataAwsLaunchConfigurationRootBlockDeviceOutputReference ¶
type DataAwsLaunchConfigurationRootBlockDeviceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeleteOnTermination() cdktf.IResolvable
Encrypted() cdktf.IResolvable
// Experimental.
Fqn() *string
InternalValue() *DataAwsLaunchConfigurationRootBlockDevice
SetInternalValue(val *DataAwsLaunchConfigurationRootBlockDevice)
Iops() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Throughput() *float64
VolumeSize() *float64
VolumeType() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLaunchConfigurationRootBlockDeviceOutputReference ¶
func NewDataAwsLaunchConfigurationRootBlockDeviceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLaunchConfigurationRootBlockDeviceOutputReference
Source Files
¶
- dataawslaunchconfiguration.go
- dataawslaunchconfiguration_DataAwsLaunchConfiguration.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationConfig.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationEbsBlockDevice.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationEbsBlockDeviceList.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationEbsBlockDeviceList__runtime_type_checks.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationEbsBlockDeviceOutputReference.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationEbsBlockDeviceOutputReference__runtime_type_checks.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationEphemeralBlockDevice.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationEphemeralBlockDeviceList.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationEphemeralBlockDeviceList__runtime_type_checks.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationEphemeralBlockDeviceOutputReference.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationEphemeralBlockDeviceOutputReference__runtime_type_checks.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationMetadataOptions.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationMetadataOptionsList.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationMetadataOptionsList__runtime_type_checks.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationMetadataOptionsOutputReference.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationMetadataOptionsOutputReference__runtime_type_checks.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationRootBlockDevice.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationRootBlockDeviceList.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationRootBlockDeviceList__runtime_type_checks.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationRootBlockDeviceOutputReference.go
- dataawslaunchconfiguration_DataAwsLaunchConfigurationRootBlockDeviceOutputReference__runtime_type_checks.go
- dataawslaunchconfiguration_DataAwsLaunchConfiguration__runtime_type_checks.go