Documentation
¶
Index ¶
- func DataAwsMqBrokerInstanceTypeOfferings_IsConstruct(x interface{}) *bool
- func DataAwsMqBrokerInstanceTypeOfferings_IsTerraformDataSource(x interface{}) *bool
- func DataAwsMqBrokerInstanceTypeOfferings_IsTerraformElement(x interface{}) *bool
- func DataAwsMqBrokerInstanceTypeOfferings_TfResourceType() *string
- func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesList_Override(...)
- func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesOutputReference_Override(...)
- func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsList_Override(d DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsList, ...)
- func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsOutputReference_Override(d DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsOutputReference, ...)
- func NewDataAwsMqBrokerInstanceTypeOfferings_Override(d DataAwsMqBrokerInstanceTypeOfferings, scope constructs.Construct, id *string, ...)
- type DataAwsMqBrokerInstanceTypeOfferings
- type DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptions
- type DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZones
- type DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesList
- type DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesOutputReference
- type DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsList
- type DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsOutputReference
- type DataAwsMqBrokerInstanceTypeOfferingsConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsMqBrokerInstanceTypeOfferings_IsConstruct ¶
func DataAwsMqBrokerInstanceTypeOfferings_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsMqBrokerInstanceTypeOfferings_IsTerraformDataSource ¶
func DataAwsMqBrokerInstanceTypeOfferings_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsMqBrokerInstanceTypeOfferings_IsTerraformElement ¶
func DataAwsMqBrokerInstanceTypeOfferings_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsMqBrokerInstanceTypeOfferings_TfResourceType ¶
func DataAwsMqBrokerInstanceTypeOfferings_TfResourceType() *string
func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesList_Override ¶
func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesList_Override(d DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesOutputReference_Override ¶
func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesOutputReference_Override(d DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsList_Override ¶
func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsList_Override(d DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsOutputReference_Override ¶
func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsOutputReference_Override(d DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsMqBrokerInstanceTypeOfferings_Override ¶
func NewDataAwsMqBrokerInstanceTypeOfferings_Override(d DataAwsMqBrokerInstanceTypeOfferings, scope constructs.Construct, id *string, config *DataAwsMqBrokerInstanceTypeOfferingsConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/mq_broker_instance_type_offerings aws_mq_broker_instance_type_offerings} Data Source.
Types ¶
type DataAwsMqBrokerInstanceTypeOfferings ¶
type DataAwsMqBrokerInstanceTypeOfferings interface {
cdktf.TerraformDataSource
BrokerInstanceOptions() DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsList
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EngineType() *string
SetEngineType(val *string)
EngineTypeInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HostInstanceType() *string
SetHostInstanceType(val *string)
HostInstanceTypeInput() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
StorageType() *string
SetStorageType(val *string)
StorageTypeInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetEngineType()
ResetHostInstanceType()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetStorageType()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/mq_broker_instance_type_offerings aws_mq_broker_instance_type_offerings}.
func NewDataAwsMqBrokerInstanceTypeOfferings ¶
func NewDataAwsMqBrokerInstanceTypeOfferings(scope constructs.Construct, id *string, config *DataAwsMqBrokerInstanceTypeOfferingsConfig) DataAwsMqBrokerInstanceTypeOfferings
Create a new {@link https://www.terraform.io/docs/providers/aws/d/mq_broker_instance_type_offerings aws_mq_broker_instance_type_offerings} Data Source.
type DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptions ¶
type DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptions struct {
}
type DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZones ¶
type DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZones struct {
}
type DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesList ¶
type DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesList ¶
func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesList
type DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesOutputReference ¶
type DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZones
SetInternalValue(val *DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZones)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesOutputReference ¶
func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesOutputReference
type DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsList ¶
type DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsList ¶
func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsList
type DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsOutputReference ¶
type DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsOutputReference interface {
cdktf.ComplexObject
AvailabilityZones() DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesList
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EngineType() *string
// Experimental.
Fqn() *string
HostInstanceType() *string
InternalValue() *DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptions
SetInternalValue(val *DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptions)
StorageType() *string
SupportedDeploymentModes() *[]*string
SupportedEngineVersions() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsOutputReference ¶
func NewDataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsOutputReference
type DataAwsMqBrokerInstanceTypeOfferingsConfig ¶
type DataAwsMqBrokerInstanceTypeOfferingsConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/mq_broker_instance_type_offerings#engine_type DataAwsMqBrokerInstanceTypeOfferings#engine_type}.
EngineType *string `field:"optional" json:"engineType" yaml:"engineType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/mq_broker_instance_type_offerings#host_instance_type DataAwsMqBrokerInstanceTypeOfferings#host_instance_type}.
HostInstanceType *string `field:"optional" json:"hostInstanceType" yaml:"hostInstanceType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/mq_broker_instance_type_offerings#id DataAwsMqBrokerInstanceTypeOfferings#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/mq_broker_instance_type_offerings#storage_type DataAwsMqBrokerInstanceTypeOfferings#storage_type}.
StorageType *string `field:"optional" json:"storageType" yaml:"storageType"`
}
Source Files
¶
- dataawsmqbrokerinstancetypeofferings.go
- dataawsmqbrokerinstancetypeofferings_DataAwsMqBrokerInstanceTypeOfferings.go
- dataawsmqbrokerinstancetypeofferings_DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptions.go
- dataawsmqbrokerinstancetypeofferings_DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZones.go
- dataawsmqbrokerinstancetypeofferings_DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesList.go
- dataawsmqbrokerinstancetypeofferings_DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesList__runtime_type_checks.go
- dataawsmqbrokerinstancetypeofferings_DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesOutputReference.go
- dataawsmqbrokerinstancetypeofferings_DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsAvailabilityZonesOutputReference__runtime_type_checks.go
- dataawsmqbrokerinstancetypeofferings_DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsList.go
- dataawsmqbrokerinstancetypeofferings_DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsList__runtime_type_checks.go
- dataawsmqbrokerinstancetypeofferings_DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsOutputReference.go
- dataawsmqbrokerinstancetypeofferings_DataAwsMqBrokerInstanceTypeOfferingsBrokerInstanceOptionsOutputReference__runtime_type_checks.go
- dataawsmqbrokerinstancetypeofferings_DataAwsMqBrokerInstanceTypeOfferingsConfig.go
- dataawsmqbrokerinstancetypeofferings_DataAwsMqBrokerInstanceTypeOfferings__runtime_type_checks.go