Documentation
¶
Index ¶
- func DataAwsSecretsmanagerSecretRotation_IsConstruct(x interface{}) *bool
- func DataAwsSecretsmanagerSecretRotation_IsTerraformDataSource(x interface{}) *bool
- func DataAwsSecretsmanagerSecretRotation_IsTerraformElement(x interface{}) *bool
- func DataAwsSecretsmanagerSecretRotation_TfResourceType() *string
- func NewDataAwsSecretsmanagerSecretRotationRotationRulesList_Override(d DataAwsSecretsmanagerSecretRotationRotationRulesList, ...)
- func NewDataAwsSecretsmanagerSecretRotationRotationRulesOutputReference_Override(d DataAwsSecretsmanagerSecretRotationRotationRulesOutputReference, ...)
- func NewDataAwsSecretsmanagerSecretRotation_Override(d DataAwsSecretsmanagerSecretRotation, scope constructs.Construct, id *string, ...)
- type DataAwsSecretsmanagerSecretRotation
- type DataAwsSecretsmanagerSecretRotationConfig
- type DataAwsSecretsmanagerSecretRotationRotationRules
- type DataAwsSecretsmanagerSecretRotationRotationRulesList
- type DataAwsSecretsmanagerSecretRotationRotationRulesOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsSecretsmanagerSecretRotation_IsConstruct ¶
func DataAwsSecretsmanagerSecretRotation_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsSecretsmanagerSecretRotation_IsTerraformDataSource ¶
func DataAwsSecretsmanagerSecretRotation_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsSecretsmanagerSecretRotation_IsTerraformElement ¶
func DataAwsSecretsmanagerSecretRotation_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsSecretsmanagerSecretRotation_TfResourceType ¶
func DataAwsSecretsmanagerSecretRotation_TfResourceType() *string
func NewDataAwsSecretsmanagerSecretRotationRotationRulesList_Override ¶
func NewDataAwsSecretsmanagerSecretRotationRotationRulesList_Override(d DataAwsSecretsmanagerSecretRotationRotationRulesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsSecretsmanagerSecretRotationRotationRulesOutputReference_Override ¶
func NewDataAwsSecretsmanagerSecretRotationRotationRulesOutputReference_Override(d DataAwsSecretsmanagerSecretRotationRotationRulesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsSecretsmanagerSecretRotation_Override ¶
func NewDataAwsSecretsmanagerSecretRotation_Override(d DataAwsSecretsmanagerSecretRotation, scope constructs.Construct, id *string, config *DataAwsSecretsmanagerSecretRotationConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/secretsmanager_secret_rotation aws_secretsmanager_secret_rotation} Data Source.
Types ¶
type DataAwsSecretsmanagerSecretRotation ¶
type DataAwsSecretsmanagerSecretRotation interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
RotationEnabled() cdktf.IResolvable
RotationLambdaArn() *string
RotationRules() DataAwsSecretsmanagerSecretRotationRotationRulesList
SecretId() *string
SetSecretId(val *string)
SecretIdInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/secretsmanager_secret_rotation aws_secretsmanager_secret_rotation}.
func NewDataAwsSecretsmanagerSecretRotation ¶
func NewDataAwsSecretsmanagerSecretRotation(scope constructs.Construct, id *string, config *DataAwsSecretsmanagerSecretRotationConfig) DataAwsSecretsmanagerSecretRotation
Create a new {@link https://www.terraform.io/docs/providers/aws/d/secretsmanager_secret_rotation aws_secretsmanager_secret_rotation} Data Source.
type DataAwsSecretsmanagerSecretRotationConfig ¶
type DataAwsSecretsmanagerSecretRotationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/secretsmanager_secret_rotation#secret_id DataAwsSecretsmanagerSecretRotation#secret_id}.
SecretId *string `field:"required" json:"secretId" yaml:"secretId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/secretsmanager_secret_rotation#id DataAwsSecretsmanagerSecretRotation#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type DataAwsSecretsmanagerSecretRotationRotationRules ¶
type DataAwsSecretsmanagerSecretRotationRotationRules struct {
}
type DataAwsSecretsmanagerSecretRotationRotationRulesList ¶
type DataAwsSecretsmanagerSecretRotationRotationRulesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsSecretsmanagerSecretRotationRotationRulesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSecretsmanagerSecretRotationRotationRulesList ¶
func NewDataAwsSecretsmanagerSecretRotationRotationRulesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsSecretsmanagerSecretRotationRotationRulesList
type DataAwsSecretsmanagerSecretRotationRotationRulesOutputReference ¶
type DataAwsSecretsmanagerSecretRotationRotationRulesOutputReference interface {
cdktf.ComplexObject
AutomaticallyAfterDays() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsSecretsmanagerSecretRotationRotationRules
SetInternalValue(val *DataAwsSecretsmanagerSecretRotationRotationRules)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSecretsmanagerSecretRotationRotationRulesOutputReference ¶
func NewDataAwsSecretsmanagerSecretRotationRotationRulesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsSecretsmanagerSecretRotationRotationRulesOutputReference
Source Files
¶
- dataawssecretsmanagersecretrotation.go
- dataawssecretsmanagersecretrotation_DataAwsSecretsmanagerSecretRotation.go
- dataawssecretsmanagersecretrotation_DataAwsSecretsmanagerSecretRotationConfig.go
- dataawssecretsmanagersecretrotation_DataAwsSecretsmanagerSecretRotationRotationRules.go
- dataawssecretsmanagersecretrotation_DataAwsSecretsmanagerSecretRotationRotationRulesList.go
- dataawssecretsmanagersecretrotation_DataAwsSecretsmanagerSecretRotationRotationRulesList__runtime_type_checks.go
- dataawssecretsmanagersecretrotation_DataAwsSecretsmanagerSecretRotationRotationRulesOutputReference.go
- dataawssecretsmanagersecretrotation_DataAwsSecretsmanagerSecretRotationRotationRulesOutputReference__runtime_type_checks.go
- dataawssecretsmanagersecretrotation_DataAwsSecretsmanagerSecretRotation__runtime_type_checks.go