Documentation
¶
Index ¶
- func DataAwsSesv2DedicatedIpPool_IsConstruct(x interface{}) *bool
- func DataAwsSesv2DedicatedIpPool_IsTerraformDataSource(x interface{}) *bool
- func DataAwsSesv2DedicatedIpPool_IsTerraformElement(x interface{}) *bool
- func DataAwsSesv2DedicatedIpPool_TfResourceType() *string
- func NewDataAwsSesv2DedicatedIpPoolDedicatedIpsList_Override(d DataAwsSesv2DedicatedIpPoolDedicatedIpsList, ...)
- func NewDataAwsSesv2DedicatedIpPoolDedicatedIpsOutputReference_Override(d DataAwsSesv2DedicatedIpPoolDedicatedIpsOutputReference, ...)
- func NewDataAwsSesv2DedicatedIpPool_Override(d DataAwsSesv2DedicatedIpPool, scope constructs.Construct, id *string, ...)
- type DataAwsSesv2DedicatedIpPool
- type DataAwsSesv2DedicatedIpPoolConfig
- type DataAwsSesv2DedicatedIpPoolDedicatedIps
- type DataAwsSesv2DedicatedIpPoolDedicatedIpsList
- type DataAwsSesv2DedicatedIpPoolDedicatedIpsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsSesv2DedicatedIpPool_IsConstruct ¶
func DataAwsSesv2DedicatedIpPool_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsSesv2DedicatedIpPool_IsTerraformDataSource ¶
func DataAwsSesv2DedicatedIpPool_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsSesv2DedicatedIpPool_IsTerraformElement ¶
func DataAwsSesv2DedicatedIpPool_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsSesv2DedicatedIpPool_TfResourceType ¶
func DataAwsSesv2DedicatedIpPool_TfResourceType() *string
func NewDataAwsSesv2DedicatedIpPoolDedicatedIpsList_Override ¶
func NewDataAwsSesv2DedicatedIpPoolDedicatedIpsList_Override(d DataAwsSesv2DedicatedIpPoolDedicatedIpsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsSesv2DedicatedIpPoolDedicatedIpsOutputReference_Override ¶
func NewDataAwsSesv2DedicatedIpPoolDedicatedIpsOutputReference_Override(d DataAwsSesv2DedicatedIpPoolDedicatedIpsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsSesv2DedicatedIpPool_Override ¶
func NewDataAwsSesv2DedicatedIpPool_Override(d DataAwsSesv2DedicatedIpPool, scope constructs.Construct, id *string, config *DataAwsSesv2DedicatedIpPoolConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/sesv2_dedicated_ip_pool aws_sesv2_dedicated_ip_pool} Data Source.
Types ¶
type DataAwsSesv2DedicatedIpPool ¶
type DataAwsSesv2DedicatedIpPool interface {
cdktf.TerraformDataSource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DedicatedIps() DataAwsSesv2DedicatedIpPoolDedicatedIpsList
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
PoolName() *string
SetPoolName(val *string)
PoolNameInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
ScalingMode() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/sesv2_dedicated_ip_pool aws_sesv2_dedicated_ip_pool}.
func NewDataAwsSesv2DedicatedIpPool ¶
func NewDataAwsSesv2DedicatedIpPool(scope constructs.Construct, id *string, config *DataAwsSesv2DedicatedIpPoolConfig) DataAwsSesv2DedicatedIpPool
Create a new {@link https://www.terraform.io/docs/providers/aws/d/sesv2_dedicated_ip_pool aws_sesv2_dedicated_ip_pool} Data Source.
type DataAwsSesv2DedicatedIpPoolConfig ¶
type DataAwsSesv2DedicatedIpPoolConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/sesv2_dedicated_ip_pool#pool_name DataAwsSesv2DedicatedIpPool#pool_name}.
PoolName *string `field:"required" json:"poolName" yaml:"poolName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/sesv2_dedicated_ip_pool#id DataAwsSesv2DedicatedIpPool#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/sesv2_dedicated_ip_pool#tags DataAwsSesv2DedicatedIpPool#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsSesv2DedicatedIpPoolDedicatedIps ¶
type DataAwsSesv2DedicatedIpPoolDedicatedIps struct {
}
type DataAwsSesv2DedicatedIpPoolDedicatedIpsList ¶
type DataAwsSesv2DedicatedIpPoolDedicatedIpsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsSesv2DedicatedIpPoolDedicatedIpsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSesv2DedicatedIpPoolDedicatedIpsList ¶
func NewDataAwsSesv2DedicatedIpPoolDedicatedIpsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsSesv2DedicatedIpPoolDedicatedIpsList
type DataAwsSesv2DedicatedIpPoolDedicatedIpsOutputReference ¶
type DataAwsSesv2DedicatedIpPoolDedicatedIpsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsSesv2DedicatedIpPoolDedicatedIps
SetInternalValue(val *DataAwsSesv2DedicatedIpPoolDedicatedIps)
Ip() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
WarmupPercentage() *float64
WarmupStatus() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSesv2DedicatedIpPoolDedicatedIpsOutputReference ¶
func NewDataAwsSesv2DedicatedIpPoolDedicatedIpsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsSesv2DedicatedIpPoolDedicatedIpsOutputReference
Source Files
¶
- dataawssesv2dedicatedippool.go
- dataawssesv2dedicatedippool_DataAwsSesv2DedicatedIpPool.go
- dataawssesv2dedicatedippool_DataAwsSesv2DedicatedIpPoolConfig.go
- dataawssesv2dedicatedippool_DataAwsSesv2DedicatedIpPoolDedicatedIps.go
- dataawssesv2dedicatedippool_DataAwsSesv2DedicatedIpPoolDedicatedIpsList.go
- dataawssesv2dedicatedippool_DataAwsSesv2DedicatedIpPoolDedicatedIpsList__runtime_type_checks.go
- dataawssesv2dedicatedippool_DataAwsSesv2DedicatedIpPoolDedicatedIpsOutputReference.go
- dataawssesv2dedicatedippool_DataAwsSesv2DedicatedIpPoolDedicatedIpsOutputReference__runtime_type_checks.go
- dataawssesv2dedicatedippool_DataAwsSesv2DedicatedIpPool__runtime_type_checks.go