Documentation
¶
Index ¶
- func DataAwsSignerSigningJob_IsConstruct(x interface{}) *bool
- func DataAwsSignerSigningJob_IsTerraformDataSource(x interface{}) *bool
- func DataAwsSignerSigningJob_IsTerraformElement(x interface{}) *bool
- func DataAwsSignerSigningJob_TfResourceType() *string
- func NewDataAwsSignerSigningJobRevocationRecordList_Override(d DataAwsSignerSigningJobRevocationRecordList, ...)
- func NewDataAwsSignerSigningJobRevocationRecordOutputReference_Override(d DataAwsSignerSigningJobRevocationRecordOutputReference, ...)
- func NewDataAwsSignerSigningJobSignedObjectList_Override(d DataAwsSignerSigningJobSignedObjectList, ...)
- func NewDataAwsSignerSigningJobSignedObjectOutputReference_Override(d DataAwsSignerSigningJobSignedObjectOutputReference, ...)
- func NewDataAwsSignerSigningJobSignedObjectS3List_Override(d DataAwsSignerSigningJobSignedObjectS3List, ...)
- func NewDataAwsSignerSigningJobSignedObjectS3OutputReference_Override(d DataAwsSignerSigningJobSignedObjectS3OutputReference, ...)
- func NewDataAwsSignerSigningJobSourceList_Override(d DataAwsSignerSigningJobSourceList, ...)
- func NewDataAwsSignerSigningJobSourceOutputReference_Override(d DataAwsSignerSigningJobSourceOutputReference, ...)
- func NewDataAwsSignerSigningJobSourceS3List_Override(d DataAwsSignerSigningJobSourceS3List, ...)
- func NewDataAwsSignerSigningJobSourceS3OutputReference_Override(d DataAwsSignerSigningJobSourceS3OutputReference, ...)
- func NewDataAwsSignerSigningJob_Override(d DataAwsSignerSigningJob, scope constructs.Construct, id *string, ...)
- type DataAwsSignerSigningJob
- type DataAwsSignerSigningJobConfig
- type DataAwsSignerSigningJobRevocationRecord
- type DataAwsSignerSigningJobRevocationRecordList
- type DataAwsSignerSigningJobRevocationRecordOutputReference
- type DataAwsSignerSigningJobSignedObject
- type DataAwsSignerSigningJobSignedObjectList
- type DataAwsSignerSigningJobSignedObjectOutputReference
- type DataAwsSignerSigningJobSignedObjectS3
- type DataAwsSignerSigningJobSignedObjectS3List
- type DataAwsSignerSigningJobSignedObjectS3OutputReference
- type DataAwsSignerSigningJobSource
- type DataAwsSignerSigningJobSourceList
- type DataAwsSignerSigningJobSourceOutputReference
- type DataAwsSignerSigningJobSourceS3
- type DataAwsSignerSigningJobSourceS3List
- type DataAwsSignerSigningJobSourceS3OutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsSignerSigningJob_IsConstruct ¶
func DataAwsSignerSigningJob_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsSignerSigningJob_IsTerraformDataSource ¶
func DataAwsSignerSigningJob_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsSignerSigningJob_IsTerraformElement ¶
func DataAwsSignerSigningJob_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsSignerSigningJob_TfResourceType ¶
func DataAwsSignerSigningJob_TfResourceType() *string
func NewDataAwsSignerSigningJobRevocationRecordList_Override ¶
func NewDataAwsSignerSigningJobRevocationRecordList_Override(d DataAwsSignerSigningJobRevocationRecordList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsSignerSigningJobRevocationRecordOutputReference_Override ¶
func NewDataAwsSignerSigningJobRevocationRecordOutputReference_Override(d DataAwsSignerSigningJobRevocationRecordOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsSignerSigningJobSignedObjectList_Override ¶
func NewDataAwsSignerSigningJobSignedObjectList_Override(d DataAwsSignerSigningJobSignedObjectList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsSignerSigningJobSignedObjectOutputReference_Override ¶
func NewDataAwsSignerSigningJobSignedObjectOutputReference_Override(d DataAwsSignerSigningJobSignedObjectOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsSignerSigningJobSignedObjectS3List_Override ¶
func NewDataAwsSignerSigningJobSignedObjectS3List_Override(d DataAwsSignerSigningJobSignedObjectS3List, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsSignerSigningJobSignedObjectS3OutputReference_Override ¶
func NewDataAwsSignerSigningJobSignedObjectS3OutputReference_Override(d DataAwsSignerSigningJobSignedObjectS3OutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsSignerSigningJobSourceList_Override ¶
func NewDataAwsSignerSigningJobSourceList_Override(d DataAwsSignerSigningJobSourceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsSignerSigningJobSourceOutputReference_Override ¶
func NewDataAwsSignerSigningJobSourceOutputReference_Override(d DataAwsSignerSigningJobSourceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsSignerSigningJobSourceS3List_Override ¶
func NewDataAwsSignerSigningJobSourceS3List_Override(d DataAwsSignerSigningJobSourceS3List, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsSignerSigningJobSourceS3OutputReference_Override ¶
func NewDataAwsSignerSigningJobSourceS3OutputReference_Override(d DataAwsSignerSigningJobSourceS3OutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsSignerSigningJob_Override ¶
func NewDataAwsSignerSigningJob_Override(d DataAwsSignerSigningJob, scope constructs.Construct, id *string, config *DataAwsSignerSigningJobConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/signer_signing_job aws_signer_signing_job} Data Source.
Types ¶
type DataAwsSignerSigningJob ¶
type DataAwsSignerSigningJob interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
CompletedAt() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreatedAt() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
JobId() *string
SetJobId(val *string)
JobIdInput() *string
JobInvoker() *string
JobOwner() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
PlatformDisplayName() *string
PlatformId() *string
ProfileName() *string
ProfileVersion() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
RequestedBy() *string
RevocationRecord() DataAwsSignerSigningJobRevocationRecordList
SignatureExpiresAt() *string
SignedObject() DataAwsSignerSigningJobSignedObjectList
Source() DataAwsSignerSigningJobSourceList
Status() *string
StatusReason() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/signer_signing_job aws_signer_signing_job}.
func NewDataAwsSignerSigningJob ¶
func NewDataAwsSignerSigningJob(scope constructs.Construct, id *string, config *DataAwsSignerSigningJobConfig) DataAwsSignerSigningJob
Create a new {@link https://www.terraform.io/docs/providers/aws/d/signer_signing_job aws_signer_signing_job} Data Source.
type DataAwsSignerSigningJobConfig ¶
type DataAwsSignerSigningJobConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/signer_signing_job#job_id DataAwsSignerSigningJob#job_id}.
JobId *string `field:"required" json:"jobId" yaml:"jobId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/signer_signing_job#id DataAwsSignerSigningJob#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type DataAwsSignerSigningJobRevocationRecord ¶
type DataAwsSignerSigningJobRevocationRecord struct {
}
type DataAwsSignerSigningJobRevocationRecordList ¶
type DataAwsSignerSigningJobRevocationRecordList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsSignerSigningJobRevocationRecordOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSignerSigningJobRevocationRecordList ¶
func NewDataAwsSignerSigningJobRevocationRecordList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsSignerSigningJobRevocationRecordList
type DataAwsSignerSigningJobRevocationRecordOutputReference ¶
type DataAwsSignerSigningJobRevocationRecordOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsSignerSigningJobRevocationRecord
SetInternalValue(val *DataAwsSignerSigningJobRevocationRecord)
Reason() *string
RevokedAt() *string
RevokedBy() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSignerSigningJobRevocationRecordOutputReference ¶
func NewDataAwsSignerSigningJobRevocationRecordOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsSignerSigningJobRevocationRecordOutputReference
type DataAwsSignerSigningJobSignedObject ¶
type DataAwsSignerSigningJobSignedObject struct {
}
type DataAwsSignerSigningJobSignedObjectList ¶
type DataAwsSignerSigningJobSignedObjectList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsSignerSigningJobSignedObjectOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSignerSigningJobSignedObjectList ¶
func NewDataAwsSignerSigningJobSignedObjectList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsSignerSigningJobSignedObjectList
type DataAwsSignerSigningJobSignedObjectOutputReference ¶
type DataAwsSignerSigningJobSignedObjectOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsSignerSigningJobSignedObject
SetInternalValue(val *DataAwsSignerSigningJobSignedObject)
S3() DataAwsSignerSigningJobSignedObjectS3List
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSignerSigningJobSignedObjectOutputReference ¶
func NewDataAwsSignerSigningJobSignedObjectOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsSignerSigningJobSignedObjectOutputReference
type DataAwsSignerSigningJobSignedObjectS3 ¶
type DataAwsSignerSigningJobSignedObjectS3 struct {
}
type DataAwsSignerSigningJobSignedObjectS3List ¶
type DataAwsSignerSigningJobSignedObjectS3List interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsSignerSigningJobSignedObjectS3OutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSignerSigningJobSignedObjectS3List ¶
func NewDataAwsSignerSigningJobSignedObjectS3List(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsSignerSigningJobSignedObjectS3List
type DataAwsSignerSigningJobSignedObjectS3OutputReference ¶
type DataAwsSignerSigningJobSignedObjectS3OutputReference interface {
cdktf.ComplexObject
Bucket() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsSignerSigningJobSignedObjectS3
SetInternalValue(val *DataAwsSignerSigningJobSignedObjectS3)
Key() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSignerSigningJobSignedObjectS3OutputReference ¶
func NewDataAwsSignerSigningJobSignedObjectS3OutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsSignerSigningJobSignedObjectS3OutputReference
type DataAwsSignerSigningJobSource ¶
type DataAwsSignerSigningJobSource struct {
}
type DataAwsSignerSigningJobSourceList ¶
type DataAwsSignerSigningJobSourceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsSignerSigningJobSourceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSignerSigningJobSourceList ¶
func NewDataAwsSignerSigningJobSourceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsSignerSigningJobSourceList
type DataAwsSignerSigningJobSourceOutputReference ¶
type DataAwsSignerSigningJobSourceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsSignerSigningJobSource
SetInternalValue(val *DataAwsSignerSigningJobSource)
S3() DataAwsSignerSigningJobSourceS3List
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSignerSigningJobSourceOutputReference ¶
func NewDataAwsSignerSigningJobSourceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsSignerSigningJobSourceOutputReference
type DataAwsSignerSigningJobSourceS3 ¶
type DataAwsSignerSigningJobSourceS3 struct {
}
type DataAwsSignerSigningJobSourceS3List ¶
type DataAwsSignerSigningJobSourceS3List interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsSignerSigningJobSourceS3OutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSignerSigningJobSourceS3List ¶
func NewDataAwsSignerSigningJobSourceS3List(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsSignerSigningJobSourceS3List
type DataAwsSignerSigningJobSourceS3OutputReference ¶
type DataAwsSignerSigningJobSourceS3OutputReference interface {
cdktf.ComplexObject
Bucket() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsSignerSigningJobSourceS3
SetInternalValue(val *DataAwsSignerSigningJobSourceS3)
Key() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Version() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSignerSigningJobSourceS3OutputReference ¶
func NewDataAwsSignerSigningJobSourceS3OutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsSignerSigningJobSourceS3OutputReference
Source Files
¶
- dataawssignersigningjob.go
- dataawssignersigningjob_DataAwsSignerSigningJob.go
- dataawssignersigningjob_DataAwsSignerSigningJobConfig.go
- dataawssignersigningjob_DataAwsSignerSigningJobRevocationRecord.go
- dataawssignersigningjob_DataAwsSignerSigningJobRevocationRecordList.go
- dataawssignersigningjob_DataAwsSignerSigningJobRevocationRecordList__runtime_type_checks.go
- dataawssignersigningjob_DataAwsSignerSigningJobRevocationRecordOutputReference.go
- dataawssignersigningjob_DataAwsSignerSigningJobRevocationRecordOutputReference__runtime_type_checks.go
- dataawssignersigningjob_DataAwsSignerSigningJobSignedObject.go
- dataawssignersigningjob_DataAwsSignerSigningJobSignedObjectList.go
- dataawssignersigningjob_DataAwsSignerSigningJobSignedObjectList__runtime_type_checks.go
- dataawssignersigningjob_DataAwsSignerSigningJobSignedObjectOutputReference.go
- dataawssignersigningjob_DataAwsSignerSigningJobSignedObjectOutputReference__runtime_type_checks.go
- dataawssignersigningjob_DataAwsSignerSigningJobSignedObjectS3.go
- dataawssignersigningjob_DataAwsSignerSigningJobSignedObjectS3List.go
- dataawssignersigningjob_DataAwsSignerSigningJobSignedObjectS3List__runtime_type_checks.go
- dataawssignersigningjob_DataAwsSignerSigningJobSignedObjectS3OutputReference.go
- dataawssignersigningjob_DataAwsSignerSigningJobSignedObjectS3OutputReference__runtime_type_checks.go
- dataawssignersigningjob_DataAwsSignerSigningJobSource.go
- dataawssignersigningjob_DataAwsSignerSigningJobSourceList.go
- dataawssignersigningjob_DataAwsSignerSigningJobSourceList__runtime_type_checks.go
- dataawssignersigningjob_DataAwsSignerSigningJobSourceOutputReference.go
- dataawssignersigningjob_DataAwsSignerSigningJobSourceOutputReference__runtime_type_checks.go
- dataawssignersigningjob_DataAwsSignerSigningJobSourceS3.go
- dataawssignersigningjob_DataAwsSignerSigningJobSourceS3List.go
- dataawssignersigningjob_DataAwsSignerSigningJobSourceS3List__runtime_type_checks.go
- dataawssignersigningjob_DataAwsSignerSigningJobSourceS3OutputReference.go
- dataawssignersigningjob_DataAwsSignerSigningJobSourceS3OutputReference__runtime_type_checks.go
- dataawssignersigningjob_DataAwsSignerSigningJob__runtime_type_checks.go