Documentation
¶
Index ¶
- func EcsCluster_IsConstruct(x interface{}) *bool
- func EcsCluster_IsTerraformElement(x interface{}) *bool
- func EcsCluster_IsTerraformResource(x interface{}) *bool
- func EcsCluster_TfResourceType() *string
- func NewEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationOutputReference_Override(...)
- func NewEcsClusterConfigurationExecuteCommandConfigurationOutputReference_Override(e EcsClusterConfigurationExecuteCommandConfigurationOutputReference, ...)
- func NewEcsClusterConfigurationOutputReference_Override(e EcsClusterConfigurationOutputReference, ...)
- func NewEcsClusterDefaultCapacityProviderStrategyList_Override(e EcsClusterDefaultCapacityProviderStrategyList, ...)
- func NewEcsClusterDefaultCapacityProviderStrategyOutputReference_Override(e EcsClusterDefaultCapacityProviderStrategyOutputReference, ...)
- func NewEcsClusterServiceConnectDefaultsOutputReference_Override(e EcsClusterServiceConnectDefaultsOutputReference, ...)
- func NewEcsClusterSettingList_Override(e EcsClusterSettingList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewEcsClusterSettingOutputReference_Override(e EcsClusterSettingOutputReference, ...)
- func NewEcsCluster_Override(e EcsCluster, scope constructs.Construct, id *string, config *EcsClusterConfig)
- type EcsCluster
- type EcsClusterConfig
- type EcsClusterConfiguration
- type EcsClusterConfigurationExecuteCommandConfiguration
- type EcsClusterConfigurationExecuteCommandConfigurationLogConfiguration
- type EcsClusterConfigurationExecuteCommandConfigurationLogConfigurationOutputReference
- type EcsClusterConfigurationExecuteCommandConfigurationOutputReference
- type EcsClusterConfigurationOutputReference
- type EcsClusterDefaultCapacityProviderStrategy
- type EcsClusterDefaultCapacityProviderStrategyList
- type EcsClusterDefaultCapacityProviderStrategyOutputReference
- type EcsClusterServiceConnectDefaults
- type EcsClusterServiceConnectDefaultsOutputReference
- type EcsClusterSetting
- type EcsClusterSettingList
- type EcsClusterSettingOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EcsCluster_IsConstruct ¶
func EcsCluster_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func EcsCluster_IsTerraformElement ¶
func EcsCluster_IsTerraformElement(x interface{}) *bool
Experimental.
func EcsCluster_IsTerraformResource ¶
func EcsCluster_IsTerraformResource(x interface{}) *bool
Experimental.
func EcsCluster_TfResourceType ¶
func EcsCluster_TfResourceType() *string
func NewEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationOutputReference_Override ¶
func NewEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationOutputReference_Override(e EcsClusterConfigurationExecuteCommandConfigurationLogConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEcsClusterConfigurationExecuteCommandConfigurationOutputReference_Override ¶
func NewEcsClusterConfigurationExecuteCommandConfigurationOutputReference_Override(e EcsClusterConfigurationExecuteCommandConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEcsClusterConfigurationOutputReference_Override ¶
func NewEcsClusterConfigurationOutputReference_Override(e EcsClusterConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEcsClusterDefaultCapacityProviderStrategyList_Override ¶
func NewEcsClusterDefaultCapacityProviderStrategyList_Override(e EcsClusterDefaultCapacityProviderStrategyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEcsClusterDefaultCapacityProviderStrategyOutputReference_Override ¶
func NewEcsClusterDefaultCapacityProviderStrategyOutputReference_Override(e EcsClusterDefaultCapacityProviderStrategyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEcsClusterServiceConnectDefaultsOutputReference_Override ¶ added in v11.0.3
func NewEcsClusterServiceConnectDefaultsOutputReference_Override(e EcsClusterServiceConnectDefaultsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEcsClusterSettingList_Override ¶
func NewEcsClusterSettingList_Override(e EcsClusterSettingList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEcsClusterSettingOutputReference_Override ¶
func NewEcsClusterSettingOutputReference_Override(e EcsClusterSettingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEcsCluster_Override ¶
func NewEcsCluster_Override(e EcsCluster, scope constructs.Construct, id *string, config *EcsClusterConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster aws_ecs_cluster} Resource.
Types ¶
type EcsCluster ¶
type EcsCluster interface {
cdktf.TerraformResource
Arn() *string
CapacityProviders() *[]*string
SetCapacityProviders(val *[]*string)
CapacityProvidersInput() *[]*string
// Experimental.
CdktfStack() cdktf.TerraformStack
Configuration() EcsClusterConfigurationOutputReference
ConfigurationInput() *EcsClusterConfiguration
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DefaultCapacityProviderStrategy() EcsClusterDefaultCapacityProviderStrategyList
DefaultCapacityProviderStrategyInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ServiceConnectDefaults() EcsClusterServiceConnectDefaultsOutputReference
ServiceConnectDefaultsInput() *EcsClusterServiceConnectDefaults
Setting() EcsClusterSettingList
SettingInput() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutConfiguration(value *EcsClusterConfiguration)
PutDefaultCapacityProviderStrategy(value interface{})
PutServiceConnectDefaults(value *EcsClusterServiceConnectDefaults)
PutSetting(value interface{})
ResetCapacityProviders()
ResetConfiguration()
ResetDefaultCapacityProviderStrategy()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetServiceConnectDefaults()
ResetSetting()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster aws_ecs_cluster}.
func NewEcsCluster ¶
func NewEcsCluster(scope constructs.Construct, id *string, config *EcsClusterConfig) EcsCluster
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster aws_ecs_cluster} Resource.
type EcsClusterConfig ¶
type EcsClusterConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#name EcsCluster#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#capacity_providers EcsCluster#capacity_providers}.
CapacityProviders *[]*string `field:"optional" json:"capacityProviders" yaml:"capacityProviders"`
// configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#configuration EcsCluster#configuration}
Configuration *EcsClusterConfiguration `field:"optional" json:"configuration" yaml:"configuration"`
// default_capacity_provider_strategy block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#default_capacity_provider_strategy EcsCluster#default_capacity_provider_strategy}
DefaultCapacityProviderStrategy interface{} `field:"optional" json:"defaultCapacityProviderStrategy" yaml:"defaultCapacityProviderStrategy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#id EcsCluster#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// service_connect_defaults block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#service_connect_defaults EcsCluster#service_connect_defaults}
ServiceConnectDefaults *EcsClusterServiceConnectDefaults `field:"optional" json:"serviceConnectDefaults" yaml:"serviceConnectDefaults"`
// setting block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#setting EcsCluster#setting}
Setting interface{} `field:"optional" json:"setting" yaml:"setting"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#tags EcsCluster#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#tags_all EcsCluster#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type EcsClusterConfiguration ¶
type EcsClusterConfiguration struct {
// execute_command_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#execute_command_configuration EcsCluster#execute_command_configuration}
ExecuteCommandConfiguration *EcsClusterConfigurationExecuteCommandConfiguration `field:"optional" json:"executeCommandConfiguration" yaml:"executeCommandConfiguration"`
}
type EcsClusterConfigurationExecuteCommandConfiguration ¶
type EcsClusterConfigurationExecuteCommandConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#kms_key_id EcsCluster#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
// log_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#log_configuration EcsCluster#log_configuration}
LogConfiguration *EcsClusterConfigurationExecuteCommandConfigurationLogConfiguration `field:"optional" json:"logConfiguration" yaml:"logConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#logging EcsCluster#logging}.
Logging *string `field:"optional" json:"logging" yaml:"logging"`
}
type EcsClusterConfigurationExecuteCommandConfigurationLogConfiguration ¶
type EcsClusterConfigurationExecuteCommandConfigurationLogConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#cloud_watch_encryption_enabled EcsCluster#cloud_watch_encryption_enabled}.
CloudWatchEncryptionEnabled interface{} `field:"optional" json:"cloudWatchEncryptionEnabled" yaml:"cloudWatchEncryptionEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#cloud_watch_log_group_name EcsCluster#cloud_watch_log_group_name}.
CloudWatchLogGroupName *string `field:"optional" json:"cloudWatchLogGroupName" yaml:"cloudWatchLogGroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#s3_bucket_encryption_enabled EcsCluster#s3_bucket_encryption_enabled}.
S3BucketEncryptionEnabled interface{} `field:"optional" json:"s3BucketEncryptionEnabled" yaml:"s3BucketEncryptionEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#s3_bucket_name EcsCluster#s3_bucket_name}.
S3BucketName *string `field:"optional" json:"s3BucketName" yaml:"s3BucketName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#s3_key_prefix EcsCluster#s3_key_prefix}.
S3KeyPrefix *string `field:"optional" json:"s3KeyPrefix" yaml:"s3KeyPrefix"`
}
type EcsClusterConfigurationExecuteCommandConfigurationLogConfigurationOutputReference ¶
type EcsClusterConfigurationExecuteCommandConfigurationLogConfigurationOutputReference interface {
cdktf.ComplexObject
CloudWatchEncryptionEnabled() interface{}
SetCloudWatchEncryptionEnabled(val interface{})
CloudWatchEncryptionEnabledInput() interface{}
CloudWatchLogGroupName() *string
SetCloudWatchLogGroupName(val *string)
CloudWatchLogGroupNameInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EcsClusterConfigurationExecuteCommandConfigurationLogConfiguration
SetInternalValue(val *EcsClusterConfigurationExecuteCommandConfigurationLogConfiguration)
S3BucketEncryptionEnabled() interface{}
SetS3BucketEncryptionEnabled(val interface{})
S3BucketEncryptionEnabledInput() interface{}
S3BucketName() *string
SetS3BucketName(val *string)
S3BucketNameInput() *string
S3KeyPrefix() *string
SetS3KeyPrefix(val *string)
S3KeyPrefixInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCloudWatchEncryptionEnabled()
ResetCloudWatchLogGroupName()
ResetS3BucketEncryptionEnabled()
ResetS3BucketName()
ResetS3KeyPrefix()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationOutputReference ¶
func NewEcsClusterConfigurationExecuteCommandConfigurationLogConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EcsClusterConfigurationExecuteCommandConfigurationLogConfigurationOutputReference
type EcsClusterConfigurationExecuteCommandConfigurationOutputReference ¶
type EcsClusterConfigurationExecuteCommandConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EcsClusterConfigurationExecuteCommandConfiguration
SetInternalValue(val *EcsClusterConfigurationExecuteCommandConfiguration)
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
LogConfiguration() EcsClusterConfigurationExecuteCommandConfigurationLogConfigurationOutputReference
LogConfigurationInput() *EcsClusterConfigurationExecuteCommandConfigurationLogConfiguration
Logging() *string
SetLogging(val *string)
LoggingInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutLogConfiguration(value *EcsClusterConfigurationExecuteCommandConfigurationLogConfiguration)
ResetKmsKeyId()
ResetLogConfiguration()
ResetLogging()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcsClusterConfigurationExecuteCommandConfigurationOutputReference ¶
func NewEcsClusterConfigurationExecuteCommandConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EcsClusterConfigurationExecuteCommandConfigurationOutputReference
type EcsClusterConfigurationOutputReference ¶
type EcsClusterConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
ExecuteCommandConfiguration() EcsClusterConfigurationExecuteCommandConfigurationOutputReference
ExecuteCommandConfigurationInput() *EcsClusterConfigurationExecuteCommandConfiguration
// Experimental.
Fqn() *string
InternalValue() *EcsClusterConfiguration
SetInternalValue(val *EcsClusterConfiguration)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutExecuteCommandConfiguration(value *EcsClusterConfigurationExecuteCommandConfiguration)
ResetExecuteCommandConfiguration()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcsClusterConfigurationOutputReference ¶
func NewEcsClusterConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EcsClusterConfigurationOutputReference
type EcsClusterDefaultCapacityProviderStrategy ¶
type EcsClusterDefaultCapacityProviderStrategy struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#capacity_provider EcsCluster#capacity_provider}.
CapacityProvider *string `field:"required" json:"capacityProvider" yaml:"capacityProvider"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#base EcsCluster#base}.
Base *float64 `field:"optional" json:"base" yaml:"base"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#weight EcsCluster#weight}.
Weight *float64 `field:"optional" json:"weight" yaml:"weight"`
}
type EcsClusterDefaultCapacityProviderStrategyList ¶
type EcsClusterDefaultCapacityProviderStrategyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EcsClusterDefaultCapacityProviderStrategyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcsClusterDefaultCapacityProviderStrategyList ¶
func NewEcsClusterDefaultCapacityProviderStrategyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EcsClusterDefaultCapacityProviderStrategyList
type EcsClusterDefaultCapacityProviderStrategyOutputReference ¶
type EcsClusterDefaultCapacityProviderStrategyOutputReference interface {
cdktf.ComplexObject
Base() *float64
SetBase(val *float64)
BaseInput() *float64
CapacityProvider() *string
SetCapacityProvider(val *string)
CapacityProviderInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Weight() *float64
SetWeight(val *float64)
WeightInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBase()
ResetWeight()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcsClusterDefaultCapacityProviderStrategyOutputReference ¶
func NewEcsClusterDefaultCapacityProviderStrategyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EcsClusterDefaultCapacityProviderStrategyOutputReference
type EcsClusterServiceConnectDefaults ¶ added in v11.0.3
type EcsClusterServiceConnectDefaults struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#namespace EcsCluster#namespace}.
Namespace *string `field:"required" json:"namespace" yaml:"namespace"`
}
type EcsClusterServiceConnectDefaultsOutputReference ¶ added in v11.0.3
type EcsClusterServiceConnectDefaultsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EcsClusterServiceConnectDefaults
SetInternalValue(val *EcsClusterServiceConnectDefaults)
Namespace() *string
SetNamespace(val *string)
NamespaceInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcsClusterServiceConnectDefaultsOutputReference ¶ added in v11.0.3
func NewEcsClusterServiceConnectDefaultsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EcsClusterServiceConnectDefaultsOutputReference
type EcsClusterSetting ¶
type EcsClusterSetting struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#name EcsCluster#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#value EcsCluster#value}.
Value *string `field:"required" json:"value" yaml:"value"`
}
type EcsClusterSettingList ¶
type EcsClusterSettingList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EcsClusterSettingOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcsClusterSettingList ¶
func NewEcsClusterSettingList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EcsClusterSettingList
type EcsClusterSettingOutputReference ¶
type EcsClusterSettingOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcsClusterSettingOutputReference ¶
func NewEcsClusterSettingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EcsClusterSettingOutputReference
Source Files
¶
- ecscluster.go
- ecscluster_EcsCluster.go
- ecscluster_EcsClusterConfig.go
- ecscluster_EcsClusterConfiguration.go
- ecscluster_EcsClusterConfigurationExecuteCommandConfiguration.go
- ecscluster_EcsClusterConfigurationExecuteCommandConfigurationLogConfiguration.go
- ecscluster_EcsClusterConfigurationExecuteCommandConfigurationLogConfigurationOutputReference.go
- ecscluster_EcsClusterConfigurationExecuteCommandConfigurationLogConfigurationOutputReference__runtime_type_checks.go
- ecscluster_EcsClusterConfigurationExecuteCommandConfigurationOutputReference.go
- ecscluster_EcsClusterConfigurationExecuteCommandConfigurationOutputReference__runtime_type_checks.go
- ecscluster_EcsClusterConfigurationOutputReference.go
- ecscluster_EcsClusterConfigurationOutputReference__runtime_type_checks.go
- ecscluster_EcsClusterDefaultCapacityProviderStrategy.go
- ecscluster_EcsClusterDefaultCapacityProviderStrategyList.go
- ecscluster_EcsClusterDefaultCapacityProviderStrategyList__runtime_type_checks.go
- ecscluster_EcsClusterDefaultCapacityProviderStrategyOutputReference.go
- ecscluster_EcsClusterDefaultCapacityProviderStrategyOutputReference__runtime_type_checks.go
- ecscluster_EcsClusterServiceConnectDefaults.go
- ecscluster_EcsClusterServiceConnectDefaultsOutputReference.go
- ecscluster_EcsClusterServiceConnectDefaultsOutputReference__runtime_type_checks.go
- ecscluster_EcsClusterSetting.go
- ecscluster_EcsClusterSettingList.go
- ecscluster_EcsClusterSettingList__runtime_type_checks.go
- ecscluster_EcsClusterSettingOutputReference.go
- ecscluster_EcsClusterSettingOutputReference__runtime_type_checks.go
- ecscluster_EcsCluster__runtime_type_checks.go