Documentation
¶
Index ¶
- func EcsClusterCapacityProviders_IsConstruct(x interface{}) *bool
- func EcsClusterCapacityProviders_IsTerraformElement(x interface{}) *bool
- func EcsClusterCapacityProviders_IsTerraformResource(x interface{}) *bool
- func EcsClusterCapacityProviders_TfResourceType() *string
- func NewEcsClusterCapacityProvidersDefaultCapacityProviderStrategyList_Override(e EcsClusterCapacityProvidersDefaultCapacityProviderStrategyList, ...)
- func NewEcsClusterCapacityProvidersDefaultCapacityProviderStrategyOutputReference_Override(e EcsClusterCapacityProvidersDefaultCapacityProviderStrategyOutputReference, ...)
- func NewEcsClusterCapacityProviders_Override(e EcsClusterCapacityProviders, scope constructs.Construct, id *string, ...)
- type EcsClusterCapacityProviders
- type EcsClusterCapacityProvidersConfig
- type EcsClusterCapacityProvidersDefaultCapacityProviderStrategy
- type EcsClusterCapacityProvidersDefaultCapacityProviderStrategyList
- type EcsClusterCapacityProvidersDefaultCapacityProviderStrategyOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EcsClusterCapacityProviders_IsConstruct ¶
func EcsClusterCapacityProviders_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func EcsClusterCapacityProviders_IsTerraformElement ¶
func EcsClusterCapacityProviders_IsTerraformElement(x interface{}) *bool
Experimental.
func EcsClusterCapacityProviders_IsTerraformResource ¶
func EcsClusterCapacityProviders_IsTerraformResource(x interface{}) *bool
Experimental.
func EcsClusterCapacityProviders_TfResourceType ¶
func EcsClusterCapacityProviders_TfResourceType() *string
func NewEcsClusterCapacityProvidersDefaultCapacityProviderStrategyList_Override ¶
func NewEcsClusterCapacityProvidersDefaultCapacityProviderStrategyList_Override(e EcsClusterCapacityProvidersDefaultCapacityProviderStrategyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEcsClusterCapacityProvidersDefaultCapacityProviderStrategyOutputReference_Override ¶
func NewEcsClusterCapacityProvidersDefaultCapacityProviderStrategyOutputReference_Override(e EcsClusterCapacityProvidersDefaultCapacityProviderStrategyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEcsClusterCapacityProviders_Override ¶
func NewEcsClusterCapacityProviders_Override(e EcsClusterCapacityProviders, scope constructs.Construct, id *string, config *EcsClusterCapacityProvidersConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster_capacity_providers aws_ecs_cluster_capacity_providers} Resource.
Types ¶
type EcsClusterCapacityProviders ¶
type EcsClusterCapacityProviders interface {
cdktf.TerraformResource
CapacityProviders() *[]*string
SetCapacityProviders(val *[]*string)
CapacityProvidersInput() *[]*string
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterName() *string
SetClusterName(val *string)
ClusterNameInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DefaultCapacityProviderStrategy() EcsClusterCapacityProvidersDefaultCapacityProviderStrategyList
DefaultCapacityProviderStrategyInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDefaultCapacityProviderStrategy(value interface{})
ResetCapacityProviders()
ResetDefaultCapacityProviderStrategy()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster_capacity_providers aws_ecs_cluster_capacity_providers}.
func NewEcsClusterCapacityProviders ¶
func NewEcsClusterCapacityProviders(scope constructs.Construct, id *string, config *EcsClusterCapacityProvidersConfig) EcsClusterCapacityProviders
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster_capacity_providers aws_ecs_cluster_capacity_providers} Resource.
type EcsClusterCapacityProvidersConfig ¶
type EcsClusterCapacityProvidersConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster_capacity_providers#cluster_name EcsClusterCapacityProviders#cluster_name}.
ClusterName *string `field:"required" json:"clusterName" yaml:"clusterName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster_capacity_providers#capacity_providers EcsClusterCapacityProviders#capacity_providers}.
CapacityProviders *[]*string `field:"optional" json:"capacityProviders" yaml:"capacityProviders"`
// default_capacity_provider_strategy block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster_capacity_providers#default_capacity_provider_strategy EcsClusterCapacityProviders#default_capacity_provider_strategy}
DefaultCapacityProviderStrategy interface{} `field:"optional" json:"defaultCapacityProviderStrategy" yaml:"defaultCapacityProviderStrategy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster_capacity_providers#id EcsClusterCapacityProviders#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type EcsClusterCapacityProvidersDefaultCapacityProviderStrategy ¶
type EcsClusterCapacityProvidersDefaultCapacityProviderStrategy struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster_capacity_providers#capacity_provider EcsClusterCapacityProviders#capacity_provider}.
CapacityProvider *string `field:"required" json:"capacityProvider" yaml:"capacityProvider"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster_capacity_providers#base EcsClusterCapacityProviders#base}.
Base *float64 `field:"optional" json:"base" yaml:"base"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster_capacity_providers#weight EcsClusterCapacityProviders#weight}.
Weight *float64 `field:"optional" json:"weight" yaml:"weight"`
}
type EcsClusterCapacityProvidersDefaultCapacityProviderStrategyList ¶
type EcsClusterCapacityProvidersDefaultCapacityProviderStrategyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EcsClusterCapacityProvidersDefaultCapacityProviderStrategyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcsClusterCapacityProvidersDefaultCapacityProviderStrategyList ¶
func NewEcsClusterCapacityProvidersDefaultCapacityProviderStrategyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EcsClusterCapacityProvidersDefaultCapacityProviderStrategyList
type EcsClusterCapacityProvidersDefaultCapacityProviderStrategyOutputReference ¶
type EcsClusterCapacityProvidersDefaultCapacityProviderStrategyOutputReference interface {
cdktf.ComplexObject
Base() *float64
SetBase(val *float64)
BaseInput() *float64
CapacityProvider() *string
SetCapacityProvider(val *string)
CapacityProviderInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Weight() *float64
SetWeight(val *float64)
WeightInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBase()
ResetWeight()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcsClusterCapacityProvidersDefaultCapacityProviderStrategyOutputReference ¶
func NewEcsClusterCapacityProvidersDefaultCapacityProviderStrategyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EcsClusterCapacityProvidersDefaultCapacityProviderStrategyOutputReference
Source Files
¶
- ecsclustercapacityproviders.go
- ecsclustercapacityproviders_EcsClusterCapacityProviders.go
- ecsclustercapacityproviders_EcsClusterCapacityProvidersConfig.go
- ecsclustercapacityproviders_EcsClusterCapacityProvidersDefaultCapacityProviderStrategy.go
- ecsclustercapacityproviders_EcsClusterCapacityProvidersDefaultCapacityProviderStrategyList.go
- ecsclustercapacityproviders_EcsClusterCapacityProvidersDefaultCapacityProviderStrategyList__runtime_type_checks.go
- ecsclustercapacityproviders_EcsClusterCapacityProvidersDefaultCapacityProviderStrategyOutputReference.go
- ecsclustercapacityproviders_EcsClusterCapacityProvidersDefaultCapacityProviderStrategyOutputReference__runtime_type_checks.go
- ecsclustercapacityproviders_EcsClusterCapacityProviders__runtime_type_checks.go