Documentation
¶
Index ¶
- func EcsTaskSet_IsConstruct(x interface{}) *bool
- func EcsTaskSet_IsTerraformElement(x interface{}) *bool
- func EcsTaskSet_IsTerraformResource(x interface{}) *bool
- func EcsTaskSet_TfResourceType() *string
- func NewEcsTaskSetCapacityProviderStrategyList_Override(e EcsTaskSetCapacityProviderStrategyList, ...)
- func NewEcsTaskSetCapacityProviderStrategyOutputReference_Override(e EcsTaskSetCapacityProviderStrategyOutputReference, ...)
- func NewEcsTaskSetLoadBalancerList_Override(e EcsTaskSetLoadBalancerList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewEcsTaskSetLoadBalancerOutputReference_Override(e EcsTaskSetLoadBalancerOutputReference, ...)
- func NewEcsTaskSetNetworkConfigurationOutputReference_Override(e EcsTaskSetNetworkConfigurationOutputReference, ...)
- func NewEcsTaskSetScaleOutputReference_Override(e EcsTaskSetScaleOutputReference, terraformResource cdktf.IInterpolatingParent, ...)
- func NewEcsTaskSetServiceRegistriesOutputReference_Override(e EcsTaskSetServiceRegistriesOutputReference, ...)
- func NewEcsTaskSet_Override(e EcsTaskSet, scope constructs.Construct, id *string, config *EcsTaskSetConfig)
- type EcsTaskSet
- type EcsTaskSetCapacityProviderStrategy
- type EcsTaskSetCapacityProviderStrategyList
- type EcsTaskSetCapacityProviderStrategyOutputReference
- type EcsTaskSetConfig
- type EcsTaskSetLoadBalancer
- type EcsTaskSetLoadBalancerList
- type EcsTaskSetLoadBalancerOutputReference
- type EcsTaskSetNetworkConfiguration
- type EcsTaskSetNetworkConfigurationOutputReference
- type EcsTaskSetScale
- type EcsTaskSetScaleOutputReference
- type EcsTaskSetServiceRegistries
- type EcsTaskSetServiceRegistriesOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EcsTaskSet_IsConstruct ¶
func EcsTaskSet_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func EcsTaskSet_IsTerraformElement ¶
func EcsTaskSet_IsTerraformElement(x interface{}) *bool
Experimental.
func EcsTaskSet_IsTerraformResource ¶
func EcsTaskSet_IsTerraformResource(x interface{}) *bool
Experimental.
func EcsTaskSet_TfResourceType ¶
func EcsTaskSet_TfResourceType() *string
func NewEcsTaskSetCapacityProviderStrategyList_Override ¶
func NewEcsTaskSetCapacityProviderStrategyList_Override(e EcsTaskSetCapacityProviderStrategyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEcsTaskSetCapacityProviderStrategyOutputReference_Override ¶
func NewEcsTaskSetCapacityProviderStrategyOutputReference_Override(e EcsTaskSetCapacityProviderStrategyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEcsTaskSetLoadBalancerList_Override ¶
func NewEcsTaskSetLoadBalancerList_Override(e EcsTaskSetLoadBalancerList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEcsTaskSetLoadBalancerOutputReference_Override ¶
func NewEcsTaskSetLoadBalancerOutputReference_Override(e EcsTaskSetLoadBalancerOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEcsTaskSetNetworkConfigurationOutputReference_Override ¶
func NewEcsTaskSetNetworkConfigurationOutputReference_Override(e EcsTaskSetNetworkConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEcsTaskSetScaleOutputReference_Override ¶
func NewEcsTaskSetScaleOutputReference_Override(e EcsTaskSetScaleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEcsTaskSetServiceRegistriesOutputReference_Override ¶
func NewEcsTaskSetServiceRegistriesOutputReference_Override(e EcsTaskSetServiceRegistriesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEcsTaskSet_Override ¶
func NewEcsTaskSet_Override(e EcsTaskSet, scope constructs.Construct, id *string, config *EcsTaskSetConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set aws_ecs_task_set} Resource.
Types ¶
type EcsTaskSet ¶
type EcsTaskSet interface {
cdktf.TerraformResource
Arn() *string
CapacityProviderStrategy() EcsTaskSetCapacityProviderStrategyList
CapacityProviderStrategyInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
Cluster() *string
SetCluster(val *string)
ClusterInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
ExternalId() *string
SetExternalId(val *string)
ExternalIdInput() *string
ForceDelete() interface{}
SetForceDelete(val interface{})
ForceDeleteInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
LaunchType() *string
SetLaunchType(val *string)
LaunchTypeInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LoadBalancer() EcsTaskSetLoadBalancerList
LoadBalancerInput() interface{}
NetworkConfiguration() EcsTaskSetNetworkConfigurationOutputReference
NetworkConfigurationInput() *EcsTaskSetNetworkConfiguration
// The tree node.
Node() constructs.Node
PlatformVersion() *string
SetPlatformVersion(val *string)
PlatformVersionInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Scale() EcsTaskSetScaleOutputReference
ScaleInput() *EcsTaskSetScale
Service() *string
SetService(val *string)
ServiceInput() *string
ServiceRegistries() EcsTaskSetServiceRegistriesOutputReference
ServiceRegistriesInput() *EcsTaskSetServiceRegistries
StabilityStatus() *string
Status() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
TaskDefinition() *string
SetTaskDefinition(val *string)
TaskDefinitionInput() *string
TaskSetId() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
WaitUntilStable() interface{}
SetWaitUntilStable(val interface{})
WaitUntilStableInput() interface{}
WaitUntilStableTimeout() *string
SetWaitUntilStableTimeout(val *string)
WaitUntilStableTimeoutInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCapacityProviderStrategy(value interface{})
PutLoadBalancer(value interface{})
PutNetworkConfiguration(value *EcsTaskSetNetworkConfiguration)
PutScale(value *EcsTaskSetScale)
PutServiceRegistries(value *EcsTaskSetServiceRegistries)
ResetCapacityProviderStrategy()
ResetExternalId()
ResetForceDelete()
ResetId()
ResetLaunchType()
ResetLoadBalancer()
ResetNetworkConfiguration()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPlatformVersion()
ResetScale()
ResetServiceRegistries()
ResetTags()
ResetTagsAll()
ResetWaitUntilStable()
ResetWaitUntilStableTimeout()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set aws_ecs_task_set}.
func NewEcsTaskSet ¶
func NewEcsTaskSet(scope constructs.Construct, id *string, config *EcsTaskSetConfig) EcsTaskSet
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set aws_ecs_task_set} Resource.
type EcsTaskSetCapacityProviderStrategy ¶
type EcsTaskSetCapacityProviderStrategy struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#capacity_provider EcsTaskSet#capacity_provider}.
CapacityProvider *string `field:"required" json:"capacityProvider" yaml:"capacityProvider"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#weight EcsTaskSet#weight}.
Weight *float64 `field:"required" json:"weight" yaml:"weight"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#base EcsTaskSet#base}.
Base *float64 `field:"optional" json:"base" yaml:"base"`
}
type EcsTaskSetCapacityProviderStrategyList ¶
type EcsTaskSetCapacityProviderStrategyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EcsTaskSetCapacityProviderStrategyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcsTaskSetCapacityProviderStrategyList ¶
func NewEcsTaskSetCapacityProviderStrategyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EcsTaskSetCapacityProviderStrategyList
type EcsTaskSetCapacityProviderStrategyOutputReference ¶
type EcsTaskSetCapacityProviderStrategyOutputReference interface {
cdktf.ComplexObject
Base() *float64
SetBase(val *float64)
BaseInput() *float64
CapacityProvider() *string
SetCapacityProvider(val *string)
CapacityProviderInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Weight() *float64
SetWeight(val *float64)
WeightInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBase()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcsTaskSetCapacityProviderStrategyOutputReference ¶
func NewEcsTaskSetCapacityProviderStrategyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EcsTaskSetCapacityProviderStrategyOutputReference
type EcsTaskSetConfig ¶
type EcsTaskSetConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#cluster EcsTaskSet#cluster}.
Cluster *string `field:"required" json:"cluster" yaml:"cluster"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#service EcsTaskSet#service}.
Service *string `field:"required" json:"service" yaml:"service"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#task_definition EcsTaskSet#task_definition}.
TaskDefinition *string `field:"required" json:"taskDefinition" yaml:"taskDefinition"`
// capacity_provider_strategy block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#capacity_provider_strategy EcsTaskSet#capacity_provider_strategy}
CapacityProviderStrategy interface{} `field:"optional" json:"capacityProviderStrategy" yaml:"capacityProviderStrategy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#external_id EcsTaskSet#external_id}.
ExternalId *string `field:"optional" json:"externalId" yaml:"externalId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#force_delete EcsTaskSet#force_delete}.
ForceDelete interface{} `field:"optional" json:"forceDelete" yaml:"forceDelete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#id EcsTaskSet#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#launch_type EcsTaskSet#launch_type}.
LaunchType *string `field:"optional" json:"launchType" yaml:"launchType"`
// load_balancer block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#load_balancer EcsTaskSet#load_balancer}
LoadBalancer interface{} `field:"optional" json:"loadBalancer" yaml:"loadBalancer"`
// network_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#network_configuration EcsTaskSet#network_configuration}
NetworkConfiguration *EcsTaskSetNetworkConfiguration `field:"optional" json:"networkConfiguration" yaml:"networkConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#platform_version EcsTaskSet#platform_version}.
PlatformVersion *string `field:"optional" json:"platformVersion" yaml:"platformVersion"`
// scale block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#scale EcsTaskSet#scale}
Scale *EcsTaskSetScale `field:"optional" json:"scale" yaml:"scale"`
// service_registries block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#service_registries EcsTaskSet#service_registries}
ServiceRegistries *EcsTaskSetServiceRegistries `field:"optional" json:"serviceRegistries" yaml:"serviceRegistries"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#tags EcsTaskSet#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#tags_all EcsTaskSet#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#wait_until_stable EcsTaskSet#wait_until_stable}.
WaitUntilStable interface{} `field:"optional" json:"waitUntilStable" yaml:"waitUntilStable"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#wait_until_stable_timeout EcsTaskSet#wait_until_stable_timeout}.
WaitUntilStableTimeout *string `field:"optional" json:"waitUntilStableTimeout" yaml:"waitUntilStableTimeout"`
}
type EcsTaskSetLoadBalancer ¶
type EcsTaskSetLoadBalancer struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#container_name EcsTaskSet#container_name}.
ContainerName *string `field:"required" json:"containerName" yaml:"containerName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#container_port EcsTaskSet#container_port}.
ContainerPort *float64 `field:"optional" json:"containerPort" yaml:"containerPort"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#load_balancer_name EcsTaskSet#load_balancer_name}.
LoadBalancerName *string `field:"optional" json:"loadBalancerName" yaml:"loadBalancerName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#target_group_arn EcsTaskSet#target_group_arn}.
TargetGroupArn *string `field:"optional" json:"targetGroupArn" yaml:"targetGroupArn"`
}
type EcsTaskSetLoadBalancerList ¶
type EcsTaskSetLoadBalancerList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EcsTaskSetLoadBalancerOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcsTaskSetLoadBalancerList ¶
func NewEcsTaskSetLoadBalancerList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EcsTaskSetLoadBalancerList
type EcsTaskSetLoadBalancerOutputReference ¶
type EcsTaskSetLoadBalancerOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ContainerName() *string
SetContainerName(val *string)
ContainerNameInput() *string
ContainerPort() *float64
SetContainerPort(val *float64)
ContainerPortInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
LoadBalancerName() *string
SetLoadBalancerName(val *string)
LoadBalancerNameInput() *string
TargetGroupArn() *string
SetTargetGroupArn(val *string)
TargetGroupArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetContainerPort()
ResetLoadBalancerName()
ResetTargetGroupArn()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcsTaskSetLoadBalancerOutputReference ¶
func NewEcsTaskSetLoadBalancerOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EcsTaskSetLoadBalancerOutputReference
type EcsTaskSetNetworkConfiguration ¶
type EcsTaskSetNetworkConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#subnets EcsTaskSet#subnets}.
Subnets *[]*string `field:"required" json:"subnets" yaml:"subnets"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#assign_public_ip EcsTaskSet#assign_public_ip}.
AssignPublicIp interface{} `field:"optional" json:"assignPublicIp" yaml:"assignPublicIp"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#security_groups EcsTaskSet#security_groups}.
SecurityGroups *[]*string `field:"optional" json:"securityGroups" yaml:"securityGroups"`
}
type EcsTaskSetNetworkConfigurationOutputReference ¶
type EcsTaskSetNetworkConfigurationOutputReference interface {
cdktf.ComplexObject
AssignPublicIp() interface{}
SetAssignPublicIp(val interface{})
AssignPublicIpInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EcsTaskSetNetworkConfiguration
SetInternalValue(val *EcsTaskSetNetworkConfiguration)
SecurityGroups() *[]*string
SetSecurityGroups(val *[]*string)
SecurityGroupsInput() *[]*string
Subnets() *[]*string
SetSubnets(val *[]*string)
SubnetsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAssignPublicIp()
ResetSecurityGroups()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcsTaskSetNetworkConfigurationOutputReference ¶
func NewEcsTaskSetNetworkConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EcsTaskSetNetworkConfigurationOutputReference
type EcsTaskSetScale ¶
type EcsTaskSetScale struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#unit EcsTaskSet#unit}.
Unit *string `field:"optional" json:"unit" yaml:"unit"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#value EcsTaskSet#value}.
Value *float64 `field:"optional" json:"value" yaml:"value"`
}
type EcsTaskSetScaleOutputReference ¶
type EcsTaskSetScaleOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EcsTaskSetScale
SetInternalValue(val *EcsTaskSetScale)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Unit() *string
SetUnit(val *string)
UnitInput() *string
Value() *float64
SetValue(val *float64)
ValueInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetUnit()
ResetValue()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcsTaskSetScaleOutputReference ¶
func NewEcsTaskSetScaleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EcsTaskSetScaleOutputReference
type EcsTaskSetServiceRegistries ¶
type EcsTaskSetServiceRegistries struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#registry_arn EcsTaskSet#registry_arn}.
RegistryArn *string `field:"required" json:"registryArn" yaml:"registryArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#container_name EcsTaskSet#container_name}.
ContainerName *string `field:"optional" json:"containerName" yaml:"containerName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#container_port EcsTaskSet#container_port}.
ContainerPort *float64 `field:"optional" json:"containerPort" yaml:"containerPort"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#port EcsTaskSet#port}.
Port *float64 `field:"optional" json:"port" yaml:"port"`
}
type EcsTaskSetServiceRegistriesOutputReference ¶
type EcsTaskSetServiceRegistriesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ContainerName() *string
SetContainerName(val *string)
ContainerNameInput() *string
ContainerPort() *float64
SetContainerPort(val *float64)
ContainerPortInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EcsTaskSetServiceRegistries
SetInternalValue(val *EcsTaskSetServiceRegistries)
Port() *float64
SetPort(val *float64)
PortInput() *float64
RegistryArn() *string
SetRegistryArn(val *string)
RegistryArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetContainerName()
ResetContainerPort()
ResetPort()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcsTaskSetServiceRegistriesOutputReference ¶
func NewEcsTaskSetServiceRegistriesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EcsTaskSetServiceRegistriesOutputReference
Source Files
¶
- ecstaskset.go
- ecstaskset_EcsTaskSet.go
- ecstaskset_EcsTaskSetCapacityProviderStrategy.go
- ecstaskset_EcsTaskSetCapacityProviderStrategyList.go
- ecstaskset_EcsTaskSetCapacityProviderStrategyList__runtime_type_checks.go
- ecstaskset_EcsTaskSetCapacityProviderStrategyOutputReference.go
- ecstaskset_EcsTaskSetCapacityProviderStrategyOutputReference__runtime_type_checks.go
- ecstaskset_EcsTaskSetConfig.go
- ecstaskset_EcsTaskSetLoadBalancer.go
- ecstaskset_EcsTaskSetLoadBalancerList.go
- ecstaskset_EcsTaskSetLoadBalancerList__runtime_type_checks.go
- ecstaskset_EcsTaskSetLoadBalancerOutputReference.go
- ecstaskset_EcsTaskSetLoadBalancerOutputReference__runtime_type_checks.go
- ecstaskset_EcsTaskSetNetworkConfiguration.go
- ecstaskset_EcsTaskSetNetworkConfigurationOutputReference.go
- ecstaskset_EcsTaskSetNetworkConfigurationOutputReference__runtime_type_checks.go
- ecstaskset_EcsTaskSetScale.go
- ecstaskset_EcsTaskSetScaleOutputReference.go
- ecstaskset_EcsTaskSetScaleOutputReference__runtime_type_checks.go
- ecstaskset_EcsTaskSetServiceRegistries.go
- ecstaskset_EcsTaskSetServiceRegistriesOutputReference.go
- ecstaskset_EcsTaskSetServiceRegistriesOutputReference__runtime_type_checks.go
- ecstaskset_EcsTaskSet__runtime_type_checks.go