Documentation
¶
Index ¶
- func EksNodeGroup_IsConstruct(x interface{}) *bool
- func EksNodeGroup_IsTerraformElement(x interface{}) *bool
- func EksNodeGroup_IsTerraformResource(x interface{}) *bool
- func EksNodeGroup_TfResourceType() *string
- func NewEksNodeGroupLaunchTemplateOutputReference_Override(e EksNodeGroupLaunchTemplateOutputReference, ...)
- func NewEksNodeGroupRemoteAccessOutputReference_Override(e EksNodeGroupRemoteAccessOutputReference, ...)
- func NewEksNodeGroupResourcesAutoscalingGroupsList_Override(e EksNodeGroupResourcesAutoscalingGroupsList, ...)
- func NewEksNodeGroupResourcesAutoscalingGroupsOutputReference_Override(e EksNodeGroupResourcesAutoscalingGroupsOutputReference, ...)
- func NewEksNodeGroupResourcesList_Override(e EksNodeGroupResourcesList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewEksNodeGroupResourcesOutputReference_Override(e EksNodeGroupResourcesOutputReference, ...)
- func NewEksNodeGroupScalingConfigOutputReference_Override(e EksNodeGroupScalingConfigOutputReference, ...)
- func NewEksNodeGroupTaintList_Override(e EksNodeGroupTaintList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewEksNodeGroupTaintOutputReference_Override(e EksNodeGroupTaintOutputReference, ...)
- func NewEksNodeGroupTimeoutsOutputReference_Override(e EksNodeGroupTimeoutsOutputReference, ...)
- func NewEksNodeGroupUpdateConfigOutputReference_Override(e EksNodeGroupUpdateConfigOutputReference, ...)
- func NewEksNodeGroup_Override(e EksNodeGroup, scope constructs.Construct, id *string, ...)
- type EksNodeGroup
- type EksNodeGroupConfig
- type EksNodeGroupLaunchTemplate
- type EksNodeGroupLaunchTemplateOutputReference
- type EksNodeGroupRemoteAccess
- type EksNodeGroupRemoteAccessOutputReference
- type EksNodeGroupResources
- type EksNodeGroupResourcesAutoscalingGroups
- type EksNodeGroupResourcesAutoscalingGroupsList
- type EksNodeGroupResourcesAutoscalingGroupsOutputReference
- type EksNodeGroupResourcesList
- type EksNodeGroupResourcesOutputReference
- type EksNodeGroupScalingConfig
- type EksNodeGroupScalingConfigOutputReference
- type EksNodeGroupTaint
- type EksNodeGroupTaintList
- type EksNodeGroupTaintOutputReference
- type EksNodeGroupTimeouts
- type EksNodeGroupTimeoutsOutputReference
- type EksNodeGroupUpdateConfig
- type EksNodeGroupUpdateConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EksNodeGroup_IsConstruct ¶
func EksNodeGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func EksNodeGroup_IsTerraformElement ¶
func EksNodeGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func EksNodeGroup_IsTerraformResource ¶
func EksNodeGroup_IsTerraformResource(x interface{}) *bool
Experimental.
func EksNodeGroup_TfResourceType ¶
func EksNodeGroup_TfResourceType() *string
func NewEksNodeGroupLaunchTemplateOutputReference_Override ¶
func NewEksNodeGroupLaunchTemplateOutputReference_Override(e EksNodeGroupLaunchTemplateOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEksNodeGroupRemoteAccessOutputReference_Override ¶
func NewEksNodeGroupRemoteAccessOutputReference_Override(e EksNodeGroupRemoteAccessOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEksNodeGroupResourcesAutoscalingGroupsList_Override ¶
func NewEksNodeGroupResourcesAutoscalingGroupsList_Override(e EksNodeGroupResourcesAutoscalingGroupsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEksNodeGroupResourcesAutoscalingGroupsOutputReference_Override ¶
func NewEksNodeGroupResourcesAutoscalingGroupsOutputReference_Override(e EksNodeGroupResourcesAutoscalingGroupsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEksNodeGroupResourcesList_Override ¶
func NewEksNodeGroupResourcesList_Override(e EksNodeGroupResourcesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEksNodeGroupResourcesOutputReference_Override ¶
func NewEksNodeGroupResourcesOutputReference_Override(e EksNodeGroupResourcesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEksNodeGroupScalingConfigOutputReference_Override ¶
func NewEksNodeGroupScalingConfigOutputReference_Override(e EksNodeGroupScalingConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEksNodeGroupTaintList_Override ¶
func NewEksNodeGroupTaintList_Override(e EksNodeGroupTaintList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEksNodeGroupTaintOutputReference_Override ¶
func NewEksNodeGroupTaintOutputReference_Override(e EksNodeGroupTaintOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEksNodeGroupTimeoutsOutputReference_Override ¶
func NewEksNodeGroupTimeoutsOutputReference_Override(e EksNodeGroupTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEksNodeGroupUpdateConfigOutputReference_Override ¶
func NewEksNodeGroupUpdateConfigOutputReference_Override(e EksNodeGroupUpdateConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEksNodeGroup_Override ¶
func NewEksNodeGroup_Override(e EksNodeGroup, scope constructs.Construct, id *string, config *EksNodeGroupConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group aws_eks_node_group} Resource.
Types ¶
type EksNodeGroup ¶
type EksNodeGroup interface {
cdktf.TerraformResource
AmiType() *string
SetAmiType(val *string)
AmiTypeInput() *string
Arn() *string
CapacityType() *string
SetCapacityType(val *string)
CapacityTypeInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterName() *string
SetClusterName(val *string)
ClusterNameInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DiskSize() *float64
SetDiskSize(val *float64)
DiskSizeInput() *float64
ForceUpdateVersion() interface{}
SetForceUpdateVersion(val interface{})
ForceUpdateVersionInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InstanceTypes() *[]*string
SetInstanceTypes(val *[]*string)
InstanceTypesInput() *[]*string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
LaunchTemplate() EksNodeGroupLaunchTemplateOutputReference
LaunchTemplateInput() *EksNodeGroupLaunchTemplate
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
NodeGroupName() *string
SetNodeGroupName(val *string)
NodeGroupNameInput() *string
NodeGroupNamePrefix() *string
SetNodeGroupNamePrefix(val *string)
NodeGroupNamePrefixInput() *string
NodeRoleArn() *string
SetNodeRoleArn(val *string)
NodeRoleArnInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ReleaseVersion() *string
SetReleaseVersion(val *string)
ReleaseVersionInput() *string
RemoteAccess() EksNodeGroupRemoteAccessOutputReference
RemoteAccessInput() *EksNodeGroupRemoteAccess
Resources() EksNodeGroupResourcesList
ScalingConfig() EksNodeGroupScalingConfigOutputReference
ScalingConfigInput() *EksNodeGroupScalingConfig
Status() *string
SubnetIds() *[]*string
SetSubnetIds(val *[]*string)
SubnetIdsInput() *[]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
Taint() EksNodeGroupTaintList
TaintInput() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() EksNodeGroupTimeoutsOutputReference
TimeoutsInput() interface{}
UpdateConfig() EksNodeGroupUpdateConfigOutputReference
UpdateConfigInput() *EksNodeGroupUpdateConfig
Version() *string
SetVersion(val *string)
VersionInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutLaunchTemplate(value *EksNodeGroupLaunchTemplate)
PutRemoteAccess(value *EksNodeGroupRemoteAccess)
PutScalingConfig(value *EksNodeGroupScalingConfig)
PutTaint(value interface{})
PutTimeouts(value *EksNodeGroupTimeouts)
PutUpdateConfig(value *EksNodeGroupUpdateConfig)
ResetAmiType()
ResetCapacityType()
ResetDiskSize()
ResetForceUpdateVersion()
ResetId()
ResetInstanceTypes()
ResetLabels()
ResetLaunchTemplate()
ResetNodeGroupName()
ResetNodeGroupNamePrefix()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetReleaseVersion()
ResetRemoteAccess()
ResetTags()
ResetTagsAll()
ResetTaint()
ResetTimeouts()
ResetUpdateConfig()
ResetVersion()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group aws_eks_node_group}.
func NewEksNodeGroup ¶
func NewEksNodeGroup(scope constructs.Construct, id *string, config *EksNodeGroupConfig) EksNodeGroup
Create a new {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group aws_eks_node_group} Resource.
type EksNodeGroupConfig ¶
type EksNodeGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#cluster_name EksNodeGroup#cluster_name}.
ClusterName *string `field:"required" json:"clusterName" yaml:"clusterName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#node_role_arn EksNodeGroup#node_role_arn}.
NodeRoleArn *string `field:"required" json:"nodeRoleArn" yaml:"nodeRoleArn"`
// scaling_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#scaling_config EksNodeGroup#scaling_config}
ScalingConfig *EksNodeGroupScalingConfig `field:"required" json:"scalingConfig" yaml:"scalingConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#subnet_ids EksNodeGroup#subnet_ids}.
SubnetIds *[]*string `field:"required" json:"subnetIds" yaml:"subnetIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#ami_type EksNodeGroup#ami_type}.
AmiType *string `field:"optional" json:"amiType" yaml:"amiType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#capacity_type EksNodeGroup#capacity_type}.
CapacityType *string `field:"optional" json:"capacityType" yaml:"capacityType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#disk_size EksNodeGroup#disk_size}.
DiskSize *float64 `field:"optional" json:"diskSize" yaml:"diskSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#force_update_version EksNodeGroup#force_update_version}.
ForceUpdateVersion interface{} `field:"optional" json:"forceUpdateVersion" yaml:"forceUpdateVersion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#id EksNodeGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#instance_types EksNodeGroup#instance_types}.
InstanceTypes *[]*string `field:"optional" json:"instanceTypes" yaml:"instanceTypes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#labels EksNodeGroup#labels}.
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// launch_template block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#launch_template EksNodeGroup#launch_template}
LaunchTemplate *EksNodeGroupLaunchTemplate `field:"optional" json:"launchTemplate" yaml:"launchTemplate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#node_group_name EksNodeGroup#node_group_name}.
NodeGroupName *string `field:"optional" json:"nodeGroupName" yaml:"nodeGroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#node_group_name_prefix EksNodeGroup#node_group_name_prefix}.
NodeGroupNamePrefix *string `field:"optional" json:"nodeGroupNamePrefix" yaml:"nodeGroupNamePrefix"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#release_version EksNodeGroup#release_version}.
ReleaseVersion *string `field:"optional" json:"releaseVersion" yaml:"releaseVersion"`
// remote_access block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#remote_access EksNodeGroup#remote_access}
RemoteAccess *EksNodeGroupRemoteAccess `field:"optional" json:"remoteAccess" yaml:"remoteAccess"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#tags EksNodeGroup#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#tags_all EksNodeGroup#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// taint block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#taint EksNodeGroup#taint}
Taint interface{} `field:"optional" json:"taint" yaml:"taint"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#timeouts EksNodeGroup#timeouts}
Timeouts *EksNodeGroupTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// update_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#update_config EksNodeGroup#update_config}
UpdateConfig *EksNodeGroupUpdateConfig `field:"optional" json:"updateConfig" yaml:"updateConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#version EksNodeGroup#version}.
Version *string `field:"optional" json:"version" yaml:"version"`
}
type EksNodeGroupLaunchTemplate ¶
type EksNodeGroupLaunchTemplate struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#version EksNodeGroup#version}.
Version *string `field:"required" json:"version" yaml:"version"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#id EksNodeGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#name EksNodeGroup#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
}
type EksNodeGroupLaunchTemplateOutputReference ¶
type EksNodeGroupLaunchTemplateOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
SetId(val *string)
IdInput() *string
InternalValue() *EksNodeGroupLaunchTemplate
SetInternalValue(val *EksNodeGroupLaunchTemplate)
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Version() *string
SetVersion(val *string)
VersionInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetId()
ResetName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksNodeGroupLaunchTemplateOutputReference ¶
func NewEksNodeGroupLaunchTemplateOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EksNodeGroupLaunchTemplateOutputReference
type EksNodeGroupRemoteAccess ¶
type EksNodeGroupRemoteAccess struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#ec2_ssh_key EksNodeGroup#ec2_ssh_key}.
Ec2SshKey *string `field:"optional" json:"ec2SshKey" yaml:"ec2SshKey"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#source_security_group_ids EksNodeGroup#source_security_group_ids}.
SourceSecurityGroupIds *[]*string `field:"optional" json:"sourceSecurityGroupIds" yaml:"sourceSecurityGroupIds"`
}
type EksNodeGroupRemoteAccessOutputReference ¶
type EksNodeGroupRemoteAccessOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Ec2SshKey() *string
SetEc2SshKey(val *string)
Ec2SshKeyInput() *string
// Experimental.
Fqn() *string
InternalValue() *EksNodeGroupRemoteAccess
SetInternalValue(val *EksNodeGroupRemoteAccess)
SourceSecurityGroupIds() *[]*string
SetSourceSecurityGroupIds(val *[]*string)
SourceSecurityGroupIdsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEc2SshKey()
ResetSourceSecurityGroupIds()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksNodeGroupRemoteAccessOutputReference ¶
func NewEksNodeGroupRemoteAccessOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EksNodeGroupRemoteAccessOutputReference
type EksNodeGroupResources ¶
type EksNodeGroupResources struct {
}
type EksNodeGroupResourcesAutoscalingGroups ¶
type EksNodeGroupResourcesAutoscalingGroups struct {
}
type EksNodeGroupResourcesAutoscalingGroupsList ¶
type EksNodeGroupResourcesAutoscalingGroupsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EksNodeGroupResourcesAutoscalingGroupsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksNodeGroupResourcesAutoscalingGroupsList ¶
func NewEksNodeGroupResourcesAutoscalingGroupsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EksNodeGroupResourcesAutoscalingGroupsList
type EksNodeGroupResourcesAutoscalingGroupsOutputReference ¶
type EksNodeGroupResourcesAutoscalingGroupsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EksNodeGroupResourcesAutoscalingGroups
SetInternalValue(val *EksNodeGroupResourcesAutoscalingGroups)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksNodeGroupResourcesAutoscalingGroupsOutputReference ¶
func NewEksNodeGroupResourcesAutoscalingGroupsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EksNodeGroupResourcesAutoscalingGroupsOutputReference
type EksNodeGroupResourcesList ¶
type EksNodeGroupResourcesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EksNodeGroupResourcesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksNodeGroupResourcesList ¶
func NewEksNodeGroupResourcesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EksNodeGroupResourcesList
type EksNodeGroupResourcesOutputReference ¶
type EksNodeGroupResourcesOutputReference interface {
cdktf.ComplexObject
AutoscalingGroups() EksNodeGroupResourcesAutoscalingGroupsList
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EksNodeGroupResources
SetInternalValue(val *EksNodeGroupResources)
RemoteAccessSecurityGroupId() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksNodeGroupResourcesOutputReference ¶
func NewEksNodeGroupResourcesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EksNodeGroupResourcesOutputReference
type EksNodeGroupScalingConfig ¶
type EksNodeGroupScalingConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#desired_size EksNodeGroup#desired_size}.
DesiredSize *float64 `field:"required" json:"desiredSize" yaml:"desiredSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#max_size EksNodeGroup#max_size}.
MaxSize *float64 `field:"required" json:"maxSize" yaml:"maxSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#min_size EksNodeGroup#min_size}.
MinSize *float64 `field:"required" json:"minSize" yaml:"minSize"`
}
type EksNodeGroupScalingConfigOutputReference ¶
type EksNodeGroupScalingConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DesiredSize() *float64
SetDesiredSize(val *float64)
DesiredSizeInput() *float64
// Experimental.
Fqn() *string
InternalValue() *EksNodeGroupScalingConfig
SetInternalValue(val *EksNodeGroupScalingConfig)
MaxSize() *float64
SetMaxSize(val *float64)
MaxSizeInput() *float64
MinSize() *float64
SetMinSize(val *float64)
MinSizeInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksNodeGroupScalingConfigOutputReference ¶
func NewEksNodeGroupScalingConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EksNodeGroupScalingConfigOutputReference
type EksNodeGroupTaint ¶
type EksNodeGroupTaint struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#effect EksNodeGroup#effect}.
Effect *string `field:"required" json:"effect" yaml:"effect"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#key EksNodeGroup#key}.
Key *string `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#value EksNodeGroup#value}.
Value *string `field:"optional" json:"value" yaml:"value"`
}
type EksNodeGroupTaintList ¶
type EksNodeGroupTaintList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EksNodeGroupTaintOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksNodeGroupTaintList ¶
func NewEksNodeGroupTaintList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EksNodeGroupTaintList
type EksNodeGroupTaintOutputReference ¶
type EksNodeGroupTaintOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Effect() *string
SetEffect(val *string)
EffectInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetValue()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksNodeGroupTaintOutputReference ¶
func NewEksNodeGroupTaintOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EksNodeGroupTaintOutputReference
type EksNodeGroupTimeouts ¶
type EksNodeGroupTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#create EksNodeGroup#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#delete EksNodeGroup#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group#update EksNodeGroup#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type EksNodeGroupTimeoutsOutputReference ¶
type EksNodeGroupTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksNodeGroupTimeoutsOutputReference ¶
func NewEksNodeGroupTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EksNodeGroupTimeoutsOutputReference
type EksNodeGroupUpdateConfigOutputReference ¶
type EksNodeGroupUpdateConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EksNodeGroupUpdateConfig
SetInternalValue(val *EksNodeGroupUpdateConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksNodeGroupUpdateConfigOutputReference ¶
func NewEksNodeGroupUpdateConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EksNodeGroupUpdateConfigOutputReference
Source Files
¶
- eksnodegroup.go
- eksnodegroup_EksNodeGroup.go
- eksnodegroup_EksNodeGroupConfig.go
- eksnodegroup_EksNodeGroupLaunchTemplate.go
- eksnodegroup_EksNodeGroupLaunchTemplateOutputReference.go
- eksnodegroup_EksNodeGroupLaunchTemplateOutputReference__runtime_type_checks.go
- eksnodegroup_EksNodeGroupRemoteAccess.go
- eksnodegroup_EksNodeGroupRemoteAccessOutputReference.go
- eksnodegroup_EksNodeGroupRemoteAccessOutputReference__runtime_type_checks.go
- eksnodegroup_EksNodeGroupResources.go
- eksnodegroup_EksNodeGroupResourcesAutoscalingGroups.go
- eksnodegroup_EksNodeGroupResourcesAutoscalingGroupsList.go
- eksnodegroup_EksNodeGroupResourcesAutoscalingGroupsList__runtime_type_checks.go
- eksnodegroup_EksNodeGroupResourcesAutoscalingGroupsOutputReference.go
- eksnodegroup_EksNodeGroupResourcesAutoscalingGroupsOutputReference__runtime_type_checks.go
- eksnodegroup_EksNodeGroupResourcesList.go
- eksnodegroup_EksNodeGroupResourcesList__runtime_type_checks.go
- eksnodegroup_EksNodeGroupResourcesOutputReference.go
- eksnodegroup_EksNodeGroupResourcesOutputReference__runtime_type_checks.go
- eksnodegroup_EksNodeGroupScalingConfig.go
- eksnodegroup_EksNodeGroupScalingConfigOutputReference.go
- eksnodegroup_EksNodeGroupScalingConfigOutputReference__runtime_type_checks.go
- eksnodegroup_EksNodeGroupTaint.go
- eksnodegroup_EksNodeGroupTaintList.go
- eksnodegroup_EksNodeGroupTaintList__runtime_type_checks.go
- eksnodegroup_EksNodeGroupTaintOutputReference.go
- eksnodegroup_EksNodeGroupTaintOutputReference__runtime_type_checks.go
- eksnodegroup_EksNodeGroupTimeouts.go
- eksnodegroup_EksNodeGroupTimeoutsOutputReference.go
- eksnodegroup_EksNodeGroupTimeoutsOutputReference__runtime_type_checks.go
- eksnodegroup_EksNodeGroupUpdateConfig.go
- eksnodegroup_EksNodeGroupUpdateConfigOutputReference.go
- eksnodegroup_EksNodeGroupUpdateConfigOutputReference__runtime_type_checks.go
- eksnodegroup_EksNodeGroup__runtime_type_checks.go