Documentation
¶
Index ¶
- func ElasticacheCluster_IsConstruct(x interface{}) *bool
- func ElasticacheCluster_IsTerraformElement(x interface{}) *bool
- func ElasticacheCluster_IsTerraformResource(x interface{}) *bool
- func ElasticacheCluster_TfResourceType() *string
- func NewElasticacheClusterCacheNodesList_Override(e ElasticacheClusterCacheNodesList, ...)
- func NewElasticacheClusterCacheNodesOutputReference_Override(e ElasticacheClusterCacheNodesOutputReference, ...)
- func NewElasticacheClusterLogDeliveryConfigurationList_Override(e ElasticacheClusterLogDeliveryConfigurationList, ...)
- func NewElasticacheClusterLogDeliveryConfigurationOutputReference_Override(e ElasticacheClusterLogDeliveryConfigurationOutputReference, ...)
- func NewElasticacheCluster_Override(e ElasticacheCluster, scope constructs.Construct, id *string, ...)
- type ElasticacheCluster
- type ElasticacheClusterCacheNodes
- type ElasticacheClusterCacheNodesList
- type ElasticacheClusterCacheNodesOutputReference
- type ElasticacheClusterConfig
- type ElasticacheClusterLogDeliveryConfiguration
- type ElasticacheClusterLogDeliveryConfigurationList
- type ElasticacheClusterLogDeliveryConfigurationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ElasticacheCluster_IsConstruct ¶
func ElasticacheCluster_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ElasticacheCluster_IsTerraformElement ¶
func ElasticacheCluster_IsTerraformElement(x interface{}) *bool
Experimental.
func ElasticacheCluster_IsTerraformResource ¶
func ElasticacheCluster_IsTerraformResource(x interface{}) *bool
Experimental.
func ElasticacheCluster_TfResourceType ¶
func ElasticacheCluster_TfResourceType() *string
func NewElasticacheClusterCacheNodesList_Override ¶
func NewElasticacheClusterCacheNodesList_Override(e ElasticacheClusterCacheNodesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewElasticacheClusterCacheNodesOutputReference_Override ¶
func NewElasticacheClusterCacheNodesOutputReference_Override(e ElasticacheClusterCacheNodesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewElasticacheClusterLogDeliveryConfigurationList_Override ¶
func NewElasticacheClusterLogDeliveryConfigurationList_Override(e ElasticacheClusterLogDeliveryConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewElasticacheClusterLogDeliveryConfigurationOutputReference_Override ¶
func NewElasticacheClusterLogDeliveryConfigurationOutputReference_Override(e ElasticacheClusterLogDeliveryConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewElasticacheCluster_Override ¶
func NewElasticacheCluster_Override(e ElasticacheCluster, scope constructs.Construct, id *string, config *ElasticacheClusterConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster aws_elasticache_cluster} Resource.
Types ¶
type ElasticacheCluster ¶
type ElasticacheCluster interface {
cdktf.TerraformResource
ApplyImmediately() interface{}
SetApplyImmediately(val interface{})
ApplyImmediatelyInput() interface{}
Arn() *string
AutoMinorVersionUpgrade() *string
SetAutoMinorVersionUpgrade(val *string)
AutoMinorVersionUpgradeInput() *string
AvailabilityZone() *string
SetAvailabilityZone(val *string)
AvailabilityZoneInput() *string
AzMode() *string
SetAzMode(val *string)
AzModeInput() *string
CacheNodes() ElasticacheClusterCacheNodesList
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterAddress() *string
ClusterId() *string
SetClusterId(val *string)
ClusterIdInput() *string
ConfigurationEndpoint() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Engine() *string
SetEngine(val *string)
EngineInput() *string
EngineVersion() *string
SetEngineVersion(val *string)
EngineVersionActual() *string
EngineVersionInput() *string
FinalSnapshotIdentifier() *string
SetFinalSnapshotIdentifier(val *string)
FinalSnapshotIdentifierInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IpDiscovery() *string
SetIpDiscovery(val *string)
IpDiscoveryInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LogDeliveryConfiguration() ElasticacheClusterLogDeliveryConfigurationList
LogDeliveryConfigurationInput() interface{}
MaintenanceWindow() *string
SetMaintenanceWindow(val *string)
MaintenanceWindowInput() *string
NetworkType() *string
SetNetworkType(val *string)
NetworkTypeInput() *string
// The tree node.
Node() constructs.Node
NodeType() *string
SetNodeType(val *string)
NodeTypeInput() *string
NotificationTopicArn() *string
SetNotificationTopicArn(val *string)
NotificationTopicArnInput() *string
NumCacheNodes() *float64
SetNumCacheNodes(val *float64)
NumCacheNodesInput() *float64
OutpostMode() *string
SetOutpostMode(val *string)
OutpostModeInput() *string
ParameterGroupName() *string
SetParameterGroupName(val *string)
ParameterGroupNameInput() *string
Port() *float64
SetPort(val *float64)
PortInput() *float64
PreferredAvailabilityZones() *[]*string
SetPreferredAvailabilityZones(val *[]*string)
PreferredAvailabilityZonesInput() *[]*string
PreferredOutpostArn() *string
SetPreferredOutpostArn(val *string)
PreferredOutpostArnInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ReplicationGroupId() *string
SetReplicationGroupId(val *string)
ReplicationGroupIdInput() *string
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
SecurityGroupNames() *[]*string
SetSecurityGroupNames(val *[]*string)
SecurityGroupNamesInput() *[]*string
SnapshotArns() *[]*string
SetSnapshotArns(val *[]*string)
SnapshotArnsInput() *[]*string
SnapshotName() *string
SetSnapshotName(val *string)
SnapshotNameInput() *string
SnapshotRetentionLimit() *float64
SetSnapshotRetentionLimit(val *float64)
SnapshotRetentionLimitInput() *float64
SnapshotWindow() *string
SetSnapshotWindow(val *string)
SnapshotWindowInput() *string
SubnetGroupName() *string
SetSubnetGroupName(val *string)
SubnetGroupNameInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutLogDeliveryConfiguration(value interface{})
ResetApplyImmediately()
ResetAutoMinorVersionUpgrade()
ResetAvailabilityZone()
ResetAzMode()
ResetEngine()
ResetEngineVersion()
ResetFinalSnapshotIdentifier()
ResetId()
ResetIpDiscovery()
ResetLogDeliveryConfiguration()
ResetMaintenanceWindow()
ResetNetworkType()
ResetNodeType()
ResetNotificationTopicArn()
ResetNumCacheNodes()
ResetOutpostMode()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetParameterGroupName()
ResetPort()
ResetPreferredAvailabilityZones()
ResetPreferredOutpostArn()
ResetReplicationGroupId()
ResetSecurityGroupIds()
ResetSecurityGroupNames()
ResetSnapshotArns()
ResetSnapshotName()
ResetSnapshotRetentionLimit()
ResetSnapshotWindow()
ResetSubnetGroupName()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster aws_elasticache_cluster}.
func NewElasticacheCluster ¶
func NewElasticacheCluster(scope constructs.Construct, id *string, config *ElasticacheClusterConfig) ElasticacheCluster
Create a new {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster aws_elasticache_cluster} Resource.
type ElasticacheClusterCacheNodes ¶
type ElasticacheClusterCacheNodes struct {
}
type ElasticacheClusterCacheNodesList ¶
type ElasticacheClusterCacheNodesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ElasticacheClusterCacheNodesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElasticacheClusterCacheNodesList ¶
func NewElasticacheClusterCacheNodesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ElasticacheClusterCacheNodesList
type ElasticacheClusterCacheNodesOutputReference ¶
type ElasticacheClusterCacheNodesOutputReference interface {
cdktf.ComplexObject
Address() *string
AvailabilityZone() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *ElasticacheClusterCacheNodes
SetInternalValue(val *ElasticacheClusterCacheNodes)
OutpostArn() *string
Port() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElasticacheClusterCacheNodesOutputReference ¶
func NewElasticacheClusterCacheNodesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ElasticacheClusterCacheNodesOutputReference
type ElasticacheClusterConfig ¶
type ElasticacheClusterConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#cluster_id ElasticacheCluster#cluster_id}.
ClusterId *string `field:"required" json:"clusterId" yaml:"clusterId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#apply_immediately ElasticacheCluster#apply_immediately}.
ApplyImmediately interface{} `field:"optional" json:"applyImmediately" yaml:"applyImmediately"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#auto_minor_version_upgrade ElasticacheCluster#auto_minor_version_upgrade}.
AutoMinorVersionUpgrade *string `field:"optional" json:"autoMinorVersionUpgrade" yaml:"autoMinorVersionUpgrade"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#availability_zone ElasticacheCluster#availability_zone}.
AvailabilityZone *string `field:"optional" json:"availabilityZone" yaml:"availabilityZone"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#az_mode ElasticacheCluster#az_mode}.
AzMode *string `field:"optional" json:"azMode" yaml:"azMode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#engine ElasticacheCluster#engine}.
Engine *string `field:"optional" json:"engine" yaml:"engine"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#engine_version ElasticacheCluster#engine_version}.
EngineVersion *string `field:"optional" json:"engineVersion" yaml:"engineVersion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#final_snapshot_identifier ElasticacheCluster#final_snapshot_identifier}.
FinalSnapshotIdentifier *string `field:"optional" json:"finalSnapshotIdentifier" yaml:"finalSnapshotIdentifier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#id ElasticacheCluster#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#ip_discovery ElasticacheCluster#ip_discovery}.
IpDiscovery *string `field:"optional" json:"ipDiscovery" yaml:"ipDiscovery"`
// log_delivery_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#log_delivery_configuration ElasticacheCluster#log_delivery_configuration}
LogDeliveryConfiguration interface{} `field:"optional" json:"logDeliveryConfiguration" yaml:"logDeliveryConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#maintenance_window ElasticacheCluster#maintenance_window}.
MaintenanceWindow *string `field:"optional" json:"maintenanceWindow" yaml:"maintenanceWindow"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#network_type ElasticacheCluster#network_type}.
NetworkType *string `field:"optional" json:"networkType" yaml:"networkType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#node_type ElasticacheCluster#node_type}.
NodeType *string `field:"optional" json:"nodeType" yaml:"nodeType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#notification_topic_arn ElasticacheCluster#notification_topic_arn}.
NotificationTopicArn *string `field:"optional" json:"notificationTopicArn" yaml:"notificationTopicArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#num_cache_nodes ElasticacheCluster#num_cache_nodes}.
NumCacheNodes *float64 `field:"optional" json:"numCacheNodes" yaml:"numCacheNodes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#outpost_mode ElasticacheCluster#outpost_mode}.
OutpostMode *string `field:"optional" json:"outpostMode" yaml:"outpostMode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#parameter_group_name ElasticacheCluster#parameter_group_name}.
ParameterGroupName *string `field:"optional" json:"parameterGroupName" yaml:"parameterGroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#port ElasticacheCluster#port}.
Port *float64 `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#preferred_availability_zones ElasticacheCluster#preferred_availability_zones}.
PreferredAvailabilityZones *[]*string `field:"optional" json:"preferredAvailabilityZones" yaml:"preferredAvailabilityZones"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#preferred_outpost_arn ElasticacheCluster#preferred_outpost_arn}.
PreferredOutpostArn *string `field:"optional" json:"preferredOutpostArn" yaml:"preferredOutpostArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#replication_group_id ElasticacheCluster#replication_group_id}.
ReplicationGroupId *string `field:"optional" json:"replicationGroupId" yaml:"replicationGroupId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#security_group_ids ElasticacheCluster#security_group_ids}.
SecurityGroupIds *[]*string `field:"optional" json:"securityGroupIds" yaml:"securityGroupIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#security_group_names ElasticacheCluster#security_group_names}.
SecurityGroupNames *[]*string `field:"optional" json:"securityGroupNames" yaml:"securityGroupNames"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#snapshot_arns ElasticacheCluster#snapshot_arns}.
SnapshotArns *[]*string `field:"optional" json:"snapshotArns" yaml:"snapshotArns"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#snapshot_name ElasticacheCluster#snapshot_name}.
SnapshotName *string `field:"optional" json:"snapshotName" yaml:"snapshotName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#snapshot_retention_limit ElasticacheCluster#snapshot_retention_limit}.
SnapshotRetentionLimit *float64 `field:"optional" json:"snapshotRetentionLimit" yaml:"snapshotRetentionLimit"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#snapshot_window ElasticacheCluster#snapshot_window}.
SnapshotWindow *string `field:"optional" json:"snapshotWindow" yaml:"snapshotWindow"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#subnet_group_name ElasticacheCluster#subnet_group_name}.
SubnetGroupName *string `field:"optional" json:"subnetGroupName" yaml:"subnetGroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#tags ElasticacheCluster#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#tags_all ElasticacheCluster#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type ElasticacheClusterLogDeliveryConfiguration ¶
type ElasticacheClusterLogDeliveryConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#destination ElasticacheCluster#destination}.
Destination *string `field:"required" json:"destination" yaml:"destination"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#destination_type ElasticacheCluster#destination_type}.
DestinationType *string `field:"required" json:"destinationType" yaml:"destinationType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#log_format ElasticacheCluster#log_format}.
LogFormat *string `field:"required" json:"logFormat" yaml:"logFormat"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_cluster#log_type ElasticacheCluster#log_type}.
LogType *string `field:"required" json:"logType" yaml:"logType"`
}
type ElasticacheClusterLogDeliveryConfigurationList ¶
type ElasticacheClusterLogDeliveryConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ElasticacheClusterLogDeliveryConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElasticacheClusterLogDeliveryConfigurationList ¶
func NewElasticacheClusterLogDeliveryConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ElasticacheClusterLogDeliveryConfigurationList
type ElasticacheClusterLogDeliveryConfigurationOutputReference ¶
type ElasticacheClusterLogDeliveryConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Destination() *string
SetDestination(val *string)
DestinationInput() *string
DestinationType() *string
SetDestinationType(val *string)
DestinationTypeInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
LogFormat() *string
SetLogFormat(val *string)
LogFormatInput() *string
LogType() *string
SetLogType(val *string)
LogTypeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElasticacheClusterLogDeliveryConfigurationOutputReference ¶
func NewElasticacheClusterLogDeliveryConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ElasticacheClusterLogDeliveryConfigurationOutputReference
Source Files
¶
- elasticachecluster.go
- elasticachecluster_ElasticacheCluster.go
- elasticachecluster_ElasticacheClusterCacheNodes.go
- elasticachecluster_ElasticacheClusterCacheNodesList.go
- elasticachecluster_ElasticacheClusterCacheNodesList__runtime_type_checks.go
- elasticachecluster_ElasticacheClusterCacheNodesOutputReference.go
- elasticachecluster_ElasticacheClusterCacheNodesOutputReference__runtime_type_checks.go
- elasticachecluster_ElasticacheClusterConfig.go
- elasticachecluster_ElasticacheClusterLogDeliveryConfiguration.go
- elasticachecluster_ElasticacheClusterLogDeliveryConfigurationList.go
- elasticachecluster_ElasticacheClusterLogDeliveryConfigurationList__runtime_type_checks.go
- elasticachecluster_ElasticacheClusterLogDeliveryConfigurationOutputReference.go
- elasticachecluster_ElasticacheClusterLogDeliveryConfigurationOutputReference__runtime_type_checks.go
- elasticachecluster_ElasticacheCluster__runtime_type_checks.go