Documentation
¶
Index ¶
- func ElasticacheReplicationGroup_IsConstruct(x interface{}) *bool
- func ElasticacheReplicationGroup_IsTerraformElement(x interface{}) *bool
- func ElasticacheReplicationGroup_IsTerraformResource(x interface{}) *bool
- func ElasticacheReplicationGroup_TfResourceType() *string
- func NewElasticacheReplicationGroupClusterModeOutputReference_Override(e ElasticacheReplicationGroupClusterModeOutputReference, ...)
- func NewElasticacheReplicationGroupLogDeliveryConfigurationList_Override(e ElasticacheReplicationGroupLogDeliveryConfigurationList, ...)
- func NewElasticacheReplicationGroupLogDeliveryConfigurationOutputReference_Override(e ElasticacheReplicationGroupLogDeliveryConfigurationOutputReference, ...)
- func NewElasticacheReplicationGroupTimeoutsOutputReference_Override(e ElasticacheReplicationGroupTimeoutsOutputReference, ...)
- func NewElasticacheReplicationGroup_Override(e ElasticacheReplicationGroup, scope constructs.Construct, id *string, ...)
- type ElasticacheReplicationGroup
- type ElasticacheReplicationGroupClusterMode
- type ElasticacheReplicationGroupClusterModeOutputReference
- type ElasticacheReplicationGroupConfig
- type ElasticacheReplicationGroupLogDeliveryConfiguration
- type ElasticacheReplicationGroupLogDeliveryConfigurationList
- type ElasticacheReplicationGroupLogDeliveryConfigurationOutputReference
- type ElasticacheReplicationGroupTimeouts
- type ElasticacheReplicationGroupTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ElasticacheReplicationGroup_IsConstruct ¶
func ElasticacheReplicationGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ElasticacheReplicationGroup_IsTerraformElement ¶
func ElasticacheReplicationGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func ElasticacheReplicationGroup_IsTerraformResource ¶
func ElasticacheReplicationGroup_IsTerraformResource(x interface{}) *bool
Experimental.
func ElasticacheReplicationGroup_TfResourceType ¶
func ElasticacheReplicationGroup_TfResourceType() *string
func NewElasticacheReplicationGroupClusterModeOutputReference_Override ¶
func NewElasticacheReplicationGroupClusterModeOutputReference_Override(e ElasticacheReplicationGroupClusterModeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewElasticacheReplicationGroupLogDeliveryConfigurationList_Override ¶
func NewElasticacheReplicationGroupLogDeliveryConfigurationList_Override(e ElasticacheReplicationGroupLogDeliveryConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewElasticacheReplicationGroupLogDeliveryConfigurationOutputReference_Override ¶
func NewElasticacheReplicationGroupLogDeliveryConfigurationOutputReference_Override(e ElasticacheReplicationGroupLogDeliveryConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewElasticacheReplicationGroupTimeoutsOutputReference_Override ¶
func NewElasticacheReplicationGroupTimeoutsOutputReference_Override(e ElasticacheReplicationGroupTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewElasticacheReplicationGroup_Override ¶
func NewElasticacheReplicationGroup_Override(e ElasticacheReplicationGroup, scope constructs.Construct, id *string, config *ElasticacheReplicationGroupConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group aws_elasticache_replication_group} Resource.
Types ¶
type ElasticacheReplicationGroup ¶
type ElasticacheReplicationGroup interface {
cdktf.TerraformResource
ApplyImmediately() interface{}
SetApplyImmediately(val interface{})
ApplyImmediatelyInput() interface{}
Arn() *string
AtRestEncryptionEnabled() interface{}
SetAtRestEncryptionEnabled(val interface{})
AtRestEncryptionEnabledInput() interface{}
AuthToken() *string
SetAuthToken(val *string)
AuthTokenInput() *string
AutomaticFailoverEnabled() interface{}
SetAutomaticFailoverEnabled(val interface{})
AutomaticFailoverEnabledInput() interface{}
AutoMinorVersionUpgrade() *string
SetAutoMinorVersionUpgrade(val *string)
AutoMinorVersionUpgradeInput() *string
AvailabilityZones() *[]*string
SetAvailabilityZones(val *[]*string)
AvailabilityZonesInput() *[]*string
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterEnabled() cdktf.IResolvable
ClusterMode() ElasticacheReplicationGroupClusterModeOutputReference
ClusterModeInput() *ElasticacheReplicationGroupClusterMode
ConfigurationEndpointAddress() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DataTieringEnabled() interface{}
SetDataTieringEnabled(val interface{})
DataTieringEnabledInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Engine() *string
SetEngine(val *string)
EngineInput() *string
EngineVersion() *string
SetEngineVersion(val *string)
EngineVersionActual() *string
EngineVersionInput() *string
FinalSnapshotIdentifier() *string
SetFinalSnapshotIdentifier(val *string)
FinalSnapshotIdentifierInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GlobalReplicationGroupId() *string
SetGlobalReplicationGroupId(val *string)
GlobalReplicationGroupIdInput() *string
Id() *string
SetId(val *string)
IdInput() *string
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LogDeliveryConfiguration() ElasticacheReplicationGroupLogDeliveryConfigurationList
LogDeliveryConfigurationInput() interface{}
MaintenanceWindow() *string
SetMaintenanceWindow(val *string)
MaintenanceWindowInput() *string
MemberClusters() *[]*string
MultiAzEnabled() interface{}
SetMultiAzEnabled(val interface{})
MultiAzEnabledInput() interface{}
// The tree node.
Node() constructs.Node
NodeType() *string
SetNodeType(val *string)
NodeTypeInput() *string
NotificationTopicArn() *string
SetNotificationTopicArn(val *string)
NotificationTopicArnInput() *string
NumberCacheClusters() *float64
SetNumberCacheClusters(val *float64)
NumberCacheClustersInput() *float64
NumCacheClusters() *float64
SetNumCacheClusters(val *float64)
NumCacheClustersInput() *float64
NumNodeGroups() *float64
SetNumNodeGroups(val *float64)
NumNodeGroupsInput() *float64
ParameterGroupName() *string
SetParameterGroupName(val *string)
ParameterGroupNameInput() *string
Port() *float64
SetPort(val *float64)
PortInput() *float64
PreferredCacheClusterAzs() *[]*string
SetPreferredCacheClusterAzs(val *[]*string)
PreferredCacheClusterAzsInput() *[]*string
PrimaryEndpointAddress() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ReaderEndpointAddress() *string
ReplicasPerNodeGroup() *float64
SetReplicasPerNodeGroup(val *float64)
ReplicasPerNodeGroupInput() *float64
ReplicationGroupDescription() *string
SetReplicationGroupDescription(val *string)
ReplicationGroupDescriptionInput() *string
ReplicationGroupId() *string
SetReplicationGroupId(val *string)
ReplicationGroupIdInput() *string
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
SecurityGroupNames() *[]*string
SetSecurityGroupNames(val *[]*string)
SecurityGroupNamesInput() *[]*string
SnapshotArns() *[]*string
SetSnapshotArns(val *[]*string)
SnapshotArnsInput() *[]*string
SnapshotName() *string
SetSnapshotName(val *string)
SnapshotNameInput() *string
SnapshotRetentionLimit() *float64
SetSnapshotRetentionLimit(val *float64)
SnapshotRetentionLimitInput() *float64
SnapshotWindow() *string
SetSnapshotWindow(val *string)
SnapshotWindowInput() *string
SubnetGroupName() *string
SetSubnetGroupName(val *string)
SubnetGroupNameInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() ElasticacheReplicationGroupTimeoutsOutputReference
TimeoutsInput() interface{}
TransitEncryptionEnabled() interface{}
SetTransitEncryptionEnabled(val interface{})
TransitEncryptionEnabledInput() interface{}
UserGroupIds() *[]*string
SetUserGroupIds(val *[]*string)
UserGroupIdsInput() *[]*string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutClusterMode(value *ElasticacheReplicationGroupClusterMode)
PutLogDeliveryConfiguration(value interface{})
PutTimeouts(value *ElasticacheReplicationGroupTimeouts)
ResetApplyImmediately()
ResetAtRestEncryptionEnabled()
ResetAuthToken()
ResetAutomaticFailoverEnabled()
ResetAutoMinorVersionUpgrade()
ResetAvailabilityZones()
ResetClusterMode()
ResetDataTieringEnabled()
ResetDescription()
ResetEngine()
ResetEngineVersion()
ResetFinalSnapshotIdentifier()
ResetGlobalReplicationGroupId()
ResetId()
ResetKmsKeyId()
ResetLogDeliveryConfiguration()
ResetMaintenanceWindow()
ResetMultiAzEnabled()
ResetNodeType()
ResetNotificationTopicArn()
ResetNumberCacheClusters()
ResetNumCacheClusters()
ResetNumNodeGroups()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetParameterGroupName()
ResetPort()
ResetPreferredCacheClusterAzs()
ResetReplicasPerNodeGroup()
ResetReplicationGroupDescription()
ResetSecurityGroupIds()
ResetSecurityGroupNames()
ResetSnapshotArns()
ResetSnapshotName()
ResetSnapshotRetentionLimit()
ResetSnapshotWindow()
ResetSubnetGroupName()
ResetTags()
ResetTagsAll()
ResetTimeouts()
ResetTransitEncryptionEnabled()
ResetUserGroupIds()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group aws_elasticache_replication_group}.
func NewElasticacheReplicationGroup ¶
func NewElasticacheReplicationGroup(scope constructs.Construct, id *string, config *ElasticacheReplicationGroupConfig) ElasticacheReplicationGroup
Create a new {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group aws_elasticache_replication_group} Resource.
type ElasticacheReplicationGroupClusterMode ¶
type ElasticacheReplicationGroupClusterMode struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#num_node_groups ElasticacheReplicationGroup#num_node_groups}.
NumNodeGroups *float64 `field:"optional" json:"numNodeGroups" yaml:"numNodeGroups"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#replicas_per_node_group ElasticacheReplicationGroup#replicas_per_node_group}.
ReplicasPerNodeGroup *float64 `field:"optional" json:"replicasPerNodeGroup" yaml:"replicasPerNodeGroup"`
}
type ElasticacheReplicationGroupClusterModeOutputReference ¶
type ElasticacheReplicationGroupClusterModeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ElasticacheReplicationGroupClusterMode
SetInternalValue(val *ElasticacheReplicationGroupClusterMode)
NumNodeGroups() *float64
SetNumNodeGroups(val *float64)
NumNodeGroupsInput() *float64
ReplicasPerNodeGroup() *float64
SetReplicasPerNodeGroup(val *float64)
ReplicasPerNodeGroupInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetNumNodeGroups()
ResetReplicasPerNodeGroup()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElasticacheReplicationGroupClusterModeOutputReference ¶
func NewElasticacheReplicationGroupClusterModeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ElasticacheReplicationGroupClusterModeOutputReference
type ElasticacheReplicationGroupConfig ¶
type ElasticacheReplicationGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#replication_group_id ElasticacheReplicationGroup#replication_group_id}.
ReplicationGroupId *string `field:"required" json:"replicationGroupId" yaml:"replicationGroupId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#apply_immediately ElasticacheReplicationGroup#apply_immediately}.
ApplyImmediately interface{} `field:"optional" json:"applyImmediately" yaml:"applyImmediately"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#at_rest_encryption_enabled ElasticacheReplicationGroup#at_rest_encryption_enabled}.
AtRestEncryptionEnabled interface{} `field:"optional" json:"atRestEncryptionEnabled" yaml:"atRestEncryptionEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#auth_token ElasticacheReplicationGroup#auth_token}.
AuthToken *string `field:"optional" json:"authToken" yaml:"authToken"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#automatic_failover_enabled ElasticacheReplicationGroup#automatic_failover_enabled}.
AutomaticFailoverEnabled interface{} `field:"optional" json:"automaticFailoverEnabled" yaml:"automaticFailoverEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#auto_minor_version_upgrade ElasticacheReplicationGroup#auto_minor_version_upgrade}.
AutoMinorVersionUpgrade *string `field:"optional" json:"autoMinorVersionUpgrade" yaml:"autoMinorVersionUpgrade"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#availability_zones ElasticacheReplicationGroup#availability_zones}.
AvailabilityZones *[]*string `field:"optional" json:"availabilityZones" yaml:"availabilityZones"`
// cluster_mode block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#cluster_mode ElasticacheReplicationGroup#cluster_mode}
ClusterMode *ElasticacheReplicationGroupClusterMode `field:"optional" json:"clusterMode" yaml:"clusterMode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#data_tiering_enabled ElasticacheReplicationGroup#data_tiering_enabled}.
DataTieringEnabled interface{} `field:"optional" json:"dataTieringEnabled" yaml:"dataTieringEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#description ElasticacheReplicationGroup#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#engine ElasticacheReplicationGroup#engine}.
Engine *string `field:"optional" json:"engine" yaml:"engine"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#engine_version ElasticacheReplicationGroup#engine_version}.
EngineVersion *string `field:"optional" json:"engineVersion" yaml:"engineVersion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#final_snapshot_identifier ElasticacheReplicationGroup#final_snapshot_identifier}.
FinalSnapshotIdentifier *string `field:"optional" json:"finalSnapshotIdentifier" yaml:"finalSnapshotIdentifier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#global_replication_group_id ElasticacheReplicationGroup#global_replication_group_id}.
GlobalReplicationGroupId *string `field:"optional" json:"globalReplicationGroupId" yaml:"globalReplicationGroupId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#id ElasticacheReplicationGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#kms_key_id ElasticacheReplicationGroup#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
// log_delivery_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#log_delivery_configuration ElasticacheReplicationGroup#log_delivery_configuration}
LogDeliveryConfiguration interface{} `field:"optional" json:"logDeliveryConfiguration" yaml:"logDeliveryConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#maintenance_window ElasticacheReplicationGroup#maintenance_window}.
MaintenanceWindow *string `field:"optional" json:"maintenanceWindow" yaml:"maintenanceWindow"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#multi_az_enabled ElasticacheReplicationGroup#multi_az_enabled}.
MultiAzEnabled interface{} `field:"optional" json:"multiAzEnabled" yaml:"multiAzEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#node_type ElasticacheReplicationGroup#node_type}.
NodeType *string `field:"optional" json:"nodeType" yaml:"nodeType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#notification_topic_arn ElasticacheReplicationGroup#notification_topic_arn}.
NotificationTopicArn *string `field:"optional" json:"notificationTopicArn" yaml:"notificationTopicArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#number_cache_clusters ElasticacheReplicationGroup#number_cache_clusters}.
NumberCacheClusters *float64 `field:"optional" json:"numberCacheClusters" yaml:"numberCacheClusters"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#num_cache_clusters ElasticacheReplicationGroup#num_cache_clusters}.
NumCacheClusters *float64 `field:"optional" json:"numCacheClusters" yaml:"numCacheClusters"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#num_node_groups ElasticacheReplicationGroup#num_node_groups}.
NumNodeGroups *float64 `field:"optional" json:"numNodeGroups" yaml:"numNodeGroups"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#parameter_group_name ElasticacheReplicationGroup#parameter_group_name}.
ParameterGroupName *string `field:"optional" json:"parameterGroupName" yaml:"parameterGroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#port ElasticacheReplicationGroup#port}.
Port *float64 `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#preferred_cache_cluster_azs ElasticacheReplicationGroup#preferred_cache_cluster_azs}.
PreferredCacheClusterAzs *[]*string `field:"optional" json:"preferredCacheClusterAzs" yaml:"preferredCacheClusterAzs"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#replicas_per_node_group ElasticacheReplicationGroup#replicas_per_node_group}.
ReplicasPerNodeGroup *float64 `field:"optional" json:"replicasPerNodeGroup" yaml:"replicasPerNodeGroup"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#replication_group_description ElasticacheReplicationGroup#replication_group_description}.
ReplicationGroupDescription *string `field:"optional" json:"replicationGroupDescription" yaml:"replicationGroupDescription"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#security_group_ids ElasticacheReplicationGroup#security_group_ids}.
SecurityGroupIds *[]*string `field:"optional" json:"securityGroupIds" yaml:"securityGroupIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#security_group_names ElasticacheReplicationGroup#security_group_names}.
SecurityGroupNames *[]*string `field:"optional" json:"securityGroupNames" yaml:"securityGroupNames"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#snapshot_arns ElasticacheReplicationGroup#snapshot_arns}.
SnapshotArns *[]*string `field:"optional" json:"snapshotArns" yaml:"snapshotArns"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#snapshot_name ElasticacheReplicationGroup#snapshot_name}.
SnapshotName *string `field:"optional" json:"snapshotName" yaml:"snapshotName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#snapshot_retention_limit ElasticacheReplicationGroup#snapshot_retention_limit}.
SnapshotRetentionLimit *float64 `field:"optional" json:"snapshotRetentionLimit" yaml:"snapshotRetentionLimit"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#snapshot_window ElasticacheReplicationGroup#snapshot_window}.
SnapshotWindow *string `field:"optional" json:"snapshotWindow" yaml:"snapshotWindow"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#subnet_group_name ElasticacheReplicationGroup#subnet_group_name}.
SubnetGroupName *string `field:"optional" json:"subnetGroupName" yaml:"subnetGroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#tags ElasticacheReplicationGroup#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#tags_all ElasticacheReplicationGroup#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#timeouts ElasticacheReplicationGroup#timeouts}
Timeouts *ElasticacheReplicationGroupTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#transit_encryption_enabled ElasticacheReplicationGroup#transit_encryption_enabled}.
TransitEncryptionEnabled interface{} `field:"optional" json:"transitEncryptionEnabled" yaml:"transitEncryptionEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#user_group_ids ElasticacheReplicationGroup#user_group_ids}.
UserGroupIds *[]*string `field:"optional" json:"userGroupIds" yaml:"userGroupIds"`
}
type ElasticacheReplicationGroupLogDeliveryConfiguration ¶
type ElasticacheReplicationGroupLogDeliveryConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#destination ElasticacheReplicationGroup#destination}.
Destination *string `field:"required" json:"destination" yaml:"destination"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#destination_type ElasticacheReplicationGroup#destination_type}.
DestinationType *string `field:"required" json:"destinationType" yaml:"destinationType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#log_format ElasticacheReplicationGroup#log_format}.
LogFormat *string `field:"required" json:"logFormat" yaml:"logFormat"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#log_type ElasticacheReplicationGroup#log_type}.
LogType *string `field:"required" json:"logType" yaml:"logType"`
}
type ElasticacheReplicationGroupLogDeliveryConfigurationList ¶
type ElasticacheReplicationGroupLogDeliveryConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ElasticacheReplicationGroupLogDeliveryConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElasticacheReplicationGroupLogDeliveryConfigurationList ¶
func NewElasticacheReplicationGroupLogDeliveryConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ElasticacheReplicationGroupLogDeliveryConfigurationList
type ElasticacheReplicationGroupLogDeliveryConfigurationOutputReference ¶
type ElasticacheReplicationGroupLogDeliveryConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Destination() *string
SetDestination(val *string)
DestinationInput() *string
DestinationType() *string
SetDestinationType(val *string)
DestinationTypeInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
LogFormat() *string
SetLogFormat(val *string)
LogFormatInput() *string
LogType() *string
SetLogType(val *string)
LogTypeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElasticacheReplicationGroupLogDeliveryConfigurationOutputReference ¶
func NewElasticacheReplicationGroupLogDeliveryConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ElasticacheReplicationGroupLogDeliveryConfigurationOutputReference
type ElasticacheReplicationGroupTimeouts ¶
type ElasticacheReplicationGroupTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#create ElasticacheReplicationGroup#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#delete ElasticacheReplicationGroup#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticache_replication_group#update ElasticacheReplicationGroup#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type ElasticacheReplicationGroupTimeoutsOutputReference ¶
type ElasticacheReplicationGroupTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElasticacheReplicationGroupTimeoutsOutputReference ¶
func NewElasticacheReplicationGroupTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ElasticacheReplicationGroupTimeoutsOutputReference
Source Files
¶
- elasticachereplicationgroup.go
- elasticachereplicationgroup_ElasticacheReplicationGroup.go
- elasticachereplicationgroup_ElasticacheReplicationGroupClusterMode.go
- elasticachereplicationgroup_ElasticacheReplicationGroupClusterModeOutputReference.go
- elasticachereplicationgroup_ElasticacheReplicationGroupClusterModeOutputReference__runtime_type_checks.go
- elasticachereplicationgroup_ElasticacheReplicationGroupConfig.go
- elasticachereplicationgroup_ElasticacheReplicationGroupLogDeliveryConfiguration.go
- elasticachereplicationgroup_ElasticacheReplicationGroupLogDeliveryConfigurationList.go
- elasticachereplicationgroup_ElasticacheReplicationGroupLogDeliveryConfigurationList__runtime_type_checks.go
- elasticachereplicationgroup_ElasticacheReplicationGroupLogDeliveryConfigurationOutputReference.go
- elasticachereplicationgroup_ElasticacheReplicationGroupLogDeliveryConfigurationOutputReference__runtime_type_checks.go
- elasticachereplicationgroup_ElasticacheReplicationGroupTimeouts.go
- elasticachereplicationgroup_ElasticacheReplicationGroupTimeoutsOutputReference.go
- elasticachereplicationgroup_ElasticacheReplicationGroupTimeoutsOutputReference__runtime_type_checks.go
- elasticachereplicationgroup_ElasticacheReplicationGroup__runtime_type_checks.go