Documentation
¶
Index ¶
- func ElasticBeanstalkConfigurationTemplate_IsConstruct(x interface{}) *bool
- func ElasticBeanstalkConfigurationTemplate_IsTerraformElement(x interface{}) *bool
- func ElasticBeanstalkConfigurationTemplate_IsTerraformResource(x interface{}) *bool
- func ElasticBeanstalkConfigurationTemplate_TfResourceType() *string
- func NewElasticBeanstalkConfigurationTemplateSettingList_Override(e ElasticBeanstalkConfigurationTemplateSettingList, ...)
- func NewElasticBeanstalkConfigurationTemplateSettingOutputReference_Override(e ElasticBeanstalkConfigurationTemplateSettingOutputReference, ...)
- func NewElasticBeanstalkConfigurationTemplate_Override(e ElasticBeanstalkConfigurationTemplate, scope constructs.Construct, ...)
- type ElasticBeanstalkConfigurationTemplate
- type ElasticBeanstalkConfigurationTemplateConfig
- type ElasticBeanstalkConfigurationTemplateSetting
- type ElasticBeanstalkConfigurationTemplateSettingList
- type ElasticBeanstalkConfigurationTemplateSettingOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ElasticBeanstalkConfigurationTemplate_IsConstruct ¶
func ElasticBeanstalkConfigurationTemplate_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ElasticBeanstalkConfigurationTemplate_IsTerraformElement ¶
func ElasticBeanstalkConfigurationTemplate_IsTerraformElement(x interface{}) *bool
Experimental.
func ElasticBeanstalkConfigurationTemplate_IsTerraformResource ¶
func ElasticBeanstalkConfigurationTemplate_IsTerraformResource(x interface{}) *bool
Experimental.
func ElasticBeanstalkConfigurationTemplate_TfResourceType ¶
func ElasticBeanstalkConfigurationTemplate_TfResourceType() *string
func NewElasticBeanstalkConfigurationTemplateSettingList_Override ¶
func NewElasticBeanstalkConfigurationTemplateSettingList_Override(e ElasticBeanstalkConfigurationTemplateSettingList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewElasticBeanstalkConfigurationTemplateSettingOutputReference_Override ¶
func NewElasticBeanstalkConfigurationTemplateSettingOutputReference_Override(e ElasticBeanstalkConfigurationTemplateSettingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewElasticBeanstalkConfigurationTemplate_Override ¶
func NewElasticBeanstalkConfigurationTemplate_Override(e ElasticBeanstalkConfigurationTemplate, scope constructs.Construct, id *string, config *ElasticBeanstalkConfigurationTemplateConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/elastic_beanstalk_configuration_template aws_elastic_beanstalk_configuration_template} Resource.
Types ¶
type ElasticBeanstalkConfigurationTemplate ¶
type ElasticBeanstalkConfigurationTemplate interface {
cdktf.TerraformResource
Application() *string
SetApplication(val *string)
ApplicationInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
EnvironmentId() *string
SetEnvironmentId(val *string)
EnvironmentIdInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Setting() ElasticBeanstalkConfigurationTemplateSettingList
SettingInput() interface{}
SolutionStackName() *string
SetSolutionStackName(val *string)
SolutionStackNameInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutSetting(value interface{})
ResetDescription()
ResetEnvironmentId()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSetting()
ResetSolutionStackName()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/elastic_beanstalk_configuration_template aws_elastic_beanstalk_configuration_template}.
func NewElasticBeanstalkConfigurationTemplate ¶
func NewElasticBeanstalkConfigurationTemplate(scope constructs.Construct, id *string, config *ElasticBeanstalkConfigurationTemplateConfig) ElasticBeanstalkConfigurationTemplate
Create a new {@link https://www.terraform.io/docs/providers/aws/r/elastic_beanstalk_configuration_template aws_elastic_beanstalk_configuration_template} Resource.
type ElasticBeanstalkConfigurationTemplateConfig ¶
type ElasticBeanstalkConfigurationTemplateConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastic_beanstalk_configuration_template#application ElasticBeanstalkConfigurationTemplate#application}.
Application *string `field:"required" json:"application" yaml:"application"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastic_beanstalk_configuration_template#name ElasticBeanstalkConfigurationTemplate#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastic_beanstalk_configuration_template#description ElasticBeanstalkConfigurationTemplate#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastic_beanstalk_configuration_template#environment_id ElasticBeanstalkConfigurationTemplate#environment_id}.
EnvironmentId *string `field:"optional" json:"environmentId" yaml:"environmentId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastic_beanstalk_configuration_template#id ElasticBeanstalkConfigurationTemplate#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// setting block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastic_beanstalk_configuration_template#setting ElasticBeanstalkConfigurationTemplate#setting}
Setting interface{} `field:"optional" json:"setting" yaml:"setting"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastic_beanstalk_configuration_template#solution_stack_name ElasticBeanstalkConfigurationTemplate#solution_stack_name}.
SolutionStackName *string `field:"optional" json:"solutionStackName" yaml:"solutionStackName"`
}
type ElasticBeanstalkConfigurationTemplateSetting ¶
type ElasticBeanstalkConfigurationTemplateSetting struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastic_beanstalk_configuration_template#name ElasticBeanstalkConfigurationTemplate#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastic_beanstalk_configuration_template#namespace ElasticBeanstalkConfigurationTemplate#namespace}.
Namespace *string `field:"required" json:"namespace" yaml:"namespace"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastic_beanstalk_configuration_template#value ElasticBeanstalkConfigurationTemplate#value}.
Value *string `field:"required" json:"value" yaml:"value"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastic_beanstalk_configuration_template#resource ElasticBeanstalkConfigurationTemplate#resource}.
Resource *string `field:"optional" json:"resource" yaml:"resource"`
}
type ElasticBeanstalkConfigurationTemplateSettingList ¶
type ElasticBeanstalkConfigurationTemplateSettingList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ElasticBeanstalkConfigurationTemplateSettingOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElasticBeanstalkConfigurationTemplateSettingList ¶
func NewElasticBeanstalkConfigurationTemplateSettingList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ElasticBeanstalkConfigurationTemplateSettingList
type ElasticBeanstalkConfigurationTemplateSettingOutputReference ¶
type ElasticBeanstalkConfigurationTemplateSettingOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
Namespace() *string
SetNamespace(val *string)
NamespaceInput() *string
Resource() *string
SetResource(val *string)
ResourceInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetResource()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElasticBeanstalkConfigurationTemplateSettingOutputReference ¶
func NewElasticBeanstalkConfigurationTemplateSettingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ElasticBeanstalkConfigurationTemplateSettingOutputReference
Source Files
¶
- elasticbeanstalkconfigurationtemplate.go
- elasticbeanstalkconfigurationtemplate_ElasticBeanstalkConfigurationTemplate.go
- elasticbeanstalkconfigurationtemplate_ElasticBeanstalkConfigurationTemplateConfig.go
- elasticbeanstalkconfigurationtemplate_ElasticBeanstalkConfigurationTemplateSetting.go
- elasticbeanstalkconfigurationtemplate_ElasticBeanstalkConfigurationTemplateSettingList.go
- elasticbeanstalkconfigurationtemplate_ElasticBeanstalkConfigurationTemplateSettingList__runtime_type_checks.go
- elasticbeanstalkconfigurationtemplate_ElasticBeanstalkConfigurationTemplateSettingOutputReference.go
- elasticbeanstalkconfigurationtemplate_ElasticBeanstalkConfigurationTemplateSettingOutputReference__runtime_type_checks.go
- elasticbeanstalkconfigurationtemplate_ElasticBeanstalkConfigurationTemplate__runtime_type_checks.go