Documentation
¶
Index ¶
- func EmrInstanceGroup_IsConstruct(x interface{}) *bool
- func EmrInstanceGroup_IsTerraformElement(x interface{}) *bool
- func EmrInstanceGroup_IsTerraformResource(x interface{}) *bool
- func EmrInstanceGroup_TfResourceType() *string
- func NewEmrInstanceGroupEbsConfigList_Override(e EmrInstanceGroupEbsConfigList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewEmrInstanceGroupEbsConfigOutputReference_Override(e EmrInstanceGroupEbsConfigOutputReference, ...)
- func NewEmrInstanceGroup_Override(e EmrInstanceGroup, scope constructs.Construct, id *string, ...)
- type EmrInstanceGroup
- type EmrInstanceGroupConfig
- type EmrInstanceGroupEbsConfig
- type EmrInstanceGroupEbsConfigList
- type EmrInstanceGroupEbsConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EmrInstanceGroup_IsConstruct ¶
func EmrInstanceGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func EmrInstanceGroup_IsTerraformElement ¶
func EmrInstanceGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func EmrInstanceGroup_IsTerraformResource ¶
func EmrInstanceGroup_IsTerraformResource(x interface{}) *bool
Experimental.
func EmrInstanceGroup_TfResourceType ¶
func EmrInstanceGroup_TfResourceType() *string
func NewEmrInstanceGroupEbsConfigList_Override ¶
func NewEmrInstanceGroupEbsConfigList_Override(e EmrInstanceGroupEbsConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEmrInstanceGroupEbsConfigOutputReference_Override ¶
func NewEmrInstanceGroupEbsConfigOutputReference_Override(e EmrInstanceGroupEbsConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEmrInstanceGroup_Override ¶
func NewEmrInstanceGroup_Override(e EmrInstanceGroup, scope constructs.Construct, id *string, config *EmrInstanceGroupConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/emr_instance_group aws_emr_instance_group} Resource.
Types ¶
type EmrInstanceGroup ¶
type EmrInstanceGroup interface {
cdktf.TerraformResource
AutoscalingPolicy() *string
SetAutoscalingPolicy(val *string)
AutoscalingPolicyInput() *string
BidPrice() *string
SetBidPrice(val *string)
BidPriceInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterId() *string
SetClusterId(val *string)
ClusterIdInput() *string
ConfigurationsJson() *string
SetConfigurationsJson(val *string)
ConfigurationsJsonInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EbsConfig() EmrInstanceGroupEbsConfigList
EbsConfigInput() interface{}
EbsOptimized() interface{}
SetEbsOptimized(val interface{})
EbsOptimizedInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InstanceCount() *float64
SetInstanceCount(val *float64)
InstanceCountInput() *float64
InstanceType() *string
SetInstanceType(val *string)
InstanceTypeInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RunningInstanceCount() *float64
Status() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutEbsConfig(value interface{})
ResetAutoscalingPolicy()
ResetBidPrice()
ResetConfigurationsJson()
ResetEbsConfig()
ResetEbsOptimized()
ResetId()
ResetInstanceCount()
ResetName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/emr_instance_group aws_emr_instance_group}.
func NewEmrInstanceGroup ¶
func NewEmrInstanceGroup(scope constructs.Construct, id *string, config *EmrInstanceGroupConfig) EmrInstanceGroup
Create a new {@link https://www.terraform.io/docs/providers/aws/r/emr_instance_group aws_emr_instance_group} Resource.
type EmrInstanceGroupConfig ¶
type EmrInstanceGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_instance_group#cluster_id EmrInstanceGroup#cluster_id}.
ClusterId *string `field:"required" json:"clusterId" yaml:"clusterId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_instance_group#instance_type EmrInstanceGroup#instance_type}.
InstanceType *string `field:"required" json:"instanceType" yaml:"instanceType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_instance_group#autoscaling_policy EmrInstanceGroup#autoscaling_policy}.
AutoscalingPolicy *string `field:"optional" json:"autoscalingPolicy" yaml:"autoscalingPolicy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_instance_group#bid_price EmrInstanceGroup#bid_price}.
BidPrice *string `field:"optional" json:"bidPrice" yaml:"bidPrice"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_instance_group#configurations_json EmrInstanceGroup#configurations_json}.
ConfigurationsJson *string `field:"optional" json:"configurationsJson" yaml:"configurationsJson"`
// ebs_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_instance_group#ebs_config EmrInstanceGroup#ebs_config}
EbsConfig interface{} `field:"optional" json:"ebsConfig" yaml:"ebsConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_instance_group#ebs_optimized EmrInstanceGroup#ebs_optimized}.
EbsOptimized interface{} `field:"optional" json:"ebsOptimized" yaml:"ebsOptimized"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_instance_group#id EmrInstanceGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_instance_group#instance_count EmrInstanceGroup#instance_count}.
InstanceCount *float64 `field:"optional" json:"instanceCount" yaml:"instanceCount"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_instance_group#name EmrInstanceGroup#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
}
type EmrInstanceGroupEbsConfig ¶
type EmrInstanceGroupEbsConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_instance_group#size EmrInstanceGroup#size}.
Size *float64 `field:"required" json:"size" yaml:"size"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_instance_group#type EmrInstanceGroup#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_instance_group#iops EmrInstanceGroup#iops}.
Iops *float64 `field:"optional" json:"iops" yaml:"iops"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_instance_group#volumes_per_instance EmrInstanceGroup#volumes_per_instance}.
VolumesPerInstance *float64 `field:"optional" json:"volumesPerInstance" yaml:"volumesPerInstance"`
}
type EmrInstanceGroupEbsConfigList ¶
type EmrInstanceGroupEbsConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EmrInstanceGroupEbsConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrInstanceGroupEbsConfigList ¶
func NewEmrInstanceGroupEbsConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EmrInstanceGroupEbsConfigList
type EmrInstanceGroupEbsConfigOutputReference ¶
type EmrInstanceGroupEbsConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Iops() *float64
SetIops(val *float64)
IopsInput() *float64
Size() *float64
SetSize(val *float64)
SizeInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
VolumesPerInstance() *float64
SetVolumesPerInstance(val *float64)
VolumesPerInstanceInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetIops()
ResetVolumesPerInstance()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrInstanceGroupEbsConfigOutputReference ¶
func NewEmrInstanceGroupEbsConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EmrInstanceGroupEbsConfigOutputReference
Source Files
¶
- emrinstancegroup.go
- emrinstancegroup_EmrInstanceGroup.go
- emrinstancegroup_EmrInstanceGroupConfig.go
- emrinstancegroup_EmrInstanceGroupEbsConfig.go
- emrinstancegroup_EmrInstanceGroupEbsConfigList.go
- emrinstancegroup_EmrInstanceGroupEbsConfigList__runtime_type_checks.go
- emrinstancegroup_EmrInstanceGroupEbsConfigOutputReference.go
- emrinstancegroup_EmrInstanceGroupEbsConfigOutputReference__runtime_type_checks.go
- emrinstancegroup_EmrInstanceGroup__runtime_type_checks.go