Documentation
¶
Index ¶
- func FlowLog_IsConstruct(x interface{}) *bool
- func FlowLog_IsTerraformElement(x interface{}) *bool
- func FlowLog_IsTerraformResource(x interface{}) *bool
- func FlowLog_TfResourceType() *string
- func NewFlowLogDestinationOptionsOutputReference_Override(f FlowLogDestinationOptionsOutputReference, ...)
- func NewFlowLog_Override(f FlowLog, scope constructs.Construct, id *string, config *FlowLogConfig)
- type FlowLog
- type FlowLogConfig
- type FlowLogDestinationOptions
- type FlowLogDestinationOptionsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FlowLog_IsConstruct ¶
func FlowLog_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func FlowLog_IsTerraformElement ¶
func FlowLog_IsTerraformElement(x interface{}) *bool
Experimental.
func FlowLog_IsTerraformResource ¶
func FlowLog_IsTerraformResource(x interface{}) *bool
Experimental.
func FlowLog_TfResourceType ¶
func FlowLog_TfResourceType() *string
func NewFlowLogDestinationOptionsOutputReference_Override ¶
func NewFlowLogDestinationOptionsOutputReference_Override(f FlowLogDestinationOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFlowLog_Override ¶
func NewFlowLog_Override(f FlowLog, scope constructs.Construct, id *string, config *FlowLogConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/flow_log aws_flow_log} Resource.
Types ¶
type FlowLog ¶
type FlowLog interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DestinationOptions() FlowLogDestinationOptionsOutputReference
DestinationOptionsInput() *FlowLogDestinationOptions
EniId() *string
SetEniId(val *string)
EniIdInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
IamRoleArn() *string
SetIamRoleArn(val *string)
IamRoleArnInput() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LogDestination() *string
SetLogDestination(val *string)
LogDestinationInput() *string
LogDestinationType() *string
SetLogDestinationType(val *string)
LogDestinationTypeInput() *string
LogFormat() *string
SetLogFormat(val *string)
LogFormatInput() *string
LogGroupName() *string
SetLogGroupName(val *string)
LogGroupNameInput() *string
MaxAggregationInterval() *float64
SetMaxAggregationInterval(val *float64)
MaxAggregationIntervalInput() *float64
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SubnetId() *string
SetSubnetId(val *string)
SubnetIdInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
TrafficType() *string
SetTrafficType(val *string)
TrafficTypeInput() *string
TransitGatewayAttachmentId() *string
SetTransitGatewayAttachmentId(val *string)
TransitGatewayAttachmentIdInput() *string
TransitGatewayId() *string
SetTransitGatewayId(val *string)
TransitGatewayIdInput() *string
VpcId() *string
SetVpcId(val *string)
VpcIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDestinationOptions(value *FlowLogDestinationOptions)
ResetDestinationOptions()
ResetEniId()
ResetIamRoleArn()
ResetId()
ResetLogDestination()
ResetLogDestinationType()
ResetLogFormat()
ResetLogGroupName()
ResetMaxAggregationInterval()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSubnetId()
ResetTags()
ResetTagsAll()
ResetTrafficType()
ResetTransitGatewayAttachmentId()
ResetTransitGatewayId()
ResetVpcId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/flow_log aws_flow_log}.
func NewFlowLog ¶
func NewFlowLog(scope constructs.Construct, id *string, config *FlowLogConfig) FlowLog
Create a new {@link https://www.terraform.io/docs/providers/aws/r/flow_log aws_flow_log} Resource.
type FlowLogConfig ¶
type FlowLogConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// destination_options block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log#destination_options FlowLog#destination_options}
DestinationOptions *FlowLogDestinationOptions `field:"optional" json:"destinationOptions" yaml:"destinationOptions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log#eni_id FlowLog#eni_id}.
EniId *string `field:"optional" json:"eniId" yaml:"eniId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log#iam_role_arn FlowLog#iam_role_arn}.
IamRoleArn *string `field:"optional" json:"iamRoleArn" yaml:"iamRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log#id FlowLog#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log#log_destination FlowLog#log_destination}.
LogDestination *string `field:"optional" json:"logDestination" yaml:"logDestination"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log#log_destination_type FlowLog#log_destination_type}.
LogDestinationType *string `field:"optional" json:"logDestinationType" yaml:"logDestinationType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log#log_format FlowLog#log_format}.
LogFormat *string `field:"optional" json:"logFormat" yaml:"logFormat"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log#log_group_name FlowLog#log_group_name}.
LogGroupName *string `field:"optional" json:"logGroupName" yaml:"logGroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log#max_aggregation_interval FlowLog#max_aggregation_interval}.
MaxAggregationInterval *float64 `field:"optional" json:"maxAggregationInterval" yaml:"maxAggregationInterval"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log#subnet_id FlowLog#subnet_id}.
SubnetId *string `field:"optional" json:"subnetId" yaml:"subnetId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log#tags FlowLog#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log#tags_all FlowLog#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log#traffic_type FlowLog#traffic_type}.
TrafficType *string `field:"optional" json:"trafficType" yaml:"trafficType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log#transit_gateway_attachment_id FlowLog#transit_gateway_attachment_id}.
TransitGatewayAttachmentId *string `field:"optional" json:"transitGatewayAttachmentId" yaml:"transitGatewayAttachmentId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log#transit_gateway_id FlowLog#transit_gateway_id}.
TransitGatewayId *string `field:"optional" json:"transitGatewayId" yaml:"transitGatewayId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log#vpc_id FlowLog#vpc_id}.
VpcId *string `field:"optional" json:"vpcId" yaml:"vpcId"`
}
type FlowLogDestinationOptions ¶
type FlowLogDestinationOptions struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log#file_format FlowLog#file_format}.
FileFormat *string `field:"optional" json:"fileFormat" yaml:"fileFormat"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log#hive_compatible_partitions FlowLog#hive_compatible_partitions}.
HiveCompatiblePartitions interface{} `field:"optional" json:"hiveCompatiblePartitions" yaml:"hiveCompatiblePartitions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log#per_hour_partition FlowLog#per_hour_partition}.
PerHourPartition interface{} `field:"optional" json:"perHourPartition" yaml:"perHourPartition"`
}
type FlowLogDestinationOptionsOutputReference ¶
type FlowLogDestinationOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FileFormat() *string
SetFileFormat(val *string)
FileFormatInput() *string
// Experimental.
Fqn() *string
HiveCompatiblePartitions() interface{}
SetHiveCompatiblePartitions(val interface{})
HiveCompatiblePartitionsInput() interface{}
InternalValue() *FlowLogDestinationOptions
SetInternalValue(val *FlowLogDestinationOptions)
PerHourPartition() interface{}
SetPerHourPartition(val interface{})
PerHourPartitionInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetFileFormat()
ResetHiveCompatiblePartitions()
ResetPerHourPartition()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFlowLogDestinationOptionsOutputReference ¶
func NewFlowLogDestinationOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FlowLogDestinationOptionsOutputReference