Documentation
¶
Index ¶
- func FsxOntapFileSystem_IsConstruct(x interface{}) *bool
- func FsxOntapFileSystem_IsTerraformElement(x interface{}) *bool
- func FsxOntapFileSystem_IsTerraformResource(x interface{}) *bool
- func FsxOntapFileSystem_TfResourceType() *string
- func NewFsxOntapFileSystemDiskIopsConfigurationOutputReference_Override(f FsxOntapFileSystemDiskIopsConfigurationOutputReference, ...)
- func NewFsxOntapFileSystemEndpointsInterclusterList_Override(f FsxOntapFileSystemEndpointsInterclusterList, ...)
- func NewFsxOntapFileSystemEndpointsInterclusterOutputReference_Override(f FsxOntapFileSystemEndpointsInterclusterOutputReference, ...)
- func NewFsxOntapFileSystemEndpointsList_Override(f FsxOntapFileSystemEndpointsList, ...)
- func NewFsxOntapFileSystemEndpointsManagementList_Override(f FsxOntapFileSystemEndpointsManagementList, ...)
- func NewFsxOntapFileSystemEndpointsManagementOutputReference_Override(f FsxOntapFileSystemEndpointsManagementOutputReference, ...)
- func NewFsxOntapFileSystemEndpointsOutputReference_Override(f FsxOntapFileSystemEndpointsOutputReference, ...)
- func NewFsxOntapFileSystemTimeoutsOutputReference_Override(f FsxOntapFileSystemTimeoutsOutputReference, ...)
- func NewFsxOntapFileSystem_Override(f FsxOntapFileSystem, scope constructs.Construct, id *string, ...)
- type FsxOntapFileSystem
- type FsxOntapFileSystemConfig
- type FsxOntapFileSystemDiskIopsConfiguration
- type FsxOntapFileSystemDiskIopsConfigurationOutputReference
- type FsxOntapFileSystemEndpoints
- type FsxOntapFileSystemEndpointsIntercluster
- type FsxOntapFileSystemEndpointsInterclusterList
- type FsxOntapFileSystemEndpointsInterclusterOutputReference
- type FsxOntapFileSystemEndpointsList
- type FsxOntapFileSystemEndpointsManagement
- type FsxOntapFileSystemEndpointsManagementList
- type FsxOntapFileSystemEndpointsManagementOutputReference
- type FsxOntapFileSystemEndpointsOutputReference
- type FsxOntapFileSystemTimeouts
- type FsxOntapFileSystemTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FsxOntapFileSystem_IsConstruct ¶
func FsxOntapFileSystem_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func FsxOntapFileSystem_IsTerraformElement ¶
func FsxOntapFileSystem_IsTerraformElement(x interface{}) *bool
Experimental.
func FsxOntapFileSystem_IsTerraformResource ¶
func FsxOntapFileSystem_IsTerraformResource(x interface{}) *bool
Experimental.
func FsxOntapFileSystem_TfResourceType ¶
func FsxOntapFileSystem_TfResourceType() *string
func NewFsxOntapFileSystemDiskIopsConfigurationOutputReference_Override ¶
func NewFsxOntapFileSystemDiskIopsConfigurationOutputReference_Override(f FsxOntapFileSystemDiskIopsConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFsxOntapFileSystemEndpointsInterclusterList_Override ¶
func NewFsxOntapFileSystemEndpointsInterclusterList_Override(f FsxOntapFileSystemEndpointsInterclusterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewFsxOntapFileSystemEndpointsInterclusterOutputReference_Override ¶
func NewFsxOntapFileSystemEndpointsInterclusterOutputReference_Override(f FsxOntapFileSystemEndpointsInterclusterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewFsxOntapFileSystemEndpointsList_Override ¶
func NewFsxOntapFileSystemEndpointsList_Override(f FsxOntapFileSystemEndpointsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewFsxOntapFileSystemEndpointsManagementList_Override ¶
func NewFsxOntapFileSystemEndpointsManagementList_Override(f FsxOntapFileSystemEndpointsManagementList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewFsxOntapFileSystemEndpointsManagementOutputReference_Override ¶
func NewFsxOntapFileSystemEndpointsManagementOutputReference_Override(f FsxOntapFileSystemEndpointsManagementOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewFsxOntapFileSystemEndpointsOutputReference_Override ¶
func NewFsxOntapFileSystemEndpointsOutputReference_Override(f FsxOntapFileSystemEndpointsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewFsxOntapFileSystemTimeoutsOutputReference_Override ¶
func NewFsxOntapFileSystemTimeoutsOutputReference_Override(f FsxOntapFileSystemTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFsxOntapFileSystem_Override ¶
func NewFsxOntapFileSystem_Override(f FsxOntapFileSystem, scope constructs.Construct, id *string, config *FsxOntapFileSystemConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system aws_fsx_ontap_file_system} Resource.
Types ¶
type FsxOntapFileSystem ¶
type FsxOntapFileSystem interface {
cdktf.TerraformResource
Arn() *string
AutomaticBackupRetentionDays() *float64
SetAutomaticBackupRetentionDays(val *float64)
AutomaticBackupRetentionDaysInput() *float64
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DailyAutomaticBackupStartTime() *string
SetDailyAutomaticBackupStartTime(val *string)
DailyAutomaticBackupStartTimeInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeploymentType() *string
SetDeploymentType(val *string)
DeploymentTypeInput() *string
DiskIopsConfiguration() FsxOntapFileSystemDiskIopsConfigurationOutputReference
DiskIopsConfigurationInput() *FsxOntapFileSystemDiskIopsConfiguration
DnsName() *string
EndpointIpAddressRange() *string
SetEndpointIpAddressRange(val *string)
EndpointIpAddressRangeInput() *string
Endpoints() FsxOntapFileSystemEndpointsList
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
FsxAdminPassword() *string
SetFsxAdminPassword(val *string)
FsxAdminPasswordInput() *string
Id() *string
SetId(val *string)
IdInput() *string
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
NetworkInterfaceIds() *[]*string
// The tree node.
Node() constructs.Node
OwnerId() *string
PreferredSubnetId() *string
SetPreferredSubnetId(val *string)
PreferredSubnetIdInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RouteTableIds() *[]*string
SetRouteTableIds(val *[]*string)
RouteTableIdsInput() *[]*string
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
StorageCapacity() *float64
SetStorageCapacity(val *float64)
StorageCapacityInput() *float64
StorageType() *string
SetStorageType(val *string)
StorageTypeInput() *string
SubnetIds() *[]*string
SetSubnetIds(val *[]*string)
SubnetIdsInput() *[]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
ThroughputCapacity() *float64
SetThroughputCapacity(val *float64)
ThroughputCapacityInput() *float64
Timeouts() FsxOntapFileSystemTimeoutsOutputReference
TimeoutsInput() interface{}
VpcId() *string
WeeklyMaintenanceStartTime() *string
SetWeeklyMaintenanceStartTime(val *string)
WeeklyMaintenanceStartTimeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDiskIopsConfiguration(value *FsxOntapFileSystemDiskIopsConfiguration)
PutTimeouts(value *FsxOntapFileSystemTimeouts)
ResetAutomaticBackupRetentionDays()
ResetDailyAutomaticBackupStartTime()
ResetDiskIopsConfiguration()
ResetEndpointIpAddressRange()
ResetFsxAdminPassword()
ResetId()
ResetKmsKeyId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRouteTableIds()
ResetSecurityGroupIds()
ResetStorageCapacity()
ResetStorageType()
ResetTags()
ResetTagsAll()
ResetTimeouts()
ResetWeeklyMaintenanceStartTime()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system aws_fsx_ontap_file_system}.
func NewFsxOntapFileSystem ¶
func NewFsxOntapFileSystem(scope constructs.Construct, id *string, config *FsxOntapFileSystemConfig) FsxOntapFileSystem
Create a new {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system aws_fsx_ontap_file_system} Resource.
type FsxOntapFileSystemConfig ¶
type FsxOntapFileSystemConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#deployment_type FsxOntapFileSystem#deployment_type}.
DeploymentType *string `field:"required" json:"deploymentType" yaml:"deploymentType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#preferred_subnet_id FsxOntapFileSystem#preferred_subnet_id}.
PreferredSubnetId *string `field:"required" json:"preferredSubnetId" yaml:"preferredSubnetId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#subnet_ids FsxOntapFileSystem#subnet_ids}.
SubnetIds *[]*string `field:"required" json:"subnetIds" yaml:"subnetIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#throughput_capacity FsxOntapFileSystem#throughput_capacity}.
ThroughputCapacity *float64 `field:"required" json:"throughputCapacity" yaml:"throughputCapacity"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#automatic_backup_retention_days FsxOntapFileSystem#automatic_backup_retention_days}.
AutomaticBackupRetentionDays *float64 `field:"optional" json:"automaticBackupRetentionDays" yaml:"automaticBackupRetentionDays"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#daily_automatic_backup_start_time FsxOntapFileSystem#daily_automatic_backup_start_time}.
DailyAutomaticBackupStartTime *string `field:"optional" json:"dailyAutomaticBackupStartTime" yaml:"dailyAutomaticBackupStartTime"`
// disk_iops_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#disk_iops_configuration FsxOntapFileSystem#disk_iops_configuration}
DiskIopsConfiguration *FsxOntapFileSystemDiskIopsConfiguration `field:"optional" json:"diskIopsConfiguration" yaml:"diskIopsConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#endpoint_ip_address_range FsxOntapFileSystem#endpoint_ip_address_range}.
EndpointIpAddressRange *string `field:"optional" json:"endpointIpAddressRange" yaml:"endpointIpAddressRange"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#fsx_admin_password FsxOntapFileSystem#fsx_admin_password}.
FsxAdminPassword *string `field:"optional" json:"fsxAdminPassword" yaml:"fsxAdminPassword"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#id FsxOntapFileSystem#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#kms_key_id FsxOntapFileSystem#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#route_table_ids FsxOntapFileSystem#route_table_ids}.
RouteTableIds *[]*string `field:"optional" json:"routeTableIds" yaml:"routeTableIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#security_group_ids FsxOntapFileSystem#security_group_ids}.
SecurityGroupIds *[]*string `field:"optional" json:"securityGroupIds" yaml:"securityGroupIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#storage_capacity FsxOntapFileSystem#storage_capacity}.
StorageCapacity *float64 `field:"optional" json:"storageCapacity" yaml:"storageCapacity"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#storage_type FsxOntapFileSystem#storage_type}.
StorageType *string `field:"optional" json:"storageType" yaml:"storageType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#tags FsxOntapFileSystem#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#tags_all FsxOntapFileSystem#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#timeouts FsxOntapFileSystem#timeouts}
Timeouts *FsxOntapFileSystemTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#weekly_maintenance_start_time FsxOntapFileSystem#weekly_maintenance_start_time}.
WeeklyMaintenanceStartTime *string `field:"optional" json:"weeklyMaintenanceStartTime" yaml:"weeklyMaintenanceStartTime"`
}
type FsxOntapFileSystemDiskIopsConfiguration ¶
type FsxOntapFileSystemDiskIopsConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#iops FsxOntapFileSystem#iops}.
Iops *float64 `field:"optional" json:"iops" yaml:"iops"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#mode FsxOntapFileSystem#mode}.
Mode *string `field:"optional" json:"mode" yaml:"mode"`
}
type FsxOntapFileSystemDiskIopsConfigurationOutputReference ¶
type FsxOntapFileSystemDiskIopsConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *FsxOntapFileSystemDiskIopsConfiguration
SetInternalValue(val *FsxOntapFileSystemDiskIopsConfiguration)
Iops() *float64
SetIops(val *float64)
IopsInput() *float64
Mode() *string
SetMode(val *string)
ModeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetIops()
ResetMode()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxOntapFileSystemDiskIopsConfigurationOutputReference ¶
func NewFsxOntapFileSystemDiskIopsConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FsxOntapFileSystemDiskIopsConfigurationOutputReference
type FsxOntapFileSystemEndpoints ¶
type FsxOntapFileSystemEndpoints struct {
}
type FsxOntapFileSystemEndpointsIntercluster ¶
type FsxOntapFileSystemEndpointsIntercluster struct {
}
type FsxOntapFileSystemEndpointsInterclusterList ¶
type FsxOntapFileSystemEndpointsInterclusterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) FsxOntapFileSystemEndpointsInterclusterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxOntapFileSystemEndpointsInterclusterList ¶
func NewFsxOntapFileSystemEndpointsInterclusterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) FsxOntapFileSystemEndpointsInterclusterList
type FsxOntapFileSystemEndpointsInterclusterOutputReference ¶
type FsxOntapFileSystemEndpointsInterclusterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DnsName() *string
// Experimental.
Fqn() *string
InternalValue() *FsxOntapFileSystemEndpointsIntercluster
SetInternalValue(val *FsxOntapFileSystemEndpointsIntercluster)
IpAddresses() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxOntapFileSystemEndpointsInterclusterOutputReference ¶
func NewFsxOntapFileSystemEndpointsInterclusterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) FsxOntapFileSystemEndpointsInterclusterOutputReference
type FsxOntapFileSystemEndpointsList ¶
type FsxOntapFileSystemEndpointsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) FsxOntapFileSystemEndpointsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxOntapFileSystemEndpointsList ¶
func NewFsxOntapFileSystemEndpointsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) FsxOntapFileSystemEndpointsList
type FsxOntapFileSystemEndpointsManagement ¶
type FsxOntapFileSystemEndpointsManagement struct {
}
type FsxOntapFileSystemEndpointsManagementList ¶
type FsxOntapFileSystemEndpointsManagementList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) FsxOntapFileSystemEndpointsManagementOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxOntapFileSystemEndpointsManagementList ¶
func NewFsxOntapFileSystemEndpointsManagementList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) FsxOntapFileSystemEndpointsManagementList
type FsxOntapFileSystemEndpointsManagementOutputReference ¶
type FsxOntapFileSystemEndpointsManagementOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DnsName() *string
// Experimental.
Fqn() *string
InternalValue() *FsxOntapFileSystemEndpointsManagement
SetInternalValue(val *FsxOntapFileSystemEndpointsManagement)
IpAddresses() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxOntapFileSystemEndpointsManagementOutputReference ¶
func NewFsxOntapFileSystemEndpointsManagementOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) FsxOntapFileSystemEndpointsManagementOutputReference
type FsxOntapFileSystemEndpointsOutputReference ¶
type FsxOntapFileSystemEndpointsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Intercluster() FsxOntapFileSystemEndpointsInterclusterList
InternalValue() *FsxOntapFileSystemEndpoints
SetInternalValue(val *FsxOntapFileSystemEndpoints)
Management() FsxOntapFileSystemEndpointsManagementList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxOntapFileSystemEndpointsOutputReference ¶
func NewFsxOntapFileSystemEndpointsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) FsxOntapFileSystemEndpointsOutputReference
type FsxOntapFileSystemTimeouts ¶
type FsxOntapFileSystemTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#create FsxOntapFileSystem#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#delete FsxOntapFileSystem#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system#update FsxOntapFileSystem#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type FsxOntapFileSystemTimeoutsOutputReference ¶
type FsxOntapFileSystemTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxOntapFileSystemTimeoutsOutputReference ¶
func NewFsxOntapFileSystemTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FsxOntapFileSystemTimeoutsOutputReference
Source Files
¶
- fsxontapfilesystem.go
- fsxontapfilesystem_FsxOntapFileSystem.go
- fsxontapfilesystem_FsxOntapFileSystemConfig.go
- fsxontapfilesystem_FsxOntapFileSystemDiskIopsConfiguration.go
- fsxontapfilesystem_FsxOntapFileSystemDiskIopsConfigurationOutputReference.go
- fsxontapfilesystem_FsxOntapFileSystemDiskIopsConfigurationOutputReference__runtime_type_checks.go
- fsxontapfilesystem_FsxOntapFileSystemEndpoints.go
- fsxontapfilesystem_FsxOntapFileSystemEndpointsIntercluster.go
- fsxontapfilesystem_FsxOntapFileSystemEndpointsInterclusterList.go
- fsxontapfilesystem_FsxOntapFileSystemEndpointsInterclusterList__runtime_type_checks.go
- fsxontapfilesystem_FsxOntapFileSystemEndpointsInterclusterOutputReference.go
- fsxontapfilesystem_FsxOntapFileSystemEndpointsInterclusterOutputReference__runtime_type_checks.go
- fsxontapfilesystem_FsxOntapFileSystemEndpointsList.go
- fsxontapfilesystem_FsxOntapFileSystemEndpointsList__runtime_type_checks.go
- fsxontapfilesystem_FsxOntapFileSystemEndpointsManagement.go
- fsxontapfilesystem_FsxOntapFileSystemEndpointsManagementList.go
- fsxontapfilesystem_FsxOntapFileSystemEndpointsManagementList__runtime_type_checks.go
- fsxontapfilesystem_FsxOntapFileSystemEndpointsManagementOutputReference.go
- fsxontapfilesystem_FsxOntapFileSystemEndpointsManagementOutputReference__runtime_type_checks.go
- fsxontapfilesystem_FsxOntapFileSystemEndpointsOutputReference.go
- fsxontapfilesystem_FsxOntapFileSystemEndpointsOutputReference__runtime_type_checks.go
- fsxontapfilesystem_FsxOntapFileSystemTimeouts.go
- fsxontapfilesystem_FsxOntapFileSystemTimeoutsOutputReference.go
- fsxontapfilesystem_FsxOntapFileSystemTimeoutsOutputReference__runtime_type_checks.go
- fsxontapfilesystem_FsxOntapFileSystem__runtime_type_checks.go