Documentation
¶
Index ¶
- func GameliftFleet_IsConstruct(x interface{}) *bool
- func GameliftFleet_IsTerraformElement(x interface{}) *bool
- func GameliftFleet_IsTerraformResource(x interface{}) *bool
- func GameliftFleet_TfResourceType() *string
- func NewGameliftFleetCertificateConfigurationOutputReference_Override(g GameliftFleetCertificateConfigurationOutputReference, ...)
- func NewGameliftFleetEc2InboundPermissionList_Override(g GameliftFleetEc2InboundPermissionList, ...)
- func NewGameliftFleetEc2InboundPermissionOutputReference_Override(g GameliftFleetEc2InboundPermissionOutputReference, ...)
- func NewGameliftFleetResourceCreationLimitPolicyOutputReference_Override(g GameliftFleetResourceCreationLimitPolicyOutputReference, ...)
- func NewGameliftFleetRuntimeConfigurationOutputReference_Override(g GameliftFleetRuntimeConfigurationOutputReference, ...)
- func NewGameliftFleetRuntimeConfigurationServerProcessList_Override(g GameliftFleetRuntimeConfigurationServerProcessList, ...)
- func NewGameliftFleetRuntimeConfigurationServerProcessOutputReference_Override(g GameliftFleetRuntimeConfigurationServerProcessOutputReference, ...)
- func NewGameliftFleetTimeoutsOutputReference_Override(g GameliftFleetTimeoutsOutputReference, ...)
- func NewGameliftFleet_Override(g GameliftFleet, scope constructs.Construct, id *string, ...)
- type GameliftFleet
- type GameliftFleetCertificateConfiguration
- type GameliftFleetCertificateConfigurationOutputReference
- type GameliftFleetConfig
- type GameliftFleetEc2InboundPermission
- type GameliftFleetEc2InboundPermissionList
- type GameliftFleetEc2InboundPermissionOutputReference
- type GameliftFleetResourceCreationLimitPolicy
- type GameliftFleetResourceCreationLimitPolicyOutputReference
- type GameliftFleetRuntimeConfiguration
- type GameliftFleetRuntimeConfigurationOutputReference
- type GameliftFleetRuntimeConfigurationServerProcess
- type GameliftFleetRuntimeConfigurationServerProcessList
- type GameliftFleetRuntimeConfigurationServerProcessOutputReference
- type GameliftFleetTimeouts
- type GameliftFleetTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GameliftFleet_IsConstruct ¶
func GameliftFleet_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GameliftFleet_IsTerraformElement ¶
func GameliftFleet_IsTerraformElement(x interface{}) *bool
Experimental.
func GameliftFleet_IsTerraformResource ¶
func GameliftFleet_IsTerraformResource(x interface{}) *bool
Experimental.
func GameliftFleet_TfResourceType ¶
func GameliftFleet_TfResourceType() *string
func NewGameliftFleetCertificateConfigurationOutputReference_Override ¶
func NewGameliftFleetCertificateConfigurationOutputReference_Override(g GameliftFleetCertificateConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGameliftFleetEc2InboundPermissionList_Override ¶
func NewGameliftFleetEc2InboundPermissionList_Override(g GameliftFleetEc2InboundPermissionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGameliftFleetEc2InboundPermissionOutputReference_Override ¶
func NewGameliftFleetEc2InboundPermissionOutputReference_Override(g GameliftFleetEc2InboundPermissionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGameliftFleetResourceCreationLimitPolicyOutputReference_Override ¶
func NewGameliftFleetResourceCreationLimitPolicyOutputReference_Override(g GameliftFleetResourceCreationLimitPolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGameliftFleetRuntimeConfigurationOutputReference_Override ¶
func NewGameliftFleetRuntimeConfigurationOutputReference_Override(g GameliftFleetRuntimeConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGameliftFleetRuntimeConfigurationServerProcessList_Override ¶
func NewGameliftFleetRuntimeConfigurationServerProcessList_Override(g GameliftFleetRuntimeConfigurationServerProcessList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGameliftFleetRuntimeConfigurationServerProcessOutputReference_Override ¶
func NewGameliftFleetRuntimeConfigurationServerProcessOutputReference_Override(g GameliftFleetRuntimeConfigurationServerProcessOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGameliftFleetTimeoutsOutputReference_Override ¶
func NewGameliftFleetTimeoutsOutputReference_Override(g GameliftFleetTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGameliftFleet_Override ¶
func NewGameliftFleet_Override(g GameliftFleet, scope constructs.Construct, id *string, config *GameliftFleetConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet aws_gamelift_fleet} Resource.
Types ¶
type GameliftFleet ¶
type GameliftFleet interface {
cdktf.TerraformResource
Arn() *string
BuildArn() *string
BuildId() *string
SetBuildId(val *string)
BuildIdInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CertificateConfiguration() GameliftFleetCertificateConfigurationOutputReference
CertificateConfigurationInput() *GameliftFleetCertificateConfiguration
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Ec2InboundPermission() GameliftFleetEc2InboundPermissionList
Ec2InboundPermissionInput() interface{}
Ec2InstanceType() *string
SetEc2InstanceType(val *string)
Ec2InstanceTypeInput() *string
FleetType() *string
SetFleetType(val *string)
FleetTypeInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InstanceRoleArn() *string
SetInstanceRoleArn(val *string)
InstanceRoleArnInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LogPaths() *[]*string
MetricGroups() *[]*string
SetMetricGroups(val *[]*string)
MetricGroupsInput() *[]*string
Name() *string
SetName(val *string)
NameInput() *string
NewGameSessionProtectionPolicy() *string
SetNewGameSessionProtectionPolicy(val *string)
NewGameSessionProtectionPolicyInput() *string
// The tree node.
Node() constructs.Node
OperatingSystem() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ResourceCreationLimitPolicy() GameliftFleetResourceCreationLimitPolicyOutputReference
ResourceCreationLimitPolicyInput() *GameliftFleetResourceCreationLimitPolicy
RuntimeConfiguration() GameliftFleetRuntimeConfigurationOutputReference
RuntimeConfigurationInput() *GameliftFleetRuntimeConfiguration
ScriptArn() *string
ScriptId() *string
SetScriptId(val *string)
ScriptIdInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GameliftFleetTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCertificateConfiguration(value *GameliftFleetCertificateConfiguration)
PutEc2InboundPermission(value interface{})
PutResourceCreationLimitPolicy(value *GameliftFleetResourceCreationLimitPolicy)
PutRuntimeConfiguration(value *GameliftFleetRuntimeConfiguration)
PutTimeouts(value *GameliftFleetTimeouts)
ResetBuildId()
ResetCertificateConfiguration()
ResetDescription()
ResetEc2InboundPermission()
ResetFleetType()
ResetId()
ResetInstanceRoleArn()
ResetMetricGroups()
ResetNewGameSessionProtectionPolicy()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetResourceCreationLimitPolicy()
ResetRuntimeConfiguration()
ResetScriptId()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet aws_gamelift_fleet}.
func NewGameliftFleet ¶
func NewGameliftFleet(scope constructs.Construct, id *string, config *GameliftFleetConfig) GameliftFleet
Create a new {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet aws_gamelift_fleet} Resource.
type GameliftFleetCertificateConfiguration ¶
type GameliftFleetCertificateConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#certificate_type GameliftFleet#certificate_type}.
CertificateType *string `field:"optional" json:"certificateType" yaml:"certificateType"`
}
type GameliftFleetCertificateConfigurationOutputReference ¶
type GameliftFleetCertificateConfigurationOutputReference interface {
cdktf.ComplexObject
CertificateType() *string
SetCertificateType(val *string)
CertificateTypeInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GameliftFleetCertificateConfiguration
SetInternalValue(val *GameliftFleetCertificateConfiguration)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCertificateType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGameliftFleetCertificateConfigurationOutputReference ¶
func NewGameliftFleetCertificateConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GameliftFleetCertificateConfigurationOutputReference
type GameliftFleetConfig ¶
type GameliftFleetConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#ec2_instance_type GameliftFleet#ec2_instance_type}.
Ec2InstanceType *string `field:"required" json:"ec2InstanceType" yaml:"ec2InstanceType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#name GameliftFleet#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#build_id GameliftFleet#build_id}.
BuildId *string `field:"optional" json:"buildId" yaml:"buildId"`
// certificate_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#certificate_configuration GameliftFleet#certificate_configuration}
CertificateConfiguration *GameliftFleetCertificateConfiguration `field:"optional" json:"certificateConfiguration" yaml:"certificateConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#description GameliftFleet#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// ec2_inbound_permission block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#ec2_inbound_permission GameliftFleet#ec2_inbound_permission}
Ec2InboundPermission interface{} `field:"optional" json:"ec2InboundPermission" yaml:"ec2InboundPermission"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#fleet_type GameliftFleet#fleet_type}.
FleetType *string `field:"optional" json:"fleetType" yaml:"fleetType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#id GameliftFleet#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#instance_role_arn GameliftFleet#instance_role_arn}.
InstanceRoleArn *string `field:"optional" json:"instanceRoleArn" yaml:"instanceRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#metric_groups GameliftFleet#metric_groups}.
MetricGroups *[]*string `field:"optional" json:"metricGroups" yaml:"metricGroups"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#new_game_session_protection_policy GameliftFleet#new_game_session_protection_policy}.
NewGameSessionProtectionPolicy *string `field:"optional" json:"newGameSessionProtectionPolicy" yaml:"newGameSessionProtectionPolicy"`
// resource_creation_limit_policy block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#resource_creation_limit_policy GameliftFleet#resource_creation_limit_policy}
ResourceCreationLimitPolicy *GameliftFleetResourceCreationLimitPolicy `field:"optional" json:"resourceCreationLimitPolicy" yaml:"resourceCreationLimitPolicy"`
// runtime_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#runtime_configuration GameliftFleet#runtime_configuration}
RuntimeConfiguration *GameliftFleetRuntimeConfiguration `field:"optional" json:"runtimeConfiguration" yaml:"runtimeConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#script_id GameliftFleet#script_id}.
ScriptId *string `field:"optional" json:"scriptId" yaml:"scriptId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#tags GameliftFleet#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#tags_all GameliftFleet#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#timeouts GameliftFleet#timeouts}
Timeouts *GameliftFleetTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GameliftFleetEc2InboundPermission ¶
type GameliftFleetEc2InboundPermission struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#from_port GameliftFleet#from_port}.
FromPort *float64 `field:"required" json:"fromPort" yaml:"fromPort"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#ip_range GameliftFleet#ip_range}.
IpRange *string `field:"required" json:"ipRange" yaml:"ipRange"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#protocol GameliftFleet#protocol}.
Protocol *string `field:"required" json:"protocol" yaml:"protocol"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#to_port GameliftFleet#to_port}.
ToPort *float64 `field:"required" json:"toPort" yaml:"toPort"`
}
type GameliftFleetEc2InboundPermissionList ¶
type GameliftFleetEc2InboundPermissionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GameliftFleetEc2InboundPermissionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGameliftFleetEc2InboundPermissionList ¶
func NewGameliftFleetEc2InboundPermissionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GameliftFleetEc2InboundPermissionList
type GameliftFleetEc2InboundPermissionOutputReference ¶
type GameliftFleetEc2InboundPermissionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
FromPort() *float64
SetFromPort(val *float64)
FromPortInput() *float64
InternalValue() interface{}
SetInternalValue(val interface{})
IpRange() *string
SetIpRange(val *string)
IpRangeInput() *string
Protocol() *string
SetProtocol(val *string)
ProtocolInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ToPort() *float64
SetToPort(val *float64)
ToPortInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGameliftFleetEc2InboundPermissionOutputReference ¶
func NewGameliftFleetEc2InboundPermissionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GameliftFleetEc2InboundPermissionOutputReference
type GameliftFleetResourceCreationLimitPolicy ¶
type GameliftFleetResourceCreationLimitPolicy struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#new_game_sessions_per_creator GameliftFleet#new_game_sessions_per_creator}.
NewGameSessionsPerCreator *float64 `field:"optional" json:"newGameSessionsPerCreator" yaml:"newGameSessionsPerCreator"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#policy_period_in_minutes GameliftFleet#policy_period_in_minutes}.
PolicyPeriodInMinutes *float64 `field:"optional" json:"policyPeriodInMinutes" yaml:"policyPeriodInMinutes"`
}
type GameliftFleetResourceCreationLimitPolicyOutputReference ¶
type GameliftFleetResourceCreationLimitPolicyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GameliftFleetResourceCreationLimitPolicy
SetInternalValue(val *GameliftFleetResourceCreationLimitPolicy)
NewGameSessionsPerCreator() *float64
SetNewGameSessionsPerCreator(val *float64)
NewGameSessionsPerCreatorInput() *float64
PolicyPeriodInMinutes() *float64
SetPolicyPeriodInMinutes(val *float64)
PolicyPeriodInMinutesInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetNewGameSessionsPerCreator()
ResetPolicyPeriodInMinutes()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGameliftFleetResourceCreationLimitPolicyOutputReference ¶
func NewGameliftFleetResourceCreationLimitPolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GameliftFleetResourceCreationLimitPolicyOutputReference
type GameliftFleetRuntimeConfiguration ¶
type GameliftFleetRuntimeConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#game_session_activation_timeout_seconds GameliftFleet#game_session_activation_timeout_seconds}.
GameSessionActivationTimeoutSeconds *float64 `field:"optional" json:"gameSessionActivationTimeoutSeconds" yaml:"gameSessionActivationTimeoutSeconds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#max_concurrent_game_session_activations GameliftFleet#max_concurrent_game_session_activations}.
MaxConcurrentGameSessionActivations *float64 `field:"optional" json:"maxConcurrentGameSessionActivations" yaml:"maxConcurrentGameSessionActivations"`
// server_process block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#server_process GameliftFleet#server_process}
ServerProcess interface{} `field:"optional" json:"serverProcess" yaml:"serverProcess"`
}
type GameliftFleetRuntimeConfigurationOutputReference ¶
type GameliftFleetRuntimeConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
GameSessionActivationTimeoutSeconds() *float64
SetGameSessionActivationTimeoutSeconds(val *float64)
GameSessionActivationTimeoutSecondsInput() *float64
InternalValue() *GameliftFleetRuntimeConfiguration
SetInternalValue(val *GameliftFleetRuntimeConfiguration)
MaxConcurrentGameSessionActivations() *float64
SetMaxConcurrentGameSessionActivations(val *float64)
MaxConcurrentGameSessionActivationsInput() *float64
ServerProcess() GameliftFleetRuntimeConfigurationServerProcessList
ServerProcessInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutServerProcess(value interface{})
ResetGameSessionActivationTimeoutSeconds()
ResetMaxConcurrentGameSessionActivations()
ResetServerProcess()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGameliftFleetRuntimeConfigurationOutputReference ¶
func NewGameliftFleetRuntimeConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GameliftFleetRuntimeConfigurationOutputReference
type GameliftFleetRuntimeConfigurationServerProcess ¶
type GameliftFleetRuntimeConfigurationServerProcess struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#concurrent_executions GameliftFleet#concurrent_executions}.
ConcurrentExecutions *float64 `field:"required" json:"concurrentExecutions" yaml:"concurrentExecutions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#launch_path GameliftFleet#launch_path}.
LaunchPath *string `field:"required" json:"launchPath" yaml:"launchPath"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#parameters GameliftFleet#parameters}.
Parameters *string `field:"optional" json:"parameters" yaml:"parameters"`
}
type GameliftFleetRuntimeConfigurationServerProcessList ¶
type GameliftFleetRuntimeConfigurationServerProcessList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GameliftFleetRuntimeConfigurationServerProcessOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGameliftFleetRuntimeConfigurationServerProcessList ¶
func NewGameliftFleetRuntimeConfigurationServerProcessList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GameliftFleetRuntimeConfigurationServerProcessList
type GameliftFleetRuntimeConfigurationServerProcessOutputReference ¶
type GameliftFleetRuntimeConfigurationServerProcessOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ConcurrentExecutions() *float64
SetConcurrentExecutions(val *float64)
ConcurrentExecutionsInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
LaunchPath() *string
SetLaunchPath(val *string)
LaunchPathInput() *string
Parameters() *string
SetParameters(val *string)
ParametersInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetParameters()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGameliftFleetRuntimeConfigurationServerProcessOutputReference ¶
func NewGameliftFleetRuntimeConfigurationServerProcessOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GameliftFleetRuntimeConfigurationServerProcessOutputReference
type GameliftFleetTimeouts ¶
type GameliftFleetTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#create GameliftFleet#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_fleet#delete GameliftFleet#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type GameliftFleetTimeoutsOutputReference ¶
type GameliftFleetTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGameliftFleetTimeoutsOutputReference ¶
func NewGameliftFleetTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GameliftFleetTimeoutsOutputReference
Source Files
¶
- gameliftfleet.go
- gameliftfleet_GameliftFleet.go
- gameliftfleet_GameliftFleetCertificateConfiguration.go
- gameliftfleet_GameliftFleetCertificateConfigurationOutputReference.go
- gameliftfleet_GameliftFleetCertificateConfigurationOutputReference__runtime_type_checks.go
- gameliftfleet_GameliftFleetConfig.go
- gameliftfleet_GameliftFleetEc2InboundPermission.go
- gameliftfleet_GameliftFleetEc2InboundPermissionList.go
- gameliftfleet_GameliftFleetEc2InboundPermissionList__runtime_type_checks.go
- gameliftfleet_GameliftFleetEc2InboundPermissionOutputReference.go
- gameliftfleet_GameliftFleetEc2InboundPermissionOutputReference__runtime_type_checks.go
- gameliftfleet_GameliftFleetResourceCreationLimitPolicy.go
- gameliftfleet_GameliftFleetResourceCreationLimitPolicyOutputReference.go
- gameliftfleet_GameliftFleetResourceCreationLimitPolicyOutputReference__runtime_type_checks.go
- gameliftfleet_GameliftFleetRuntimeConfiguration.go
- gameliftfleet_GameliftFleetRuntimeConfigurationOutputReference.go
- gameliftfleet_GameliftFleetRuntimeConfigurationOutputReference__runtime_type_checks.go
- gameliftfleet_GameliftFleetRuntimeConfigurationServerProcess.go
- gameliftfleet_GameliftFleetRuntimeConfigurationServerProcessList.go
- gameliftfleet_GameliftFleetRuntimeConfigurationServerProcessList__runtime_type_checks.go
- gameliftfleet_GameliftFleetRuntimeConfigurationServerProcessOutputReference.go
- gameliftfleet_GameliftFleetRuntimeConfigurationServerProcessOutputReference__runtime_type_checks.go
- gameliftfleet_GameliftFleetTimeouts.go
- gameliftfleet_GameliftFleetTimeoutsOutputReference.go
- gameliftfleet_GameliftFleetTimeoutsOutputReference__runtime_type_checks.go
- gameliftfleet_GameliftFleet__runtime_type_checks.go