Documentation
¶
Index ¶
- func GlueCatalogDatabase_IsConstruct(x interface{}) *bool
- func GlueCatalogDatabase_IsTerraformElement(x interface{}) *bool
- func GlueCatalogDatabase_IsTerraformResource(x interface{}) *bool
- func GlueCatalogDatabase_TfResourceType() *string
- func NewGlueCatalogDatabaseCreateTableDefaultPermissionList_Override(g GlueCatalogDatabaseCreateTableDefaultPermissionList, ...)
- func NewGlueCatalogDatabaseCreateTableDefaultPermissionOutputReference_Override(g GlueCatalogDatabaseCreateTableDefaultPermissionOutputReference, ...)
- func NewGlueCatalogDatabaseCreateTableDefaultPermissionPrincipalOutputReference_Override(g GlueCatalogDatabaseCreateTableDefaultPermissionPrincipalOutputReference, ...)
- func NewGlueCatalogDatabaseTargetDatabaseOutputReference_Override(g GlueCatalogDatabaseTargetDatabaseOutputReference, ...)
- func NewGlueCatalogDatabase_Override(g GlueCatalogDatabase, scope constructs.Construct, id *string, ...)
- type GlueCatalogDatabase
- type GlueCatalogDatabaseConfig
- type GlueCatalogDatabaseCreateTableDefaultPermission
- type GlueCatalogDatabaseCreateTableDefaultPermissionList
- type GlueCatalogDatabaseCreateTableDefaultPermissionOutputReference
- type GlueCatalogDatabaseCreateTableDefaultPermissionPrincipal
- type GlueCatalogDatabaseCreateTableDefaultPermissionPrincipalOutputReference
- type GlueCatalogDatabaseTargetDatabase
- type GlueCatalogDatabaseTargetDatabaseOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GlueCatalogDatabase_IsConstruct ¶
func GlueCatalogDatabase_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GlueCatalogDatabase_IsTerraformElement ¶
func GlueCatalogDatabase_IsTerraformElement(x interface{}) *bool
Experimental.
func GlueCatalogDatabase_IsTerraformResource ¶
func GlueCatalogDatabase_IsTerraformResource(x interface{}) *bool
Experimental.
func GlueCatalogDatabase_TfResourceType ¶
func GlueCatalogDatabase_TfResourceType() *string
func NewGlueCatalogDatabaseCreateTableDefaultPermissionList_Override ¶
func NewGlueCatalogDatabaseCreateTableDefaultPermissionList_Override(g GlueCatalogDatabaseCreateTableDefaultPermissionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGlueCatalogDatabaseCreateTableDefaultPermissionOutputReference_Override ¶
func NewGlueCatalogDatabaseCreateTableDefaultPermissionOutputReference_Override(g GlueCatalogDatabaseCreateTableDefaultPermissionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGlueCatalogDatabaseCreateTableDefaultPermissionPrincipalOutputReference_Override ¶
func NewGlueCatalogDatabaseCreateTableDefaultPermissionPrincipalOutputReference_Override(g GlueCatalogDatabaseCreateTableDefaultPermissionPrincipalOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGlueCatalogDatabaseTargetDatabaseOutputReference_Override ¶
func NewGlueCatalogDatabaseTargetDatabaseOutputReference_Override(g GlueCatalogDatabaseTargetDatabaseOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGlueCatalogDatabase_Override ¶
func NewGlueCatalogDatabase_Override(g GlueCatalogDatabase, scope constructs.Construct, id *string, config *GlueCatalogDatabaseConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database aws_glue_catalog_database} Resource.
Types ¶
type GlueCatalogDatabase ¶
type GlueCatalogDatabase interface {
cdktf.TerraformResource
Arn() *string
CatalogId() *string
SetCatalogId(val *string)
CatalogIdInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreateTableDefaultPermission() GlueCatalogDatabaseCreateTableDefaultPermissionList
CreateTableDefaultPermissionInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LocationUri() *string
SetLocationUri(val *string)
LocationUriInput() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Parameters() *map[string]*string
SetParameters(val *map[string]*string)
ParametersInput() *map[string]*string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
TargetDatabase() GlueCatalogDatabaseTargetDatabaseOutputReference
TargetDatabaseInput() *GlueCatalogDatabaseTargetDatabase
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCreateTableDefaultPermission(value interface{})
PutTargetDatabase(value *GlueCatalogDatabaseTargetDatabase)
ResetCatalogId()
ResetCreateTableDefaultPermission()
ResetDescription()
ResetId()
ResetLocationUri()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetParameters()
ResetTargetDatabase()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database aws_glue_catalog_database}.
func NewGlueCatalogDatabase ¶
func NewGlueCatalogDatabase(scope constructs.Construct, id *string, config *GlueCatalogDatabaseConfig) GlueCatalogDatabase
Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database aws_glue_catalog_database} Resource.
type GlueCatalogDatabaseConfig ¶
type GlueCatalogDatabaseConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database#name GlueCatalogDatabase#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database#catalog_id GlueCatalogDatabase#catalog_id}.
CatalogId *string `field:"optional" json:"catalogId" yaml:"catalogId"`
// create_table_default_permission block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database#create_table_default_permission GlueCatalogDatabase#create_table_default_permission}
CreateTableDefaultPermission interface{} `field:"optional" json:"createTableDefaultPermission" yaml:"createTableDefaultPermission"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database#description GlueCatalogDatabase#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database#id GlueCatalogDatabase#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database#location_uri GlueCatalogDatabase#location_uri}.
LocationUri *string `field:"optional" json:"locationUri" yaml:"locationUri"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database#parameters GlueCatalogDatabase#parameters}.
Parameters *map[string]*string `field:"optional" json:"parameters" yaml:"parameters"`
// target_database block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database#target_database GlueCatalogDatabase#target_database}
TargetDatabase *GlueCatalogDatabaseTargetDatabase `field:"optional" json:"targetDatabase" yaml:"targetDatabase"`
}
type GlueCatalogDatabaseCreateTableDefaultPermission ¶
type GlueCatalogDatabaseCreateTableDefaultPermission struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database#permissions GlueCatalogDatabase#permissions}.
Permissions *[]*string `field:"optional" json:"permissions" yaml:"permissions"`
// principal block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database#principal GlueCatalogDatabase#principal}
Principal *GlueCatalogDatabaseCreateTableDefaultPermissionPrincipal `field:"optional" json:"principal" yaml:"principal"`
}
type GlueCatalogDatabaseCreateTableDefaultPermissionList ¶
type GlueCatalogDatabaseCreateTableDefaultPermissionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GlueCatalogDatabaseCreateTableDefaultPermissionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueCatalogDatabaseCreateTableDefaultPermissionList ¶
func NewGlueCatalogDatabaseCreateTableDefaultPermissionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GlueCatalogDatabaseCreateTableDefaultPermissionList
type GlueCatalogDatabaseCreateTableDefaultPermissionOutputReference ¶
type GlueCatalogDatabaseCreateTableDefaultPermissionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Permissions() *[]*string
SetPermissions(val *[]*string)
PermissionsInput() *[]*string
Principal() GlueCatalogDatabaseCreateTableDefaultPermissionPrincipalOutputReference
PrincipalInput() *GlueCatalogDatabaseCreateTableDefaultPermissionPrincipal
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutPrincipal(value *GlueCatalogDatabaseCreateTableDefaultPermissionPrincipal)
ResetPermissions()
ResetPrincipal()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueCatalogDatabaseCreateTableDefaultPermissionOutputReference ¶
func NewGlueCatalogDatabaseCreateTableDefaultPermissionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GlueCatalogDatabaseCreateTableDefaultPermissionOutputReference
type GlueCatalogDatabaseCreateTableDefaultPermissionPrincipal ¶
type GlueCatalogDatabaseCreateTableDefaultPermissionPrincipal struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database#data_lake_principal_identifier GlueCatalogDatabase#data_lake_principal_identifier}.
DataLakePrincipalIdentifier *string `field:"optional" json:"dataLakePrincipalIdentifier" yaml:"dataLakePrincipalIdentifier"`
}
type GlueCatalogDatabaseCreateTableDefaultPermissionPrincipalOutputReference ¶
type GlueCatalogDatabaseCreateTableDefaultPermissionPrincipalOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DataLakePrincipalIdentifier() *string
SetDataLakePrincipalIdentifier(val *string)
DataLakePrincipalIdentifierInput() *string
// Experimental.
Fqn() *string
InternalValue() *GlueCatalogDatabaseCreateTableDefaultPermissionPrincipal
SetInternalValue(val *GlueCatalogDatabaseCreateTableDefaultPermissionPrincipal)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDataLakePrincipalIdentifier()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueCatalogDatabaseCreateTableDefaultPermissionPrincipalOutputReference ¶
func NewGlueCatalogDatabaseCreateTableDefaultPermissionPrincipalOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GlueCatalogDatabaseCreateTableDefaultPermissionPrincipalOutputReference
type GlueCatalogDatabaseTargetDatabase ¶
type GlueCatalogDatabaseTargetDatabase struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database#catalog_id GlueCatalogDatabase#catalog_id}.
CatalogId *string `field:"required" json:"catalogId" yaml:"catalogId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database#database_name GlueCatalogDatabase#database_name}.
DatabaseName *string `field:"required" json:"databaseName" yaml:"databaseName"`
}
type GlueCatalogDatabaseTargetDatabaseOutputReference ¶
type GlueCatalogDatabaseTargetDatabaseOutputReference interface {
cdktf.ComplexObject
CatalogId() *string
SetCatalogId(val *string)
CatalogIdInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DatabaseName() *string
SetDatabaseName(val *string)
DatabaseNameInput() *string
// Experimental.
Fqn() *string
InternalValue() *GlueCatalogDatabaseTargetDatabase
SetInternalValue(val *GlueCatalogDatabaseTargetDatabase)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueCatalogDatabaseTargetDatabaseOutputReference ¶
func NewGlueCatalogDatabaseTargetDatabaseOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GlueCatalogDatabaseTargetDatabaseOutputReference
Source Files
¶
- gluecatalogdatabase.go
- gluecatalogdatabase_GlueCatalogDatabase.go
- gluecatalogdatabase_GlueCatalogDatabaseConfig.go
- gluecatalogdatabase_GlueCatalogDatabaseCreateTableDefaultPermission.go
- gluecatalogdatabase_GlueCatalogDatabaseCreateTableDefaultPermissionList.go
- gluecatalogdatabase_GlueCatalogDatabaseCreateTableDefaultPermissionList__runtime_type_checks.go
- gluecatalogdatabase_GlueCatalogDatabaseCreateTableDefaultPermissionOutputReference.go
- gluecatalogdatabase_GlueCatalogDatabaseCreateTableDefaultPermissionOutputReference__runtime_type_checks.go
- gluecatalogdatabase_GlueCatalogDatabaseCreateTableDefaultPermissionPrincipal.go
- gluecatalogdatabase_GlueCatalogDatabaseCreateTableDefaultPermissionPrincipalOutputReference.go
- gluecatalogdatabase_GlueCatalogDatabaseCreateTableDefaultPermissionPrincipalOutputReference__runtime_type_checks.go
- gluecatalogdatabase_GlueCatalogDatabaseTargetDatabase.go
- gluecatalogdatabase_GlueCatalogDatabaseTargetDatabaseOutputReference.go
- gluecatalogdatabase_GlueCatalogDatabaseTargetDatabaseOutputReference__runtime_type_checks.go
- gluecatalogdatabase_GlueCatalogDatabase__runtime_type_checks.go