Documentation
¶
Index ¶
- func GuarddutyOrganizationConfiguration_IsConstruct(x interface{}) *bool
- func GuarddutyOrganizationConfiguration_IsTerraformElement(x interface{}) *bool
- func GuarddutyOrganizationConfiguration_IsTerraformResource(x interface{}) *bool
- func GuarddutyOrganizationConfiguration_TfResourceType() *string
- func NewGuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogsOutputReference_Override(...)
- func NewGuarddutyOrganizationConfigurationDatasourcesKubernetesOutputReference_Override(g GuarddutyOrganizationConfigurationDatasourcesKubernetesOutputReference, ...)
- func NewGuarddutyOrganizationConfigurationDatasourcesMalwareProtectionOutputReference_Override(...)
- func NewGuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference_Override(...)
- func NewGuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference_Override(...)
- func NewGuarddutyOrganizationConfigurationDatasourcesOutputReference_Override(g GuarddutyOrganizationConfigurationDatasourcesOutputReference, ...)
- func NewGuarddutyOrganizationConfigurationDatasourcesS3LogsOutputReference_Override(g GuarddutyOrganizationConfigurationDatasourcesS3LogsOutputReference, ...)
- func NewGuarddutyOrganizationConfiguration_Override(g GuarddutyOrganizationConfiguration, scope constructs.Construct, id *string, ...)
- type GuarddutyOrganizationConfiguration
- type GuarddutyOrganizationConfigurationConfig
- type GuarddutyOrganizationConfigurationDatasources
- type GuarddutyOrganizationConfigurationDatasourcesKubernetes
- type GuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogs
- type GuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogsOutputReference
- type GuarddutyOrganizationConfigurationDatasourcesKubernetesOutputReference
- type GuarddutyOrganizationConfigurationDatasourcesMalwareProtection
- type GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionOutputReference
- type GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindings
- type GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes
- type GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference
- type GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference
- type GuarddutyOrganizationConfigurationDatasourcesOutputReference
- type GuarddutyOrganizationConfigurationDatasourcesS3Logs
- type GuarddutyOrganizationConfigurationDatasourcesS3LogsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GuarddutyOrganizationConfiguration_IsConstruct ¶
func GuarddutyOrganizationConfiguration_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GuarddutyOrganizationConfiguration_IsTerraformElement ¶
func GuarddutyOrganizationConfiguration_IsTerraformElement(x interface{}) *bool
Experimental.
func GuarddutyOrganizationConfiguration_IsTerraformResource ¶
func GuarddutyOrganizationConfiguration_IsTerraformResource(x interface{}) *bool
Experimental.
func GuarddutyOrganizationConfiguration_TfResourceType ¶
func GuarddutyOrganizationConfiguration_TfResourceType() *string
func NewGuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogsOutputReference_Override ¶
func NewGuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogsOutputReference_Override(g GuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGuarddutyOrganizationConfigurationDatasourcesKubernetesOutputReference_Override ¶
func NewGuarddutyOrganizationConfigurationDatasourcesKubernetesOutputReference_Override(g GuarddutyOrganizationConfigurationDatasourcesKubernetesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGuarddutyOrganizationConfigurationDatasourcesMalwareProtectionOutputReference_Override ¶
func NewGuarddutyOrganizationConfigurationDatasourcesMalwareProtectionOutputReference_Override(g GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference_Override ¶
func NewGuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference_Override(g GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference_Override ¶
func NewGuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference_Override(g GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGuarddutyOrganizationConfigurationDatasourcesOutputReference_Override ¶
func NewGuarddutyOrganizationConfigurationDatasourcesOutputReference_Override(g GuarddutyOrganizationConfigurationDatasourcesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGuarddutyOrganizationConfigurationDatasourcesS3LogsOutputReference_Override ¶
func NewGuarddutyOrganizationConfigurationDatasourcesS3LogsOutputReference_Override(g GuarddutyOrganizationConfigurationDatasourcesS3LogsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGuarddutyOrganizationConfiguration_Override ¶
func NewGuarddutyOrganizationConfiguration_Override(g GuarddutyOrganizationConfiguration, scope constructs.Construct, id *string, config *GuarddutyOrganizationConfigurationConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration aws_guardduty_organization_configuration} Resource.
Types ¶
type GuarddutyOrganizationConfiguration ¶
type GuarddutyOrganizationConfiguration interface {
cdktf.TerraformResource
AutoEnable() interface{}
SetAutoEnable(val interface{})
AutoEnableInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
Datasources() GuarddutyOrganizationConfigurationDatasourcesOutputReference
DatasourcesInput() *GuarddutyOrganizationConfigurationDatasources
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DetectorId() *string
SetDetectorId(val *string)
DetectorIdInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDatasources(value *GuarddutyOrganizationConfigurationDatasources)
ResetDatasources()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration aws_guardduty_organization_configuration}.
func NewGuarddutyOrganizationConfiguration ¶
func NewGuarddutyOrganizationConfiguration(scope constructs.Construct, id *string, config *GuarddutyOrganizationConfigurationConfig) GuarddutyOrganizationConfiguration
Create a new {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration aws_guardduty_organization_configuration} Resource.
type GuarddutyOrganizationConfigurationConfig ¶
type GuarddutyOrganizationConfigurationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration#auto_enable GuarddutyOrganizationConfiguration#auto_enable}.
AutoEnable interface{} `field:"required" json:"autoEnable" yaml:"autoEnable"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration#detector_id GuarddutyOrganizationConfiguration#detector_id}.
DetectorId *string `field:"required" json:"detectorId" yaml:"detectorId"`
// datasources block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration#datasources GuarddutyOrganizationConfiguration#datasources}
Datasources *GuarddutyOrganizationConfigurationDatasources `field:"optional" json:"datasources" yaml:"datasources"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration#id GuarddutyOrganizationConfiguration#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type GuarddutyOrganizationConfigurationDatasources ¶
type GuarddutyOrganizationConfigurationDatasources struct {
// kubernetes block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration#kubernetes GuarddutyOrganizationConfiguration#kubernetes}
Kubernetes *GuarddutyOrganizationConfigurationDatasourcesKubernetes `field:"optional" json:"kubernetes" yaml:"kubernetes"`
// malware_protection block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration#malware_protection GuarddutyOrganizationConfiguration#malware_protection}
MalwareProtection *GuarddutyOrganizationConfigurationDatasourcesMalwareProtection `field:"optional" json:"malwareProtection" yaml:"malwareProtection"`
// s3_logs block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration#s3_logs GuarddutyOrganizationConfiguration#s3_logs}
S3Logs *GuarddutyOrganizationConfigurationDatasourcesS3Logs `field:"optional" json:"s3Logs" yaml:"s3Logs"`
}
type GuarddutyOrganizationConfigurationDatasourcesKubernetes ¶
type GuarddutyOrganizationConfigurationDatasourcesKubernetes struct {
// audit_logs block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration#audit_logs GuarddutyOrganizationConfiguration#audit_logs}
AuditLogs *GuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogs `field:"required" json:"auditLogs" yaml:"auditLogs"`
}
type GuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogs ¶
type GuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogs struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration#enable GuarddutyOrganizationConfiguration#enable}.
Enable interface{} `field:"required" json:"enable" yaml:"enable"`
}
type GuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogsOutputReference ¶
type GuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enable() interface{}
SetEnable(val interface{})
EnableInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *GuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogs
SetInternalValue(val *GuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogs)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogsOutputReference ¶
func NewGuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogsOutputReference
type GuarddutyOrganizationConfigurationDatasourcesKubernetesOutputReference ¶
type GuarddutyOrganizationConfigurationDatasourcesKubernetesOutputReference interface {
cdktf.ComplexObject
AuditLogs() GuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogsOutputReference
AuditLogsInput() *GuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogs
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GuarddutyOrganizationConfigurationDatasourcesKubernetes
SetInternalValue(val *GuarddutyOrganizationConfigurationDatasourcesKubernetes)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAuditLogs(value *GuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogs)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGuarddutyOrganizationConfigurationDatasourcesKubernetesOutputReference ¶
func NewGuarddutyOrganizationConfigurationDatasourcesKubernetesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GuarddutyOrganizationConfigurationDatasourcesKubernetesOutputReference
type GuarddutyOrganizationConfigurationDatasourcesMalwareProtection ¶
type GuarddutyOrganizationConfigurationDatasourcesMalwareProtection struct {
// scan_ec2_instance_with_findings block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration#scan_ec2_instance_with_findings GuarddutyOrganizationConfiguration#scan_ec2_instance_with_findings}
ScanEc2InstanceWithFindings *GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindings `field:"required" json:"scanEc2InstanceWithFindings" yaml:"scanEc2InstanceWithFindings"`
}
type GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionOutputReference ¶
type GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GuarddutyOrganizationConfigurationDatasourcesMalwareProtection
SetInternalValue(val *GuarddutyOrganizationConfigurationDatasourcesMalwareProtection)
ScanEc2InstanceWithFindings() GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference
ScanEc2InstanceWithFindingsInput() *GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindings
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutScanEc2InstanceWithFindings(value *GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindings)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGuarddutyOrganizationConfigurationDatasourcesMalwareProtectionOutputReference ¶
func NewGuarddutyOrganizationConfigurationDatasourcesMalwareProtectionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionOutputReference
type GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindings ¶
type GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindings struct {
// ebs_volumes block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration#ebs_volumes GuarddutyOrganizationConfiguration#ebs_volumes}
EbsVolumes *GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes `field:"required" json:"ebsVolumes" yaml:"ebsVolumes"`
}
type GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes ¶
type GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration#auto_enable GuarddutyOrganizationConfiguration#auto_enable}.
AutoEnable interface{} `field:"required" json:"autoEnable" yaml:"autoEnable"`
}
type GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference ¶
type GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference interface {
cdktf.ComplexObject
AutoEnable() interface{}
SetAutoEnable(val interface{})
AutoEnableInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes
SetInternalValue(val *GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference ¶
func NewGuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference
type GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference ¶
type GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EbsVolumes() GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference
EbsVolumesInput() *GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes
// Experimental.
Fqn() *string
InternalValue() *GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindings
SetInternalValue(val *GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindings)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutEbsVolumes(value *GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference ¶
func NewGuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference
type GuarddutyOrganizationConfigurationDatasourcesOutputReference ¶
type GuarddutyOrganizationConfigurationDatasourcesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GuarddutyOrganizationConfigurationDatasources
SetInternalValue(val *GuarddutyOrganizationConfigurationDatasources)
Kubernetes() GuarddutyOrganizationConfigurationDatasourcesKubernetesOutputReference
KubernetesInput() *GuarddutyOrganizationConfigurationDatasourcesKubernetes
MalwareProtection() GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionOutputReference
MalwareProtectionInput() *GuarddutyOrganizationConfigurationDatasourcesMalwareProtection
S3Logs() GuarddutyOrganizationConfigurationDatasourcesS3LogsOutputReference
S3LogsInput() *GuarddutyOrganizationConfigurationDatasourcesS3Logs
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutKubernetes(value *GuarddutyOrganizationConfigurationDatasourcesKubernetes)
PutMalwareProtection(value *GuarddutyOrganizationConfigurationDatasourcesMalwareProtection)
PutS3Logs(value *GuarddutyOrganizationConfigurationDatasourcesS3Logs)
ResetKubernetes()
ResetMalwareProtection()
ResetS3Logs()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGuarddutyOrganizationConfigurationDatasourcesOutputReference ¶
func NewGuarddutyOrganizationConfigurationDatasourcesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GuarddutyOrganizationConfigurationDatasourcesOutputReference
type GuarddutyOrganizationConfigurationDatasourcesS3Logs ¶
type GuarddutyOrganizationConfigurationDatasourcesS3Logs struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration#auto_enable GuarddutyOrganizationConfiguration#auto_enable}.
AutoEnable interface{} `field:"required" json:"autoEnable" yaml:"autoEnable"`
}
type GuarddutyOrganizationConfigurationDatasourcesS3LogsOutputReference ¶
type GuarddutyOrganizationConfigurationDatasourcesS3LogsOutputReference interface {
cdktf.ComplexObject
AutoEnable() interface{}
SetAutoEnable(val interface{})
AutoEnableInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GuarddutyOrganizationConfigurationDatasourcesS3Logs
SetInternalValue(val *GuarddutyOrganizationConfigurationDatasourcesS3Logs)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGuarddutyOrganizationConfigurationDatasourcesS3LogsOutputReference ¶
func NewGuarddutyOrganizationConfigurationDatasourcesS3LogsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GuarddutyOrganizationConfigurationDatasourcesS3LogsOutputReference
Source Files
¶
- guarddutyorganizationconfiguration.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfiguration.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationConfig.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasources.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesKubernetes.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogs.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogsOutputReference.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesKubernetesAuditLogsOutputReference__runtime_type_checks.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesKubernetesOutputReference.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesKubernetesOutputReference__runtime_type_checks.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesMalwareProtection.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionOutputReference.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionOutputReference__runtime_type_checks.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindings.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference__runtime_type_checks.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference__runtime_type_checks.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesOutputReference.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesOutputReference__runtime_type_checks.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesS3Logs.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesS3LogsOutputReference.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfigurationDatasourcesS3LogsOutputReference__runtime_type_checks.go
- guarddutyorganizationconfiguration_GuarddutyOrganizationConfiguration__runtime_type_checks.go