Documentation
¶
Index ¶
- func IdentitystoreGroup_IsConstruct(x interface{}) *bool
- func IdentitystoreGroup_IsTerraformElement(x interface{}) *bool
- func IdentitystoreGroup_IsTerraformResource(x interface{}) *bool
- func IdentitystoreGroup_TfResourceType() *string
- func NewIdentitystoreGroupExternalIdsList_Override(i IdentitystoreGroupExternalIdsList, ...)
- func NewIdentitystoreGroupExternalIdsOutputReference_Override(i IdentitystoreGroupExternalIdsOutputReference, ...)
- func NewIdentitystoreGroup_Override(i IdentitystoreGroup, scope constructs.Construct, id *string, ...)
- type IdentitystoreGroup
- type IdentitystoreGroupConfig
- type IdentitystoreGroupExternalIds
- type IdentitystoreGroupExternalIdsList
- type IdentitystoreGroupExternalIdsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IdentitystoreGroup_IsConstruct ¶
func IdentitystoreGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func IdentitystoreGroup_IsTerraformElement ¶
func IdentitystoreGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func IdentitystoreGroup_IsTerraformResource ¶
func IdentitystoreGroup_IsTerraformResource(x interface{}) *bool
Experimental.
func IdentitystoreGroup_TfResourceType ¶
func IdentitystoreGroup_TfResourceType() *string
func NewIdentitystoreGroupExternalIdsList_Override ¶
func NewIdentitystoreGroupExternalIdsList_Override(i IdentitystoreGroupExternalIdsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewIdentitystoreGroupExternalIdsOutputReference_Override ¶
func NewIdentitystoreGroupExternalIdsOutputReference_Override(i IdentitystoreGroupExternalIdsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewIdentitystoreGroup_Override ¶
func NewIdentitystoreGroup_Override(i IdentitystoreGroup, scope constructs.Construct, id *string, config *IdentitystoreGroupConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/identitystore_group aws_identitystore_group} Resource.
Types ¶
type IdentitystoreGroup ¶
type IdentitystoreGroup interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
ExternalIds() IdentitystoreGroupExternalIdsList
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GroupId() *string
Id() *string
SetId(val *string)
IdentityStoreId() *string
SetIdentityStoreId(val *string)
IdentityStoreIdInput() *string
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetDescription()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/identitystore_group aws_identitystore_group}.
func NewIdentitystoreGroup ¶
func NewIdentitystoreGroup(scope constructs.Construct, id *string, config *IdentitystoreGroupConfig) IdentitystoreGroup
Create a new {@link https://www.terraform.io/docs/providers/aws/r/identitystore_group aws_identitystore_group} Resource.
type IdentitystoreGroupConfig ¶
type IdentitystoreGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/identitystore_group#display_name IdentitystoreGroup#display_name}.
DisplayName *string `field:"required" json:"displayName" yaml:"displayName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/identitystore_group#identity_store_id IdentitystoreGroup#identity_store_id}.
IdentityStoreId *string `field:"required" json:"identityStoreId" yaml:"identityStoreId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/identitystore_group#description IdentitystoreGroup#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/identitystore_group#id IdentitystoreGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type IdentitystoreGroupExternalIds ¶
type IdentitystoreGroupExternalIds struct {
}
type IdentitystoreGroupExternalIdsList ¶
type IdentitystoreGroupExternalIdsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) IdentitystoreGroupExternalIdsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIdentitystoreGroupExternalIdsList ¶
func NewIdentitystoreGroupExternalIdsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) IdentitystoreGroupExternalIdsList
type IdentitystoreGroupExternalIdsOutputReference ¶
type IdentitystoreGroupExternalIdsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *IdentitystoreGroupExternalIds
SetInternalValue(val *IdentitystoreGroupExternalIds)
Issuer() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIdentitystoreGroupExternalIdsOutputReference ¶
func NewIdentitystoreGroupExternalIdsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) IdentitystoreGroupExternalIdsOutputReference
Source Files
¶
- identitystoregroup.go
- identitystoregroup_IdentitystoreGroup.go
- identitystoregroup_IdentitystoreGroupConfig.go
- identitystoregroup_IdentitystoreGroupExternalIds.go
- identitystoregroup_IdentitystoreGroupExternalIdsList.go
- identitystoregroup_IdentitystoreGroupExternalIdsList__runtime_type_checks.go
- identitystoregroup_IdentitystoreGroupExternalIdsOutputReference.go
- identitystoregroup_IdentitystoreGroupExternalIdsOutputReference__runtime_type_checks.go
- identitystoregroup_IdentitystoreGroup__runtime_type_checks.go