Documentation
¶
Index ¶
- func KendraExperience_IsConstruct(x interface{}) *bool
- func KendraExperience_IsTerraformElement(x interface{}) *bool
- func KendraExperience_IsTerraformResource(x interface{}) *bool
- func KendraExperience_TfResourceType() *string
- func NewKendraExperienceConfigurationContentSourceConfigurationOutputReference_Override(k KendraExperienceConfigurationContentSourceConfigurationOutputReference, ...)
- func NewKendraExperienceConfigurationOutputReference_Override(k KendraExperienceConfigurationOutputReference, ...)
- func NewKendraExperienceConfigurationUserIdentityConfigurationOutputReference_Override(k KendraExperienceConfigurationUserIdentityConfigurationOutputReference, ...)
- func NewKendraExperienceEndpointsList_Override(k KendraExperienceEndpointsList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewKendraExperienceEndpointsOutputReference_Override(k KendraExperienceEndpointsOutputReference, ...)
- func NewKendraExperienceTimeoutsOutputReference_Override(k KendraExperienceTimeoutsOutputReference, ...)
- func NewKendraExperience_Override(k KendraExperience, scope constructs.Construct, id *string, ...)
- type KendraExperience
- type KendraExperienceConfig
- type KendraExperienceConfiguration
- type KendraExperienceConfigurationContentSourceConfiguration
- type KendraExperienceConfigurationContentSourceConfigurationOutputReference
- type KendraExperienceConfigurationOutputReference
- type KendraExperienceConfigurationUserIdentityConfiguration
- type KendraExperienceConfigurationUserIdentityConfigurationOutputReference
- type KendraExperienceEndpoints
- type KendraExperienceEndpointsList
- type KendraExperienceEndpointsOutputReference
- type KendraExperienceTimeouts
- type KendraExperienceTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func KendraExperience_IsConstruct ¶
func KendraExperience_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func KendraExperience_IsTerraformElement ¶
func KendraExperience_IsTerraformElement(x interface{}) *bool
Experimental.
func KendraExperience_IsTerraformResource ¶
func KendraExperience_IsTerraformResource(x interface{}) *bool
Experimental.
func KendraExperience_TfResourceType ¶
func KendraExperience_TfResourceType() *string
func NewKendraExperienceConfigurationContentSourceConfigurationOutputReference_Override ¶
func NewKendraExperienceConfigurationContentSourceConfigurationOutputReference_Override(k KendraExperienceConfigurationContentSourceConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewKendraExperienceConfigurationOutputReference_Override ¶
func NewKendraExperienceConfigurationOutputReference_Override(k KendraExperienceConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewKendraExperienceConfigurationUserIdentityConfigurationOutputReference_Override ¶
func NewKendraExperienceConfigurationUserIdentityConfigurationOutputReference_Override(k KendraExperienceConfigurationUserIdentityConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewKendraExperienceEndpointsList_Override ¶
func NewKendraExperienceEndpointsList_Override(k KendraExperienceEndpointsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewKendraExperienceEndpointsOutputReference_Override ¶
func NewKendraExperienceEndpointsOutputReference_Override(k KendraExperienceEndpointsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewKendraExperienceTimeoutsOutputReference_Override ¶
func NewKendraExperienceTimeoutsOutputReference_Override(k KendraExperienceTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewKendraExperience_Override ¶
func NewKendraExperience_Override(k KendraExperience, scope constructs.Construct, id *string, config *KendraExperienceConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/kendra_experience aws_kendra_experience} Resource.
Types ¶
type KendraExperience ¶
type KendraExperience interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
Configuration() KendraExperienceConfigurationOutputReference
ConfigurationInput() *KendraExperienceConfiguration
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Endpoints() KendraExperienceEndpointsList
ExperienceId() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IndexId() *string
SetIndexId(val *string)
IndexIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
Status() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() KendraExperienceTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutConfiguration(value *KendraExperienceConfiguration)
PutTimeouts(value *KendraExperienceTimeouts)
ResetConfiguration()
ResetDescription()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/kendra_experience aws_kendra_experience}.
func NewKendraExperience ¶
func NewKendraExperience(scope constructs.Construct, id *string, config *KendraExperienceConfig) KendraExperience
Create a new {@link https://www.terraform.io/docs/providers/aws/r/kendra_experience aws_kendra_experience} Resource.
type KendraExperienceConfig ¶
type KendraExperienceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kendra_experience#index_id KendraExperience#index_id}.
IndexId *string `field:"required" json:"indexId" yaml:"indexId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kendra_experience#name KendraExperience#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kendra_experience#role_arn KendraExperience#role_arn}.
RoleArn *string `field:"required" json:"roleArn" yaml:"roleArn"`
// configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kendra_experience#configuration KendraExperience#configuration}
Configuration *KendraExperienceConfiguration `field:"optional" json:"configuration" yaml:"configuration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kendra_experience#description KendraExperience#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kendra_experience#id KendraExperience#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kendra_experience#timeouts KendraExperience#timeouts}
Timeouts *KendraExperienceTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type KendraExperienceConfiguration ¶
type KendraExperienceConfiguration struct {
// content_source_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kendra_experience#content_source_configuration KendraExperience#content_source_configuration}
ContentSourceConfiguration *KendraExperienceConfigurationContentSourceConfiguration `field:"optional" json:"contentSourceConfiguration" yaml:"contentSourceConfiguration"`
// user_identity_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kendra_experience#user_identity_configuration KendraExperience#user_identity_configuration}
UserIdentityConfiguration *KendraExperienceConfigurationUserIdentityConfiguration `field:"optional" json:"userIdentityConfiguration" yaml:"userIdentityConfiguration"`
}
type KendraExperienceConfigurationContentSourceConfiguration ¶
type KendraExperienceConfigurationContentSourceConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kendra_experience#data_source_ids KendraExperience#data_source_ids}.
DataSourceIds *[]*string `field:"optional" json:"dataSourceIds" yaml:"dataSourceIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kendra_experience#direct_put_content KendraExperience#direct_put_content}.
DirectPutContent interface{} `field:"optional" json:"directPutContent" yaml:"directPutContent"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kendra_experience#faq_ids KendraExperience#faq_ids}.
FaqIds *[]*string `field:"optional" json:"faqIds" yaml:"faqIds"`
}
type KendraExperienceConfigurationContentSourceConfigurationOutputReference ¶
type KendraExperienceConfigurationContentSourceConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DataSourceIds() *[]*string
SetDataSourceIds(val *[]*string)
DataSourceIdsInput() *[]*string
DirectPutContent() interface{}
SetDirectPutContent(val interface{})
DirectPutContentInput() interface{}
FaqIds() *[]*string
SetFaqIds(val *[]*string)
FaqIdsInput() *[]*string
// Experimental.
Fqn() *string
InternalValue() *KendraExperienceConfigurationContentSourceConfiguration
SetInternalValue(val *KendraExperienceConfigurationContentSourceConfiguration)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDataSourceIds()
ResetDirectPutContent()
ResetFaqIds()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewKendraExperienceConfigurationContentSourceConfigurationOutputReference ¶
func NewKendraExperienceConfigurationContentSourceConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) KendraExperienceConfigurationContentSourceConfigurationOutputReference
type KendraExperienceConfigurationOutputReference ¶
type KendraExperienceConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ContentSourceConfiguration() KendraExperienceConfigurationContentSourceConfigurationOutputReference
ContentSourceConfigurationInput() *KendraExperienceConfigurationContentSourceConfiguration
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *KendraExperienceConfiguration
SetInternalValue(val *KendraExperienceConfiguration)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UserIdentityConfiguration() KendraExperienceConfigurationUserIdentityConfigurationOutputReference
UserIdentityConfigurationInput() *KendraExperienceConfigurationUserIdentityConfiguration
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutContentSourceConfiguration(value *KendraExperienceConfigurationContentSourceConfiguration)
PutUserIdentityConfiguration(value *KendraExperienceConfigurationUserIdentityConfiguration)
ResetContentSourceConfiguration()
ResetUserIdentityConfiguration()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewKendraExperienceConfigurationOutputReference ¶
func NewKendraExperienceConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) KendraExperienceConfigurationOutputReference
type KendraExperienceConfigurationUserIdentityConfiguration ¶
type KendraExperienceConfigurationUserIdentityConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kendra_experience#identity_attribute_name KendraExperience#identity_attribute_name}.
IdentityAttributeName *string `field:"required" json:"identityAttributeName" yaml:"identityAttributeName"`
}
type KendraExperienceConfigurationUserIdentityConfigurationOutputReference ¶
type KendraExperienceConfigurationUserIdentityConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IdentityAttributeName() *string
SetIdentityAttributeName(val *string)
IdentityAttributeNameInput() *string
InternalValue() *KendraExperienceConfigurationUserIdentityConfiguration
SetInternalValue(val *KendraExperienceConfigurationUserIdentityConfiguration)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewKendraExperienceConfigurationUserIdentityConfigurationOutputReference ¶
func NewKendraExperienceConfigurationUserIdentityConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) KendraExperienceConfigurationUserIdentityConfigurationOutputReference
type KendraExperienceEndpoints ¶
type KendraExperienceEndpoints struct {
}
type KendraExperienceEndpointsList ¶
type KendraExperienceEndpointsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) KendraExperienceEndpointsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewKendraExperienceEndpointsList ¶
func NewKendraExperienceEndpointsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) KendraExperienceEndpointsList
type KendraExperienceEndpointsOutputReference ¶
type KendraExperienceEndpointsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Endpoint() *string
EndpointType() *string
// Experimental.
Fqn() *string
InternalValue() *KendraExperienceEndpoints
SetInternalValue(val *KendraExperienceEndpoints)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewKendraExperienceEndpointsOutputReference ¶
func NewKendraExperienceEndpointsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) KendraExperienceEndpointsOutputReference
type KendraExperienceTimeouts ¶
type KendraExperienceTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kendra_experience#create KendraExperience#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kendra_experience#delete KendraExperience#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kendra_experience#update KendraExperience#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type KendraExperienceTimeoutsOutputReference ¶
type KendraExperienceTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewKendraExperienceTimeoutsOutputReference ¶
func NewKendraExperienceTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) KendraExperienceTimeoutsOutputReference
Source Files
¶
- kendraexperience.go
- kendraexperience_KendraExperience.go
- kendraexperience_KendraExperienceConfig.go
- kendraexperience_KendraExperienceConfiguration.go
- kendraexperience_KendraExperienceConfigurationContentSourceConfiguration.go
- kendraexperience_KendraExperienceConfigurationContentSourceConfigurationOutputReference.go
- kendraexperience_KendraExperienceConfigurationContentSourceConfigurationOutputReference__runtime_type_checks.go
- kendraexperience_KendraExperienceConfigurationOutputReference.go
- kendraexperience_KendraExperienceConfigurationOutputReference__runtime_type_checks.go
- kendraexperience_KendraExperienceConfigurationUserIdentityConfiguration.go
- kendraexperience_KendraExperienceConfigurationUserIdentityConfigurationOutputReference.go
- kendraexperience_KendraExperienceConfigurationUserIdentityConfigurationOutputReference__runtime_type_checks.go
- kendraexperience_KendraExperienceEndpoints.go
- kendraexperience_KendraExperienceEndpointsList.go
- kendraexperience_KendraExperienceEndpointsList__runtime_type_checks.go
- kendraexperience_KendraExperienceEndpointsOutputReference.go
- kendraexperience_KendraExperienceEndpointsOutputReference__runtime_type_checks.go
- kendraexperience_KendraExperienceTimeouts.go
- kendraexperience_KendraExperienceTimeoutsOutputReference.go
- kendraexperience_KendraExperienceTimeoutsOutputReference__runtime_type_checks.go
- kendraexperience_KendraExperience__runtime_type_checks.go