Documentation
¶
Index ¶
- func LbListener_IsConstruct(x interface{}) *bool
- func LbListener_IsTerraformElement(x interface{}) *bool
- func LbListener_IsTerraformResource(x interface{}) *bool
- func LbListener_TfResourceType() *string
- func NewLbListenerDefaultActionAuthenticateCognitoOutputReference_Override(l LbListenerDefaultActionAuthenticateCognitoOutputReference, ...)
- func NewLbListenerDefaultActionAuthenticateOidcOutputReference_Override(l LbListenerDefaultActionAuthenticateOidcOutputReference, ...)
- func NewLbListenerDefaultActionFixedResponseOutputReference_Override(l LbListenerDefaultActionFixedResponseOutputReference, ...)
- func NewLbListenerDefaultActionForwardOutputReference_Override(l LbListenerDefaultActionForwardOutputReference, ...)
- func NewLbListenerDefaultActionForwardStickinessOutputReference_Override(l LbListenerDefaultActionForwardStickinessOutputReference, ...)
- func NewLbListenerDefaultActionForwardTargetGroupList_Override(l LbListenerDefaultActionForwardTargetGroupList, ...)
- func NewLbListenerDefaultActionForwardTargetGroupOutputReference_Override(l LbListenerDefaultActionForwardTargetGroupOutputReference, ...)
- func NewLbListenerDefaultActionList_Override(l LbListenerDefaultActionList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewLbListenerDefaultActionOutputReference_Override(l LbListenerDefaultActionOutputReference, ...)
- func NewLbListenerDefaultActionRedirectOutputReference_Override(l LbListenerDefaultActionRedirectOutputReference, ...)
- func NewLbListenerTimeoutsOutputReference_Override(l LbListenerTimeoutsOutputReference, ...)
- func NewLbListener_Override(l LbListener, scope constructs.Construct, id *string, config *LbListenerConfig)
- type LbListener
- type LbListenerConfig
- type LbListenerDefaultAction
- type LbListenerDefaultActionAuthenticateCognito
- type LbListenerDefaultActionAuthenticateCognitoOutputReference
- type LbListenerDefaultActionAuthenticateOidc
- type LbListenerDefaultActionAuthenticateOidcOutputReference
- type LbListenerDefaultActionFixedResponse
- type LbListenerDefaultActionFixedResponseOutputReference
- type LbListenerDefaultActionForward
- type LbListenerDefaultActionForwardOutputReference
- type LbListenerDefaultActionForwardStickiness
- type LbListenerDefaultActionForwardStickinessOutputReference
- type LbListenerDefaultActionForwardTargetGroup
- type LbListenerDefaultActionForwardTargetGroupList
- type LbListenerDefaultActionForwardTargetGroupOutputReference
- type LbListenerDefaultActionList
- type LbListenerDefaultActionOutputReference
- type LbListenerDefaultActionRedirect
- type LbListenerDefaultActionRedirectOutputReference
- type LbListenerTimeouts
- type LbListenerTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LbListener_IsConstruct ¶
func LbListener_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func LbListener_IsTerraformElement ¶
func LbListener_IsTerraformElement(x interface{}) *bool
Experimental.
func LbListener_IsTerraformResource ¶
func LbListener_IsTerraformResource(x interface{}) *bool
Experimental.
func LbListener_TfResourceType ¶
func LbListener_TfResourceType() *string
func NewLbListenerDefaultActionAuthenticateCognitoOutputReference_Override ¶
func NewLbListenerDefaultActionAuthenticateCognitoOutputReference_Override(l LbListenerDefaultActionAuthenticateCognitoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLbListenerDefaultActionAuthenticateOidcOutputReference_Override ¶
func NewLbListenerDefaultActionAuthenticateOidcOutputReference_Override(l LbListenerDefaultActionAuthenticateOidcOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLbListenerDefaultActionFixedResponseOutputReference_Override ¶
func NewLbListenerDefaultActionFixedResponseOutputReference_Override(l LbListenerDefaultActionFixedResponseOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLbListenerDefaultActionForwardOutputReference_Override ¶
func NewLbListenerDefaultActionForwardOutputReference_Override(l LbListenerDefaultActionForwardOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLbListenerDefaultActionForwardStickinessOutputReference_Override ¶
func NewLbListenerDefaultActionForwardStickinessOutputReference_Override(l LbListenerDefaultActionForwardStickinessOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLbListenerDefaultActionForwardTargetGroupList_Override ¶
func NewLbListenerDefaultActionForwardTargetGroupList_Override(l LbListenerDefaultActionForwardTargetGroupList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewLbListenerDefaultActionForwardTargetGroupOutputReference_Override ¶
func NewLbListenerDefaultActionForwardTargetGroupOutputReference_Override(l LbListenerDefaultActionForwardTargetGroupOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewLbListenerDefaultActionList_Override ¶
func NewLbListenerDefaultActionList_Override(l LbListenerDefaultActionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewLbListenerDefaultActionOutputReference_Override ¶
func NewLbListenerDefaultActionOutputReference_Override(l LbListenerDefaultActionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewLbListenerDefaultActionRedirectOutputReference_Override ¶
func NewLbListenerDefaultActionRedirectOutputReference_Override(l LbListenerDefaultActionRedirectOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLbListenerTimeoutsOutputReference_Override ¶
func NewLbListenerTimeoutsOutputReference_Override(l LbListenerTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLbListener_Override ¶
func NewLbListener_Override(l LbListener, scope constructs.Construct, id *string, config *LbListenerConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/lb_listener aws_lb_listener} Resource.
Types ¶
type LbListener ¶
type LbListener interface {
cdktf.TerraformResource
AlpnPolicy() *string
SetAlpnPolicy(val *string)
AlpnPolicyInput() *string
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CertificateArn() *string
SetCertificateArn(val *string)
CertificateArnInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DefaultAction() LbListenerDefaultActionList
DefaultActionInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LoadBalancerArn() *string
SetLoadBalancerArn(val *string)
LoadBalancerArnInput() *string
// The tree node.
Node() constructs.Node
Port() *float64
SetPort(val *float64)
PortInput() *float64
Protocol() *string
SetProtocol(val *string)
ProtocolInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SslPolicy() *string
SetSslPolicy(val *string)
SslPolicyInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() LbListenerTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDefaultAction(value interface{})
PutTimeouts(value *LbListenerTimeouts)
ResetAlpnPolicy()
ResetCertificateArn()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPort()
ResetProtocol()
ResetSslPolicy()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/lb_listener aws_lb_listener}.
func NewLbListener ¶
func NewLbListener(scope constructs.Construct, id *string, config *LbListenerConfig) LbListener
Create a new {@link https://www.terraform.io/docs/providers/aws/r/lb_listener aws_lb_listener} Resource.
type LbListenerConfig ¶
type LbListenerConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// default_action block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#default_action LbListener#default_action}
DefaultAction interface{} `field:"required" json:"defaultAction" yaml:"defaultAction"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#load_balancer_arn LbListener#load_balancer_arn}.
LoadBalancerArn *string `field:"required" json:"loadBalancerArn" yaml:"loadBalancerArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#alpn_policy LbListener#alpn_policy}.
AlpnPolicy *string `field:"optional" json:"alpnPolicy" yaml:"alpnPolicy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#certificate_arn LbListener#certificate_arn}.
CertificateArn *string `field:"optional" json:"certificateArn" yaml:"certificateArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#id LbListener#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#port LbListener#port}.
Port *float64 `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#protocol LbListener#protocol}.
Protocol *string `field:"optional" json:"protocol" yaml:"protocol"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#ssl_policy LbListener#ssl_policy}.
SslPolicy *string `field:"optional" json:"sslPolicy" yaml:"sslPolicy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#tags LbListener#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#tags_all LbListener#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#timeouts LbListener#timeouts}
Timeouts *LbListenerTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type LbListenerDefaultAction ¶
type LbListenerDefaultAction struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#type LbListener#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// authenticate_cognito block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#authenticate_cognito LbListener#authenticate_cognito}
AuthenticateCognito *LbListenerDefaultActionAuthenticateCognito `field:"optional" json:"authenticateCognito" yaml:"authenticateCognito"`
// authenticate_oidc block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#authenticate_oidc LbListener#authenticate_oidc}
AuthenticateOidc *LbListenerDefaultActionAuthenticateOidc `field:"optional" json:"authenticateOidc" yaml:"authenticateOidc"`
// fixed_response block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#fixed_response LbListener#fixed_response}
FixedResponse *LbListenerDefaultActionFixedResponse `field:"optional" json:"fixedResponse" yaml:"fixedResponse"`
// forward block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#forward LbListener#forward}
Forward *LbListenerDefaultActionForward `field:"optional" json:"forward" yaml:"forward"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#order LbListener#order}.
Order *float64 `field:"optional" json:"order" yaml:"order"`
// redirect block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#redirect LbListener#redirect}
Redirect *LbListenerDefaultActionRedirect `field:"optional" json:"redirect" yaml:"redirect"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#target_group_arn LbListener#target_group_arn}.
TargetGroupArn *string `field:"optional" json:"targetGroupArn" yaml:"targetGroupArn"`
}
type LbListenerDefaultActionAuthenticateCognito ¶
type LbListenerDefaultActionAuthenticateCognito struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#user_pool_arn LbListener#user_pool_arn}.
UserPoolArn *string `field:"required" json:"userPoolArn" yaml:"userPoolArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#user_pool_client_id LbListener#user_pool_client_id}.
UserPoolClientId *string `field:"required" json:"userPoolClientId" yaml:"userPoolClientId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#user_pool_domain LbListener#user_pool_domain}.
UserPoolDomain *string `field:"required" json:"userPoolDomain" yaml:"userPoolDomain"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#authentication_request_extra_params LbListener#authentication_request_extra_params}.
AuthenticationRequestExtraParams *map[string]*string `field:"optional" json:"authenticationRequestExtraParams" yaml:"authenticationRequestExtraParams"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#on_unauthenticated_request LbListener#on_unauthenticated_request}.
OnUnauthenticatedRequest *string `field:"optional" json:"onUnauthenticatedRequest" yaml:"onUnauthenticatedRequest"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#scope LbListener#scope}.
Scope *string `field:"optional" json:"scope" yaml:"scope"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#session_cookie_name LbListener#session_cookie_name}.
SessionCookieName *string `field:"optional" json:"sessionCookieName" yaml:"sessionCookieName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#session_timeout LbListener#session_timeout}.
SessionTimeout *float64 `field:"optional" json:"sessionTimeout" yaml:"sessionTimeout"`
}
type LbListenerDefaultActionAuthenticateCognitoOutputReference ¶
type LbListenerDefaultActionAuthenticateCognitoOutputReference interface {
cdktf.ComplexObject
AuthenticationRequestExtraParams() *map[string]*string
SetAuthenticationRequestExtraParams(val *map[string]*string)
AuthenticationRequestExtraParamsInput() *map[string]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LbListenerDefaultActionAuthenticateCognito
SetInternalValue(val *LbListenerDefaultActionAuthenticateCognito)
OnUnauthenticatedRequest() *string
SetOnUnauthenticatedRequest(val *string)
OnUnauthenticatedRequestInput() *string
Scope() *string
SetScope(val *string)
ScopeInput() *string
SessionCookieName() *string
SetSessionCookieName(val *string)
SessionCookieNameInput() *string
SessionTimeout() *float64
SetSessionTimeout(val *float64)
SessionTimeoutInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UserPoolArn() *string
SetUserPoolArn(val *string)
UserPoolArnInput() *string
UserPoolClientId() *string
SetUserPoolClientId(val *string)
UserPoolClientIdInput() *string
UserPoolDomain() *string
SetUserPoolDomain(val *string)
UserPoolDomainInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAuthenticationRequestExtraParams()
ResetOnUnauthenticatedRequest()
ResetScope()
ResetSessionCookieName()
ResetSessionTimeout()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLbListenerDefaultActionAuthenticateCognitoOutputReference ¶
func NewLbListenerDefaultActionAuthenticateCognitoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LbListenerDefaultActionAuthenticateCognitoOutputReference
type LbListenerDefaultActionAuthenticateOidc ¶
type LbListenerDefaultActionAuthenticateOidc struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#authorization_endpoint LbListener#authorization_endpoint}.
AuthorizationEndpoint *string `field:"required" json:"authorizationEndpoint" yaml:"authorizationEndpoint"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#client_id LbListener#client_id}.
ClientId *string `field:"required" json:"clientId" yaml:"clientId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#client_secret LbListener#client_secret}.
ClientSecret *string `field:"required" json:"clientSecret" yaml:"clientSecret"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#issuer LbListener#issuer}.
Issuer *string `field:"required" json:"issuer" yaml:"issuer"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#token_endpoint LbListener#token_endpoint}.
TokenEndpoint *string `field:"required" json:"tokenEndpoint" yaml:"tokenEndpoint"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#user_info_endpoint LbListener#user_info_endpoint}.
UserInfoEndpoint *string `field:"required" json:"userInfoEndpoint" yaml:"userInfoEndpoint"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#authentication_request_extra_params LbListener#authentication_request_extra_params}.
AuthenticationRequestExtraParams *map[string]*string `field:"optional" json:"authenticationRequestExtraParams" yaml:"authenticationRequestExtraParams"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#on_unauthenticated_request LbListener#on_unauthenticated_request}.
OnUnauthenticatedRequest *string `field:"optional" json:"onUnauthenticatedRequest" yaml:"onUnauthenticatedRequest"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#scope LbListener#scope}.
Scope *string `field:"optional" json:"scope" yaml:"scope"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#session_cookie_name LbListener#session_cookie_name}.
SessionCookieName *string `field:"optional" json:"sessionCookieName" yaml:"sessionCookieName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#session_timeout LbListener#session_timeout}.
SessionTimeout *float64 `field:"optional" json:"sessionTimeout" yaml:"sessionTimeout"`
}
type LbListenerDefaultActionAuthenticateOidcOutputReference ¶
type LbListenerDefaultActionAuthenticateOidcOutputReference interface {
cdktf.ComplexObject
AuthenticationRequestExtraParams() *map[string]*string
SetAuthenticationRequestExtraParams(val *map[string]*string)
AuthenticationRequestExtraParamsInput() *map[string]*string
AuthorizationEndpoint() *string
SetAuthorizationEndpoint(val *string)
AuthorizationEndpointInput() *string
ClientId() *string
SetClientId(val *string)
ClientIdInput() *string
ClientSecret() *string
SetClientSecret(val *string)
ClientSecretInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LbListenerDefaultActionAuthenticateOidc
SetInternalValue(val *LbListenerDefaultActionAuthenticateOidc)
Issuer() *string
SetIssuer(val *string)
IssuerInput() *string
OnUnauthenticatedRequest() *string
SetOnUnauthenticatedRequest(val *string)
OnUnauthenticatedRequestInput() *string
Scope() *string
SetScope(val *string)
ScopeInput() *string
SessionCookieName() *string
SetSessionCookieName(val *string)
SessionCookieNameInput() *string
SessionTimeout() *float64
SetSessionTimeout(val *float64)
SessionTimeoutInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TokenEndpoint() *string
SetTokenEndpoint(val *string)
TokenEndpointInput() *string
UserInfoEndpoint() *string
SetUserInfoEndpoint(val *string)
UserInfoEndpointInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAuthenticationRequestExtraParams()
ResetOnUnauthenticatedRequest()
ResetScope()
ResetSessionCookieName()
ResetSessionTimeout()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLbListenerDefaultActionAuthenticateOidcOutputReference ¶
func NewLbListenerDefaultActionAuthenticateOidcOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LbListenerDefaultActionAuthenticateOidcOutputReference
type LbListenerDefaultActionFixedResponse ¶
type LbListenerDefaultActionFixedResponse struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#content_type LbListener#content_type}.
ContentType *string `field:"required" json:"contentType" yaml:"contentType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#message_body LbListener#message_body}.
MessageBody *string `field:"optional" json:"messageBody" yaml:"messageBody"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#status_code LbListener#status_code}.
StatusCode *string `field:"optional" json:"statusCode" yaml:"statusCode"`
}
type LbListenerDefaultActionFixedResponseOutputReference ¶
type LbListenerDefaultActionFixedResponseOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ContentType() *string
SetContentType(val *string)
ContentTypeInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LbListenerDefaultActionFixedResponse
SetInternalValue(val *LbListenerDefaultActionFixedResponse)
MessageBody() *string
SetMessageBody(val *string)
MessageBodyInput() *string
StatusCode() *string
SetStatusCode(val *string)
StatusCodeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetMessageBody()
ResetStatusCode()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLbListenerDefaultActionFixedResponseOutputReference ¶
func NewLbListenerDefaultActionFixedResponseOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LbListenerDefaultActionFixedResponseOutputReference
type LbListenerDefaultActionForward ¶
type LbListenerDefaultActionForward struct {
// target_group block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#target_group LbListener#target_group}
TargetGroup interface{} `field:"required" json:"targetGroup" yaml:"targetGroup"`
// stickiness block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#stickiness LbListener#stickiness}
Stickiness *LbListenerDefaultActionForwardStickiness `field:"optional" json:"stickiness" yaml:"stickiness"`
}
type LbListenerDefaultActionForwardOutputReference ¶
type LbListenerDefaultActionForwardOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LbListenerDefaultActionForward
SetInternalValue(val *LbListenerDefaultActionForward)
Stickiness() LbListenerDefaultActionForwardStickinessOutputReference
StickinessInput() *LbListenerDefaultActionForwardStickiness
TargetGroup() LbListenerDefaultActionForwardTargetGroupList
TargetGroupInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutStickiness(value *LbListenerDefaultActionForwardStickiness)
PutTargetGroup(value interface{})
ResetStickiness()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLbListenerDefaultActionForwardOutputReference ¶
func NewLbListenerDefaultActionForwardOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LbListenerDefaultActionForwardOutputReference
type LbListenerDefaultActionForwardStickiness ¶
type LbListenerDefaultActionForwardStickiness struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#duration LbListener#duration}.
Duration *float64 `field:"required" json:"duration" yaml:"duration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#enabled LbListener#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
}
type LbListenerDefaultActionForwardStickinessOutputReference ¶
type LbListenerDefaultActionForwardStickinessOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Duration() *float64
SetDuration(val *float64)
DurationInput() *float64
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *LbListenerDefaultActionForwardStickiness
SetInternalValue(val *LbListenerDefaultActionForwardStickiness)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnabled()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLbListenerDefaultActionForwardStickinessOutputReference ¶
func NewLbListenerDefaultActionForwardStickinessOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LbListenerDefaultActionForwardStickinessOutputReference
type LbListenerDefaultActionForwardTargetGroup ¶
type LbListenerDefaultActionForwardTargetGroup struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#arn LbListener#arn}.
Arn *string `field:"required" json:"arn" yaml:"arn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#weight LbListener#weight}.
Weight *float64 `field:"optional" json:"weight" yaml:"weight"`
}
type LbListenerDefaultActionForwardTargetGroupList ¶
type LbListenerDefaultActionForwardTargetGroupList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) LbListenerDefaultActionForwardTargetGroupOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLbListenerDefaultActionForwardTargetGroupList ¶
func NewLbListenerDefaultActionForwardTargetGroupList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) LbListenerDefaultActionForwardTargetGroupList
type LbListenerDefaultActionForwardTargetGroupOutputReference ¶
type LbListenerDefaultActionForwardTargetGroupOutputReference interface {
cdktf.ComplexObject
Arn() *string
SetArn(val *string)
ArnInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Weight() *float64
SetWeight(val *float64)
WeightInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetWeight()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLbListenerDefaultActionForwardTargetGroupOutputReference ¶
func NewLbListenerDefaultActionForwardTargetGroupOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) LbListenerDefaultActionForwardTargetGroupOutputReference
type LbListenerDefaultActionList ¶
type LbListenerDefaultActionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) LbListenerDefaultActionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLbListenerDefaultActionList ¶
func NewLbListenerDefaultActionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) LbListenerDefaultActionList
type LbListenerDefaultActionOutputReference ¶
type LbListenerDefaultActionOutputReference interface {
cdktf.ComplexObject
AuthenticateCognito() LbListenerDefaultActionAuthenticateCognitoOutputReference
AuthenticateCognitoInput() *LbListenerDefaultActionAuthenticateCognito
AuthenticateOidc() LbListenerDefaultActionAuthenticateOidcOutputReference
AuthenticateOidcInput() *LbListenerDefaultActionAuthenticateOidc
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FixedResponse() LbListenerDefaultActionFixedResponseOutputReference
FixedResponseInput() *LbListenerDefaultActionFixedResponse
Forward() LbListenerDefaultActionForwardOutputReference
ForwardInput() *LbListenerDefaultActionForward
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Order() *float64
SetOrder(val *float64)
OrderInput() *float64
Redirect() LbListenerDefaultActionRedirectOutputReference
RedirectInput() *LbListenerDefaultActionRedirect
TargetGroupArn() *string
SetTargetGroupArn(val *string)
TargetGroupArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAuthenticateCognito(value *LbListenerDefaultActionAuthenticateCognito)
PutAuthenticateOidc(value *LbListenerDefaultActionAuthenticateOidc)
PutFixedResponse(value *LbListenerDefaultActionFixedResponse)
PutForward(value *LbListenerDefaultActionForward)
PutRedirect(value *LbListenerDefaultActionRedirect)
ResetAuthenticateCognito()
ResetAuthenticateOidc()
ResetFixedResponse()
ResetForward()
ResetOrder()
ResetRedirect()
ResetTargetGroupArn()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLbListenerDefaultActionOutputReference ¶
func NewLbListenerDefaultActionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) LbListenerDefaultActionOutputReference
type LbListenerDefaultActionRedirect ¶
type LbListenerDefaultActionRedirect struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#status_code LbListener#status_code}.
StatusCode *string `field:"required" json:"statusCode" yaml:"statusCode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#host LbListener#host}.
Host *string `field:"optional" json:"host" yaml:"host"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#path LbListener#path}.
Path *string `field:"optional" json:"path" yaml:"path"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#port LbListener#port}.
Port *string `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#protocol LbListener#protocol}.
Protocol *string `field:"optional" json:"protocol" yaml:"protocol"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#query LbListener#query}.
Query *string `field:"optional" json:"query" yaml:"query"`
}
type LbListenerDefaultActionRedirectOutputReference ¶
type LbListenerDefaultActionRedirectOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Host() *string
SetHost(val *string)
HostInput() *string
InternalValue() *LbListenerDefaultActionRedirect
SetInternalValue(val *LbListenerDefaultActionRedirect)
Path() *string
SetPath(val *string)
PathInput() *string
Port() *string
SetPort(val *string)
PortInput() *string
Protocol() *string
SetProtocol(val *string)
ProtocolInput() *string
Query() *string
SetQuery(val *string)
QueryInput() *string
StatusCode() *string
SetStatusCode(val *string)
StatusCodeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetHost()
ResetPath()
ResetPort()
ResetProtocol()
ResetQuery()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLbListenerDefaultActionRedirectOutputReference ¶
func NewLbListenerDefaultActionRedirectOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LbListenerDefaultActionRedirectOutputReference
type LbListenerTimeouts ¶
type LbListenerTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener#read LbListener#read}.
Read *string `field:"optional" json:"read" yaml:"read"`
}
type LbListenerTimeoutsOutputReference ¶
type LbListenerTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Read() *string
SetRead(val *string)
ReadInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetRead()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLbListenerTimeoutsOutputReference ¶
func NewLbListenerTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LbListenerTimeoutsOutputReference
Source Files
¶
- lblistener.go
- lblistener_LbListener.go
- lblistener_LbListenerConfig.go
- lblistener_LbListenerDefaultAction.go
- lblistener_LbListenerDefaultActionAuthenticateCognito.go
- lblistener_LbListenerDefaultActionAuthenticateCognitoOutputReference.go
- lblistener_LbListenerDefaultActionAuthenticateCognitoOutputReference__runtime_type_checks.go
- lblistener_LbListenerDefaultActionAuthenticateOidc.go
- lblistener_LbListenerDefaultActionAuthenticateOidcOutputReference.go
- lblistener_LbListenerDefaultActionAuthenticateOidcOutputReference__runtime_type_checks.go
- lblistener_LbListenerDefaultActionFixedResponse.go
- lblistener_LbListenerDefaultActionFixedResponseOutputReference.go
- lblistener_LbListenerDefaultActionFixedResponseOutputReference__runtime_type_checks.go
- lblistener_LbListenerDefaultActionForward.go
- lblistener_LbListenerDefaultActionForwardOutputReference.go
- lblistener_LbListenerDefaultActionForwardOutputReference__runtime_type_checks.go
- lblistener_LbListenerDefaultActionForwardStickiness.go
- lblistener_LbListenerDefaultActionForwardStickinessOutputReference.go
- lblistener_LbListenerDefaultActionForwardStickinessOutputReference__runtime_type_checks.go
- lblistener_LbListenerDefaultActionForwardTargetGroup.go
- lblistener_LbListenerDefaultActionForwardTargetGroupList.go
- lblistener_LbListenerDefaultActionForwardTargetGroupList__runtime_type_checks.go
- lblistener_LbListenerDefaultActionForwardTargetGroupOutputReference.go
- lblistener_LbListenerDefaultActionForwardTargetGroupOutputReference__runtime_type_checks.go
- lblistener_LbListenerDefaultActionList.go
- lblistener_LbListenerDefaultActionList__runtime_type_checks.go
- lblistener_LbListenerDefaultActionOutputReference.go
- lblistener_LbListenerDefaultActionOutputReference__runtime_type_checks.go
- lblistener_LbListenerDefaultActionRedirect.go
- lblistener_LbListenerDefaultActionRedirectOutputReference.go
- lblistener_LbListenerDefaultActionRedirectOutputReference__runtime_type_checks.go
- lblistener_LbListenerTimeouts.go
- lblistener_LbListenerTimeoutsOutputReference.go
- lblistener_LbListenerTimeoutsOutputReference__runtime_type_checks.go
- lblistener_LbListener__runtime_type_checks.go