Documentation
¶
Index ¶
- func LexBotAlias_IsConstruct(x interface{}) *bool
- func LexBotAlias_IsTerraformElement(x interface{}) *bool
- func LexBotAlias_IsTerraformResource(x interface{}) *bool
- func LexBotAlias_TfResourceType() *string
- func NewLexBotAliasConversationLogsLogSettingsList_Override(l LexBotAliasConversationLogsLogSettingsList, ...)
- func NewLexBotAliasConversationLogsLogSettingsOutputReference_Override(l LexBotAliasConversationLogsLogSettingsOutputReference, ...)
- func NewLexBotAliasConversationLogsOutputReference_Override(l LexBotAliasConversationLogsOutputReference, ...)
- func NewLexBotAliasTimeoutsOutputReference_Override(l LexBotAliasTimeoutsOutputReference, ...)
- func NewLexBotAlias_Override(l LexBotAlias, scope constructs.Construct, id *string, ...)
- type LexBotAlias
- type LexBotAliasConfig
- type LexBotAliasConversationLogs
- type LexBotAliasConversationLogsLogSettings
- type LexBotAliasConversationLogsLogSettingsList
- type LexBotAliasConversationLogsLogSettingsOutputReference
- type LexBotAliasConversationLogsOutputReference
- type LexBotAliasTimeouts
- type LexBotAliasTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LexBotAlias_IsConstruct ¶
func LexBotAlias_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func LexBotAlias_IsTerraformElement ¶
func LexBotAlias_IsTerraformElement(x interface{}) *bool
Experimental.
func LexBotAlias_IsTerraformResource ¶
func LexBotAlias_IsTerraformResource(x interface{}) *bool
Experimental.
func LexBotAlias_TfResourceType ¶
func LexBotAlias_TfResourceType() *string
func NewLexBotAliasConversationLogsLogSettingsList_Override ¶
func NewLexBotAliasConversationLogsLogSettingsList_Override(l LexBotAliasConversationLogsLogSettingsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewLexBotAliasConversationLogsLogSettingsOutputReference_Override ¶
func NewLexBotAliasConversationLogsLogSettingsOutputReference_Override(l LexBotAliasConversationLogsLogSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewLexBotAliasConversationLogsOutputReference_Override ¶
func NewLexBotAliasConversationLogsOutputReference_Override(l LexBotAliasConversationLogsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLexBotAliasTimeoutsOutputReference_Override ¶
func NewLexBotAliasTimeoutsOutputReference_Override(l LexBotAliasTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLexBotAlias_Override ¶
func NewLexBotAlias_Override(l LexBotAlias, scope constructs.Construct, id *string, config *LexBotAliasConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/lex_bot_alias aws_lex_bot_alias} Resource.
Types ¶
type LexBotAlias ¶
type LexBotAlias interface {
cdktf.TerraformResource
Arn() *string
BotName() *string
SetBotName(val *string)
BotNameInput() *string
BotVersion() *string
SetBotVersion(val *string)
BotVersionInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
Checksum() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ConversationLogs() LexBotAliasConversationLogsOutputReference
ConversationLogsInput() *LexBotAliasConversationLogs
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreatedDate() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
LastUpdatedDate() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() LexBotAliasTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutConversationLogs(value *LexBotAliasConversationLogs)
PutTimeouts(value *LexBotAliasTimeouts)
ResetConversationLogs()
ResetDescription()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/lex_bot_alias aws_lex_bot_alias}.
func NewLexBotAlias ¶
func NewLexBotAlias(scope constructs.Construct, id *string, config *LexBotAliasConfig) LexBotAlias
Create a new {@link https://www.terraform.io/docs/providers/aws/r/lex_bot_alias aws_lex_bot_alias} Resource.
type LexBotAliasConfig ¶
type LexBotAliasConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lex_bot_alias#bot_name LexBotAlias#bot_name}.
BotName *string `field:"required" json:"botName" yaml:"botName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lex_bot_alias#bot_version LexBotAlias#bot_version}.
BotVersion *string `field:"required" json:"botVersion" yaml:"botVersion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lex_bot_alias#name LexBotAlias#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// conversation_logs block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lex_bot_alias#conversation_logs LexBotAlias#conversation_logs}
ConversationLogs *LexBotAliasConversationLogs `field:"optional" json:"conversationLogs" yaml:"conversationLogs"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lex_bot_alias#description LexBotAlias#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lex_bot_alias#id LexBotAlias#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lex_bot_alias#timeouts LexBotAlias#timeouts}
Timeouts *LexBotAliasTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type LexBotAliasConversationLogs ¶
type LexBotAliasConversationLogs struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lex_bot_alias#iam_role_arn LexBotAlias#iam_role_arn}.
IamRoleArn *string `field:"required" json:"iamRoleArn" yaml:"iamRoleArn"`
// log_settings block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lex_bot_alias#log_settings LexBotAlias#log_settings}
LogSettings interface{} `field:"optional" json:"logSettings" yaml:"logSettings"`
}
type LexBotAliasConversationLogsLogSettings ¶
type LexBotAliasConversationLogsLogSettings struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lex_bot_alias#destination LexBotAlias#destination}.
Destination *string `field:"required" json:"destination" yaml:"destination"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lex_bot_alias#log_type LexBotAlias#log_type}.
LogType *string `field:"required" json:"logType" yaml:"logType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lex_bot_alias#resource_arn LexBotAlias#resource_arn}.
ResourceArn *string `field:"required" json:"resourceArn" yaml:"resourceArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lex_bot_alias#kms_key_arn LexBotAlias#kms_key_arn}.
KmsKeyArn *string `field:"optional" json:"kmsKeyArn" yaml:"kmsKeyArn"`
}
type LexBotAliasConversationLogsLogSettingsList ¶
type LexBotAliasConversationLogsLogSettingsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) LexBotAliasConversationLogsLogSettingsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLexBotAliasConversationLogsLogSettingsList ¶
func NewLexBotAliasConversationLogsLogSettingsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) LexBotAliasConversationLogsLogSettingsList
type LexBotAliasConversationLogsLogSettingsOutputReference ¶
type LexBotAliasConversationLogsLogSettingsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Destination() *string
SetDestination(val *string)
DestinationInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
KmsKeyArn() *string
SetKmsKeyArn(val *string)
KmsKeyArnInput() *string
LogType() *string
SetLogType(val *string)
LogTypeInput() *string
ResourceArn() *string
SetResourceArn(val *string)
ResourceArnInput() *string
ResourcePrefix() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetKmsKeyArn()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLexBotAliasConversationLogsLogSettingsOutputReference ¶
func NewLexBotAliasConversationLogsLogSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) LexBotAliasConversationLogsLogSettingsOutputReference
type LexBotAliasConversationLogsOutputReference ¶
type LexBotAliasConversationLogsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IamRoleArn() *string
SetIamRoleArn(val *string)
IamRoleArnInput() *string
InternalValue() *LexBotAliasConversationLogs
SetInternalValue(val *LexBotAliasConversationLogs)
LogSettings() LexBotAliasConversationLogsLogSettingsList
LogSettingsInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutLogSettings(value interface{})
ResetLogSettings()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLexBotAliasConversationLogsOutputReference ¶
func NewLexBotAliasConversationLogsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LexBotAliasConversationLogsOutputReference
type LexBotAliasTimeouts ¶
type LexBotAliasTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lex_bot_alias#create LexBotAlias#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lex_bot_alias#delete LexBotAlias#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lex_bot_alias#update LexBotAlias#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type LexBotAliasTimeoutsOutputReference ¶
type LexBotAliasTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLexBotAliasTimeoutsOutputReference ¶
func NewLexBotAliasTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LexBotAliasTimeoutsOutputReference
Source Files
¶
- lexbotalias.go
- lexbotalias_LexBotAlias.go
- lexbotalias_LexBotAliasConfig.go
- lexbotalias_LexBotAliasConversationLogs.go
- lexbotalias_LexBotAliasConversationLogsLogSettings.go
- lexbotalias_LexBotAliasConversationLogsLogSettingsList.go
- lexbotalias_LexBotAliasConversationLogsLogSettingsList__runtime_type_checks.go
- lexbotalias_LexBotAliasConversationLogsLogSettingsOutputReference.go
- lexbotalias_LexBotAliasConversationLogsLogSettingsOutputReference__runtime_type_checks.go
- lexbotalias_LexBotAliasConversationLogsOutputReference.go
- lexbotalias_LexBotAliasConversationLogsOutputReference__runtime_type_checks.go
- lexbotalias_LexBotAliasTimeouts.go
- lexbotalias_LexBotAliasTimeoutsOutputReference.go
- lexbotalias_LexBotAliasTimeoutsOutputReference__runtime_type_checks.go
- lexbotalias_LexBotAlias__runtime_type_checks.go