Documentation
¶
Index ¶
- func NetworkfirewallFirewall_IsConstruct(x interface{}) *bool
- func NetworkfirewallFirewall_IsTerraformElement(x interface{}) *bool
- func NetworkfirewallFirewall_IsTerraformResource(x interface{}) *bool
- func NetworkfirewallFirewall_TfResourceType() *string
- func NewNetworkfirewallFirewallEncryptionConfigurationOutputReference_Override(n NetworkfirewallFirewallEncryptionConfigurationOutputReference, ...)
- func NewNetworkfirewallFirewallFirewallStatusList_Override(n NetworkfirewallFirewallFirewallStatusList, ...)
- func NewNetworkfirewallFirewallFirewallStatusOutputReference_Override(n NetworkfirewallFirewallFirewallStatusOutputReference, ...)
- func NewNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList_Override(n NetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList, ...)
- func NewNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference_Override(n NetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference, ...)
- func NewNetworkfirewallFirewallFirewallStatusSyncStatesList_Override(n NetworkfirewallFirewallFirewallStatusSyncStatesList, ...)
- func NewNetworkfirewallFirewallFirewallStatusSyncStatesOutputReference_Override(n NetworkfirewallFirewallFirewallStatusSyncStatesOutputReference, ...)
- func NewNetworkfirewallFirewallSubnetMappingList_Override(n NetworkfirewallFirewallSubnetMappingList, ...)
- func NewNetworkfirewallFirewallSubnetMappingOutputReference_Override(n NetworkfirewallFirewallSubnetMappingOutputReference, ...)
- func NewNetworkfirewallFirewall_Override(n NetworkfirewallFirewall, scope constructs.Construct, id *string, ...)
- type NetworkfirewallFirewall
- type NetworkfirewallFirewallConfig
- type NetworkfirewallFirewallEncryptionConfiguration
- type NetworkfirewallFirewallEncryptionConfigurationOutputReference
- type NetworkfirewallFirewallFirewallStatus
- type NetworkfirewallFirewallFirewallStatusList
- type NetworkfirewallFirewallFirewallStatusOutputReference
- type NetworkfirewallFirewallFirewallStatusSyncStates
- type NetworkfirewallFirewallFirewallStatusSyncStatesAttachment
- type NetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList
- type NetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference
- type NetworkfirewallFirewallFirewallStatusSyncStatesList
- type NetworkfirewallFirewallFirewallStatusSyncStatesOutputReference
- type NetworkfirewallFirewallSubnetMapping
- type NetworkfirewallFirewallSubnetMappingList
- type NetworkfirewallFirewallSubnetMappingOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NetworkfirewallFirewall_IsConstruct ¶
func NetworkfirewallFirewall_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func NetworkfirewallFirewall_IsTerraformElement ¶
func NetworkfirewallFirewall_IsTerraformElement(x interface{}) *bool
Experimental.
func NetworkfirewallFirewall_IsTerraformResource ¶
func NetworkfirewallFirewall_IsTerraformResource(x interface{}) *bool
Experimental.
func NetworkfirewallFirewall_TfResourceType ¶
func NetworkfirewallFirewall_TfResourceType() *string
func NewNetworkfirewallFirewallEncryptionConfigurationOutputReference_Override ¶ added in v11.0.6
func NewNetworkfirewallFirewallEncryptionConfigurationOutputReference_Override(n NetworkfirewallFirewallEncryptionConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewNetworkfirewallFirewallFirewallStatusList_Override ¶
func NewNetworkfirewallFirewallFirewallStatusList_Override(n NetworkfirewallFirewallFirewallStatusList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewNetworkfirewallFirewallFirewallStatusOutputReference_Override ¶
func NewNetworkfirewallFirewallFirewallStatusOutputReference_Override(n NetworkfirewallFirewallFirewallStatusOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList_Override ¶
func NewNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList_Override(n NetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference_Override ¶
func NewNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference_Override(n NetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewNetworkfirewallFirewallFirewallStatusSyncStatesList_Override ¶
func NewNetworkfirewallFirewallFirewallStatusSyncStatesList_Override(n NetworkfirewallFirewallFirewallStatusSyncStatesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewNetworkfirewallFirewallFirewallStatusSyncStatesOutputReference_Override ¶
func NewNetworkfirewallFirewallFirewallStatusSyncStatesOutputReference_Override(n NetworkfirewallFirewallFirewallStatusSyncStatesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewNetworkfirewallFirewallSubnetMappingList_Override ¶
func NewNetworkfirewallFirewallSubnetMappingList_Override(n NetworkfirewallFirewallSubnetMappingList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewNetworkfirewallFirewallSubnetMappingOutputReference_Override ¶
func NewNetworkfirewallFirewallSubnetMappingOutputReference_Override(n NetworkfirewallFirewallSubnetMappingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewNetworkfirewallFirewall_Override ¶
func NewNetworkfirewallFirewall_Override(n NetworkfirewallFirewall, scope constructs.Construct, id *string, config *NetworkfirewallFirewallConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_firewall aws_networkfirewall_firewall} Resource.
Types ¶
type NetworkfirewallFirewall ¶
type NetworkfirewallFirewall interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DeleteProtection() interface{}
SetDeleteProtection(val interface{})
DeleteProtectionInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
EncryptionConfiguration() NetworkfirewallFirewallEncryptionConfigurationOutputReference
EncryptionConfigurationInput() *NetworkfirewallFirewallEncryptionConfiguration
FirewallPolicyArn() *string
SetFirewallPolicyArn(val *string)
FirewallPolicyArnInput() *string
FirewallPolicyChangeProtection() interface{}
SetFirewallPolicyChangeProtection(val interface{})
FirewallPolicyChangeProtectionInput() interface{}
FirewallStatus() NetworkfirewallFirewallFirewallStatusList
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SubnetChangeProtection() interface{}
SetSubnetChangeProtection(val interface{})
SubnetChangeProtectionInput() interface{}
SubnetMapping() NetworkfirewallFirewallSubnetMappingList
SubnetMappingInput() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
UpdateToken() *string
VpcId() *string
SetVpcId(val *string)
VpcIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutEncryptionConfiguration(value *NetworkfirewallFirewallEncryptionConfiguration)
PutSubnetMapping(value interface{})
ResetDeleteProtection()
ResetDescription()
ResetEncryptionConfiguration()
ResetFirewallPolicyChangeProtection()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSubnetChangeProtection()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_firewall aws_networkfirewall_firewall}.
func NewNetworkfirewallFirewall ¶
func NewNetworkfirewallFirewall(scope constructs.Construct, id *string, config *NetworkfirewallFirewallConfig) NetworkfirewallFirewall
Create a new {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_firewall aws_networkfirewall_firewall} Resource.
type NetworkfirewallFirewallConfig ¶
type NetworkfirewallFirewallConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_firewall#firewall_policy_arn NetworkfirewallFirewall#firewall_policy_arn}.
FirewallPolicyArn *string `field:"required" json:"firewallPolicyArn" yaml:"firewallPolicyArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_firewall#name NetworkfirewallFirewall#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// subnet_mapping block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_firewall#subnet_mapping NetworkfirewallFirewall#subnet_mapping}
SubnetMapping interface{} `field:"required" json:"subnetMapping" yaml:"subnetMapping"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_firewall#vpc_id NetworkfirewallFirewall#vpc_id}.
VpcId *string `field:"required" json:"vpcId" yaml:"vpcId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_firewall#delete_protection NetworkfirewallFirewall#delete_protection}.
DeleteProtection interface{} `field:"optional" json:"deleteProtection" yaml:"deleteProtection"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_firewall#description NetworkfirewallFirewall#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// encryption_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_firewall#encryption_configuration NetworkfirewallFirewall#encryption_configuration}
EncryptionConfiguration *NetworkfirewallFirewallEncryptionConfiguration `field:"optional" json:"encryptionConfiguration" yaml:"encryptionConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_firewall#firewall_policy_change_protection NetworkfirewallFirewall#firewall_policy_change_protection}.
FirewallPolicyChangeProtection interface{} `field:"optional" json:"firewallPolicyChangeProtection" yaml:"firewallPolicyChangeProtection"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_firewall#id NetworkfirewallFirewall#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_firewall#subnet_change_protection NetworkfirewallFirewall#subnet_change_protection}.
SubnetChangeProtection interface{} `field:"optional" json:"subnetChangeProtection" yaml:"subnetChangeProtection"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_firewall#tags NetworkfirewallFirewall#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_firewall#tags_all NetworkfirewallFirewall#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type NetworkfirewallFirewallEncryptionConfiguration ¶ added in v11.0.6
type NetworkfirewallFirewallEncryptionConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_firewall#type NetworkfirewallFirewall#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_firewall#key_id NetworkfirewallFirewall#key_id}.
KeyId *string `field:"optional" json:"keyId" yaml:"keyId"`
}
type NetworkfirewallFirewallEncryptionConfigurationOutputReference ¶ added in v11.0.6
type NetworkfirewallFirewallEncryptionConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *NetworkfirewallFirewallEncryptionConfiguration
SetInternalValue(val *NetworkfirewallFirewallEncryptionConfiguration)
KeyId() *string
SetKeyId(val *string)
KeyIdInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetKeyId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkfirewallFirewallEncryptionConfigurationOutputReference ¶ added in v11.0.6
func NewNetworkfirewallFirewallEncryptionConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) NetworkfirewallFirewallEncryptionConfigurationOutputReference
type NetworkfirewallFirewallFirewallStatus ¶
type NetworkfirewallFirewallFirewallStatus struct {
}
type NetworkfirewallFirewallFirewallStatusList ¶
type NetworkfirewallFirewallFirewallStatusList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) NetworkfirewallFirewallFirewallStatusOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkfirewallFirewallFirewallStatusList ¶
func NewNetworkfirewallFirewallFirewallStatusList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) NetworkfirewallFirewallFirewallStatusList
type NetworkfirewallFirewallFirewallStatusOutputReference ¶
type NetworkfirewallFirewallFirewallStatusOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *NetworkfirewallFirewallFirewallStatus
SetInternalValue(val *NetworkfirewallFirewallFirewallStatus)
SyncStates() NetworkfirewallFirewallFirewallStatusSyncStatesList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkfirewallFirewallFirewallStatusOutputReference ¶
func NewNetworkfirewallFirewallFirewallStatusOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) NetworkfirewallFirewallFirewallStatusOutputReference
type NetworkfirewallFirewallFirewallStatusSyncStates ¶
type NetworkfirewallFirewallFirewallStatusSyncStates struct {
}
type NetworkfirewallFirewallFirewallStatusSyncStatesAttachment ¶
type NetworkfirewallFirewallFirewallStatusSyncStatesAttachment struct {
}
type NetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList ¶
type NetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) NetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList ¶
func NewNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) NetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList
type NetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference ¶
type NetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EndpointId() *string
// Experimental.
Fqn() *string
InternalValue() *NetworkfirewallFirewallFirewallStatusSyncStatesAttachment
SetInternalValue(val *NetworkfirewallFirewallFirewallStatusSyncStatesAttachment)
SubnetId() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference ¶
func NewNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) NetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference
type NetworkfirewallFirewallFirewallStatusSyncStatesList ¶
type NetworkfirewallFirewallFirewallStatusSyncStatesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) NetworkfirewallFirewallFirewallStatusSyncStatesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkfirewallFirewallFirewallStatusSyncStatesList ¶
func NewNetworkfirewallFirewallFirewallStatusSyncStatesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) NetworkfirewallFirewallFirewallStatusSyncStatesList
type NetworkfirewallFirewallFirewallStatusSyncStatesOutputReference ¶
type NetworkfirewallFirewallFirewallStatusSyncStatesOutputReference interface {
cdktf.ComplexObject
Attachment() NetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList
AvailabilityZone() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *NetworkfirewallFirewallFirewallStatusSyncStates
SetInternalValue(val *NetworkfirewallFirewallFirewallStatusSyncStates)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkfirewallFirewallFirewallStatusSyncStatesOutputReference ¶
func NewNetworkfirewallFirewallFirewallStatusSyncStatesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) NetworkfirewallFirewallFirewallStatusSyncStatesOutputReference
type NetworkfirewallFirewallSubnetMapping ¶
type NetworkfirewallFirewallSubnetMapping struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_firewall#subnet_id NetworkfirewallFirewall#subnet_id}.
SubnetId *string `field:"required" json:"subnetId" yaml:"subnetId"`
}
type NetworkfirewallFirewallSubnetMappingList ¶
type NetworkfirewallFirewallSubnetMappingList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) NetworkfirewallFirewallSubnetMappingOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkfirewallFirewallSubnetMappingList ¶
func NewNetworkfirewallFirewallSubnetMappingList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) NetworkfirewallFirewallSubnetMappingList
type NetworkfirewallFirewallSubnetMappingOutputReference ¶
type NetworkfirewallFirewallSubnetMappingOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
SubnetId() *string
SetSubnetId(val *string)
SubnetIdInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkfirewallFirewallSubnetMappingOutputReference ¶
func NewNetworkfirewallFirewallSubnetMappingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) NetworkfirewallFirewallSubnetMappingOutputReference
Source Files
¶
- networkfirewallfirewall.go
- networkfirewallfirewall_NetworkfirewallFirewall.go
- networkfirewallfirewall_NetworkfirewallFirewallConfig.go
- networkfirewallfirewall_NetworkfirewallFirewallEncryptionConfiguration.go
- networkfirewallfirewall_NetworkfirewallFirewallEncryptionConfigurationOutputReference.go
- networkfirewallfirewall_NetworkfirewallFirewallEncryptionConfigurationOutputReference__runtime_type_checks.go
- networkfirewallfirewall_NetworkfirewallFirewallFirewallStatus.go
- networkfirewallfirewall_NetworkfirewallFirewallFirewallStatusList.go
- networkfirewallfirewall_NetworkfirewallFirewallFirewallStatusList__runtime_type_checks.go
- networkfirewallfirewall_NetworkfirewallFirewallFirewallStatusOutputReference.go
- networkfirewallfirewall_NetworkfirewallFirewallFirewallStatusOutputReference__runtime_type_checks.go
- networkfirewallfirewall_NetworkfirewallFirewallFirewallStatusSyncStates.go
- networkfirewallfirewall_NetworkfirewallFirewallFirewallStatusSyncStatesAttachment.go
- networkfirewallfirewall_NetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList.go
- networkfirewallfirewall_NetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList__runtime_type_checks.go
- networkfirewallfirewall_NetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference.go
- networkfirewallfirewall_NetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference__runtime_type_checks.go
- networkfirewallfirewall_NetworkfirewallFirewallFirewallStatusSyncStatesList.go
- networkfirewallfirewall_NetworkfirewallFirewallFirewallStatusSyncStatesList__runtime_type_checks.go
- networkfirewallfirewall_NetworkfirewallFirewallFirewallStatusSyncStatesOutputReference.go
- networkfirewallfirewall_NetworkfirewallFirewallFirewallStatusSyncStatesOutputReference__runtime_type_checks.go
- networkfirewallfirewall_NetworkfirewallFirewallSubnetMapping.go
- networkfirewallfirewall_NetworkfirewallFirewallSubnetMappingList.go
- networkfirewallfirewall_NetworkfirewallFirewallSubnetMappingList__runtime_type_checks.go
- networkfirewallfirewall_NetworkfirewallFirewallSubnetMappingOutputReference.go
- networkfirewallfirewall_NetworkfirewallFirewallSubnetMappingOutputReference__runtime_type_checks.go
- networkfirewallfirewall_NetworkfirewallFirewall__runtime_type_checks.go