Documentation
¶
Index ¶
- func NewOpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsList_Override(o OpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsList, ...)
- func NewOpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsOutputReference_Override(o OpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsOutputReference, ...)
- func NewOpsworksEcsClusterLayerCloudwatchConfigurationOutputReference_Override(o OpsworksEcsClusterLayerCloudwatchConfigurationOutputReference, ...)
- func NewOpsworksEcsClusterLayerEbsVolumeList_Override(o OpsworksEcsClusterLayerEbsVolumeList, ...)
- func NewOpsworksEcsClusterLayerEbsVolumeOutputReference_Override(o OpsworksEcsClusterLayerEbsVolumeOutputReference, ...)
- func NewOpsworksEcsClusterLayerLoadBasedAutoScalingDownscalingOutputReference_Override(o OpsworksEcsClusterLayerLoadBasedAutoScalingDownscalingOutputReference, ...)
- func NewOpsworksEcsClusterLayerLoadBasedAutoScalingOutputReference_Override(o OpsworksEcsClusterLayerLoadBasedAutoScalingOutputReference, ...)
- func NewOpsworksEcsClusterLayerLoadBasedAutoScalingUpscalingOutputReference_Override(o OpsworksEcsClusterLayerLoadBasedAutoScalingUpscalingOutputReference, ...)
- func NewOpsworksEcsClusterLayer_Override(o OpsworksEcsClusterLayer, scope constructs.Construct, id *string, ...)
- func OpsworksEcsClusterLayer_IsConstruct(x interface{}) *bool
- func OpsworksEcsClusterLayer_IsTerraformElement(x interface{}) *bool
- func OpsworksEcsClusterLayer_IsTerraformResource(x interface{}) *bool
- func OpsworksEcsClusterLayer_TfResourceType() *string
- type OpsworksEcsClusterLayer
- type OpsworksEcsClusterLayerCloudwatchConfiguration
- type OpsworksEcsClusterLayerCloudwatchConfigurationLogStreams
- type OpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsList
- type OpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsOutputReference
- type OpsworksEcsClusterLayerCloudwatchConfigurationOutputReference
- type OpsworksEcsClusterLayerConfig
- type OpsworksEcsClusterLayerEbsVolume
- type OpsworksEcsClusterLayerEbsVolumeList
- type OpsworksEcsClusterLayerEbsVolumeOutputReference
- type OpsworksEcsClusterLayerLoadBasedAutoScaling
- type OpsworksEcsClusterLayerLoadBasedAutoScalingDownscaling
- type OpsworksEcsClusterLayerLoadBasedAutoScalingDownscalingOutputReference
- type OpsworksEcsClusterLayerLoadBasedAutoScalingOutputReference
- type OpsworksEcsClusterLayerLoadBasedAutoScalingUpscaling
- type OpsworksEcsClusterLayerLoadBasedAutoScalingUpscalingOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewOpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsList_Override ¶
func NewOpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsList_Override(o OpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewOpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsOutputReference_Override ¶
func NewOpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsOutputReference_Override(o OpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewOpsworksEcsClusterLayerCloudwatchConfigurationOutputReference_Override ¶
func NewOpsworksEcsClusterLayerCloudwatchConfigurationOutputReference_Override(o OpsworksEcsClusterLayerCloudwatchConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpsworksEcsClusterLayerEbsVolumeList_Override ¶
func NewOpsworksEcsClusterLayerEbsVolumeList_Override(o OpsworksEcsClusterLayerEbsVolumeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewOpsworksEcsClusterLayerEbsVolumeOutputReference_Override ¶
func NewOpsworksEcsClusterLayerEbsVolumeOutputReference_Override(o OpsworksEcsClusterLayerEbsVolumeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewOpsworksEcsClusterLayerLoadBasedAutoScalingDownscalingOutputReference_Override ¶
func NewOpsworksEcsClusterLayerLoadBasedAutoScalingDownscalingOutputReference_Override(o OpsworksEcsClusterLayerLoadBasedAutoScalingDownscalingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpsworksEcsClusterLayerLoadBasedAutoScalingOutputReference_Override ¶
func NewOpsworksEcsClusterLayerLoadBasedAutoScalingOutputReference_Override(o OpsworksEcsClusterLayerLoadBasedAutoScalingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpsworksEcsClusterLayerLoadBasedAutoScalingUpscalingOutputReference_Override ¶
func NewOpsworksEcsClusterLayerLoadBasedAutoScalingUpscalingOutputReference_Override(o OpsworksEcsClusterLayerLoadBasedAutoScalingUpscalingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpsworksEcsClusterLayer_Override ¶
func NewOpsworksEcsClusterLayer_Override(o OpsworksEcsClusterLayer, scope constructs.Construct, id *string, config *OpsworksEcsClusterLayerConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer aws_opsworks_ecs_cluster_layer} Resource.
func OpsworksEcsClusterLayer_IsConstruct ¶
func OpsworksEcsClusterLayer_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func OpsworksEcsClusterLayer_IsTerraformElement ¶
func OpsworksEcsClusterLayer_IsTerraformElement(x interface{}) *bool
Experimental.
func OpsworksEcsClusterLayer_IsTerraformResource ¶
func OpsworksEcsClusterLayer_IsTerraformResource(x interface{}) *bool
Experimental.
func OpsworksEcsClusterLayer_TfResourceType ¶
func OpsworksEcsClusterLayer_TfResourceType() *string
Types ¶
type OpsworksEcsClusterLayer ¶
type OpsworksEcsClusterLayer interface {
cdktf.TerraformResource
Arn() *string
AutoAssignElasticIps() interface{}
SetAutoAssignElasticIps(val interface{})
AutoAssignElasticIpsInput() interface{}
AutoAssignPublicIps() interface{}
SetAutoAssignPublicIps(val interface{})
AutoAssignPublicIpsInput() interface{}
AutoHealing() interface{}
SetAutoHealing(val interface{})
AutoHealingInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
CloudwatchConfiguration() OpsworksEcsClusterLayerCloudwatchConfigurationOutputReference
CloudwatchConfigurationInput() *OpsworksEcsClusterLayerCloudwatchConfiguration
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CustomConfigureRecipes() *[]*string
SetCustomConfigureRecipes(val *[]*string)
CustomConfigureRecipesInput() *[]*string
CustomDeployRecipes() *[]*string
SetCustomDeployRecipes(val *[]*string)
CustomDeployRecipesInput() *[]*string
CustomInstanceProfileArn() *string
SetCustomInstanceProfileArn(val *string)
CustomInstanceProfileArnInput() *string
CustomJson() *string
SetCustomJson(val *string)
CustomJsonInput() *string
CustomSecurityGroupIds() *[]*string
SetCustomSecurityGroupIds(val *[]*string)
CustomSecurityGroupIdsInput() *[]*string
CustomSetupRecipes() *[]*string
SetCustomSetupRecipes(val *[]*string)
CustomSetupRecipesInput() *[]*string
CustomShutdownRecipes() *[]*string
SetCustomShutdownRecipes(val *[]*string)
CustomShutdownRecipesInput() *[]*string
CustomUndeployRecipes() *[]*string
SetCustomUndeployRecipes(val *[]*string)
CustomUndeployRecipesInput() *[]*string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DrainElbOnShutdown() interface{}
SetDrainElbOnShutdown(val interface{})
DrainElbOnShutdownInput() interface{}
EbsVolume() OpsworksEcsClusterLayerEbsVolumeList
EbsVolumeInput() interface{}
EcsClusterArn() *string
SetEcsClusterArn(val *string)
EcsClusterArnInput() *string
ElasticLoadBalancer() *string
SetElasticLoadBalancer(val *string)
ElasticLoadBalancerInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InstallUpdatesOnBoot() interface{}
SetInstallUpdatesOnBoot(val interface{})
InstallUpdatesOnBootInput() interface{}
InstanceShutdownTimeout() *float64
SetInstanceShutdownTimeout(val *float64)
InstanceShutdownTimeoutInput() *float64
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LoadBasedAutoScaling() OpsworksEcsClusterLayerLoadBasedAutoScalingOutputReference
LoadBasedAutoScalingInput() *OpsworksEcsClusterLayerLoadBasedAutoScaling
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
StackId() *string
SetStackId(val *string)
StackIdInput() *string
SystemPackages() *[]*string
SetSystemPackages(val *[]*string)
SystemPackagesInput() *[]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
UseEbsOptimizedInstances() interface{}
SetUseEbsOptimizedInstances(val interface{})
UseEbsOptimizedInstancesInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCloudwatchConfiguration(value *OpsworksEcsClusterLayerCloudwatchConfiguration)
PutEbsVolume(value interface{})
PutLoadBasedAutoScaling(value *OpsworksEcsClusterLayerLoadBasedAutoScaling)
ResetAutoAssignElasticIps()
ResetAutoAssignPublicIps()
ResetAutoHealing()
ResetCloudwatchConfiguration()
ResetCustomConfigureRecipes()
ResetCustomDeployRecipes()
ResetCustomInstanceProfileArn()
ResetCustomJson()
ResetCustomSecurityGroupIds()
ResetCustomSetupRecipes()
ResetCustomShutdownRecipes()
ResetCustomUndeployRecipes()
ResetDrainElbOnShutdown()
ResetEbsVolume()
ResetElasticLoadBalancer()
ResetId()
ResetInstallUpdatesOnBoot()
ResetInstanceShutdownTimeout()
ResetLoadBasedAutoScaling()
ResetName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSystemPackages()
ResetTags()
ResetTagsAll()
ResetUseEbsOptimizedInstances()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer aws_opsworks_ecs_cluster_layer}.
func NewOpsworksEcsClusterLayer ¶
func NewOpsworksEcsClusterLayer(scope constructs.Construct, id *string, config *OpsworksEcsClusterLayerConfig) OpsworksEcsClusterLayer
Create a new {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer aws_opsworks_ecs_cluster_layer} Resource.
type OpsworksEcsClusterLayerCloudwatchConfiguration ¶
type OpsworksEcsClusterLayerCloudwatchConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#enabled OpsworksEcsClusterLayer#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// log_streams block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#log_streams OpsworksEcsClusterLayer#log_streams}
LogStreams interface{} `field:"optional" json:"logStreams" yaml:"logStreams"`
}
type OpsworksEcsClusterLayerCloudwatchConfigurationLogStreams ¶
type OpsworksEcsClusterLayerCloudwatchConfigurationLogStreams struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#file OpsworksEcsClusterLayer#file}.
File *string `field:"required" json:"file" yaml:"file"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#log_group_name OpsworksEcsClusterLayer#log_group_name}.
LogGroupName *string `field:"required" json:"logGroupName" yaml:"logGroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#batch_count OpsworksEcsClusterLayer#batch_count}.
BatchCount *float64 `field:"optional" json:"batchCount" yaml:"batchCount"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#batch_size OpsworksEcsClusterLayer#batch_size}.
BatchSize *float64 `field:"optional" json:"batchSize" yaml:"batchSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#buffer_duration OpsworksEcsClusterLayer#buffer_duration}.
BufferDuration *float64 `field:"optional" json:"bufferDuration" yaml:"bufferDuration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#datetime_format OpsworksEcsClusterLayer#datetime_format}.
DatetimeFormat *string `field:"optional" json:"datetimeFormat" yaml:"datetimeFormat"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#encoding OpsworksEcsClusterLayer#encoding}.
Encoding *string `field:"optional" json:"encoding" yaml:"encoding"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#file_fingerprint_lines OpsworksEcsClusterLayer#file_fingerprint_lines}.
FileFingerprintLines *string `field:"optional" json:"fileFingerprintLines" yaml:"fileFingerprintLines"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#initial_position OpsworksEcsClusterLayer#initial_position}.
InitialPosition *string `field:"optional" json:"initialPosition" yaml:"initialPosition"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#multiline_start_pattern OpsworksEcsClusterLayer#multiline_start_pattern}.
MultilineStartPattern *string `field:"optional" json:"multilineStartPattern" yaml:"multilineStartPattern"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#time_zone OpsworksEcsClusterLayer#time_zone}.
TimeZone *string `field:"optional" json:"timeZone" yaml:"timeZone"`
}
type OpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsList ¶
type OpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) OpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsList ¶
func NewOpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) OpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsList
type OpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsOutputReference ¶
type OpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsOutputReference interface {
cdktf.ComplexObject
BatchCount() *float64
SetBatchCount(val *float64)
BatchCountInput() *float64
BatchSize() *float64
SetBatchSize(val *float64)
BatchSizeInput() *float64
BufferDuration() *float64
SetBufferDuration(val *float64)
BufferDurationInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DatetimeFormat() *string
SetDatetimeFormat(val *string)
DatetimeFormatInput() *string
Encoding() *string
SetEncoding(val *string)
EncodingInput() *string
File() *string
SetFile(val *string)
FileFingerprintLines() *string
SetFileFingerprintLines(val *string)
FileFingerprintLinesInput() *string
FileInput() *string
// Experimental.
Fqn() *string
InitialPosition() *string
SetInitialPosition(val *string)
InitialPositionInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
LogGroupName() *string
SetLogGroupName(val *string)
LogGroupNameInput() *string
MultilineStartPattern() *string
SetMultilineStartPattern(val *string)
MultilineStartPatternInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TimeZone() *string
SetTimeZone(val *string)
TimeZoneInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBatchCount()
ResetBatchSize()
ResetBufferDuration()
ResetDatetimeFormat()
ResetEncoding()
ResetFileFingerprintLines()
ResetInitialPosition()
ResetMultilineStartPattern()
ResetTimeZone()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsOutputReference ¶
func NewOpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) OpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsOutputReference
type OpsworksEcsClusterLayerCloudwatchConfigurationOutputReference ¶
type OpsworksEcsClusterLayerCloudwatchConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *OpsworksEcsClusterLayerCloudwatchConfiguration
SetInternalValue(val *OpsworksEcsClusterLayerCloudwatchConfiguration)
LogStreams() OpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsList
LogStreamsInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutLogStreams(value interface{})
ResetEnabled()
ResetLogStreams()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksEcsClusterLayerCloudwatchConfigurationOutputReference ¶
func NewOpsworksEcsClusterLayerCloudwatchConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpsworksEcsClusterLayerCloudwatchConfigurationOutputReference
type OpsworksEcsClusterLayerConfig ¶
type OpsworksEcsClusterLayerConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#ecs_cluster_arn OpsworksEcsClusterLayer#ecs_cluster_arn}.
EcsClusterArn *string `field:"required" json:"ecsClusterArn" yaml:"ecsClusterArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#stack_id OpsworksEcsClusterLayer#stack_id}.
StackId *string `field:"required" json:"stackId" yaml:"stackId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#auto_assign_elastic_ips OpsworksEcsClusterLayer#auto_assign_elastic_ips}.
AutoAssignElasticIps interface{} `field:"optional" json:"autoAssignElasticIps" yaml:"autoAssignElasticIps"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#auto_assign_public_ips OpsworksEcsClusterLayer#auto_assign_public_ips}.
AutoAssignPublicIps interface{} `field:"optional" json:"autoAssignPublicIps" yaml:"autoAssignPublicIps"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#auto_healing OpsworksEcsClusterLayer#auto_healing}.
AutoHealing interface{} `field:"optional" json:"autoHealing" yaml:"autoHealing"`
// cloudwatch_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#cloudwatch_configuration OpsworksEcsClusterLayer#cloudwatch_configuration}
CloudwatchConfiguration *OpsworksEcsClusterLayerCloudwatchConfiguration `field:"optional" json:"cloudwatchConfiguration" yaml:"cloudwatchConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#custom_configure_recipes OpsworksEcsClusterLayer#custom_configure_recipes}.
CustomConfigureRecipes *[]*string `field:"optional" json:"customConfigureRecipes" yaml:"customConfigureRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#custom_deploy_recipes OpsworksEcsClusterLayer#custom_deploy_recipes}.
CustomDeployRecipes *[]*string `field:"optional" json:"customDeployRecipes" yaml:"customDeployRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#custom_instance_profile_arn OpsworksEcsClusterLayer#custom_instance_profile_arn}.
CustomInstanceProfileArn *string `field:"optional" json:"customInstanceProfileArn" yaml:"customInstanceProfileArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#custom_json OpsworksEcsClusterLayer#custom_json}.
CustomJson *string `field:"optional" json:"customJson" yaml:"customJson"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#custom_security_group_ids OpsworksEcsClusterLayer#custom_security_group_ids}.
CustomSecurityGroupIds *[]*string `field:"optional" json:"customSecurityGroupIds" yaml:"customSecurityGroupIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#custom_setup_recipes OpsworksEcsClusterLayer#custom_setup_recipes}.
CustomSetupRecipes *[]*string `field:"optional" json:"customSetupRecipes" yaml:"customSetupRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#custom_shutdown_recipes OpsworksEcsClusterLayer#custom_shutdown_recipes}.
CustomShutdownRecipes *[]*string `field:"optional" json:"customShutdownRecipes" yaml:"customShutdownRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#custom_undeploy_recipes OpsworksEcsClusterLayer#custom_undeploy_recipes}.
CustomUndeployRecipes *[]*string `field:"optional" json:"customUndeployRecipes" yaml:"customUndeployRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#drain_elb_on_shutdown OpsworksEcsClusterLayer#drain_elb_on_shutdown}.
DrainElbOnShutdown interface{} `field:"optional" json:"drainElbOnShutdown" yaml:"drainElbOnShutdown"`
// ebs_volume block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#ebs_volume OpsworksEcsClusterLayer#ebs_volume}
EbsVolume interface{} `field:"optional" json:"ebsVolume" yaml:"ebsVolume"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#elastic_load_balancer OpsworksEcsClusterLayer#elastic_load_balancer}.
ElasticLoadBalancer *string `field:"optional" json:"elasticLoadBalancer" yaml:"elasticLoadBalancer"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#id OpsworksEcsClusterLayer#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#install_updates_on_boot OpsworksEcsClusterLayer#install_updates_on_boot}.
InstallUpdatesOnBoot interface{} `field:"optional" json:"installUpdatesOnBoot" yaml:"installUpdatesOnBoot"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#instance_shutdown_timeout OpsworksEcsClusterLayer#instance_shutdown_timeout}.
InstanceShutdownTimeout *float64 `field:"optional" json:"instanceShutdownTimeout" yaml:"instanceShutdownTimeout"`
// load_based_auto_scaling block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#load_based_auto_scaling OpsworksEcsClusterLayer#load_based_auto_scaling}
LoadBasedAutoScaling *OpsworksEcsClusterLayerLoadBasedAutoScaling `field:"optional" json:"loadBasedAutoScaling" yaml:"loadBasedAutoScaling"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#name OpsworksEcsClusterLayer#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#system_packages OpsworksEcsClusterLayer#system_packages}.
SystemPackages *[]*string `field:"optional" json:"systemPackages" yaml:"systemPackages"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#tags OpsworksEcsClusterLayer#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#tags_all OpsworksEcsClusterLayer#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#use_ebs_optimized_instances OpsworksEcsClusterLayer#use_ebs_optimized_instances}.
UseEbsOptimizedInstances interface{} `field:"optional" json:"useEbsOptimizedInstances" yaml:"useEbsOptimizedInstances"`
}
type OpsworksEcsClusterLayerEbsVolume ¶
type OpsworksEcsClusterLayerEbsVolume struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#mount_point OpsworksEcsClusterLayer#mount_point}.
MountPoint *string `field:"required" json:"mountPoint" yaml:"mountPoint"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#number_of_disks OpsworksEcsClusterLayer#number_of_disks}.
NumberOfDisks *float64 `field:"required" json:"numberOfDisks" yaml:"numberOfDisks"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#size OpsworksEcsClusterLayer#size}.
Size *float64 `field:"required" json:"size" yaml:"size"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#encrypted OpsworksEcsClusterLayer#encrypted}.
Encrypted interface{} `field:"optional" json:"encrypted" yaml:"encrypted"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#iops OpsworksEcsClusterLayer#iops}.
Iops *float64 `field:"optional" json:"iops" yaml:"iops"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#raid_level OpsworksEcsClusterLayer#raid_level}.
RaidLevel *string `field:"optional" json:"raidLevel" yaml:"raidLevel"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#type OpsworksEcsClusterLayer#type}.
Type *string `field:"optional" json:"type" yaml:"type"`
}
type OpsworksEcsClusterLayerEbsVolumeList ¶
type OpsworksEcsClusterLayerEbsVolumeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) OpsworksEcsClusterLayerEbsVolumeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksEcsClusterLayerEbsVolumeList ¶
func NewOpsworksEcsClusterLayerEbsVolumeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) OpsworksEcsClusterLayerEbsVolumeList
type OpsworksEcsClusterLayerEbsVolumeOutputReference ¶
type OpsworksEcsClusterLayerEbsVolumeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Encrypted() interface{}
SetEncrypted(val interface{})
EncryptedInput() interface{}
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Iops() *float64
SetIops(val *float64)
IopsInput() *float64
MountPoint() *string
SetMountPoint(val *string)
MountPointInput() *string
NumberOfDisks() *float64
SetNumberOfDisks(val *float64)
NumberOfDisksInput() *float64
RaidLevel() *string
SetRaidLevel(val *string)
RaidLevelInput() *string
Size() *float64
SetSize(val *float64)
SizeInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEncrypted()
ResetIops()
ResetRaidLevel()
ResetType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksEcsClusterLayerEbsVolumeOutputReference ¶
func NewOpsworksEcsClusterLayerEbsVolumeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) OpsworksEcsClusterLayerEbsVolumeOutputReference
type OpsworksEcsClusterLayerLoadBasedAutoScaling ¶
type OpsworksEcsClusterLayerLoadBasedAutoScaling struct {
// downscaling block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#downscaling OpsworksEcsClusterLayer#downscaling}
Downscaling *OpsworksEcsClusterLayerLoadBasedAutoScalingDownscaling `field:"optional" json:"downscaling" yaml:"downscaling"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#enable OpsworksEcsClusterLayer#enable}.
Enable interface{} `field:"optional" json:"enable" yaml:"enable"`
// upscaling block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#upscaling OpsworksEcsClusterLayer#upscaling}
Upscaling *OpsworksEcsClusterLayerLoadBasedAutoScalingUpscaling `field:"optional" json:"upscaling" yaml:"upscaling"`
}
type OpsworksEcsClusterLayerLoadBasedAutoScalingDownscaling ¶
type OpsworksEcsClusterLayerLoadBasedAutoScalingDownscaling struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#alarms OpsworksEcsClusterLayer#alarms}.
Alarms *[]*string `field:"optional" json:"alarms" yaml:"alarms"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#cpu_threshold OpsworksEcsClusterLayer#cpu_threshold}.
CpuThreshold *float64 `field:"optional" json:"cpuThreshold" yaml:"cpuThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#ignore_metrics_time OpsworksEcsClusterLayer#ignore_metrics_time}.
IgnoreMetricsTime *float64 `field:"optional" json:"ignoreMetricsTime" yaml:"ignoreMetricsTime"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#instance_count OpsworksEcsClusterLayer#instance_count}.
InstanceCount *float64 `field:"optional" json:"instanceCount" yaml:"instanceCount"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#load_threshold OpsworksEcsClusterLayer#load_threshold}.
LoadThreshold *float64 `field:"optional" json:"loadThreshold" yaml:"loadThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#memory_threshold OpsworksEcsClusterLayer#memory_threshold}.
MemoryThreshold *float64 `field:"optional" json:"memoryThreshold" yaml:"memoryThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#thresholds_wait_time OpsworksEcsClusterLayer#thresholds_wait_time}.
ThresholdsWaitTime *float64 `field:"optional" json:"thresholdsWaitTime" yaml:"thresholdsWaitTime"`
}
type OpsworksEcsClusterLayerLoadBasedAutoScalingDownscalingOutputReference ¶
type OpsworksEcsClusterLayerLoadBasedAutoScalingDownscalingOutputReference interface {
cdktf.ComplexObject
Alarms() *[]*string
SetAlarms(val *[]*string)
AlarmsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CpuThreshold() *float64
SetCpuThreshold(val *float64)
CpuThresholdInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IgnoreMetricsTime() *float64
SetIgnoreMetricsTime(val *float64)
IgnoreMetricsTimeInput() *float64
InstanceCount() *float64
SetInstanceCount(val *float64)
InstanceCountInput() *float64
InternalValue() *OpsworksEcsClusterLayerLoadBasedAutoScalingDownscaling
SetInternalValue(val *OpsworksEcsClusterLayerLoadBasedAutoScalingDownscaling)
LoadThreshold() *float64
SetLoadThreshold(val *float64)
LoadThresholdInput() *float64
MemoryThreshold() *float64
SetMemoryThreshold(val *float64)
MemoryThresholdInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ThresholdsWaitTime() *float64
SetThresholdsWaitTime(val *float64)
ThresholdsWaitTimeInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAlarms()
ResetCpuThreshold()
ResetIgnoreMetricsTime()
ResetInstanceCount()
ResetLoadThreshold()
ResetMemoryThreshold()
ResetThresholdsWaitTime()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksEcsClusterLayerLoadBasedAutoScalingDownscalingOutputReference ¶
func NewOpsworksEcsClusterLayerLoadBasedAutoScalingDownscalingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpsworksEcsClusterLayerLoadBasedAutoScalingDownscalingOutputReference
type OpsworksEcsClusterLayerLoadBasedAutoScalingOutputReference ¶
type OpsworksEcsClusterLayerLoadBasedAutoScalingOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Downscaling() OpsworksEcsClusterLayerLoadBasedAutoScalingDownscalingOutputReference
DownscalingInput() *OpsworksEcsClusterLayerLoadBasedAutoScalingDownscaling
Enable() interface{}
SetEnable(val interface{})
EnableInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *OpsworksEcsClusterLayerLoadBasedAutoScaling
SetInternalValue(val *OpsworksEcsClusterLayerLoadBasedAutoScaling)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Upscaling() OpsworksEcsClusterLayerLoadBasedAutoScalingUpscalingOutputReference
UpscalingInput() *OpsworksEcsClusterLayerLoadBasedAutoScalingUpscaling
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutDownscaling(value *OpsworksEcsClusterLayerLoadBasedAutoScalingDownscaling)
PutUpscaling(value *OpsworksEcsClusterLayerLoadBasedAutoScalingUpscaling)
ResetDownscaling()
ResetEnable()
ResetUpscaling()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksEcsClusterLayerLoadBasedAutoScalingOutputReference ¶
func NewOpsworksEcsClusterLayerLoadBasedAutoScalingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpsworksEcsClusterLayerLoadBasedAutoScalingOutputReference
type OpsworksEcsClusterLayerLoadBasedAutoScalingUpscaling ¶
type OpsworksEcsClusterLayerLoadBasedAutoScalingUpscaling struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#alarms OpsworksEcsClusterLayer#alarms}.
Alarms *[]*string `field:"optional" json:"alarms" yaml:"alarms"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#cpu_threshold OpsworksEcsClusterLayer#cpu_threshold}.
CpuThreshold *float64 `field:"optional" json:"cpuThreshold" yaml:"cpuThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#ignore_metrics_time OpsworksEcsClusterLayer#ignore_metrics_time}.
IgnoreMetricsTime *float64 `field:"optional" json:"ignoreMetricsTime" yaml:"ignoreMetricsTime"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#instance_count OpsworksEcsClusterLayer#instance_count}.
InstanceCount *float64 `field:"optional" json:"instanceCount" yaml:"instanceCount"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#load_threshold OpsworksEcsClusterLayer#load_threshold}.
LoadThreshold *float64 `field:"optional" json:"loadThreshold" yaml:"loadThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#memory_threshold OpsworksEcsClusterLayer#memory_threshold}.
MemoryThreshold *float64 `field:"optional" json:"memoryThreshold" yaml:"memoryThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_ecs_cluster_layer#thresholds_wait_time OpsworksEcsClusterLayer#thresholds_wait_time}.
ThresholdsWaitTime *float64 `field:"optional" json:"thresholdsWaitTime" yaml:"thresholdsWaitTime"`
}
type OpsworksEcsClusterLayerLoadBasedAutoScalingUpscalingOutputReference ¶
type OpsworksEcsClusterLayerLoadBasedAutoScalingUpscalingOutputReference interface {
cdktf.ComplexObject
Alarms() *[]*string
SetAlarms(val *[]*string)
AlarmsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CpuThreshold() *float64
SetCpuThreshold(val *float64)
CpuThresholdInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IgnoreMetricsTime() *float64
SetIgnoreMetricsTime(val *float64)
IgnoreMetricsTimeInput() *float64
InstanceCount() *float64
SetInstanceCount(val *float64)
InstanceCountInput() *float64
InternalValue() *OpsworksEcsClusterLayerLoadBasedAutoScalingUpscaling
SetInternalValue(val *OpsworksEcsClusterLayerLoadBasedAutoScalingUpscaling)
LoadThreshold() *float64
SetLoadThreshold(val *float64)
LoadThresholdInput() *float64
MemoryThreshold() *float64
SetMemoryThreshold(val *float64)
MemoryThresholdInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ThresholdsWaitTime() *float64
SetThresholdsWaitTime(val *float64)
ThresholdsWaitTimeInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAlarms()
ResetCpuThreshold()
ResetIgnoreMetricsTime()
ResetInstanceCount()
ResetLoadThreshold()
ResetMemoryThreshold()
ResetThresholdsWaitTime()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksEcsClusterLayerLoadBasedAutoScalingUpscalingOutputReference ¶
func NewOpsworksEcsClusterLayerLoadBasedAutoScalingUpscalingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpsworksEcsClusterLayerLoadBasedAutoScalingUpscalingOutputReference
Source Files
¶
- opsworksecsclusterlayer.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayer.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerCloudwatchConfiguration.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerCloudwatchConfigurationLogStreams.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsList.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsList__runtime_type_checks.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsOutputReference.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerCloudwatchConfigurationLogStreamsOutputReference__runtime_type_checks.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerCloudwatchConfigurationOutputReference.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerCloudwatchConfigurationOutputReference__runtime_type_checks.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerConfig.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerEbsVolume.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerEbsVolumeList.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerEbsVolumeList__runtime_type_checks.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerEbsVolumeOutputReference.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerEbsVolumeOutputReference__runtime_type_checks.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerLoadBasedAutoScaling.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerLoadBasedAutoScalingDownscaling.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerLoadBasedAutoScalingDownscalingOutputReference.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerLoadBasedAutoScalingDownscalingOutputReference__runtime_type_checks.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerLoadBasedAutoScalingOutputReference.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerLoadBasedAutoScalingOutputReference__runtime_type_checks.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerLoadBasedAutoScalingUpscaling.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerLoadBasedAutoScalingUpscalingOutputReference.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayerLoadBasedAutoScalingUpscalingOutputReference__runtime_type_checks.go
- opsworksecsclusterlayer_OpsworksEcsClusterLayer__runtime_type_checks.go