Documentation
¶
Index ¶
- func NewOrganizationsOrganizationAccountsList_Override(o OrganizationsOrganizationAccountsList, ...)
- func NewOrganizationsOrganizationAccountsOutputReference_Override(o OrganizationsOrganizationAccountsOutputReference, ...)
- func NewOrganizationsOrganizationNonMasterAccountsList_Override(o OrganizationsOrganizationNonMasterAccountsList, ...)
- func NewOrganizationsOrganizationNonMasterAccountsOutputReference_Override(o OrganizationsOrganizationNonMasterAccountsOutputReference, ...)
- func NewOrganizationsOrganizationRootsList_Override(o OrganizationsOrganizationRootsList, ...)
- func NewOrganizationsOrganizationRootsOutputReference_Override(o OrganizationsOrganizationRootsOutputReference, ...)
- func NewOrganizationsOrganizationRootsPolicyTypesList_Override(o OrganizationsOrganizationRootsPolicyTypesList, ...)
- func NewOrganizationsOrganizationRootsPolicyTypesOutputReference_Override(o OrganizationsOrganizationRootsPolicyTypesOutputReference, ...)
- func NewOrganizationsOrganization_Override(o OrganizationsOrganization, scope constructs.Construct, id *string, ...)
- func OrganizationsOrganization_IsConstruct(x interface{}) *bool
- func OrganizationsOrganization_IsTerraformElement(x interface{}) *bool
- func OrganizationsOrganization_IsTerraformResource(x interface{}) *bool
- func OrganizationsOrganization_TfResourceType() *string
- type OrganizationsOrganization
- type OrganizationsOrganizationAccounts
- type OrganizationsOrganizationAccountsList
- type OrganizationsOrganizationAccountsOutputReference
- type OrganizationsOrganizationConfig
- type OrganizationsOrganizationNonMasterAccounts
- type OrganizationsOrganizationNonMasterAccountsList
- type OrganizationsOrganizationNonMasterAccountsOutputReference
- type OrganizationsOrganizationRoots
- type OrganizationsOrganizationRootsList
- type OrganizationsOrganizationRootsOutputReference
- type OrganizationsOrganizationRootsPolicyTypes
- type OrganizationsOrganizationRootsPolicyTypesList
- type OrganizationsOrganizationRootsPolicyTypesOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewOrganizationsOrganizationAccountsList_Override ¶
func NewOrganizationsOrganizationAccountsList_Override(o OrganizationsOrganizationAccountsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewOrganizationsOrganizationAccountsOutputReference_Override ¶
func NewOrganizationsOrganizationAccountsOutputReference_Override(o OrganizationsOrganizationAccountsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewOrganizationsOrganizationNonMasterAccountsList_Override ¶
func NewOrganizationsOrganizationNonMasterAccountsList_Override(o OrganizationsOrganizationNonMasterAccountsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewOrganizationsOrganizationNonMasterAccountsOutputReference_Override ¶
func NewOrganizationsOrganizationNonMasterAccountsOutputReference_Override(o OrganizationsOrganizationNonMasterAccountsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewOrganizationsOrganizationRootsList_Override ¶
func NewOrganizationsOrganizationRootsList_Override(o OrganizationsOrganizationRootsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewOrganizationsOrganizationRootsOutputReference_Override ¶
func NewOrganizationsOrganizationRootsOutputReference_Override(o OrganizationsOrganizationRootsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewOrganizationsOrganizationRootsPolicyTypesList_Override ¶
func NewOrganizationsOrganizationRootsPolicyTypesList_Override(o OrganizationsOrganizationRootsPolicyTypesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewOrganizationsOrganizationRootsPolicyTypesOutputReference_Override ¶
func NewOrganizationsOrganizationRootsPolicyTypesOutputReference_Override(o OrganizationsOrganizationRootsPolicyTypesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewOrganizationsOrganization_Override ¶
func NewOrganizationsOrganization_Override(o OrganizationsOrganization, scope constructs.Construct, id *string, config *OrganizationsOrganizationConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/organizations_organization aws_organizations_organization} Resource.
func OrganizationsOrganization_IsConstruct ¶
func OrganizationsOrganization_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func OrganizationsOrganization_IsTerraformElement ¶
func OrganizationsOrganization_IsTerraformElement(x interface{}) *bool
Experimental.
func OrganizationsOrganization_IsTerraformResource ¶
func OrganizationsOrganization_IsTerraformResource(x interface{}) *bool
Experimental.
func OrganizationsOrganization_TfResourceType ¶
func OrganizationsOrganization_TfResourceType() *string
Types ¶
type OrganizationsOrganization ¶
type OrganizationsOrganization interface {
cdktf.TerraformResource
Accounts() OrganizationsOrganizationAccountsList
Arn() *string
AwsServiceAccessPrincipals() *[]*string
SetAwsServiceAccessPrincipals(val *[]*string)
AwsServiceAccessPrincipalsInput() *[]*string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EnabledPolicyTypes() *[]*string
SetEnabledPolicyTypes(val *[]*string)
EnabledPolicyTypesInput() *[]*string
FeatureSet() *string
SetFeatureSet(val *string)
FeatureSetInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MasterAccountArn() *string
MasterAccountEmail() *string
MasterAccountId() *string
// The tree node.
Node() constructs.Node
NonMasterAccounts() OrganizationsOrganizationNonMasterAccountsList
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Roots() OrganizationsOrganizationRootsList
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetAwsServiceAccessPrincipals()
ResetEnabledPolicyTypes()
ResetFeatureSet()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/organizations_organization aws_organizations_organization}.
func NewOrganizationsOrganization ¶
func NewOrganizationsOrganization(scope constructs.Construct, id *string, config *OrganizationsOrganizationConfig) OrganizationsOrganization
Create a new {@link https://www.terraform.io/docs/providers/aws/r/organizations_organization aws_organizations_organization} Resource.
type OrganizationsOrganizationAccounts ¶
type OrganizationsOrganizationAccounts struct {
}
type OrganizationsOrganizationAccountsList ¶
type OrganizationsOrganizationAccountsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) OrganizationsOrganizationAccountsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOrganizationsOrganizationAccountsList ¶
func NewOrganizationsOrganizationAccountsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) OrganizationsOrganizationAccountsList
type OrganizationsOrganizationAccountsOutputReference ¶
type OrganizationsOrganizationAccountsOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Email() *string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *OrganizationsOrganizationAccounts
SetInternalValue(val *OrganizationsOrganizationAccounts)
Name() *string
Status() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOrganizationsOrganizationAccountsOutputReference ¶
func NewOrganizationsOrganizationAccountsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) OrganizationsOrganizationAccountsOutputReference
type OrganizationsOrganizationConfig ¶
type OrganizationsOrganizationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_organization#aws_service_access_principals OrganizationsOrganization#aws_service_access_principals}.
AwsServiceAccessPrincipals *[]*string `field:"optional" json:"awsServiceAccessPrincipals" yaml:"awsServiceAccessPrincipals"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_organization#enabled_policy_types OrganizationsOrganization#enabled_policy_types}.
EnabledPolicyTypes *[]*string `field:"optional" json:"enabledPolicyTypes" yaml:"enabledPolicyTypes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_organization#feature_set OrganizationsOrganization#feature_set}.
FeatureSet *string `field:"optional" json:"featureSet" yaml:"featureSet"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_organization#id OrganizationsOrganization#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type OrganizationsOrganizationNonMasterAccounts ¶
type OrganizationsOrganizationNonMasterAccounts struct {
}
type OrganizationsOrganizationNonMasterAccountsList ¶
type OrganizationsOrganizationNonMasterAccountsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) OrganizationsOrganizationNonMasterAccountsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOrganizationsOrganizationNonMasterAccountsList ¶
func NewOrganizationsOrganizationNonMasterAccountsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) OrganizationsOrganizationNonMasterAccountsList
type OrganizationsOrganizationNonMasterAccountsOutputReference ¶
type OrganizationsOrganizationNonMasterAccountsOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Email() *string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *OrganizationsOrganizationNonMasterAccounts
SetInternalValue(val *OrganizationsOrganizationNonMasterAccounts)
Name() *string
Status() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOrganizationsOrganizationNonMasterAccountsOutputReference ¶
func NewOrganizationsOrganizationNonMasterAccountsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) OrganizationsOrganizationNonMasterAccountsOutputReference
type OrganizationsOrganizationRoots ¶
type OrganizationsOrganizationRoots struct {
}
type OrganizationsOrganizationRootsList ¶
type OrganizationsOrganizationRootsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) OrganizationsOrganizationRootsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOrganizationsOrganizationRootsList ¶
func NewOrganizationsOrganizationRootsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) OrganizationsOrganizationRootsList
type OrganizationsOrganizationRootsOutputReference ¶
type OrganizationsOrganizationRootsOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *OrganizationsOrganizationRoots
SetInternalValue(val *OrganizationsOrganizationRoots)
Name() *string
PolicyTypes() OrganizationsOrganizationRootsPolicyTypesList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOrganizationsOrganizationRootsOutputReference ¶
func NewOrganizationsOrganizationRootsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) OrganizationsOrganizationRootsOutputReference
type OrganizationsOrganizationRootsPolicyTypes ¶
type OrganizationsOrganizationRootsPolicyTypes struct {
}
type OrganizationsOrganizationRootsPolicyTypesList ¶
type OrganizationsOrganizationRootsPolicyTypesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) OrganizationsOrganizationRootsPolicyTypesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOrganizationsOrganizationRootsPolicyTypesList ¶
func NewOrganizationsOrganizationRootsPolicyTypesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) OrganizationsOrganizationRootsPolicyTypesList
type OrganizationsOrganizationRootsPolicyTypesOutputReference ¶
type OrganizationsOrganizationRootsPolicyTypesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *OrganizationsOrganizationRootsPolicyTypes
SetInternalValue(val *OrganizationsOrganizationRootsPolicyTypes)
Status() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOrganizationsOrganizationRootsPolicyTypesOutputReference ¶
func NewOrganizationsOrganizationRootsPolicyTypesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) OrganizationsOrganizationRootsPolicyTypesOutputReference
Source Files
¶
- organizationsorganization.go
- organizationsorganization_OrganizationsOrganization.go
- organizationsorganization_OrganizationsOrganizationAccounts.go
- organizationsorganization_OrganizationsOrganizationAccountsList.go
- organizationsorganization_OrganizationsOrganizationAccountsList__runtime_type_checks.go
- organizationsorganization_OrganizationsOrganizationAccountsOutputReference.go
- organizationsorganization_OrganizationsOrganizationAccountsOutputReference__runtime_type_checks.go
- organizationsorganization_OrganizationsOrganizationConfig.go
- organizationsorganization_OrganizationsOrganizationNonMasterAccounts.go
- organizationsorganization_OrganizationsOrganizationNonMasterAccountsList.go
- organizationsorganization_OrganizationsOrganizationNonMasterAccountsList__runtime_type_checks.go
- organizationsorganization_OrganizationsOrganizationNonMasterAccountsOutputReference.go
- organizationsorganization_OrganizationsOrganizationNonMasterAccountsOutputReference__runtime_type_checks.go
- organizationsorganization_OrganizationsOrganizationRoots.go
- organizationsorganization_OrganizationsOrganizationRootsList.go
- organizationsorganization_OrganizationsOrganizationRootsList__runtime_type_checks.go
- organizationsorganization_OrganizationsOrganizationRootsOutputReference.go
- organizationsorganization_OrganizationsOrganizationRootsOutputReference__runtime_type_checks.go
- organizationsorganization_OrganizationsOrganizationRootsPolicyTypes.go
- organizationsorganization_OrganizationsOrganizationRootsPolicyTypesList.go
- organizationsorganization_OrganizationsOrganizationRootsPolicyTypesList__runtime_type_checks.go
- organizationsorganization_OrganizationsOrganizationRootsPolicyTypesOutputReference.go
- organizationsorganization_OrganizationsOrganizationRootsPolicyTypesOutputReference__runtime_type_checks.go
- organizationsorganization_OrganizationsOrganization__runtime_type_checks.go