Documentation
¶
Index ¶
- func NewRdsClusterRestoreToPointInTimeOutputReference_Override(r RdsClusterRestoreToPointInTimeOutputReference, ...)
- func NewRdsClusterS3ImportOutputReference_Override(r RdsClusterS3ImportOutputReference, ...)
- func NewRdsClusterScalingConfigurationOutputReference_Override(r RdsClusterScalingConfigurationOutputReference, ...)
- func NewRdsClusterServerlessv2ScalingConfigurationOutputReference_Override(r RdsClusterServerlessv2ScalingConfigurationOutputReference, ...)
- func NewRdsClusterTimeoutsOutputReference_Override(r RdsClusterTimeoutsOutputReference, ...)
- func NewRdsCluster_Override(r RdsCluster, scope constructs.Construct, id *string, config *RdsClusterConfig)
- func RdsCluster_IsConstruct(x interface{}) *bool
- func RdsCluster_IsTerraformElement(x interface{}) *bool
- func RdsCluster_IsTerraformResource(x interface{}) *bool
- func RdsCluster_TfResourceType() *string
- type RdsCluster
- type RdsClusterConfig
- type RdsClusterRestoreToPointInTime
- type RdsClusterRestoreToPointInTimeOutputReference
- type RdsClusterS3Import
- type RdsClusterS3ImportOutputReference
- type RdsClusterScalingConfiguration
- type RdsClusterScalingConfigurationOutputReference
- type RdsClusterServerlessv2ScalingConfiguration
- type RdsClusterServerlessv2ScalingConfigurationOutputReference
- type RdsClusterTimeouts
- type RdsClusterTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRdsClusterRestoreToPointInTimeOutputReference_Override ¶
func NewRdsClusterRestoreToPointInTimeOutputReference_Override(r RdsClusterRestoreToPointInTimeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewRdsClusterS3ImportOutputReference_Override ¶
func NewRdsClusterS3ImportOutputReference_Override(r RdsClusterS3ImportOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewRdsClusterScalingConfigurationOutputReference_Override ¶
func NewRdsClusterScalingConfigurationOutputReference_Override(r RdsClusterScalingConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewRdsClusterServerlessv2ScalingConfigurationOutputReference_Override ¶
func NewRdsClusterServerlessv2ScalingConfigurationOutputReference_Override(r RdsClusterServerlessv2ScalingConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewRdsClusterTimeoutsOutputReference_Override ¶
func NewRdsClusterTimeoutsOutputReference_Override(r RdsClusterTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewRdsCluster_Override ¶
func NewRdsCluster_Override(r RdsCluster, scope constructs.Construct, id *string, config *RdsClusterConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster aws_rds_cluster} Resource.
func RdsCluster_IsConstruct ¶
func RdsCluster_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func RdsCluster_IsTerraformElement ¶
func RdsCluster_IsTerraformElement(x interface{}) *bool
Experimental.
func RdsCluster_IsTerraformResource ¶
func RdsCluster_IsTerraformResource(x interface{}) *bool
Experimental.
func RdsCluster_TfResourceType ¶
func RdsCluster_TfResourceType() *string
Types ¶
type RdsCluster ¶
type RdsCluster interface {
cdktf.TerraformResource
AllocatedStorage() *float64
SetAllocatedStorage(val *float64)
AllocatedStorageInput() *float64
AllowMajorVersionUpgrade() interface{}
SetAllowMajorVersionUpgrade(val interface{})
AllowMajorVersionUpgradeInput() interface{}
ApplyImmediately() interface{}
SetApplyImmediately(val interface{})
ApplyImmediatelyInput() interface{}
Arn() *string
AvailabilityZones() *[]*string
SetAvailabilityZones(val *[]*string)
AvailabilityZonesInput() *[]*string
BacktrackWindow() *float64
SetBacktrackWindow(val *float64)
BacktrackWindowInput() *float64
BackupRetentionPeriod() *float64
SetBackupRetentionPeriod(val *float64)
BackupRetentionPeriodInput() *float64
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterIdentifier() *string
SetClusterIdentifier(val *string)
ClusterIdentifierInput() *string
ClusterIdentifierPrefix() *string
SetClusterIdentifierPrefix(val *string)
ClusterIdentifierPrefixInput() *string
ClusterMembers() *[]*string
SetClusterMembers(val *[]*string)
ClusterMembersInput() *[]*string
ClusterResourceId() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
CopyTagsToSnapshot() interface{}
SetCopyTagsToSnapshot(val interface{})
CopyTagsToSnapshotInput() interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DatabaseName() *string
SetDatabaseName(val *string)
DatabaseNameInput() *string
DbClusterInstanceClass() *string
SetDbClusterInstanceClass(val *string)
DbClusterInstanceClassInput() *string
DbClusterParameterGroupName() *string
SetDbClusterParameterGroupName(val *string)
DbClusterParameterGroupNameInput() *string
DbInstanceParameterGroupName() *string
SetDbInstanceParameterGroupName(val *string)
DbInstanceParameterGroupNameInput() *string
DbSubnetGroupName() *string
SetDbSubnetGroupName(val *string)
DbSubnetGroupNameInput() *string
DeletionProtection() interface{}
SetDeletionProtection(val interface{})
DeletionProtectionInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EnabledCloudwatchLogsExports() *[]*string
SetEnabledCloudwatchLogsExports(val *[]*string)
EnabledCloudwatchLogsExportsInput() *[]*string
EnableGlobalWriteForwarding() interface{}
SetEnableGlobalWriteForwarding(val interface{})
EnableGlobalWriteForwardingInput() interface{}
EnableHttpEndpoint() interface{}
SetEnableHttpEndpoint(val interface{})
EnableHttpEndpointInput() interface{}
Endpoint() *string
Engine() *string
SetEngine(val *string)
EngineInput() *string
EngineMode() *string
SetEngineMode(val *string)
EngineModeInput() *string
EngineVersion() *string
SetEngineVersion(val *string)
EngineVersionActual() *string
EngineVersionInput() *string
FinalSnapshotIdentifier() *string
SetFinalSnapshotIdentifier(val *string)
FinalSnapshotIdentifierInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GlobalClusterIdentifier() *string
SetGlobalClusterIdentifier(val *string)
GlobalClusterIdentifierInput() *string
HostedZoneId() *string
IamDatabaseAuthenticationEnabled() interface{}
SetIamDatabaseAuthenticationEnabled(val interface{})
IamDatabaseAuthenticationEnabledInput() interface{}
IamRoles() *[]*string
SetIamRoles(val *[]*string)
IamRolesInput() *[]*string
Id() *string
SetId(val *string)
IdInput() *string
Iops() *float64
SetIops(val *float64)
IopsInput() *float64
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MasterPassword() *string
SetMasterPassword(val *string)
MasterPasswordInput() *string
MasterUsername() *string
SetMasterUsername(val *string)
MasterUsernameInput() *string
NetworkType() *string
SetNetworkType(val *string)
NetworkTypeInput() *string
// The tree node.
Node() constructs.Node
Port() *float64
SetPort(val *float64)
PortInput() *float64
PreferredBackupWindow() *string
SetPreferredBackupWindow(val *string)
PreferredBackupWindowInput() *string
PreferredMaintenanceWindow() *string
SetPreferredMaintenanceWindow(val *string)
PreferredMaintenanceWindowInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ReaderEndpoint() *string
ReplicationSourceIdentifier() *string
SetReplicationSourceIdentifier(val *string)
ReplicationSourceIdentifierInput() *string
RestoreToPointInTime() RdsClusterRestoreToPointInTimeOutputReference
RestoreToPointInTimeInput() *RdsClusterRestoreToPointInTime
S3Import() RdsClusterS3ImportOutputReference
S3ImportInput() *RdsClusterS3Import
ScalingConfiguration() RdsClusterScalingConfigurationOutputReference
ScalingConfigurationInput() *RdsClusterScalingConfiguration
Serverlessv2ScalingConfiguration() RdsClusterServerlessv2ScalingConfigurationOutputReference
Serverlessv2ScalingConfigurationInput() *RdsClusterServerlessv2ScalingConfiguration
SkipFinalSnapshot() interface{}
SetSkipFinalSnapshot(val interface{})
SkipFinalSnapshotInput() interface{}
SnapshotIdentifier() *string
SetSnapshotIdentifier(val *string)
SnapshotIdentifierInput() *string
SourceRegion() *string
SetSourceRegion(val *string)
SourceRegionInput() *string
StorageEncrypted() interface{}
SetStorageEncrypted(val interface{})
StorageEncryptedInput() interface{}
StorageType() *string
SetStorageType(val *string)
StorageTypeInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() RdsClusterTimeoutsOutputReference
TimeoutsInput() interface{}
VpcSecurityGroupIds() *[]*string
SetVpcSecurityGroupIds(val *[]*string)
VpcSecurityGroupIdsInput() *[]*string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutRestoreToPointInTime(value *RdsClusterRestoreToPointInTime)
PutS3Import(value *RdsClusterS3Import)
PutScalingConfiguration(value *RdsClusterScalingConfiguration)
PutServerlessv2ScalingConfiguration(value *RdsClusterServerlessv2ScalingConfiguration)
PutTimeouts(value *RdsClusterTimeouts)
ResetAllocatedStorage()
ResetAllowMajorVersionUpgrade()
ResetApplyImmediately()
ResetAvailabilityZones()
ResetBacktrackWindow()
ResetBackupRetentionPeriod()
ResetClusterIdentifier()
ResetClusterIdentifierPrefix()
ResetClusterMembers()
ResetCopyTagsToSnapshot()
ResetDatabaseName()
ResetDbClusterInstanceClass()
ResetDbClusterParameterGroupName()
ResetDbInstanceParameterGroupName()
ResetDbSubnetGroupName()
ResetDeletionProtection()
ResetEnabledCloudwatchLogsExports()
ResetEnableGlobalWriteForwarding()
ResetEnableHttpEndpoint()
ResetEngine()
ResetEngineMode()
ResetEngineVersion()
ResetFinalSnapshotIdentifier()
ResetGlobalClusterIdentifier()
ResetIamDatabaseAuthenticationEnabled()
ResetIamRoles()
ResetId()
ResetIops()
ResetKmsKeyId()
ResetMasterPassword()
ResetMasterUsername()
ResetNetworkType()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPort()
ResetPreferredBackupWindow()
ResetPreferredMaintenanceWindow()
ResetReplicationSourceIdentifier()
ResetRestoreToPointInTime()
ResetS3Import()
ResetScalingConfiguration()
ResetServerlessv2ScalingConfiguration()
ResetSkipFinalSnapshot()
ResetSnapshotIdentifier()
ResetSourceRegion()
ResetStorageEncrypted()
ResetStorageType()
ResetTags()
ResetTagsAll()
ResetTimeouts()
ResetVpcSecurityGroupIds()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster aws_rds_cluster}.
func NewRdsCluster ¶
func NewRdsCluster(scope constructs.Construct, id *string, config *RdsClusterConfig) RdsCluster
Create a new {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster aws_rds_cluster} Resource.
type RdsClusterConfig ¶
type RdsClusterConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#allocated_storage RdsCluster#allocated_storage}.
AllocatedStorage *float64 `field:"optional" json:"allocatedStorage" yaml:"allocatedStorage"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#allow_major_version_upgrade RdsCluster#allow_major_version_upgrade}.
AllowMajorVersionUpgrade interface{} `field:"optional" json:"allowMajorVersionUpgrade" yaml:"allowMajorVersionUpgrade"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#apply_immediately RdsCluster#apply_immediately}.
ApplyImmediately interface{} `field:"optional" json:"applyImmediately" yaml:"applyImmediately"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#availability_zones RdsCluster#availability_zones}.
AvailabilityZones *[]*string `field:"optional" json:"availabilityZones" yaml:"availabilityZones"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#backtrack_window RdsCluster#backtrack_window}.
BacktrackWindow *float64 `field:"optional" json:"backtrackWindow" yaml:"backtrackWindow"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#backup_retention_period RdsCluster#backup_retention_period}.
BackupRetentionPeriod *float64 `field:"optional" json:"backupRetentionPeriod" yaml:"backupRetentionPeriod"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#cluster_identifier RdsCluster#cluster_identifier}.
ClusterIdentifier *string `field:"optional" json:"clusterIdentifier" yaml:"clusterIdentifier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#cluster_identifier_prefix RdsCluster#cluster_identifier_prefix}.
ClusterIdentifierPrefix *string `field:"optional" json:"clusterIdentifierPrefix" yaml:"clusterIdentifierPrefix"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#cluster_members RdsCluster#cluster_members}.
ClusterMembers *[]*string `field:"optional" json:"clusterMembers" yaml:"clusterMembers"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#copy_tags_to_snapshot RdsCluster#copy_tags_to_snapshot}.
CopyTagsToSnapshot interface{} `field:"optional" json:"copyTagsToSnapshot" yaml:"copyTagsToSnapshot"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#database_name RdsCluster#database_name}.
DatabaseName *string `field:"optional" json:"databaseName" yaml:"databaseName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#db_cluster_instance_class RdsCluster#db_cluster_instance_class}.
DbClusterInstanceClass *string `field:"optional" json:"dbClusterInstanceClass" yaml:"dbClusterInstanceClass"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#db_cluster_parameter_group_name RdsCluster#db_cluster_parameter_group_name}.
DbClusterParameterGroupName *string `field:"optional" json:"dbClusterParameterGroupName" yaml:"dbClusterParameterGroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#db_instance_parameter_group_name RdsCluster#db_instance_parameter_group_name}.
DbInstanceParameterGroupName *string `field:"optional" json:"dbInstanceParameterGroupName" yaml:"dbInstanceParameterGroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#db_subnet_group_name RdsCluster#db_subnet_group_name}.
DbSubnetGroupName *string `field:"optional" json:"dbSubnetGroupName" yaml:"dbSubnetGroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#deletion_protection RdsCluster#deletion_protection}.
DeletionProtection interface{} `field:"optional" json:"deletionProtection" yaml:"deletionProtection"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#enabled_cloudwatch_logs_exports RdsCluster#enabled_cloudwatch_logs_exports}.
EnabledCloudwatchLogsExports *[]*string `field:"optional" json:"enabledCloudwatchLogsExports" yaml:"enabledCloudwatchLogsExports"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#enable_global_write_forwarding RdsCluster#enable_global_write_forwarding}.
EnableGlobalWriteForwarding interface{} `field:"optional" json:"enableGlobalWriteForwarding" yaml:"enableGlobalWriteForwarding"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#enable_http_endpoint RdsCluster#enable_http_endpoint}.
EnableHttpEndpoint interface{} `field:"optional" json:"enableHttpEndpoint" yaml:"enableHttpEndpoint"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#engine RdsCluster#engine}.
Engine *string `field:"optional" json:"engine" yaml:"engine"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#engine_mode RdsCluster#engine_mode}.
EngineMode *string `field:"optional" json:"engineMode" yaml:"engineMode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#engine_version RdsCluster#engine_version}.
EngineVersion *string `field:"optional" json:"engineVersion" yaml:"engineVersion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#final_snapshot_identifier RdsCluster#final_snapshot_identifier}.
FinalSnapshotIdentifier *string `field:"optional" json:"finalSnapshotIdentifier" yaml:"finalSnapshotIdentifier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#global_cluster_identifier RdsCluster#global_cluster_identifier}.
GlobalClusterIdentifier *string `field:"optional" json:"globalClusterIdentifier" yaml:"globalClusterIdentifier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#iam_database_authentication_enabled RdsCluster#iam_database_authentication_enabled}.
IamDatabaseAuthenticationEnabled interface{} `field:"optional" json:"iamDatabaseAuthenticationEnabled" yaml:"iamDatabaseAuthenticationEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#iam_roles RdsCluster#iam_roles}.
IamRoles *[]*string `field:"optional" json:"iamRoles" yaml:"iamRoles"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#id RdsCluster#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#iops RdsCluster#iops}.
Iops *float64 `field:"optional" json:"iops" yaml:"iops"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#kms_key_id RdsCluster#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#master_password RdsCluster#master_password}.
MasterPassword *string `field:"optional" json:"masterPassword" yaml:"masterPassword"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#master_username RdsCluster#master_username}.
MasterUsername *string `field:"optional" json:"masterUsername" yaml:"masterUsername"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#network_type RdsCluster#network_type}.
NetworkType *string `field:"optional" json:"networkType" yaml:"networkType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#port RdsCluster#port}.
Port *float64 `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#preferred_backup_window RdsCluster#preferred_backup_window}.
PreferredBackupWindow *string `field:"optional" json:"preferredBackupWindow" yaml:"preferredBackupWindow"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#preferred_maintenance_window RdsCluster#preferred_maintenance_window}.
PreferredMaintenanceWindow *string `field:"optional" json:"preferredMaintenanceWindow" yaml:"preferredMaintenanceWindow"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#replication_source_identifier RdsCluster#replication_source_identifier}.
ReplicationSourceIdentifier *string `field:"optional" json:"replicationSourceIdentifier" yaml:"replicationSourceIdentifier"`
// restore_to_point_in_time block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#restore_to_point_in_time RdsCluster#restore_to_point_in_time}
RestoreToPointInTime *RdsClusterRestoreToPointInTime `field:"optional" json:"restoreToPointInTime" yaml:"restoreToPointInTime"`
// s3_import block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#s3_import RdsCluster#s3_import}
S3Import *RdsClusterS3Import `field:"optional" json:"s3Import" yaml:"s3Import"`
// scaling_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#scaling_configuration RdsCluster#scaling_configuration}
ScalingConfiguration *RdsClusterScalingConfiguration `field:"optional" json:"scalingConfiguration" yaml:"scalingConfiguration"`
// serverlessv2_scaling_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#serverlessv2_scaling_configuration RdsCluster#serverlessv2_scaling_configuration}
Serverlessv2ScalingConfiguration *RdsClusterServerlessv2ScalingConfiguration `field:"optional" json:"serverlessv2ScalingConfiguration" yaml:"serverlessv2ScalingConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#skip_final_snapshot RdsCluster#skip_final_snapshot}.
SkipFinalSnapshot interface{} `field:"optional" json:"skipFinalSnapshot" yaml:"skipFinalSnapshot"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#snapshot_identifier RdsCluster#snapshot_identifier}.
SnapshotIdentifier *string `field:"optional" json:"snapshotIdentifier" yaml:"snapshotIdentifier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#source_region RdsCluster#source_region}.
SourceRegion *string `field:"optional" json:"sourceRegion" yaml:"sourceRegion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#storage_encrypted RdsCluster#storage_encrypted}.
StorageEncrypted interface{} `field:"optional" json:"storageEncrypted" yaml:"storageEncrypted"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#storage_type RdsCluster#storage_type}.
StorageType *string `field:"optional" json:"storageType" yaml:"storageType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#tags RdsCluster#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#tags_all RdsCluster#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#timeouts RdsCluster#timeouts}
Timeouts *RdsClusterTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#vpc_security_group_ids RdsCluster#vpc_security_group_ids}.
VpcSecurityGroupIds *[]*string `field:"optional" json:"vpcSecurityGroupIds" yaml:"vpcSecurityGroupIds"`
}
type RdsClusterRestoreToPointInTime ¶
type RdsClusterRestoreToPointInTime struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#source_cluster_identifier RdsCluster#source_cluster_identifier}.
SourceClusterIdentifier *string `field:"required" json:"sourceClusterIdentifier" yaml:"sourceClusterIdentifier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#restore_to_time RdsCluster#restore_to_time}.
RestoreToTime *string `field:"optional" json:"restoreToTime" yaml:"restoreToTime"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#restore_type RdsCluster#restore_type}.
RestoreType *string `field:"optional" json:"restoreType" yaml:"restoreType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#use_latest_restorable_time RdsCluster#use_latest_restorable_time}.
UseLatestRestorableTime interface{} `field:"optional" json:"useLatestRestorableTime" yaml:"useLatestRestorableTime"`
}
type RdsClusterRestoreToPointInTimeOutputReference ¶
type RdsClusterRestoreToPointInTimeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *RdsClusterRestoreToPointInTime
SetInternalValue(val *RdsClusterRestoreToPointInTime)
RestoreToTime() *string
SetRestoreToTime(val *string)
RestoreToTimeInput() *string
RestoreType() *string
SetRestoreType(val *string)
RestoreTypeInput() *string
SourceClusterIdentifier() *string
SetSourceClusterIdentifier(val *string)
SourceClusterIdentifierInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UseLatestRestorableTime() interface{}
SetUseLatestRestorableTime(val interface{})
UseLatestRestorableTimeInput() interface{}
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetRestoreToTime()
ResetRestoreType()
ResetUseLatestRestorableTime()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRdsClusterRestoreToPointInTimeOutputReference ¶
func NewRdsClusterRestoreToPointInTimeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) RdsClusterRestoreToPointInTimeOutputReference
type RdsClusterS3Import ¶
type RdsClusterS3Import struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#bucket_name RdsCluster#bucket_name}.
BucketName *string `field:"required" json:"bucketName" yaml:"bucketName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#ingestion_role RdsCluster#ingestion_role}.
IngestionRole *string `field:"required" json:"ingestionRole" yaml:"ingestionRole"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#source_engine RdsCluster#source_engine}.
SourceEngine *string `field:"required" json:"sourceEngine" yaml:"sourceEngine"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#source_engine_version RdsCluster#source_engine_version}.
SourceEngineVersion *string `field:"required" json:"sourceEngineVersion" yaml:"sourceEngineVersion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#bucket_prefix RdsCluster#bucket_prefix}.
BucketPrefix *string `field:"optional" json:"bucketPrefix" yaml:"bucketPrefix"`
}
type RdsClusterS3ImportOutputReference ¶
type RdsClusterS3ImportOutputReference interface {
cdktf.ComplexObject
BucketName() *string
SetBucketName(val *string)
BucketNameInput() *string
BucketPrefix() *string
SetBucketPrefix(val *string)
BucketPrefixInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IngestionRole() *string
SetIngestionRole(val *string)
IngestionRoleInput() *string
InternalValue() *RdsClusterS3Import
SetInternalValue(val *RdsClusterS3Import)
SourceEngine() *string
SetSourceEngine(val *string)
SourceEngineInput() *string
SourceEngineVersion() *string
SetSourceEngineVersion(val *string)
SourceEngineVersionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBucketPrefix()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRdsClusterS3ImportOutputReference ¶
func NewRdsClusterS3ImportOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) RdsClusterS3ImportOutputReference
type RdsClusterScalingConfiguration ¶
type RdsClusterScalingConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#auto_pause RdsCluster#auto_pause}.
AutoPause interface{} `field:"optional" json:"autoPause" yaml:"autoPause"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#max_capacity RdsCluster#max_capacity}.
MaxCapacity *float64 `field:"optional" json:"maxCapacity" yaml:"maxCapacity"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#min_capacity RdsCluster#min_capacity}.
MinCapacity *float64 `field:"optional" json:"minCapacity" yaml:"minCapacity"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#seconds_until_auto_pause RdsCluster#seconds_until_auto_pause}.
SecondsUntilAutoPause *float64 `field:"optional" json:"secondsUntilAutoPause" yaml:"secondsUntilAutoPause"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#timeout_action RdsCluster#timeout_action}.
TimeoutAction *string `field:"optional" json:"timeoutAction" yaml:"timeoutAction"`
}
type RdsClusterScalingConfigurationOutputReference ¶
type RdsClusterScalingConfigurationOutputReference interface {
cdktf.ComplexObject
AutoPause() interface{}
SetAutoPause(val interface{})
AutoPauseInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *RdsClusterScalingConfiguration
SetInternalValue(val *RdsClusterScalingConfiguration)
MaxCapacity() *float64
SetMaxCapacity(val *float64)
MaxCapacityInput() *float64
MinCapacity() *float64
SetMinCapacity(val *float64)
MinCapacityInput() *float64
SecondsUntilAutoPause() *float64
SetSecondsUntilAutoPause(val *float64)
SecondsUntilAutoPauseInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TimeoutAction() *string
SetTimeoutAction(val *string)
TimeoutActionInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAutoPause()
ResetMaxCapacity()
ResetMinCapacity()
ResetSecondsUntilAutoPause()
ResetTimeoutAction()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRdsClusterScalingConfigurationOutputReference ¶
func NewRdsClusterScalingConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) RdsClusterScalingConfigurationOutputReference
type RdsClusterServerlessv2ScalingConfiguration ¶
type RdsClusterServerlessv2ScalingConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#max_capacity RdsCluster#max_capacity}.
MaxCapacity *float64 `field:"required" json:"maxCapacity" yaml:"maxCapacity"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#min_capacity RdsCluster#min_capacity}.
MinCapacity *float64 `field:"required" json:"minCapacity" yaml:"minCapacity"`
}
type RdsClusterServerlessv2ScalingConfigurationOutputReference ¶
type RdsClusterServerlessv2ScalingConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *RdsClusterServerlessv2ScalingConfiguration
SetInternalValue(val *RdsClusterServerlessv2ScalingConfiguration)
MaxCapacity() *float64
SetMaxCapacity(val *float64)
MaxCapacityInput() *float64
MinCapacity() *float64
SetMinCapacity(val *float64)
MinCapacityInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRdsClusterServerlessv2ScalingConfigurationOutputReference ¶
func NewRdsClusterServerlessv2ScalingConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) RdsClusterServerlessv2ScalingConfigurationOutputReference
type RdsClusterTimeouts ¶
type RdsClusterTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#create RdsCluster#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#delete RdsCluster#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster#update RdsCluster#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type RdsClusterTimeoutsOutputReference ¶
type RdsClusterTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRdsClusterTimeoutsOutputReference ¶
func NewRdsClusterTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) RdsClusterTimeoutsOutputReference
Source Files
¶
- rdscluster.go
- rdscluster_RdsCluster.go
- rdscluster_RdsClusterConfig.go
- rdscluster_RdsClusterRestoreToPointInTime.go
- rdscluster_RdsClusterRestoreToPointInTimeOutputReference.go
- rdscluster_RdsClusterRestoreToPointInTimeOutputReference__runtime_type_checks.go
- rdscluster_RdsClusterS3Import.go
- rdscluster_RdsClusterS3ImportOutputReference.go
- rdscluster_RdsClusterS3ImportOutputReference__runtime_type_checks.go
- rdscluster_RdsClusterScalingConfiguration.go
- rdscluster_RdsClusterScalingConfigurationOutputReference.go
- rdscluster_RdsClusterScalingConfigurationOutputReference__runtime_type_checks.go
- rdscluster_RdsClusterServerlessv2ScalingConfiguration.go
- rdscluster_RdsClusterServerlessv2ScalingConfigurationOutputReference.go
- rdscluster_RdsClusterServerlessv2ScalingConfigurationOutputReference__runtime_type_checks.go
- rdscluster_RdsClusterTimeouts.go
- rdscluster_RdsClusterTimeoutsOutputReference.go
- rdscluster_RdsClusterTimeoutsOutputReference__runtime_type_checks.go
- rdscluster_RdsCluster__runtime_type_checks.go