Documentation
¶
Index ¶
- func NewS3BucketWebsiteConfigurationErrorDocumentOutputReference_Override(s S3BucketWebsiteConfigurationErrorDocumentOutputReference, ...)
- func NewS3BucketWebsiteConfigurationIndexDocumentOutputReference_Override(s S3BucketWebsiteConfigurationIndexDocumentOutputReference, ...)
- func NewS3BucketWebsiteConfigurationRedirectAllRequestsToOutputReference_Override(s S3BucketWebsiteConfigurationRedirectAllRequestsToOutputReference, ...)
- func NewS3BucketWebsiteConfigurationRoutingRuleConditionOutputReference_Override(s S3BucketWebsiteConfigurationRoutingRuleConditionOutputReference, ...)
- func NewS3BucketWebsiteConfigurationRoutingRuleList_Override(s S3BucketWebsiteConfigurationRoutingRuleList, ...)
- func NewS3BucketWebsiteConfigurationRoutingRuleOutputReference_Override(s S3BucketWebsiteConfigurationRoutingRuleOutputReference, ...)
- func NewS3BucketWebsiteConfigurationRoutingRuleRedirectOutputReference_Override(s S3BucketWebsiteConfigurationRoutingRuleRedirectOutputReference, ...)
- func NewS3BucketWebsiteConfiguration_Override(s S3BucketWebsiteConfiguration, scope constructs.Construct, id *string, ...)
- func S3BucketWebsiteConfiguration_IsConstruct(x interface{}) *bool
- func S3BucketWebsiteConfiguration_IsTerraformElement(x interface{}) *bool
- func S3BucketWebsiteConfiguration_IsTerraformResource(x interface{}) *bool
- func S3BucketWebsiteConfiguration_TfResourceType() *string
- type S3BucketWebsiteConfiguration
- type S3BucketWebsiteConfigurationConfig
- type S3BucketWebsiteConfigurationErrorDocument
- type S3BucketWebsiteConfigurationErrorDocumentOutputReference
- type S3BucketWebsiteConfigurationIndexDocument
- type S3BucketWebsiteConfigurationIndexDocumentOutputReference
- type S3BucketWebsiteConfigurationRedirectAllRequestsTo
- type S3BucketWebsiteConfigurationRedirectAllRequestsToOutputReference
- type S3BucketWebsiteConfigurationRoutingRule
- type S3BucketWebsiteConfigurationRoutingRuleCondition
- type S3BucketWebsiteConfigurationRoutingRuleConditionOutputReference
- type S3BucketWebsiteConfigurationRoutingRuleList
- type S3BucketWebsiteConfigurationRoutingRuleOutputReference
- type S3BucketWebsiteConfigurationRoutingRuleRedirect
- type S3BucketWebsiteConfigurationRoutingRuleRedirectOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewS3BucketWebsiteConfigurationErrorDocumentOutputReference_Override ¶
func NewS3BucketWebsiteConfigurationErrorDocumentOutputReference_Override(s S3BucketWebsiteConfigurationErrorDocumentOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketWebsiteConfigurationIndexDocumentOutputReference_Override ¶
func NewS3BucketWebsiteConfigurationIndexDocumentOutputReference_Override(s S3BucketWebsiteConfigurationIndexDocumentOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketWebsiteConfigurationRedirectAllRequestsToOutputReference_Override ¶
func NewS3BucketWebsiteConfigurationRedirectAllRequestsToOutputReference_Override(s S3BucketWebsiteConfigurationRedirectAllRequestsToOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketWebsiteConfigurationRoutingRuleConditionOutputReference_Override ¶
func NewS3BucketWebsiteConfigurationRoutingRuleConditionOutputReference_Override(s S3BucketWebsiteConfigurationRoutingRuleConditionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketWebsiteConfigurationRoutingRuleList_Override ¶
func NewS3BucketWebsiteConfigurationRoutingRuleList_Override(s S3BucketWebsiteConfigurationRoutingRuleList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewS3BucketWebsiteConfigurationRoutingRuleOutputReference_Override ¶
func NewS3BucketWebsiteConfigurationRoutingRuleOutputReference_Override(s S3BucketWebsiteConfigurationRoutingRuleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewS3BucketWebsiteConfigurationRoutingRuleRedirectOutputReference_Override ¶
func NewS3BucketWebsiteConfigurationRoutingRuleRedirectOutputReference_Override(s S3BucketWebsiteConfigurationRoutingRuleRedirectOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketWebsiteConfiguration_Override ¶
func NewS3BucketWebsiteConfiguration_Override(s S3BucketWebsiteConfiguration, scope constructs.Construct, id *string, config *S3BucketWebsiteConfigurationConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration aws_s3_bucket_website_configuration} Resource.
func S3BucketWebsiteConfiguration_IsConstruct ¶
func S3BucketWebsiteConfiguration_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func S3BucketWebsiteConfiguration_IsTerraformElement ¶
func S3BucketWebsiteConfiguration_IsTerraformElement(x interface{}) *bool
Experimental.
func S3BucketWebsiteConfiguration_IsTerraformResource ¶
func S3BucketWebsiteConfiguration_IsTerraformResource(x interface{}) *bool
Experimental.
func S3BucketWebsiteConfiguration_TfResourceType ¶
func S3BucketWebsiteConfiguration_TfResourceType() *string
Types ¶
type S3BucketWebsiteConfiguration ¶
type S3BucketWebsiteConfiguration interface {
cdktf.TerraformResource
Bucket() *string
SetBucket(val *string)
BucketInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
ErrorDocument() S3BucketWebsiteConfigurationErrorDocumentOutputReference
ErrorDocumentInput() *S3BucketWebsiteConfigurationErrorDocument
ExpectedBucketOwner() *string
SetExpectedBucketOwner(val *string)
ExpectedBucketOwnerInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IndexDocument() S3BucketWebsiteConfigurationIndexDocumentOutputReference
IndexDocumentInput() *S3BucketWebsiteConfigurationIndexDocument
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RedirectAllRequestsTo() S3BucketWebsiteConfigurationRedirectAllRequestsToOutputReference
RedirectAllRequestsToInput() *S3BucketWebsiteConfigurationRedirectAllRequestsTo
RoutingRule() S3BucketWebsiteConfigurationRoutingRuleList
RoutingRuleInput() interface{}
RoutingRules() *string
SetRoutingRules(val *string)
RoutingRulesInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
WebsiteDomain() *string
WebsiteEndpoint() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutErrorDocument(value *S3BucketWebsiteConfigurationErrorDocument)
PutIndexDocument(value *S3BucketWebsiteConfigurationIndexDocument)
PutRedirectAllRequestsTo(value *S3BucketWebsiteConfigurationRedirectAllRequestsTo)
PutRoutingRule(value interface{})
ResetErrorDocument()
ResetExpectedBucketOwner()
ResetId()
ResetIndexDocument()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRedirectAllRequestsTo()
ResetRoutingRule()
ResetRoutingRules()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration aws_s3_bucket_website_configuration}.
func NewS3BucketWebsiteConfiguration ¶
func NewS3BucketWebsiteConfiguration(scope constructs.Construct, id *string, config *S3BucketWebsiteConfigurationConfig) S3BucketWebsiteConfiguration
Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration aws_s3_bucket_website_configuration} Resource.
type S3BucketWebsiteConfigurationConfig ¶
type S3BucketWebsiteConfigurationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#bucket S3BucketWebsiteConfiguration#bucket}.
Bucket *string `field:"required" json:"bucket" yaml:"bucket"`
// error_document block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#error_document S3BucketWebsiteConfiguration#error_document}
ErrorDocument *S3BucketWebsiteConfigurationErrorDocument `field:"optional" json:"errorDocument" yaml:"errorDocument"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#expected_bucket_owner S3BucketWebsiteConfiguration#expected_bucket_owner}.
ExpectedBucketOwner *string `field:"optional" json:"expectedBucketOwner" yaml:"expectedBucketOwner"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#id S3BucketWebsiteConfiguration#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// index_document block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#index_document S3BucketWebsiteConfiguration#index_document}
IndexDocument *S3BucketWebsiteConfigurationIndexDocument `field:"optional" json:"indexDocument" yaml:"indexDocument"`
// redirect_all_requests_to block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#redirect_all_requests_to S3BucketWebsiteConfiguration#redirect_all_requests_to}
RedirectAllRequestsTo *S3BucketWebsiteConfigurationRedirectAllRequestsTo `field:"optional" json:"redirectAllRequestsTo" yaml:"redirectAllRequestsTo"`
// routing_rule block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#routing_rule S3BucketWebsiteConfiguration#routing_rule}
RoutingRule interface{} `field:"optional" json:"routingRule" yaml:"routingRule"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#routing_rules S3BucketWebsiteConfiguration#routing_rules}.
RoutingRules *string `field:"optional" json:"routingRules" yaml:"routingRules"`
}
type S3BucketWebsiteConfigurationErrorDocument ¶
type S3BucketWebsiteConfigurationErrorDocument struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#key S3BucketWebsiteConfiguration#key}.
Key *string `field:"required" json:"key" yaml:"key"`
}
type S3BucketWebsiteConfigurationErrorDocumentOutputReference ¶
type S3BucketWebsiteConfigurationErrorDocumentOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *S3BucketWebsiteConfigurationErrorDocument
SetInternalValue(val *S3BucketWebsiteConfigurationErrorDocument)
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketWebsiteConfigurationErrorDocumentOutputReference ¶
func NewS3BucketWebsiteConfigurationErrorDocumentOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketWebsiteConfigurationErrorDocumentOutputReference
type S3BucketWebsiteConfigurationIndexDocument ¶
type S3BucketWebsiteConfigurationIndexDocument struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#suffix S3BucketWebsiteConfiguration#suffix}.
Suffix *string `field:"required" json:"suffix" yaml:"suffix"`
}
type S3BucketWebsiteConfigurationIndexDocumentOutputReference ¶
type S3BucketWebsiteConfigurationIndexDocumentOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *S3BucketWebsiteConfigurationIndexDocument
SetInternalValue(val *S3BucketWebsiteConfigurationIndexDocument)
Suffix() *string
SetSuffix(val *string)
SuffixInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketWebsiteConfigurationIndexDocumentOutputReference ¶
func NewS3BucketWebsiteConfigurationIndexDocumentOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketWebsiteConfigurationIndexDocumentOutputReference
type S3BucketWebsiteConfigurationRedirectAllRequestsTo ¶
type S3BucketWebsiteConfigurationRedirectAllRequestsTo struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#host_name S3BucketWebsiteConfiguration#host_name}.
HostName *string `field:"required" json:"hostName" yaml:"hostName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#protocol S3BucketWebsiteConfiguration#protocol}.
Protocol *string `field:"optional" json:"protocol" yaml:"protocol"`
}
type S3BucketWebsiteConfigurationRedirectAllRequestsToOutputReference ¶
type S3BucketWebsiteConfigurationRedirectAllRequestsToOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HostName() *string
SetHostName(val *string)
HostNameInput() *string
InternalValue() *S3BucketWebsiteConfigurationRedirectAllRequestsTo
SetInternalValue(val *S3BucketWebsiteConfigurationRedirectAllRequestsTo)
Protocol() *string
SetProtocol(val *string)
ProtocolInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetProtocol()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketWebsiteConfigurationRedirectAllRequestsToOutputReference ¶
func NewS3BucketWebsiteConfigurationRedirectAllRequestsToOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketWebsiteConfigurationRedirectAllRequestsToOutputReference
type S3BucketWebsiteConfigurationRoutingRule ¶
type S3BucketWebsiteConfigurationRoutingRule struct {
// redirect block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#redirect S3BucketWebsiteConfiguration#redirect}
Redirect *S3BucketWebsiteConfigurationRoutingRuleRedirect `field:"required" json:"redirect" yaml:"redirect"`
// condition block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#condition S3BucketWebsiteConfiguration#condition}
Condition *S3BucketWebsiteConfigurationRoutingRuleCondition `field:"optional" json:"condition" yaml:"condition"`
}
type S3BucketWebsiteConfigurationRoutingRuleCondition ¶
type S3BucketWebsiteConfigurationRoutingRuleCondition struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#http_error_code_returned_equals S3BucketWebsiteConfiguration#http_error_code_returned_equals}.
HttpErrorCodeReturnedEquals *string `field:"optional" json:"httpErrorCodeReturnedEquals" yaml:"httpErrorCodeReturnedEquals"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#key_prefix_equals S3BucketWebsiteConfiguration#key_prefix_equals}.
KeyPrefixEquals *string `field:"optional" json:"keyPrefixEquals" yaml:"keyPrefixEquals"`
}
type S3BucketWebsiteConfigurationRoutingRuleConditionOutputReference ¶
type S3BucketWebsiteConfigurationRoutingRuleConditionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HttpErrorCodeReturnedEquals() *string
SetHttpErrorCodeReturnedEquals(val *string)
HttpErrorCodeReturnedEqualsInput() *string
InternalValue() *S3BucketWebsiteConfigurationRoutingRuleCondition
SetInternalValue(val *S3BucketWebsiteConfigurationRoutingRuleCondition)
KeyPrefixEquals() *string
SetKeyPrefixEquals(val *string)
KeyPrefixEqualsInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetHttpErrorCodeReturnedEquals()
ResetKeyPrefixEquals()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketWebsiteConfigurationRoutingRuleConditionOutputReference ¶
func NewS3BucketWebsiteConfigurationRoutingRuleConditionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketWebsiteConfigurationRoutingRuleConditionOutputReference
type S3BucketWebsiteConfigurationRoutingRuleList ¶
type S3BucketWebsiteConfigurationRoutingRuleList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) S3BucketWebsiteConfigurationRoutingRuleOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketWebsiteConfigurationRoutingRuleList ¶
func NewS3BucketWebsiteConfigurationRoutingRuleList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) S3BucketWebsiteConfigurationRoutingRuleList
type S3BucketWebsiteConfigurationRoutingRuleOutputReference ¶
type S3BucketWebsiteConfigurationRoutingRuleOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Condition() S3BucketWebsiteConfigurationRoutingRuleConditionOutputReference
ConditionInput() *S3BucketWebsiteConfigurationRoutingRuleCondition
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Redirect() S3BucketWebsiteConfigurationRoutingRuleRedirectOutputReference
RedirectInput() *S3BucketWebsiteConfigurationRoutingRuleRedirect
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutCondition(value *S3BucketWebsiteConfigurationRoutingRuleCondition)
PutRedirect(value *S3BucketWebsiteConfigurationRoutingRuleRedirect)
ResetCondition()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketWebsiteConfigurationRoutingRuleOutputReference ¶
func NewS3BucketWebsiteConfigurationRoutingRuleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) S3BucketWebsiteConfigurationRoutingRuleOutputReference
type S3BucketWebsiteConfigurationRoutingRuleRedirect ¶
type S3BucketWebsiteConfigurationRoutingRuleRedirect struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#host_name S3BucketWebsiteConfiguration#host_name}.
HostName *string `field:"optional" json:"hostName" yaml:"hostName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#http_redirect_code S3BucketWebsiteConfiguration#http_redirect_code}.
HttpRedirectCode *string `field:"optional" json:"httpRedirectCode" yaml:"httpRedirectCode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#protocol S3BucketWebsiteConfiguration#protocol}.
Protocol *string `field:"optional" json:"protocol" yaml:"protocol"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#replace_key_prefix_with S3BucketWebsiteConfiguration#replace_key_prefix_with}.
ReplaceKeyPrefixWith *string `field:"optional" json:"replaceKeyPrefixWith" yaml:"replaceKeyPrefixWith"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_website_configuration#replace_key_with S3BucketWebsiteConfiguration#replace_key_with}.
ReplaceKeyWith *string `field:"optional" json:"replaceKeyWith" yaml:"replaceKeyWith"`
}
type S3BucketWebsiteConfigurationRoutingRuleRedirectOutputReference ¶
type S3BucketWebsiteConfigurationRoutingRuleRedirectOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HostName() *string
SetHostName(val *string)
HostNameInput() *string
HttpRedirectCode() *string
SetHttpRedirectCode(val *string)
HttpRedirectCodeInput() *string
InternalValue() *S3BucketWebsiteConfigurationRoutingRuleRedirect
SetInternalValue(val *S3BucketWebsiteConfigurationRoutingRuleRedirect)
Protocol() *string
SetProtocol(val *string)
ProtocolInput() *string
ReplaceKeyPrefixWith() *string
SetReplaceKeyPrefixWith(val *string)
ReplaceKeyPrefixWithInput() *string
ReplaceKeyWith() *string
SetReplaceKeyWith(val *string)
ReplaceKeyWithInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetHostName()
ResetHttpRedirectCode()
ResetProtocol()
ResetReplaceKeyPrefixWith()
ResetReplaceKeyWith()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketWebsiteConfigurationRoutingRuleRedirectOutputReference ¶
func NewS3BucketWebsiteConfigurationRoutingRuleRedirectOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketWebsiteConfigurationRoutingRuleRedirectOutputReference
Source Files
¶
- s3bucketwebsiteconfiguration.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfiguration.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationConfig.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationErrorDocument.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationErrorDocumentOutputReference.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationErrorDocumentOutputReference__runtime_type_checks.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationIndexDocument.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationIndexDocumentOutputReference.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationIndexDocumentOutputReference__runtime_type_checks.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationRedirectAllRequestsTo.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationRedirectAllRequestsToOutputReference.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationRedirectAllRequestsToOutputReference__runtime_type_checks.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationRoutingRule.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationRoutingRuleCondition.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationRoutingRuleConditionOutputReference.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationRoutingRuleConditionOutputReference__runtime_type_checks.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationRoutingRuleList.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationRoutingRuleList__runtime_type_checks.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationRoutingRuleOutputReference.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationRoutingRuleOutputReference__runtime_type_checks.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationRoutingRuleRedirect.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationRoutingRuleRedirectOutputReference.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfigurationRoutingRuleRedirectOutputReference__runtime_type_checks.go
- s3bucketwebsiteconfiguration_S3BucketWebsiteConfiguration__runtime_type_checks.go