Documentation
¶
Index ¶
- func NewSagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfigOutputReference_Override(...)
- func NewSagemakerAppImageConfigKernelGatewayImageConfigKernelSpecOutputReference_Override(s SagemakerAppImageConfigKernelGatewayImageConfigKernelSpecOutputReference, ...)
- func NewSagemakerAppImageConfigKernelGatewayImageConfigOutputReference_Override(s SagemakerAppImageConfigKernelGatewayImageConfigOutputReference, ...)
- func NewSagemakerAppImageConfig_Override(s SagemakerAppImageConfig, scope constructs.Construct, id *string, ...)
- func SagemakerAppImageConfig_IsConstruct(x interface{}) *bool
- func SagemakerAppImageConfig_IsTerraformElement(x interface{}) *bool
- func SagemakerAppImageConfig_IsTerraformResource(x interface{}) *bool
- func SagemakerAppImageConfig_TfResourceType() *string
- type SagemakerAppImageConfig
- type SagemakerAppImageConfigConfig
- type SagemakerAppImageConfigKernelGatewayImageConfig
- type SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfig
- type SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfigOutputReference
- type SagemakerAppImageConfigKernelGatewayImageConfigKernelSpec
- type SagemakerAppImageConfigKernelGatewayImageConfigKernelSpecOutputReference
- type SagemakerAppImageConfigKernelGatewayImageConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfigOutputReference_Override ¶
func NewSagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfigOutputReference_Override(s SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerAppImageConfigKernelGatewayImageConfigKernelSpecOutputReference_Override ¶
func NewSagemakerAppImageConfigKernelGatewayImageConfigKernelSpecOutputReference_Override(s SagemakerAppImageConfigKernelGatewayImageConfigKernelSpecOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerAppImageConfigKernelGatewayImageConfigOutputReference_Override ¶
func NewSagemakerAppImageConfigKernelGatewayImageConfigOutputReference_Override(s SagemakerAppImageConfigKernelGatewayImageConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerAppImageConfig_Override ¶
func NewSagemakerAppImageConfig_Override(s SagemakerAppImageConfig, scope constructs.Construct, id *string, config *SagemakerAppImageConfigConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config aws_sagemaker_app_image_config} Resource.
func SagemakerAppImageConfig_IsConstruct ¶
func SagemakerAppImageConfig_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SagemakerAppImageConfig_IsTerraformElement ¶
func SagemakerAppImageConfig_IsTerraformElement(x interface{}) *bool
Experimental.
func SagemakerAppImageConfig_IsTerraformResource ¶
func SagemakerAppImageConfig_IsTerraformResource(x interface{}) *bool
Experimental.
func SagemakerAppImageConfig_TfResourceType ¶
func SagemakerAppImageConfig_TfResourceType() *string
Types ¶
type SagemakerAppImageConfig ¶
type SagemakerAppImageConfig interface {
cdktf.TerraformResource
AppImageConfigName() *string
SetAppImageConfigName(val *string)
AppImageConfigNameInput() *string
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
KernelGatewayImageConfig() SagemakerAppImageConfigKernelGatewayImageConfigOutputReference
KernelGatewayImageConfigInput() *SagemakerAppImageConfigKernelGatewayImageConfig
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutKernelGatewayImageConfig(value *SagemakerAppImageConfigKernelGatewayImageConfig)
ResetId()
ResetKernelGatewayImageConfig()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config aws_sagemaker_app_image_config}.
func NewSagemakerAppImageConfig ¶
func NewSagemakerAppImageConfig(scope constructs.Construct, id *string, config *SagemakerAppImageConfigConfig) SagemakerAppImageConfig
Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config aws_sagemaker_app_image_config} Resource.
type SagemakerAppImageConfigConfig ¶
type SagemakerAppImageConfigConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config#app_image_config_name SagemakerAppImageConfig#app_image_config_name}.
AppImageConfigName *string `field:"required" json:"appImageConfigName" yaml:"appImageConfigName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config#id SagemakerAppImageConfig#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// kernel_gateway_image_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config#kernel_gateway_image_config SagemakerAppImageConfig#kernel_gateway_image_config}
KernelGatewayImageConfig *SagemakerAppImageConfigKernelGatewayImageConfig `field:"optional" json:"kernelGatewayImageConfig" yaml:"kernelGatewayImageConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config#tags SagemakerAppImageConfig#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config#tags_all SagemakerAppImageConfig#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type SagemakerAppImageConfigKernelGatewayImageConfig ¶
type SagemakerAppImageConfigKernelGatewayImageConfig struct {
// kernel_spec block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config#kernel_spec SagemakerAppImageConfig#kernel_spec}
KernelSpec *SagemakerAppImageConfigKernelGatewayImageConfigKernelSpec `field:"required" json:"kernelSpec" yaml:"kernelSpec"`
// file_system_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config#file_system_config SagemakerAppImageConfig#file_system_config}
FileSystemConfig *SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfig `field:"optional" json:"fileSystemConfig" yaml:"fileSystemConfig"`
}
type SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfig ¶
type SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config#default_gid SagemakerAppImageConfig#default_gid}.
DefaultGid *float64 `field:"optional" json:"defaultGid" yaml:"defaultGid"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config#default_uid SagemakerAppImageConfig#default_uid}.
DefaultUid *float64 `field:"optional" json:"defaultUid" yaml:"defaultUid"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config#mount_path SagemakerAppImageConfig#mount_path}.
MountPath *string `field:"optional" json:"mountPath" yaml:"mountPath"`
}
type SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfigOutputReference ¶
type SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DefaultGid() *float64
SetDefaultGid(val *float64)
DefaultGidInput() *float64
DefaultUid() *float64
SetDefaultUid(val *float64)
DefaultUidInput() *float64
// Experimental.
Fqn() *string
InternalValue() *SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfig
SetInternalValue(val *SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfig)
MountPath() *string
SetMountPath(val *string)
MountPathInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDefaultGid()
ResetDefaultUid()
ResetMountPath()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfigOutputReference ¶
func NewSagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfigOutputReference
type SagemakerAppImageConfigKernelGatewayImageConfigKernelSpec ¶
type SagemakerAppImageConfigKernelGatewayImageConfigKernelSpec struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config#name SagemakerAppImageConfig#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config#display_name SagemakerAppImageConfig#display_name}.
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
}
type SagemakerAppImageConfigKernelGatewayImageConfigKernelSpecOutputReference ¶
type SagemakerAppImageConfigKernelGatewayImageConfigKernelSpecOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
// Experimental.
Fqn() *string
InternalValue() *SagemakerAppImageConfigKernelGatewayImageConfigKernelSpec
SetInternalValue(val *SagemakerAppImageConfigKernelGatewayImageConfigKernelSpec)
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDisplayName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerAppImageConfigKernelGatewayImageConfigKernelSpecOutputReference ¶
func NewSagemakerAppImageConfigKernelGatewayImageConfigKernelSpecOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerAppImageConfigKernelGatewayImageConfigKernelSpecOutputReference
type SagemakerAppImageConfigKernelGatewayImageConfigOutputReference ¶
type SagemakerAppImageConfigKernelGatewayImageConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FileSystemConfig() SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfigOutputReference
FileSystemConfigInput() *SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfig
// Experimental.
Fqn() *string
InternalValue() *SagemakerAppImageConfigKernelGatewayImageConfig
SetInternalValue(val *SagemakerAppImageConfigKernelGatewayImageConfig)
KernelSpec() SagemakerAppImageConfigKernelGatewayImageConfigKernelSpecOutputReference
KernelSpecInput() *SagemakerAppImageConfigKernelGatewayImageConfigKernelSpec
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutFileSystemConfig(value *SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfig)
PutKernelSpec(value *SagemakerAppImageConfigKernelGatewayImageConfigKernelSpec)
ResetFileSystemConfig()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerAppImageConfigKernelGatewayImageConfigOutputReference ¶
func NewSagemakerAppImageConfigKernelGatewayImageConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerAppImageConfigKernelGatewayImageConfigOutputReference
Source Files
¶
- sagemakerappimageconfig.go
- sagemakerappimageconfig_SagemakerAppImageConfig.go
- sagemakerappimageconfig_SagemakerAppImageConfigConfig.go
- sagemakerappimageconfig_SagemakerAppImageConfigKernelGatewayImageConfig.go
- sagemakerappimageconfig_SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfig.go
- sagemakerappimageconfig_SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfigOutputReference.go
- sagemakerappimageconfig_SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfigOutputReference__runtime_type_checks.go
- sagemakerappimageconfig_SagemakerAppImageConfigKernelGatewayImageConfigKernelSpec.go
- sagemakerappimageconfig_SagemakerAppImageConfigKernelGatewayImageConfigKernelSpecOutputReference.go
- sagemakerappimageconfig_SagemakerAppImageConfigKernelGatewayImageConfigKernelSpecOutputReference__runtime_type_checks.go
- sagemakerappimageconfig_SagemakerAppImageConfigKernelGatewayImageConfigOutputReference.go
- sagemakerappimageconfig_SagemakerAppImageConfigKernelGatewayImageConfigOutputReference__runtime_type_checks.go
- sagemakerappimageconfig_SagemakerAppImageConfig__runtime_type_checks.go