Documentation
¶
Index ¶
- func NewSagemakerDeviceDeviceOutputReference_Override(s SagemakerDeviceDeviceOutputReference, ...)
- func NewSagemakerDevice_Override(s SagemakerDevice, scope constructs.Construct, id *string, ...)
- func SagemakerDevice_IsConstruct(x interface{}) *bool
- func SagemakerDevice_IsTerraformElement(x interface{}) *bool
- func SagemakerDevice_IsTerraformResource(x interface{}) *bool
- func SagemakerDevice_TfResourceType() *string
- type SagemakerDevice
- type SagemakerDeviceConfig
- type SagemakerDeviceDevice
- type SagemakerDeviceDeviceOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSagemakerDeviceDeviceOutputReference_Override ¶
func NewSagemakerDeviceDeviceOutputReference_Override(s SagemakerDeviceDeviceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerDevice_Override ¶
func NewSagemakerDevice_Override(s SagemakerDevice, scope constructs.Construct, id *string, config *SagemakerDeviceConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device aws_sagemaker_device} Resource.
func SagemakerDevice_IsConstruct ¶
func SagemakerDevice_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SagemakerDevice_IsTerraformElement ¶
func SagemakerDevice_IsTerraformElement(x interface{}) *bool
Experimental.
func SagemakerDevice_IsTerraformResource ¶
func SagemakerDevice_IsTerraformResource(x interface{}) *bool
Experimental.
func SagemakerDevice_TfResourceType ¶
func SagemakerDevice_TfResourceType() *string
Types ¶
type SagemakerDevice ¶
type SagemakerDevice interface {
cdktf.TerraformResource
AgentVersion() *string
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Device() SagemakerDeviceDeviceOutputReference
DeviceFleetName() *string
SetDeviceFleetName(val *string)
DeviceFleetNameInput() *string
DeviceInput() *SagemakerDeviceDevice
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDevice(value *SagemakerDeviceDevice)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device aws_sagemaker_device}.
func NewSagemakerDevice ¶
func NewSagemakerDevice(scope constructs.Construct, id *string, config *SagemakerDeviceConfig) SagemakerDevice
Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device aws_sagemaker_device} Resource.
type SagemakerDeviceConfig ¶
type SagemakerDeviceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// device block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device#device SagemakerDevice#device}
Device *SagemakerDeviceDevice `field:"required" json:"device" yaml:"device"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device#device_fleet_name SagemakerDevice#device_fleet_name}.
DeviceFleetName *string `field:"required" json:"deviceFleetName" yaml:"deviceFleetName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device#id SagemakerDevice#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type SagemakerDeviceDevice ¶
type SagemakerDeviceDevice struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device#device_name SagemakerDevice#device_name}.
DeviceName *string `field:"required" json:"deviceName" yaml:"deviceName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device#description SagemakerDevice#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device#iot_thing_name SagemakerDevice#iot_thing_name}.
IotThingName *string `field:"optional" json:"iotThingName" yaml:"iotThingName"`
}
type SagemakerDeviceDeviceOutputReference ¶
type SagemakerDeviceDeviceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DeviceName() *string
SetDeviceName(val *string)
DeviceNameInput() *string
// Experimental.
Fqn() *string
InternalValue() *SagemakerDeviceDevice
SetInternalValue(val *SagemakerDeviceDevice)
IotThingName() *string
SetIotThingName(val *string)
IotThingNameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDescription()
ResetIotThingName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerDeviceDeviceOutputReference ¶
func NewSagemakerDeviceDeviceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerDeviceDeviceOutputReference
Source Files
¶
- sagemakerdevice.go
- sagemakerdevice_SagemakerDevice.go
- sagemakerdevice_SagemakerDeviceConfig.go
- sagemakerdevice_SagemakerDeviceDevice.go
- sagemakerdevice_SagemakerDeviceDeviceOutputReference.go
- sagemakerdevice_SagemakerDeviceDeviceOutputReference__runtime_type_checks.go
- sagemakerdevice_SagemakerDevice__runtime_type_checks.go