Documentation
¶
Index ¶
- func NewVpcPeeringConnectionAccepterA_Override(v VpcPeeringConnectionAccepterA, scope constructs.Construct, id *string, ...)
- func NewVpcPeeringConnectionAccepterAccepterOutputReference_Override(v VpcPeeringConnectionAccepterAccepterOutputReference, ...)
- func NewVpcPeeringConnectionAccepterRequesterOutputReference_Override(v VpcPeeringConnectionAccepterRequesterOutputReference, ...)
- func NewVpcPeeringConnectionAccepterTimeoutsOutputReference_Override(v VpcPeeringConnectionAccepterTimeoutsOutputReference, ...)
- func VpcPeeringConnectionAccepterA_IsConstruct(x interface{}) *bool
- func VpcPeeringConnectionAccepterA_IsTerraformElement(x interface{}) *bool
- func VpcPeeringConnectionAccepterA_IsTerraformResource(x interface{}) *bool
- func VpcPeeringConnectionAccepterA_TfResourceType() *string
- type VpcPeeringConnectionAccepterA
- type VpcPeeringConnectionAccepterAConfig
- type VpcPeeringConnectionAccepterAccepter
- type VpcPeeringConnectionAccepterAccepterOutputReference
- type VpcPeeringConnectionAccepterRequester
- type VpcPeeringConnectionAccepterRequesterOutputReference
- type VpcPeeringConnectionAccepterTimeouts
- type VpcPeeringConnectionAccepterTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewVpcPeeringConnectionAccepterA_Override ¶
func NewVpcPeeringConnectionAccepterA_Override(v VpcPeeringConnectionAccepterA, scope constructs.Construct, id *string, config *VpcPeeringConnectionAccepterAConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter aws_vpc_peering_connection_accepter} Resource.
func NewVpcPeeringConnectionAccepterAccepterOutputReference_Override ¶
func NewVpcPeeringConnectionAccepterAccepterOutputReference_Override(v VpcPeeringConnectionAccepterAccepterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVpcPeeringConnectionAccepterRequesterOutputReference_Override ¶
func NewVpcPeeringConnectionAccepterRequesterOutputReference_Override(v VpcPeeringConnectionAccepterRequesterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVpcPeeringConnectionAccepterTimeoutsOutputReference_Override ¶
func NewVpcPeeringConnectionAccepterTimeoutsOutputReference_Override(v VpcPeeringConnectionAccepterTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func VpcPeeringConnectionAccepterA_IsConstruct ¶
func VpcPeeringConnectionAccepterA_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func VpcPeeringConnectionAccepterA_IsTerraformElement ¶
func VpcPeeringConnectionAccepterA_IsTerraformElement(x interface{}) *bool
Experimental.
func VpcPeeringConnectionAccepterA_IsTerraformResource ¶
func VpcPeeringConnectionAccepterA_IsTerraformResource(x interface{}) *bool
Experimental.
func VpcPeeringConnectionAccepterA_TfResourceType ¶
func VpcPeeringConnectionAccepterA_TfResourceType() *string
Types ¶
type VpcPeeringConnectionAccepterA ¶
type VpcPeeringConnectionAccepterA interface {
cdktf.TerraformResource
Accepter() VpcPeeringConnectionAccepterAccepterOutputReference
AccepterInput() *VpcPeeringConnectionAccepterAccepter
AcceptStatus() *string
AutoAccept() interface{}
SetAutoAccept(val interface{})
AutoAcceptInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
PeerOwnerId() *string
PeerRegion() *string
PeerVpcId() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Requester() VpcPeeringConnectionAccepterRequesterOutputReference
RequesterInput() *VpcPeeringConnectionAccepterRequester
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() VpcPeeringConnectionAccepterTimeoutsOutputReference
TimeoutsInput() interface{}
VpcId() *string
VpcPeeringConnectionId() *string
SetVpcPeeringConnectionId(val *string)
VpcPeeringConnectionIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAccepter(value *VpcPeeringConnectionAccepterAccepter)
PutRequester(value *VpcPeeringConnectionAccepterRequester)
PutTimeouts(value *VpcPeeringConnectionAccepterTimeouts)
ResetAccepter()
ResetAutoAccept()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRequester()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter aws_vpc_peering_connection_accepter}.
func NewVpcPeeringConnectionAccepterA ¶
func NewVpcPeeringConnectionAccepterA(scope constructs.Construct, id *string, config *VpcPeeringConnectionAccepterAConfig) VpcPeeringConnectionAccepterA
Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter aws_vpc_peering_connection_accepter} Resource.
type VpcPeeringConnectionAccepterAConfig ¶
type VpcPeeringConnectionAccepterAConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter#vpc_peering_connection_id VpcPeeringConnectionAccepterA#vpc_peering_connection_id}.
VpcPeeringConnectionId *string `field:"required" json:"vpcPeeringConnectionId" yaml:"vpcPeeringConnectionId"`
// accepter block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter#accepter VpcPeeringConnectionAccepterA#accepter}
Accepter *VpcPeeringConnectionAccepterAccepter `field:"optional" json:"accepter" yaml:"accepter"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter#auto_accept VpcPeeringConnectionAccepterA#auto_accept}.
AutoAccept interface{} `field:"optional" json:"autoAccept" yaml:"autoAccept"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter#id VpcPeeringConnectionAccepterA#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// requester block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter#requester VpcPeeringConnectionAccepterA#requester}
Requester *VpcPeeringConnectionAccepterRequester `field:"optional" json:"requester" yaml:"requester"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter#tags VpcPeeringConnectionAccepterA#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter#tags_all VpcPeeringConnectionAccepterA#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter#timeouts VpcPeeringConnectionAccepterA#timeouts}
Timeouts *VpcPeeringConnectionAccepterTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type VpcPeeringConnectionAccepterAccepter ¶
type VpcPeeringConnectionAccepterAccepter struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter#allow_classic_link_to_remote_vpc VpcPeeringConnectionAccepterA#allow_classic_link_to_remote_vpc}.
AllowClassicLinkToRemoteVpc interface{} `field:"optional" json:"allowClassicLinkToRemoteVpc" yaml:"allowClassicLinkToRemoteVpc"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter#allow_remote_vpc_dns_resolution VpcPeeringConnectionAccepterA#allow_remote_vpc_dns_resolution}.
AllowRemoteVpcDnsResolution interface{} `field:"optional" json:"allowRemoteVpcDnsResolution" yaml:"allowRemoteVpcDnsResolution"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter#allow_vpc_to_remote_classic_link VpcPeeringConnectionAccepterA#allow_vpc_to_remote_classic_link}.
AllowVpcToRemoteClassicLink interface{} `field:"optional" json:"allowVpcToRemoteClassicLink" yaml:"allowVpcToRemoteClassicLink"`
}
type VpcPeeringConnectionAccepterAccepterOutputReference ¶
type VpcPeeringConnectionAccepterAccepterOutputReference interface {
cdktf.ComplexObject
AllowClassicLinkToRemoteVpc() interface{}
SetAllowClassicLinkToRemoteVpc(val interface{})
AllowClassicLinkToRemoteVpcInput() interface{}
AllowRemoteVpcDnsResolution() interface{}
SetAllowRemoteVpcDnsResolution(val interface{})
AllowRemoteVpcDnsResolutionInput() interface{}
AllowVpcToRemoteClassicLink() interface{}
SetAllowVpcToRemoteClassicLink(val interface{})
AllowVpcToRemoteClassicLinkInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *VpcPeeringConnectionAccepterAccepter
SetInternalValue(val *VpcPeeringConnectionAccepterAccepter)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAllowClassicLinkToRemoteVpc()
ResetAllowRemoteVpcDnsResolution()
ResetAllowVpcToRemoteClassicLink()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpcPeeringConnectionAccepterAccepterOutputReference ¶
func NewVpcPeeringConnectionAccepterAccepterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VpcPeeringConnectionAccepterAccepterOutputReference
type VpcPeeringConnectionAccepterRequester ¶
type VpcPeeringConnectionAccepterRequester struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter#allow_classic_link_to_remote_vpc VpcPeeringConnectionAccepterA#allow_classic_link_to_remote_vpc}.
AllowClassicLinkToRemoteVpc interface{} `field:"optional" json:"allowClassicLinkToRemoteVpc" yaml:"allowClassicLinkToRemoteVpc"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter#allow_remote_vpc_dns_resolution VpcPeeringConnectionAccepterA#allow_remote_vpc_dns_resolution}.
AllowRemoteVpcDnsResolution interface{} `field:"optional" json:"allowRemoteVpcDnsResolution" yaml:"allowRemoteVpcDnsResolution"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter#allow_vpc_to_remote_classic_link VpcPeeringConnectionAccepterA#allow_vpc_to_remote_classic_link}.
AllowVpcToRemoteClassicLink interface{} `field:"optional" json:"allowVpcToRemoteClassicLink" yaml:"allowVpcToRemoteClassicLink"`
}
type VpcPeeringConnectionAccepterRequesterOutputReference ¶
type VpcPeeringConnectionAccepterRequesterOutputReference interface {
cdktf.ComplexObject
AllowClassicLinkToRemoteVpc() interface{}
SetAllowClassicLinkToRemoteVpc(val interface{})
AllowClassicLinkToRemoteVpcInput() interface{}
AllowRemoteVpcDnsResolution() interface{}
SetAllowRemoteVpcDnsResolution(val interface{})
AllowRemoteVpcDnsResolutionInput() interface{}
AllowVpcToRemoteClassicLink() interface{}
SetAllowVpcToRemoteClassicLink(val interface{})
AllowVpcToRemoteClassicLinkInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *VpcPeeringConnectionAccepterRequester
SetInternalValue(val *VpcPeeringConnectionAccepterRequester)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAllowClassicLinkToRemoteVpc()
ResetAllowRemoteVpcDnsResolution()
ResetAllowVpcToRemoteClassicLink()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpcPeeringConnectionAccepterRequesterOutputReference ¶
func NewVpcPeeringConnectionAccepterRequesterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VpcPeeringConnectionAccepterRequesterOutputReference
type VpcPeeringConnectionAccepterTimeouts ¶
type VpcPeeringConnectionAccepterTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter#create VpcPeeringConnectionAccepterA#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter#update VpcPeeringConnectionAccepterA#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type VpcPeeringConnectionAccepterTimeoutsOutputReference ¶
type VpcPeeringConnectionAccepterTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpcPeeringConnectionAccepterTimeoutsOutputReference ¶
func NewVpcPeeringConnectionAccepterTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VpcPeeringConnectionAccepterTimeoutsOutputReference
Source Files
¶
- vpcpeeringconnectionaccepter.go
- vpcpeeringconnectionaccepter_VpcPeeringConnectionAccepterA.go
- vpcpeeringconnectionaccepter_VpcPeeringConnectionAccepterAConfig.go
- vpcpeeringconnectionaccepter_VpcPeeringConnectionAccepterA__runtime_type_checks.go
- vpcpeeringconnectionaccepter_VpcPeeringConnectionAccepterAccepter.go
- vpcpeeringconnectionaccepter_VpcPeeringConnectionAccepterAccepterOutputReference.go
- vpcpeeringconnectionaccepter_VpcPeeringConnectionAccepterAccepterOutputReference__runtime_type_checks.go
- vpcpeeringconnectionaccepter_VpcPeeringConnectionAccepterRequester.go
- vpcpeeringconnectionaccepter_VpcPeeringConnectionAccepterRequesterOutputReference.go
- vpcpeeringconnectionaccepter_VpcPeeringConnectionAccepterRequesterOutputReference__runtime_type_checks.go
- vpcpeeringconnectionaccepter_VpcPeeringConnectionAccepterTimeouts.go
- vpcpeeringconnectionaccepter_VpcPeeringConnectionAccepterTimeoutsOutputReference.go
- vpcpeeringconnectionaccepter_VpcPeeringConnectionAccepterTimeoutsOutputReference__runtime_type_checks.go