Documentation
¶
Index ¶
- func NewVpcPeeringConnectionOptionsAccepterOutputReference_Override(v VpcPeeringConnectionOptionsAccepterOutputReference, ...)
- func NewVpcPeeringConnectionOptionsRequesterOutputReference_Override(v VpcPeeringConnectionOptionsRequesterOutputReference, ...)
- func NewVpcPeeringConnectionOptions_Override(v VpcPeeringConnectionOptions, scope constructs.Construct, id *string, ...)
- func VpcPeeringConnectionOptions_IsConstruct(x interface{}) *bool
- func VpcPeeringConnectionOptions_IsTerraformElement(x interface{}) *bool
- func VpcPeeringConnectionOptions_IsTerraformResource(x interface{}) *bool
- func VpcPeeringConnectionOptions_TfResourceType() *string
- type VpcPeeringConnectionOptions
- type VpcPeeringConnectionOptionsAccepter
- type VpcPeeringConnectionOptionsAccepterOutputReference
- type VpcPeeringConnectionOptionsConfig
- type VpcPeeringConnectionOptionsRequester
- type VpcPeeringConnectionOptionsRequesterOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewVpcPeeringConnectionOptionsAccepterOutputReference_Override ¶
func NewVpcPeeringConnectionOptionsAccepterOutputReference_Override(v VpcPeeringConnectionOptionsAccepterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVpcPeeringConnectionOptionsRequesterOutputReference_Override ¶
func NewVpcPeeringConnectionOptionsRequesterOutputReference_Override(v VpcPeeringConnectionOptionsRequesterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVpcPeeringConnectionOptions_Override ¶
func NewVpcPeeringConnectionOptions_Override(v VpcPeeringConnectionOptions, scope constructs.Construct, id *string, config *VpcPeeringConnectionOptionsConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options aws_vpc_peering_connection_options} Resource.
func VpcPeeringConnectionOptions_IsConstruct ¶
func VpcPeeringConnectionOptions_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func VpcPeeringConnectionOptions_IsTerraformElement ¶
func VpcPeeringConnectionOptions_IsTerraformElement(x interface{}) *bool
Experimental.
func VpcPeeringConnectionOptions_IsTerraformResource ¶
func VpcPeeringConnectionOptions_IsTerraformResource(x interface{}) *bool
Experimental.
func VpcPeeringConnectionOptions_TfResourceType ¶
func VpcPeeringConnectionOptions_TfResourceType() *string
Types ¶
type VpcPeeringConnectionOptions ¶
type VpcPeeringConnectionOptions interface {
cdktf.TerraformResource
Accepter() VpcPeeringConnectionOptionsAccepterOutputReference
AccepterInput() *VpcPeeringConnectionOptionsAccepter
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Requester() VpcPeeringConnectionOptionsRequesterOutputReference
RequesterInput() *VpcPeeringConnectionOptionsRequester
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
VpcPeeringConnectionId() *string
SetVpcPeeringConnectionId(val *string)
VpcPeeringConnectionIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAccepter(value *VpcPeeringConnectionOptionsAccepter)
PutRequester(value *VpcPeeringConnectionOptionsRequester)
ResetAccepter()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRequester()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options aws_vpc_peering_connection_options}.
func NewVpcPeeringConnectionOptions ¶
func NewVpcPeeringConnectionOptions(scope constructs.Construct, id *string, config *VpcPeeringConnectionOptionsConfig) VpcPeeringConnectionOptions
Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options aws_vpc_peering_connection_options} Resource.
type VpcPeeringConnectionOptionsAccepter ¶
type VpcPeeringConnectionOptionsAccepter struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options#allow_classic_link_to_remote_vpc VpcPeeringConnectionOptions#allow_classic_link_to_remote_vpc}.
AllowClassicLinkToRemoteVpc interface{} `field:"optional" json:"allowClassicLinkToRemoteVpc" yaml:"allowClassicLinkToRemoteVpc"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options#allow_remote_vpc_dns_resolution VpcPeeringConnectionOptions#allow_remote_vpc_dns_resolution}.
AllowRemoteVpcDnsResolution interface{} `field:"optional" json:"allowRemoteVpcDnsResolution" yaml:"allowRemoteVpcDnsResolution"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options#allow_vpc_to_remote_classic_link VpcPeeringConnectionOptions#allow_vpc_to_remote_classic_link}.
AllowVpcToRemoteClassicLink interface{} `field:"optional" json:"allowVpcToRemoteClassicLink" yaml:"allowVpcToRemoteClassicLink"`
}
type VpcPeeringConnectionOptionsAccepterOutputReference ¶
type VpcPeeringConnectionOptionsAccepterOutputReference interface {
cdktf.ComplexObject
AllowClassicLinkToRemoteVpc() interface{}
SetAllowClassicLinkToRemoteVpc(val interface{})
AllowClassicLinkToRemoteVpcInput() interface{}
AllowRemoteVpcDnsResolution() interface{}
SetAllowRemoteVpcDnsResolution(val interface{})
AllowRemoteVpcDnsResolutionInput() interface{}
AllowVpcToRemoteClassicLink() interface{}
SetAllowVpcToRemoteClassicLink(val interface{})
AllowVpcToRemoteClassicLinkInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *VpcPeeringConnectionOptionsAccepter
SetInternalValue(val *VpcPeeringConnectionOptionsAccepter)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAllowClassicLinkToRemoteVpc()
ResetAllowRemoteVpcDnsResolution()
ResetAllowVpcToRemoteClassicLink()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpcPeeringConnectionOptionsAccepterOutputReference ¶
func NewVpcPeeringConnectionOptionsAccepterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VpcPeeringConnectionOptionsAccepterOutputReference
type VpcPeeringConnectionOptionsConfig ¶
type VpcPeeringConnectionOptionsConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options#vpc_peering_connection_id VpcPeeringConnectionOptions#vpc_peering_connection_id}.
VpcPeeringConnectionId *string `field:"required" json:"vpcPeeringConnectionId" yaml:"vpcPeeringConnectionId"`
// accepter block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options#accepter VpcPeeringConnectionOptions#accepter}
Accepter *VpcPeeringConnectionOptionsAccepter `field:"optional" json:"accepter" yaml:"accepter"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options#id VpcPeeringConnectionOptions#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// requester block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options#requester VpcPeeringConnectionOptions#requester}
Requester *VpcPeeringConnectionOptionsRequester `field:"optional" json:"requester" yaml:"requester"`
}
type VpcPeeringConnectionOptionsRequester ¶
type VpcPeeringConnectionOptionsRequester struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options#allow_classic_link_to_remote_vpc VpcPeeringConnectionOptions#allow_classic_link_to_remote_vpc}.
AllowClassicLinkToRemoteVpc interface{} `field:"optional" json:"allowClassicLinkToRemoteVpc" yaml:"allowClassicLinkToRemoteVpc"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options#allow_remote_vpc_dns_resolution VpcPeeringConnectionOptions#allow_remote_vpc_dns_resolution}.
AllowRemoteVpcDnsResolution interface{} `field:"optional" json:"allowRemoteVpcDnsResolution" yaml:"allowRemoteVpcDnsResolution"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options#allow_vpc_to_remote_classic_link VpcPeeringConnectionOptions#allow_vpc_to_remote_classic_link}.
AllowVpcToRemoteClassicLink interface{} `field:"optional" json:"allowVpcToRemoteClassicLink" yaml:"allowVpcToRemoteClassicLink"`
}
type VpcPeeringConnectionOptionsRequesterOutputReference ¶
type VpcPeeringConnectionOptionsRequesterOutputReference interface {
cdktf.ComplexObject
AllowClassicLinkToRemoteVpc() interface{}
SetAllowClassicLinkToRemoteVpc(val interface{})
AllowClassicLinkToRemoteVpcInput() interface{}
AllowRemoteVpcDnsResolution() interface{}
SetAllowRemoteVpcDnsResolution(val interface{})
AllowRemoteVpcDnsResolutionInput() interface{}
AllowVpcToRemoteClassicLink() interface{}
SetAllowVpcToRemoteClassicLink(val interface{})
AllowVpcToRemoteClassicLinkInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *VpcPeeringConnectionOptionsRequester
SetInternalValue(val *VpcPeeringConnectionOptionsRequester)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAllowClassicLinkToRemoteVpc()
ResetAllowRemoteVpcDnsResolution()
ResetAllowVpcToRemoteClassicLink()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpcPeeringConnectionOptionsRequesterOutputReference ¶
func NewVpcPeeringConnectionOptionsRequesterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VpcPeeringConnectionOptionsRequesterOutputReference
Source Files
¶
- vpcpeeringconnectionoptions.go
- vpcpeeringconnectionoptions_VpcPeeringConnectionOptions.go
- vpcpeeringconnectionoptions_VpcPeeringConnectionOptionsAccepter.go
- vpcpeeringconnectionoptions_VpcPeeringConnectionOptionsAccepterOutputReference.go
- vpcpeeringconnectionoptions_VpcPeeringConnectionOptionsAccepterOutputReference__runtime_type_checks.go
- vpcpeeringconnectionoptions_VpcPeeringConnectionOptionsConfig.go
- vpcpeeringconnectionoptions_VpcPeeringConnectionOptionsRequester.go
- vpcpeeringconnectionoptions_VpcPeeringConnectionOptionsRequesterOutputReference.go
- vpcpeeringconnectionoptions_VpcPeeringConnectionOptionsRequesterOutputReference__runtime_type_checks.go
- vpcpeeringconnectionoptions_VpcPeeringConnectionOptions__runtime_type_checks.go