Documentation
¶
Index ¶
- func AlbTargetGroup_IsConstruct(x interface{}) *bool
- func AlbTargetGroup_IsTerraformElement(x interface{}) *bool
- func AlbTargetGroup_IsTerraformResource(x interface{}) *bool
- func AlbTargetGroup_TfResourceType() *string
- func NewAlbTargetGroupHealthCheckOutputReference_Override(a AlbTargetGroupHealthCheckOutputReference, ...)
- func NewAlbTargetGroupStickinessOutputReference_Override(a AlbTargetGroupStickinessOutputReference, ...)
- func NewAlbTargetGroupTargetFailoverList_Override(a AlbTargetGroupTargetFailoverList, ...)
- func NewAlbTargetGroupTargetFailoverOutputReference_Override(a AlbTargetGroupTargetFailoverOutputReference, ...)
- func NewAlbTargetGroup_Override(a AlbTargetGroup, scope constructs.Construct, id *string, ...)
- type AlbTargetGroup
- type AlbTargetGroupConfig
- type AlbTargetGroupHealthCheck
- type AlbTargetGroupHealthCheckOutputReference
- type AlbTargetGroupStickiness
- type AlbTargetGroupStickinessOutputReference
- type AlbTargetGroupTargetFailover
- type AlbTargetGroupTargetFailoverList
- type AlbTargetGroupTargetFailoverOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AlbTargetGroup_IsConstruct ¶
func AlbTargetGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AlbTargetGroup_IsTerraformElement ¶
func AlbTargetGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func AlbTargetGroup_IsTerraformResource ¶
func AlbTargetGroup_IsTerraformResource(x interface{}) *bool
Experimental.
func AlbTargetGroup_TfResourceType ¶
func AlbTargetGroup_TfResourceType() *string
func NewAlbTargetGroupHealthCheckOutputReference_Override ¶
func NewAlbTargetGroupHealthCheckOutputReference_Override(a AlbTargetGroupHealthCheckOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAlbTargetGroupStickinessOutputReference_Override ¶
func NewAlbTargetGroupStickinessOutputReference_Override(a AlbTargetGroupStickinessOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAlbTargetGroupTargetFailoverList_Override ¶
func NewAlbTargetGroupTargetFailoverList_Override(a AlbTargetGroupTargetFailoverList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAlbTargetGroupTargetFailoverOutputReference_Override ¶
func NewAlbTargetGroupTargetFailoverOutputReference_Override(a AlbTargetGroupTargetFailoverOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAlbTargetGroup_Override ¶
func NewAlbTargetGroup_Override(a AlbTargetGroup, scope constructs.Construct, id *string, config *AlbTargetGroupConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group aws_alb_target_group} Resource.
Types ¶
type AlbTargetGroup ¶
type AlbTargetGroup interface {
cdktf.TerraformResource
Arn() *string
ArnSuffix() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
ConnectionTermination() interface{}
SetConnectionTermination(val interface{})
ConnectionTerminationInput() interface{}
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeregistrationDelay() *string
SetDeregistrationDelay(val *string)
DeregistrationDelayInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HealthCheck() AlbTargetGroupHealthCheckOutputReference
HealthCheckInput() *AlbTargetGroupHealthCheck
Id() *string
SetId(val *string)
IdInput() *string
IpAddressType() *string
SetIpAddressType(val *string)
IpAddressTypeInput() *string
LambdaMultiValueHeadersEnabled() interface{}
SetLambdaMultiValueHeadersEnabled(val interface{})
LambdaMultiValueHeadersEnabledInput() interface{}
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LoadBalancingAlgorithmType() *string
SetLoadBalancingAlgorithmType(val *string)
LoadBalancingAlgorithmTypeInput() *string
LoadBalancingCrossZoneEnabled() *string
SetLoadBalancingCrossZoneEnabled(val *string)
LoadBalancingCrossZoneEnabledInput() *string
Name() *string
SetName(val *string)
NameInput() *string
NamePrefix() *string
SetNamePrefix(val *string)
NamePrefixInput() *string
// The tree node.
Node() constructs.Node
Port() *float64
SetPort(val *float64)
PortInput() *float64
PreserveClientIp() *string
SetPreserveClientIp(val *string)
PreserveClientIpInput() *string
Protocol() *string
SetProtocol(val *string)
ProtocolInput() *string
ProtocolVersion() *string
SetProtocolVersion(val *string)
ProtocolVersionInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
ProxyProtocolV2() interface{}
SetProxyProtocolV2(val interface{})
ProxyProtocolV2Input() interface{}
// Experimental.
RawOverrides() interface{}
SlowStart() *float64
SetSlowStart(val *float64)
SlowStartInput() *float64
Stickiness() AlbTargetGroupStickinessOutputReference
StickinessInput() *AlbTargetGroupStickiness
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
TargetFailover() AlbTargetGroupTargetFailoverList
TargetFailoverInput() interface{}
TargetType() *string
SetTargetType(val *string)
TargetTypeInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
VpcId() *string
SetVpcId(val *string)
VpcIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutHealthCheck(value *AlbTargetGroupHealthCheck)
PutStickiness(value *AlbTargetGroupStickiness)
PutTargetFailover(value interface{})
ResetConnectionTermination()
ResetDeregistrationDelay()
ResetHealthCheck()
ResetId()
ResetIpAddressType()
ResetLambdaMultiValueHeadersEnabled()
ResetLoadBalancingAlgorithmType()
ResetLoadBalancingCrossZoneEnabled()
ResetName()
ResetNamePrefix()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPort()
ResetPreserveClientIp()
ResetProtocol()
ResetProtocolVersion()
ResetProxyProtocolV2()
ResetSlowStart()
ResetStickiness()
ResetTags()
ResetTagsAll()
ResetTargetFailover()
ResetTargetType()
ResetVpcId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group aws_alb_target_group}.
func NewAlbTargetGroup ¶
func NewAlbTargetGroup(scope constructs.Construct, id *string, config *AlbTargetGroupConfig) AlbTargetGroup
Create a new {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group aws_alb_target_group} Resource.
type AlbTargetGroupConfig ¶
type AlbTargetGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#connection_termination AlbTargetGroup#connection_termination}.
ConnectionTermination interface{} `field:"optional" json:"connectionTermination" yaml:"connectionTermination"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#deregistration_delay AlbTargetGroup#deregistration_delay}.
DeregistrationDelay *string `field:"optional" json:"deregistrationDelay" yaml:"deregistrationDelay"`
// health_check block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#health_check AlbTargetGroup#health_check}
HealthCheck *AlbTargetGroupHealthCheck `field:"optional" json:"healthCheck" yaml:"healthCheck"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#id AlbTargetGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#ip_address_type AlbTargetGroup#ip_address_type}.
IpAddressType *string `field:"optional" json:"ipAddressType" yaml:"ipAddressType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#lambda_multi_value_headers_enabled AlbTargetGroup#lambda_multi_value_headers_enabled}.
LambdaMultiValueHeadersEnabled interface{} `field:"optional" json:"lambdaMultiValueHeadersEnabled" yaml:"lambdaMultiValueHeadersEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#load_balancing_algorithm_type AlbTargetGroup#load_balancing_algorithm_type}.
LoadBalancingAlgorithmType *string `field:"optional" json:"loadBalancingAlgorithmType" yaml:"loadBalancingAlgorithmType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#load_balancing_cross_zone_enabled AlbTargetGroup#load_balancing_cross_zone_enabled}.
LoadBalancingCrossZoneEnabled *string `field:"optional" json:"loadBalancingCrossZoneEnabled" yaml:"loadBalancingCrossZoneEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#name AlbTargetGroup#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#name_prefix AlbTargetGroup#name_prefix}.
NamePrefix *string `field:"optional" json:"namePrefix" yaml:"namePrefix"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#port AlbTargetGroup#port}.
Port *float64 `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#preserve_client_ip AlbTargetGroup#preserve_client_ip}.
PreserveClientIp *string `field:"optional" json:"preserveClientIp" yaml:"preserveClientIp"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#protocol AlbTargetGroup#protocol}.
Protocol *string `field:"optional" json:"protocol" yaml:"protocol"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#protocol_version AlbTargetGroup#protocol_version}.
ProtocolVersion *string `field:"optional" json:"protocolVersion" yaml:"protocolVersion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#proxy_protocol_v2 AlbTargetGroup#proxy_protocol_v2}.
ProxyProtocolV2 interface{} `field:"optional" json:"proxyProtocolV2" yaml:"proxyProtocolV2"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#slow_start AlbTargetGroup#slow_start}.
SlowStart *float64 `field:"optional" json:"slowStart" yaml:"slowStart"`
// stickiness block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#stickiness AlbTargetGroup#stickiness}
Stickiness *AlbTargetGroupStickiness `field:"optional" json:"stickiness" yaml:"stickiness"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#tags AlbTargetGroup#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#tags_all AlbTargetGroup#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// target_failover block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#target_failover AlbTargetGroup#target_failover}
TargetFailover interface{} `field:"optional" json:"targetFailover" yaml:"targetFailover"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#target_type AlbTargetGroup#target_type}.
TargetType *string `field:"optional" json:"targetType" yaml:"targetType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#vpc_id AlbTargetGroup#vpc_id}.
VpcId *string `field:"optional" json:"vpcId" yaml:"vpcId"`
}
type AlbTargetGroupHealthCheck ¶
type AlbTargetGroupHealthCheck struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#enabled AlbTargetGroup#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#healthy_threshold AlbTargetGroup#healthy_threshold}.
HealthyThreshold *float64 `field:"optional" json:"healthyThreshold" yaml:"healthyThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#interval AlbTargetGroup#interval}.
Interval *float64 `field:"optional" json:"interval" yaml:"interval"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#matcher AlbTargetGroup#matcher}.
Matcher *string `field:"optional" json:"matcher" yaml:"matcher"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#path AlbTargetGroup#path}.
Path *string `field:"optional" json:"path" yaml:"path"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#port AlbTargetGroup#port}.
Port *string `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#protocol AlbTargetGroup#protocol}.
Protocol *string `field:"optional" json:"protocol" yaml:"protocol"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#timeout AlbTargetGroup#timeout}.
Timeout *float64 `field:"optional" json:"timeout" yaml:"timeout"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#unhealthy_threshold AlbTargetGroup#unhealthy_threshold}.
UnhealthyThreshold *float64 `field:"optional" json:"unhealthyThreshold" yaml:"unhealthyThreshold"`
}
type AlbTargetGroupHealthCheckOutputReference ¶
type AlbTargetGroupHealthCheckOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
HealthyThreshold() *float64
SetHealthyThreshold(val *float64)
HealthyThresholdInput() *float64
InternalValue() *AlbTargetGroupHealthCheck
SetInternalValue(val *AlbTargetGroupHealthCheck)
Interval() *float64
SetInterval(val *float64)
IntervalInput() *float64
Matcher() *string
SetMatcher(val *string)
MatcherInput() *string
Path() *string
SetPath(val *string)
PathInput() *string
Port() *string
SetPort(val *string)
PortInput() *string
Protocol() *string
SetProtocol(val *string)
ProtocolInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Timeout() *float64
SetTimeout(val *float64)
TimeoutInput() *float64
UnhealthyThreshold() *float64
SetUnhealthyThreshold(val *float64)
UnhealthyThresholdInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnabled()
ResetHealthyThreshold()
ResetInterval()
ResetMatcher()
ResetPath()
ResetPort()
ResetProtocol()
ResetTimeout()
ResetUnhealthyThreshold()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlbTargetGroupHealthCheckOutputReference ¶
func NewAlbTargetGroupHealthCheckOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AlbTargetGroupHealthCheckOutputReference
type AlbTargetGroupStickiness ¶
type AlbTargetGroupStickiness struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#type AlbTargetGroup#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#cookie_duration AlbTargetGroup#cookie_duration}.
CookieDuration *float64 `field:"optional" json:"cookieDuration" yaml:"cookieDuration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#cookie_name AlbTargetGroup#cookie_name}.
CookieName *string `field:"optional" json:"cookieName" yaml:"cookieName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#enabled AlbTargetGroup#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
}
type AlbTargetGroupStickinessOutputReference ¶
type AlbTargetGroupStickinessOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CookieDuration() *float64
SetCookieDuration(val *float64)
CookieDurationInput() *float64
CookieName() *string
SetCookieName(val *string)
CookieNameInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *AlbTargetGroupStickiness
SetInternalValue(val *AlbTargetGroupStickiness)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCookieDuration()
ResetCookieName()
ResetEnabled()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlbTargetGroupStickinessOutputReference ¶
func NewAlbTargetGroupStickinessOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AlbTargetGroupStickinessOutputReference
type AlbTargetGroupTargetFailover ¶
type AlbTargetGroupTargetFailover struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#on_deregistration AlbTargetGroup#on_deregistration}.
OnDeregistration *string `field:"required" json:"onDeregistration" yaml:"onDeregistration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group#on_unhealthy AlbTargetGroup#on_unhealthy}.
OnUnhealthy *string `field:"required" json:"onUnhealthy" yaml:"onUnhealthy"`
}
type AlbTargetGroupTargetFailoverList ¶
type AlbTargetGroupTargetFailoverList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) AlbTargetGroupTargetFailoverOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlbTargetGroupTargetFailoverList ¶
func NewAlbTargetGroupTargetFailoverList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AlbTargetGroupTargetFailoverList
type AlbTargetGroupTargetFailoverOutputReference ¶
type AlbTargetGroupTargetFailoverOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
OnDeregistration() *string
SetOnDeregistration(val *string)
OnDeregistrationInput() *string
OnUnhealthy() *string
SetOnUnhealthy(val *string)
OnUnhealthyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlbTargetGroupTargetFailoverOutputReference ¶
func NewAlbTargetGroupTargetFailoverOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AlbTargetGroupTargetFailoverOutputReference
Source Files
¶
- AlbTargetGroup.go
- AlbTargetGroupConfig.go
- AlbTargetGroupHealthCheck.go
- AlbTargetGroupHealthCheckOutputReference.go
- AlbTargetGroupHealthCheckOutputReference__checks.go
- AlbTargetGroupStickiness.go
- AlbTargetGroupStickinessOutputReference.go
- AlbTargetGroupStickinessOutputReference__checks.go
- AlbTargetGroupTargetFailover.go
- AlbTargetGroupTargetFailoverList.go
- AlbTargetGroupTargetFailoverList__checks.go
- AlbTargetGroupTargetFailoverOutputReference.go
- AlbTargetGroupTargetFailoverOutputReference__checks.go
- AlbTargetGroup__checks.go
- main.go