Documentation
¶
Index ¶
- func ApiGatewayMethod_IsConstruct(x interface{}) *bool
- func ApiGatewayMethod_IsTerraformElement(x interface{}) *bool
- func ApiGatewayMethod_IsTerraformResource(x interface{}) *bool
- func ApiGatewayMethod_TfResourceType() *string
- func NewApiGatewayMethod_Override(a ApiGatewayMethod, scope constructs.Construct, id *string, ...)
- type ApiGatewayMethod
- type ApiGatewayMethodConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ApiGatewayMethod_IsConstruct ¶
func ApiGatewayMethod_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ApiGatewayMethod_IsTerraformElement ¶
func ApiGatewayMethod_IsTerraformElement(x interface{}) *bool
Experimental.
func ApiGatewayMethod_IsTerraformResource ¶
func ApiGatewayMethod_IsTerraformResource(x interface{}) *bool
Experimental.
func ApiGatewayMethod_TfResourceType ¶
func ApiGatewayMethod_TfResourceType() *string
func NewApiGatewayMethod_Override ¶
func NewApiGatewayMethod_Override(a ApiGatewayMethod, scope constructs.Construct, id *string, config *ApiGatewayMethodConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method aws_api_gateway_method} Resource.
Types ¶
type ApiGatewayMethod ¶
type ApiGatewayMethod interface {
cdktf.TerraformResource
ApiKeyRequired() interface{}
SetApiKeyRequired(val interface{})
ApiKeyRequiredInput() interface{}
Authorization() *string
SetAuthorization(val *string)
AuthorizationInput() *string
AuthorizationScopes() *[]*string
SetAuthorizationScopes(val *[]*string)
AuthorizationScopesInput() *[]*string
AuthorizerId() *string
SetAuthorizerId(val *string)
AuthorizerIdInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HttpMethod() *string
SetHttpMethod(val *string)
HttpMethodInput() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
OperationName() *string
SetOperationName(val *string)
OperationNameInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RequestModels() *map[string]*string
SetRequestModels(val *map[string]*string)
RequestModelsInput() *map[string]*string
RequestParameters() *map[string]interface{}
SetRequestParameters(val *map[string]interface{})
RequestParametersInput() *map[string]interface{}
RequestValidatorId() *string
SetRequestValidatorId(val *string)
RequestValidatorIdInput() *string
ResourceId() *string
SetResourceId(val *string)
ResourceIdInput() *string
RestApiId() *string
SetRestApiId(val *string)
RestApiIdInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetApiKeyRequired()
ResetAuthorizationScopes()
ResetAuthorizerId()
ResetId()
ResetOperationName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRequestModels()
ResetRequestParameters()
ResetRequestValidatorId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method aws_api_gateway_method}.
func NewApiGatewayMethod ¶
func NewApiGatewayMethod(scope constructs.Construct, id *string, config *ApiGatewayMethodConfig) ApiGatewayMethod
Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method aws_api_gateway_method} Resource.
type ApiGatewayMethodConfig ¶
type ApiGatewayMethodConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#authorization ApiGatewayMethod#authorization}.
Authorization *string `field:"required" json:"authorization" yaml:"authorization"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#http_method ApiGatewayMethod#http_method}.
HttpMethod *string `field:"required" json:"httpMethod" yaml:"httpMethod"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#resource_id ApiGatewayMethod#resource_id}.
ResourceId *string `field:"required" json:"resourceId" yaml:"resourceId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#rest_api_id ApiGatewayMethod#rest_api_id}.
RestApiId *string `field:"required" json:"restApiId" yaml:"restApiId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#api_key_required ApiGatewayMethod#api_key_required}.
ApiKeyRequired interface{} `field:"optional" json:"apiKeyRequired" yaml:"apiKeyRequired"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#authorization_scopes ApiGatewayMethod#authorization_scopes}.
AuthorizationScopes *[]*string `field:"optional" json:"authorizationScopes" yaml:"authorizationScopes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#authorizer_id ApiGatewayMethod#authorizer_id}.
AuthorizerId *string `field:"optional" json:"authorizerId" yaml:"authorizerId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#id ApiGatewayMethod#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#operation_name ApiGatewayMethod#operation_name}.
OperationName *string `field:"optional" json:"operationName" yaml:"operationName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#request_models ApiGatewayMethod#request_models}.
RequestModels *map[string]*string `field:"optional" json:"requestModels" yaml:"requestModels"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#request_parameters ApiGatewayMethod#request_parameters}.
RequestParameters *map[string]interface{} `field:"optional" json:"requestParameters" yaml:"requestParameters"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method#request_validator_id ApiGatewayMethod#request_validator_id}.
RequestValidatorId *string `field:"optional" json:"requestValidatorId" yaml:"requestValidatorId"`
}