Documentation
¶
Index ¶
- func ApiGatewayMethodSettings_IsConstruct(x interface{}) *bool
- func ApiGatewayMethodSettings_IsTerraformElement(x interface{}) *bool
- func ApiGatewayMethodSettings_IsTerraformResource(x interface{}) *bool
- func ApiGatewayMethodSettings_TfResourceType() *string
- func NewApiGatewayMethodSettingsSettingsOutputReference_Override(a ApiGatewayMethodSettingsSettingsOutputReference, ...)
- func NewApiGatewayMethodSettings_Override(a ApiGatewayMethodSettings, scope constructs.Construct, id *string, ...)
- type ApiGatewayMethodSettings
- type ApiGatewayMethodSettingsConfig
- type ApiGatewayMethodSettingsSettings
- type ApiGatewayMethodSettingsSettingsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ApiGatewayMethodSettings_IsConstruct ¶
func ApiGatewayMethodSettings_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ApiGatewayMethodSettings_IsTerraformElement ¶
func ApiGatewayMethodSettings_IsTerraformElement(x interface{}) *bool
Experimental.
func ApiGatewayMethodSettings_IsTerraformResource ¶
func ApiGatewayMethodSettings_IsTerraformResource(x interface{}) *bool
Experimental.
func ApiGatewayMethodSettings_TfResourceType ¶
func ApiGatewayMethodSettings_TfResourceType() *string
func NewApiGatewayMethodSettingsSettingsOutputReference_Override ¶
func NewApiGatewayMethodSettingsSettingsOutputReference_Override(a ApiGatewayMethodSettingsSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewApiGatewayMethodSettings_Override ¶
func NewApiGatewayMethodSettings_Override(a ApiGatewayMethodSettings, scope constructs.Construct, id *string, config *ApiGatewayMethodSettingsConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings aws_api_gateway_method_settings} Resource.
Types ¶
type ApiGatewayMethodSettings ¶
type ApiGatewayMethodSettings interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MethodPath() *string
SetMethodPath(val *string)
MethodPathInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RestApiId() *string
SetRestApiId(val *string)
RestApiIdInput() *string
Settings() ApiGatewayMethodSettingsSettingsOutputReference
SettingsInput() *ApiGatewayMethodSettingsSettings
StageName() *string
SetStageName(val *string)
StageNameInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutSettings(value *ApiGatewayMethodSettingsSettings)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings aws_api_gateway_method_settings}.
func NewApiGatewayMethodSettings ¶
func NewApiGatewayMethodSettings(scope constructs.Construct, id *string, config *ApiGatewayMethodSettingsConfig) ApiGatewayMethodSettings
Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings aws_api_gateway_method_settings} Resource.
type ApiGatewayMethodSettingsConfig ¶
type ApiGatewayMethodSettingsConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#method_path ApiGatewayMethodSettings#method_path}.
MethodPath *string `field:"required" json:"methodPath" yaml:"methodPath"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#rest_api_id ApiGatewayMethodSettings#rest_api_id}.
RestApiId *string `field:"required" json:"restApiId" yaml:"restApiId"`
// settings block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#settings ApiGatewayMethodSettings#settings}
Settings *ApiGatewayMethodSettingsSettings `field:"required" json:"settings" yaml:"settings"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#stage_name ApiGatewayMethodSettings#stage_name}.
StageName *string `field:"required" json:"stageName" yaml:"stageName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#id ApiGatewayMethodSettings#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type ApiGatewayMethodSettingsSettings ¶
type ApiGatewayMethodSettingsSettings struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#cache_data_encrypted ApiGatewayMethodSettings#cache_data_encrypted}.
CacheDataEncrypted interface{} `field:"optional" json:"cacheDataEncrypted" yaml:"cacheDataEncrypted"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#cache_ttl_in_seconds ApiGatewayMethodSettings#cache_ttl_in_seconds}.
CacheTtlInSeconds *float64 `field:"optional" json:"cacheTtlInSeconds" yaml:"cacheTtlInSeconds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#caching_enabled ApiGatewayMethodSettings#caching_enabled}.
CachingEnabled interface{} `field:"optional" json:"cachingEnabled" yaml:"cachingEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#data_trace_enabled ApiGatewayMethodSettings#data_trace_enabled}.
DataTraceEnabled interface{} `field:"optional" json:"dataTraceEnabled" yaml:"dataTraceEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#logging_level ApiGatewayMethodSettings#logging_level}.
LoggingLevel *string `field:"optional" json:"loggingLevel" yaml:"loggingLevel"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#metrics_enabled ApiGatewayMethodSettings#metrics_enabled}.
MetricsEnabled interface{} `field:"optional" json:"metricsEnabled" yaml:"metricsEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#require_authorization_for_cache_control ApiGatewayMethodSettings#require_authorization_for_cache_control}.
RequireAuthorizationForCacheControl interface{} `field:"optional" json:"requireAuthorizationForCacheControl" yaml:"requireAuthorizationForCacheControl"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#throttling_burst_limit ApiGatewayMethodSettings#throttling_burst_limit}.
ThrottlingBurstLimit *float64 `field:"optional" json:"throttlingBurstLimit" yaml:"throttlingBurstLimit"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#throttling_rate_limit ApiGatewayMethodSettings#throttling_rate_limit}.
ThrottlingRateLimit *float64 `field:"optional" json:"throttlingRateLimit" yaml:"throttlingRateLimit"`
UnauthorizedCacheControlHeaderStrategy *string `field:"optional" json:"unauthorizedCacheControlHeaderStrategy" yaml:"unauthorizedCacheControlHeaderStrategy"`
}
type ApiGatewayMethodSettingsSettingsOutputReference ¶
type ApiGatewayMethodSettingsSettingsOutputReference interface {
cdktf.ComplexObject
CacheDataEncrypted() interface{}
SetCacheDataEncrypted(val interface{})
CacheDataEncryptedInput() interface{}
CacheTtlInSeconds() *float64
SetCacheTtlInSeconds(val *float64)
CacheTtlInSecondsInput() *float64
CachingEnabled() interface{}
SetCachingEnabled(val interface{})
CachingEnabledInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DataTraceEnabled() interface{}
SetDataTraceEnabled(val interface{})
DataTraceEnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *ApiGatewayMethodSettingsSettings
SetInternalValue(val *ApiGatewayMethodSettingsSettings)
LoggingLevel() *string
SetLoggingLevel(val *string)
LoggingLevelInput() *string
MetricsEnabled() interface{}
SetMetricsEnabled(val interface{})
MetricsEnabledInput() interface{}
RequireAuthorizationForCacheControl() interface{}
SetRequireAuthorizationForCacheControl(val interface{})
RequireAuthorizationForCacheControlInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ThrottlingBurstLimit() *float64
SetThrottlingBurstLimit(val *float64)
ThrottlingBurstLimitInput() *float64
ThrottlingRateLimit() *float64
SetThrottlingRateLimit(val *float64)
ThrottlingRateLimitInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCacheDataEncrypted()
ResetCacheTtlInSeconds()
ResetCachingEnabled()
ResetDataTraceEnabled()
ResetLoggingLevel()
ResetMetricsEnabled()
ResetRequireAuthorizationForCacheControl()
ResetThrottlingBurstLimit()
ResetThrottlingRateLimit()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApiGatewayMethodSettingsSettingsOutputReference ¶
func NewApiGatewayMethodSettingsSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ApiGatewayMethodSettingsSettingsOutputReference