Documentation
¶
Index ¶
- func AppsyncGraphqlApi_IsConstruct(x interface{}) *bool
- func AppsyncGraphqlApi_IsTerraformElement(x interface{}) *bool
- func AppsyncGraphqlApi_IsTerraformResource(x interface{}) *bool
- func AppsyncGraphqlApi_TfResourceType() *string
- func NewAppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfigOutputReference_Override(...)
- func NewAppsyncGraphqlApiAdditionalAuthenticationProviderList_Override(a AppsyncGraphqlApiAdditionalAuthenticationProviderList, ...)
- func NewAppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfigOutputReference_Override(...)
- func NewAppsyncGraphqlApiAdditionalAuthenticationProviderOutputReference_Override(a AppsyncGraphqlApiAdditionalAuthenticationProviderOutputReference, ...)
- func NewAppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfigOutputReference_Override(...)
- func NewAppsyncGraphqlApiLambdaAuthorizerConfigOutputReference_Override(a AppsyncGraphqlApiLambdaAuthorizerConfigOutputReference, ...)
- func NewAppsyncGraphqlApiLogConfigOutputReference_Override(a AppsyncGraphqlApiLogConfigOutputReference, ...)
- func NewAppsyncGraphqlApiOpenidConnectConfigOutputReference_Override(a AppsyncGraphqlApiOpenidConnectConfigOutputReference, ...)
- func NewAppsyncGraphqlApiUserPoolConfigOutputReference_Override(a AppsyncGraphqlApiUserPoolConfigOutputReference, ...)
- func NewAppsyncGraphqlApi_Override(a AppsyncGraphqlApi, scope constructs.Construct, id *string, ...)
- type AppsyncGraphqlApi
- type AppsyncGraphqlApiAdditionalAuthenticationProvider
- type AppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfig
- type AppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfigOutputReference
- type AppsyncGraphqlApiAdditionalAuthenticationProviderList
- type AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfig
- type AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfigOutputReference
- type AppsyncGraphqlApiAdditionalAuthenticationProviderOutputReference
- type AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig
- type AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfigOutputReference
- type AppsyncGraphqlApiConfig
- type AppsyncGraphqlApiLambdaAuthorizerConfig
- type AppsyncGraphqlApiLambdaAuthorizerConfigOutputReference
- type AppsyncGraphqlApiLogConfig
- type AppsyncGraphqlApiLogConfigOutputReference
- type AppsyncGraphqlApiOpenidConnectConfig
- type AppsyncGraphqlApiOpenidConnectConfigOutputReference
- type AppsyncGraphqlApiUserPoolConfig
- type AppsyncGraphqlApiUserPoolConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AppsyncGraphqlApi_IsConstruct ¶
func AppsyncGraphqlApi_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AppsyncGraphqlApi_IsTerraformElement ¶
func AppsyncGraphqlApi_IsTerraformElement(x interface{}) *bool
Experimental.
func AppsyncGraphqlApi_IsTerraformResource ¶
func AppsyncGraphqlApi_IsTerraformResource(x interface{}) *bool
Experimental.
func AppsyncGraphqlApi_TfResourceType ¶
func AppsyncGraphqlApi_TfResourceType() *string
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfigOutputReference_Override ¶
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfigOutputReference_Override(a AppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderList_Override ¶
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderList_Override(a AppsyncGraphqlApiAdditionalAuthenticationProviderList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfigOutputReference_Override ¶
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfigOutputReference_Override(a AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderOutputReference_Override ¶
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderOutputReference_Override(a AppsyncGraphqlApiAdditionalAuthenticationProviderOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfigOutputReference_Override ¶
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfigOutputReference_Override(a AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppsyncGraphqlApiLambdaAuthorizerConfigOutputReference_Override ¶
func NewAppsyncGraphqlApiLambdaAuthorizerConfigOutputReference_Override(a AppsyncGraphqlApiLambdaAuthorizerConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppsyncGraphqlApiLogConfigOutputReference_Override ¶
func NewAppsyncGraphqlApiLogConfigOutputReference_Override(a AppsyncGraphqlApiLogConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppsyncGraphqlApiOpenidConnectConfigOutputReference_Override ¶
func NewAppsyncGraphqlApiOpenidConnectConfigOutputReference_Override(a AppsyncGraphqlApiOpenidConnectConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppsyncGraphqlApiUserPoolConfigOutputReference_Override ¶
func NewAppsyncGraphqlApiUserPoolConfigOutputReference_Override(a AppsyncGraphqlApiUserPoolConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppsyncGraphqlApi_Override ¶
func NewAppsyncGraphqlApi_Override(a AppsyncGraphqlApi, scope constructs.Construct, id *string, config *AppsyncGraphqlApiConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api aws_appsync_graphql_api} Resource.
Types ¶
type AppsyncGraphqlApi ¶
type AppsyncGraphqlApi interface {
cdktf.TerraformResource
AdditionalAuthenticationProvider() AppsyncGraphqlApiAdditionalAuthenticationProviderList
AdditionalAuthenticationProviderInput() interface{}
Arn() *string
AuthenticationType() *string
SetAuthenticationType(val *string)
AuthenticationTypeInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
LambdaAuthorizerConfig() AppsyncGraphqlApiLambdaAuthorizerConfigOutputReference
LambdaAuthorizerConfigInput() *AppsyncGraphqlApiLambdaAuthorizerConfig
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LogConfig() AppsyncGraphqlApiLogConfigOutputReference
LogConfigInput() *AppsyncGraphqlApiLogConfig
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
OpenidConnectConfig() AppsyncGraphqlApiOpenidConnectConfigOutputReference
OpenidConnectConfigInput() *AppsyncGraphqlApiOpenidConnectConfig
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Schema() *string
SetSchema(val *string)
SchemaInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Uris() cdktf.StringMap
UserPoolConfig() AppsyncGraphqlApiUserPoolConfigOutputReference
UserPoolConfigInput() *AppsyncGraphqlApiUserPoolConfig
XrayEnabled() interface{}
SetXrayEnabled(val interface{})
XrayEnabledInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAdditionalAuthenticationProvider(value interface{})
PutLambdaAuthorizerConfig(value *AppsyncGraphqlApiLambdaAuthorizerConfig)
PutLogConfig(value *AppsyncGraphqlApiLogConfig)
PutOpenidConnectConfig(value *AppsyncGraphqlApiOpenidConnectConfig)
PutUserPoolConfig(value *AppsyncGraphqlApiUserPoolConfig)
ResetAdditionalAuthenticationProvider()
ResetId()
ResetLambdaAuthorizerConfig()
ResetLogConfig()
ResetOpenidConnectConfig()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSchema()
ResetTags()
ResetTagsAll()
ResetUserPoolConfig()
ResetXrayEnabled()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api aws_appsync_graphql_api}.
func NewAppsyncGraphqlApi ¶
func NewAppsyncGraphqlApi(scope constructs.Construct, id *string, config *AppsyncGraphqlApiConfig) AppsyncGraphqlApi
Create a new {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api aws_appsync_graphql_api} Resource.
type AppsyncGraphqlApiAdditionalAuthenticationProvider ¶
type AppsyncGraphqlApiAdditionalAuthenticationProvider struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#authentication_type AppsyncGraphqlApi#authentication_type}.
AuthenticationType *string `field:"required" json:"authenticationType" yaml:"authenticationType"`
// lambda_authorizer_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#lambda_authorizer_config AppsyncGraphqlApi#lambda_authorizer_config}
LambdaAuthorizerConfig *AppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfig `field:"optional" json:"lambdaAuthorizerConfig" yaml:"lambdaAuthorizerConfig"`
// openid_connect_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#openid_connect_config AppsyncGraphqlApi#openid_connect_config}
OpenidConnectConfig *AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfig `field:"optional" json:"openidConnectConfig" yaml:"openidConnectConfig"`
// user_pool_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#user_pool_config AppsyncGraphqlApi#user_pool_config}
UserPoolConfig *AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig `field:"optional" json:"userPoolConfig" yaml:"userPoolConfig"`
}
type AppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfig ¶
type AppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#authorizer_uri AppsyncGraphqlApi#authorizer_uri}.
AuthorizerUri *string `field:"required" json:"authorizerUri" yaml:"authorizerUri"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#authorizer_result_ttl_in_seconds AppsyncGraphqlApi#authorizer_result_ttl_in_seconds}.
AuthorizerResultTtlInSeconds *float64 `field:"optional" json:"authorizerResultTtlInSeconds" yaml:"authorizerResultTtlInSeconds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#identity_validation_expression AppsyncGraphqlApi#identity_validation_expression}.
IdentityValidationExpression *string `field:"optional" json:"identityValidationExpression" yaml:"identityValidationExpression"`
}
type AppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfigOutputReference ¶
type AppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfigOutputReference interface {
cdktf.ComplexObject
AuthorizerResultTtlInSeconds() *float64
SetAuthorizerResultTtlInSeconds(val *float64)
AuthorizerResultTtlInSecondsInput() *float64
AuthorizerUri() *string
SetAuthorizerUri(val *string)
AuthorizerUriInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IdentityValidationExpression() *string
SetIdentityValidationExpression(val *string)
IdentityValidationExpressionInput() *string
InternalValue() *AppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfig
SetInternalValue(val *AppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAuthorizerResultTtlInSeconds()
ResetIdentityValidationExpression()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfigOutputReference ¶
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfigOutputReference
type AppsyncGraphqlApiAdditionalAuthenticationProviderList ¶
type AppsyncGraphqlApiAdditionalAuthenticationProviderList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) AppsyncGraphqlApiAdditionalAuthenticationProviderOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderList ¶
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AppsyncGraphqlApiAdditionalAuthenticationProviderList
type AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfig ¶
type AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#issuer AppsyncGraphqlApi#issuer}.
Issuer *string `field:"required" json:"issuer" yaml:"issuer"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#auth_ttl AppsyncGraphqlApi#auth_ttl}.
AuthTtl *float64 `field:"optional" json:"authTtl" yaml:"authTtl"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#client_id AppsyncGraphqlApi#client_id}.
ClientId *string `field:"optional" json:"clientId" yaml:"clientId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#iat_ttl AppsyncGraphqlApi#iat_ttl}.
IatTtl *float64 `field:"optional" json:"iatTtl" yaml:"iatTtl"`
}
type AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfigOutputReference ¶
type AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfigOutputReference interface {
cdktf.ComplexObject
AuthTtl() *float64
SetAuthTtl(val *float64)
AuthTtlInput() *float64
ClientId() *string
SetClientId(val *string)
ClientIdInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IatTtl() *float64
SetIatTtl(val *float64)
IatTtlInput() *float64
InternalValue() *AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfig
SetInternalValue(val *AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfig)
Issuer() *string
SetIssuer(val *string)
IssuerInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAuthTtl()
ResetClientId()
ResetIatTtl()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfigOutputReference ¶
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfigOutputReference
type AppsyncGraphqlApiAdditionalAuthenticationProviderOutputReference ¶
type AppsyncGraphqlApiAdditionalAuthenticationProviderOutputReference interface {
cdktf.ComplexObject
AuthenticationType() *string
SetAuthenticationType(val *string)
AuthenticationTypeInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
LambdaAuthorizerConfig() AppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfigOutputReference
LambdaAuthorizerConfigInput() *AppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfig
OpenidConnectConfig() AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfigOutputReference
OpenidConnectConfigInput() *AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfig
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UserPoolConfig() AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfigOutputReference
UserPoolConfigInput() *AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutLambdaAuthorizerConfig(value *AppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfig)
PutOpenidConnectConfig(value *AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfig)
PutUserPoolConfig(value *AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig)
ResetLambdaAuthorizerConfig()
ResetOpenidConnectConfig()
ResetUserPoolConfig()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderOutputReference ¶
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AppsyncGraphqlApiAdditionalAuthenticationProviderOutputReference
type AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig ¶
type AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#user_pool_id AppsyncGraphqlApi#user_pool_id}.
UserPoolId *string `field:"required" json:"userPoolId" yaml:"userPoolId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#app_id_client_regex AppsyncGraphqlApi#app_id_client_regex}.
AppIdClientRegex *string `field:"optional" json:"appIdClientRegex" yaml:"appIdClientRegex"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#aws_region AppsyncGraphqlApi#aws_region}.
AwsRegion *string `field:"optional" json:"awsRegion" yaml:"awsRegion"`
}
type AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfigOutputReference ¶
type AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfigOutputReference interface {
cdktf.ComplexObject
AppIdClientRegex() *string
SetAppIdClientRegex(val *string)
AppIdClientRegexInput() *string
AwsRegion() *string
SetAwsRegion(val *string)
AwsRegionInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig
SetInternalValue(val *AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UserPoolId() *string
SetUserPoolId(val *string)
UserPoolIdInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAppIdClientRegex()
ResetAwsRegion()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfigOutputReference ¶
func NewAppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfigOutputReference
type AppsyncGraphqlApiConfig ¶
type AppsyncGraphqlApiConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#authentication_type AppsyncGraphqlApi#authentication_type}.
AuthenticationType *string `field:"required" json:"authenticationType" yaml:"authenticationType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#name AppsyncGraphqlApi#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// additional_authentication_provider block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#additional_authentication_provider AppsyncGraphqlApi#additional_authentication_provider}
AdditionalAuthenticationProvider interface{} `field:"optional" json:"additionalAuthenticationProvider" yaml:"additionalAuthenticationProvider"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#id AppsyncGraphqlApi#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// lambda_authorizer_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#lambda_authorizer_config AppsyncGraphqlApi#lambda_authorizer_config}
LambdaAuthorizerConfig *AppsyncGraphqlApiLambdaAuthorizerConfig `field:"optional" json:"lambdaAuthorizerConfig" yaml:"lambdaAuthorizerConfig"`
// log_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#log_config AppsyncGraphqlApi#log_config}
LogConfig *AppsyncGraphqlApiLogConfig `field:"optional" json:"logConfig" yaml:"logConfig"`
// openid_connect_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#openid_connect_config AppsyncGraphqlApi#openid_connect_config}
OpenidConnectConfig *AppsyncGraphqlApiOpenidConnectConfig `field:"optional" json:"openidConnectConfig" yaml:"openidConnectConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#schema AppsyncGraphqlApi#schema}.
Schema *string `field:"optional" json:"schema" yaml:"schema"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#tags AppsyncGraphqlApi#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#tags_all AppsyncGraphqlApi#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// user_pool_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#user_pool_config AppsyncGraphqlApi#user_pool_config}
UserPoolConfig *AppsyncGraphqlApiUserPoolConfig `field:"optional" json:"userPoolConfig" yaml:"userPoolConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#xray_enabled AppsyncGraphqlApi#xray_enabled}.
XrayEnabled interface{} `field:"optional" json:"xrayEnabled" yaml:"xrayEnabled"`
}
type AppsyncGraphqlApiLambdaAuthorizerConfig ¶
type AppsyncGraphqlApiLambdaAuthorizerConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#authorizer_uri AppsyncGraphqlApi#authorizer_uri}.
AuthorizerUri *string `field:"required" json:"authorizerUri" yaml:"authorizerUri"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#authorizer_result_ttl_in_seconds AppsyncGraphqlApi#authorizer_result_ttl_in_seconds}.
AuthorizerResultTtlInSeconds *float64 `field:"optional" json:"authorizerResultTtlInSeconds" yaml:"authorizerResultTtlInSeconds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#identity_validation_expression AppsyncGraphqlApi#identity_validation_expression}.
IdentityValidationExpression *string `field:"optional" json:"identityValidationExpression" yaml:"identityValidationExpression"`
}
type AppsyncGraphqlApiLambdaAuthorizerConfigOutputReference ¶
type AppsyncGraphqlApiLambdaAuthorizerConfigOutputReference interface {
cdktf.ComplexObject
AuthorizerResultTtlInSeconds() *float64
SetAuthorizerResultTtlInSeconds(val *float64)
AuthorizerResultTtlInSecondsInput() *float64
AuthorizerUri() *string
SetAuthorizerUri(val *string)
AuthorizerUriInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IdentityValidationExpression() *string
SetIdentityValidationExpression(val *string)
IdentityValidationExpressionInput() *string
InternalValue() *AppsyncGraphqlApiLambdaAuthorizerConfig
SetInternalValue(val *AppsyncGraphqlApiLambdaAuthorizerConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAuthorizerResultTtlInSeconds()
ResetIdentityValidationExpression()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppsyncGraphqlApiLambdaAuthorizerConfigOutputReference ¶
func NewAppsyncGraphqlApiLambdaAuthorizerConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppsyncGraphqlApiLambdaAuthorizerConfigOutputReference
type AppsyncGraphqlApiLogConfig ¶
type AppsyncGraphqlApiLogConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#cloudwatch_logs_role_arn AppsyncGraphqlApi#cloudwatch_logs_role_arn}.
CloudwatchLogsRoleArn *string `field:"required" json:"cloudwatchLogsRoleArn" yaml:"cloudwatchLogsRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#field_log_level AppsyncGraphqlApi#field_log_level}.
FieldLogLevel *string `field:"required" json:"fieldLogLevel" yaml:"fieldLogLevel"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#exclude_verbose_content AppsyncGraphqlApi#exclude_verbose_content}.
ExcludeVerboseContent interface{} `field:"optional" json:"excludeVerboseContent" yaml:"excludeVerboseContent"`
}
type AppsyncGraphqlApiLogConfigOutputReference ¶
type AppsyncGraphqlApiLogConfigOutputReference interface {
cdktf.ComplexObject
CloudwatchLogsRoleArn() *string
SetCloudwatchLogsRoleArn(val *string)
CloudwatchLogsRoleArnInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
ExcludeVerboseContent() interface{}
SetExcludeVerboseContent(val interface{})
ExcludeVerboseContentInput() interface{}
FieldLogLevel() *string
SetFieldLogLevel(val *string)
FieldLogLevelInput() *string
// Experimental.
Fqn() *string
InternalValue() *AppsyncGraphqlApiLogConfig
SetInternalValue(val *AppsyncGraphqlApiLogConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetExcludeVerboseContent()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppsyncGraphqlApiLogConfigOutputReference ¶
func NewAppsyncGraphqlApiLogConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppsyncGraphqlApiLogConfigOutputReference
type AppsyncGraphqlApiOpenidConnectConfig ¶
type AppsyncGraphqlApiOpenidConnectConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#issuer AppsyncGraphqlApi#issuer}.
Issuer *string `field:"required" json:"issuer" yaml:"issuer"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#auth_ttl AppsyncGraphqlApi#auth_ttl}.
AuthTtl *float64 `field:"optional" json:"authTtl" yaml:"authTtl"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#client_id AppsyncGraphqlApi#client_id}.
ClientId *string `field:"optional" json:"clientId" yaml:"clientId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#iat_ttl AppsyncGraphqlApi#iat_ttl}.
IatTtl *float64 `field:"optional" json:"iatTtl" yaml:"iatTtl"`
}
type AppsyncGraphqlApiOpenidConnectConfigOutputReference ¶
type AppsyncGraphqlApiOpenidConnectConfigOutputReference interface {
cdktf.ComplexObject
AuthTtl() *float64
SetAuthTtl(val *float64)
AuthTtlInput() *float64
ClientId() *string
SetClientId(val *string)
ClientIdInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IatTtl() *float64
SetIatTtl(val *float64)
IatTtlInput() *float64
InternalValue() *AppsyncGraphqlApiOpenidConnectConfig
SetInternalValue(val *AppsyncGraphqlApiOpenidConnectConfig)
Issuer() *string
SetIssuer(val *string)
IssuerInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAuthTtl()
ResetClientId()
ResetIatTtl()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppsyncGraphqlApiOpenidConnectConfigOutputReference ¶
func NewAppsyncGraphqlApiOpenidConnectConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppsyncGraphqlApiOpenidConnectConfigOutputReference
type AppsyncGraphqlApiUserPoolConfig ¶
type AppsyncGraphqlApiUserPoolConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#default_action AppsyncGraphqlApi#default_action}.
DefaultAction *string `field:"required" json:"defaultAction" yaml:"defaultAction"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#user_pool_id AppsyncGraphqlApi#user_pool_id}.
UserPoolId *string `field:"required" json:"userPoolId" yaml:"userPoolId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#app_id_client_regex AppsyncGraphqlApi#app_id_client_regex}.
AppIdClientRegex *string `field:"optional" json:"appIdClientRegex" yaml:"appIdClientRegex"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api#aws_region AppsyncGraphqlApi#aws_region}.
AwsRegion *string `field:"optional" json:"awsRegion" yaml:"awsRegion"`
}
type AppsyncGraphqlApiUserPoolConfigOutputReference ¶
type AppsyncGraphqlApiUserPoolConfigOutputReference interface {
cdktf.ComplexObject
AppIdClientRegex() *string
SetAppIdClientRegex(val *string)
AppIdClientRegexInput() *string
AwsRegion() *string
SetAwsRegion(val *string)
AwsRegionInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DefaultAction() *string
SetDefaultAction(val *string)
DefaultActionInput() *string
// Experimental.
Fqn() *string
InternalValue() *AppsyncGraphqlApiUserPoolConfig
SetInternalValue(val *AppsyncGraphqlApiUserPoolConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UserPoolId() *string
SetUserPoolId(val *string)
UserPoolIdInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAppIdClientRegex()
ResetAwsRegion()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppsyncGraphqlApiUserPoolConfigOutputReference ¶
func NewAppsyncGraphqlApiUserPoolConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppsyncGraphqlApiUserPoolConfigOutputReference
Source Files
¶
- AppsyncGraphqlApi.go
- AppsyncGraphqlApiAdditionalAuthenticationProvider.go
- AppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfig.go
- AppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfigOutputReference.go
- AppsyncGraphqlApiAdditionalAuthenticationProviderLambdaAuthorizerConfigOutputReference__checks.go
- AppsyncGraphqlApiAdditionalAuthenticationProviderList.go
- AppsyncGraphqlApiAdditionalAuthenticationProviderList__checks.go
- AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfig.go
- AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfigOutputReference.go
- AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfigOutputReference__checks.go
- AppsyncGraphqlApiAdditionalAuthenticationProviderOutputReference.go
- AppsyncGraphqlApiAdditionalAuthenticationProviderOutputReference__checks.go
- AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig.go
- AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfigOutputReference.go
- AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfigOutputReference__checks.go
- AppsyncGraphqlApiConfig.go
- AppsyncGraphqlApiLambdaAuthorizerConfig.go
- AppsyncGraphqlApiLambdaAuthorizerConfigOutputReference.go
- AppsyncGraphqlApiLambdaAuthorizerConfigOutputReference__checks.go
- AppsyncGraphqlApiLogConfig.go
- AppsyncGraphqlApiLogConfigOutputReference.go
- AppsyncGraphqlApiLogConfigOutputReference__checks.go
- AppsyncGraphqlApiOpenidConnectConfig.go
- AppsyncGraphqlApiOpenidConnectConfigOutputReference.go
- AppsyncGraphqlApiOpenidConnectConfigOutputReference__checks.go
- AppsyncGraphqlApiUserPoolConfig.go
- AppsyncGraphqlApiUserPoolConfigOutputReference.go
- AppsyncGraphqlApiUserPoolConfigOutputReference__checks.go
- AppsyncGraphqlApi__checks.go
- main.go