Documentation
¶
Index ¶
- func BackupReportPlan_IsConstruct(x interface{}) *bool
- func BackupReportPlan_IsTerraformElement(x interface{}) *bool
- func BackupReportPlan_IsTerraformResource(x interface{}) *bool
- func BackupReportPlan_TfResourceType() *string
- func NewBackupReportPlanReportDeliveryChannelOutputReference_Override(b BackupReportPlanReportDeliveryChannelOutputReference, ...)
- func NewBackupReportPlanReportSettingOutputReference_Override(b BackupReportPlanReportSettingOutputReference, ...)
- func NewBackupReportPlan_Override(b BackupReportPlan, scope constructs.Construct, id *string, ...)
- type BackupReportPlan
- type BackupReportPlanConfig
- type BackupReportPlanReportDeliveryChannel
- type BackupReportPlanReportDeliveryChannelOutputReference
- type BackupReportPlanReportSetting
- type BackupReportPlanReportSettingOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BackupReportPlan_IsConstruct ¶
func BackupReportPlan_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func BackupReportPlan_IsTerraformElement ¶
func BackupReportPlan_IsTerraformElement(x interface{}) *bool
Experimental.
func BackupReportPlan_IsTerraformResource ¶
func BackupReportPlan_IsTerraformResource(x interface{}) *bool
Experimental.
func BackupReportPlan_TfResourceType ¶
func BackupReportPlan_TfResourceType() *string
func NewBackupReportPlanReportDeliveryChannelOutputReference_Override ¶
func NewBackupReportPlanReportDeliveryChannelOutputReference_Override(b BackupReportPlanReportDeliveryChannelOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBackupReportPlanReportSettingOutputReference_Override ¶
func NewBackupReportPlanReportSettingOutputReference_Override(b BackupReportPlanReportSettingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBackupReportPlan_Override ¶
func NewBackupReportPlan_Override(b BackupReportPlan, scope constructs.Construct, id *string, config *BackupReportPlanConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/backup_report_plan aws_backup_report_plan} Resource.
Types ¶
type BackupReportPlan ¶
type BackupReportPlan interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreationTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeploymentStatus() *string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ReportDeliveryChannel() BackupReportPlanReportDeliveryChannelOutputReference
ReportDeliveryChannelInput() *BackupReportPlanReportDeliveryChannel
ReportSetting() BackupReportPlanReportSettingOutputReference
ReportSettingInput() *BackupReportPlanReportSetting
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutReportDeliveryChannel(value *BackupReportPlanReportDeliveryChannel)
PutReportSetting(value *BackupReportPlanReportSetting)
ResetDescription()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/backup_report_plan aws_backup_report_plan}.
func NewBackupReportPlan ¶
func NewBackupReportPlan(scope constructs.Construct, id *string, config *BackupReportPlanConfig) BackupReportPlan
Create a new {@link https://www.terraform.io/docs/providers/aws/r/backup_report_plan aws_backup_report_plan} Resource.
type BackupReportPlanConfig ¶
type BackupReportPlanConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_report_plan#name BackupReportPlan#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// report_delivery_channel block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_report_plan#report_delivery_channel BackupReportPlan#report_delivery_channel}
ReportDeliveryChannel *BackupReportPlanReportDeliveryChannel `field:"required" json:"reportDeliveryChannel" yaml:"reportDeliveryChannel"`
// report_setting block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_report_plan#report_setting BackupReportPlan#report_setting}
ReportSetting *BackupReportPlanReportSetting `field:"required" json:"reportSetting" yaml:"reportSetting"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_report_plan#description BackupReportPlan#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_report_plan#id BackupReportPlan#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_report_plan#tags BackupReportPlan#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_report_plan#tags_all BackupReportPlan#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type BackupReportPlanReportDeliveryChannel ¶
type BackupReportPlanReportDeliveryChannel struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_report_plan#s3_bucket_name BackupReportPlan#s3_bucket_name}.
S3BucketName *string `field:"required" json:"s3BucketName" yaml:"s3BucketName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_report_plan#formats BackupReportPlan#formats}.
Formats *[]*string `field:"optional" json:"formats" yaml:"formats"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_report_plan#s3_key_prefix BackupReportPlan#s3_key_prefix}.
S3KeyPrefix *string `field:"optional" json:"s3KeyPrefix" yaml:"s3KeyPrefix"`
}
type BackupReportPlanReportDeliveryChannelOutputReference ¶
type BackupReportPlanReportDeliveryChannelOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Formats() *[]*string
SetFormats(val *[]*string)
FormatsInput() *[]*string
// Experimental.
Fqn() *string
InternalValue() *BackupReportPlanReportDeliveryChannel
SetInternalValue(val *BackupReportPlanReportDeliveryChannel)
S3BucketName() *string
SetS3BucketName(val *string)
S3BucketNameInput() *string
S3KeyPrefix() *string
SetS3KeyPrefix(val *string)
S3KeyPrefixInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetFormats()
ResetS3KeyPrefix()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupReportPlanReportDeliveryChannelOutputReference ¶
func NewBackupReportPlanReportDeliveryChannelOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BackupReportPlanReportDeliveryChannelOutputReference
type BackupReportPlanReportSetting ¶
type BackupReportPlanReportSetting struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_report_plan#report_template BackupReportPlan#report_template}.
ReportTemplate *string `field:"required" json:"reportTemplate" yaml:"reportTemplate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_report_plan#framework_arns BackupReportPlan#framework_arns}.
FrameworkArns *[]*string `field:"optional" json:"frameworkArns" yaml:"frameworkArns"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_report_plan#number_of_frameworks BackupReportPlan#number_of_frameworks}.
NumberOfFrameworks *float64 `field:"optional" json:"numberOfFrameworks" yaml:"numberOfFrameworks"`
}
type BackupReportPlanReportSettingOutputReference ¶
type BackupReportPlanReportSettingOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
FrameworkArns() *[]*string
SetFrameworkArns(val *[]*string)
FrameworkArnsInput() *[]*string
InternalValue() *BackupReportPlanReportSetting
SetInternalValue(val *BackupReportPlanReportSetting)
NumberOfFrameworks() *float64
SetNumberOfFrameworks(val *float64)
NumberOfFrameworksInput() *float64
ReportTemplate() *string
SetReportTemplate(val *string)
ReportTemplateInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetFrameworkArns()
ResetNumberOfFrameworks()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupReportPlanReportSettingOutputReference ¶
func NewBackupReportPlanReportSettingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BackupReportPlanReportSettingOutputReference
Source Files
¶
- BackupReportPlan.go
- BackupReportPlanConfig.go
- BackupReportPlanReportDeliveryChannel.go
- BackupReportPlanReportDeliveryChannelOutputReference.go
- BackupReportPlanReportDeliveryChannelOutputReference__checks.go
- BackupReportPlanReportSetting.go
- BackupReportPlanReportSettingOutputReference.go
- BackupReportPlanReportSettingOutputReference__checks.go
- BackupReportPlan__checks.go
- main.go