Documentation
¶
Index ¶
- func BatchJobDefinition_IsConstruct(x interface{}) *bool
- func BatchJobDefinition_IsTerraformElement(x interface{}) *bool
- func BatchJobDefinition_IsTerraformResource(x interface{}) *bool
- func BatchJobDefinition_TfResourceType() *string
- func NewBatchJobDefinitionRetryStrategyEvaluateOnExitList_Override(b BatchJobDefinitionRetryStrategyEvaluateOnExitList, ...)
- func NewBatchJobDefinitionRetryStrategyEvaluateOnExitOutputReference_Override(b BatchJobDefinitionRetryStrategyEvaluateOnExitOutputReference, ...)
- func NewBatchJobDefinitionRetryStrategyOutputReference_Override(b BatchJobDefinitionRetryStrategyOutputReference, ...)
- func NewBatchJobDefinitionTimeoutOutputReference_Override(b BatchJobDefinitionTimeoutOutputReference, ...)
- func NewBatchJobDefinition_Override(b BatchJobDefinition, scope constructs.Construct, id *string, ...)
- type BatchJobDefinition
- type BatchJobDefinitionConfig
- type BatchJobDefinitionRetryStrategy
- type BatchJobDefinitionRetryStrategyEvaluateOnExit
- type BatchJobDefinitionRetryStrategyEvaluateOnExitList
- type BatchJobDefinitionRetryStrategyEvaluateOnExitOutputReference
- type BatchJobDefinitionRetryStrategyOutputReference
- type BatchJobDefinitionTimeout
- type BatchJobDefinitionTimeoutOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BatchJobDefinition_IsConstruct ¶
func BatchJobDefinition_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func BatchJobDefinition_IsTerraformElement ¶
func BatchJobDefinition_IsTerraformElement(x interface{}) *bool
Experimental.
func BatchJobDefinition_IsTerraformResource ¶
func BatchJobDefinition_IsTerraformResource(x interface{}) *bool
Experimental.
func BatchJobDefinition_TfResourceType ¶
func BatchJobDefinition_TfResourceType() *string
func NewBatchJobDefinitionRetryStrategyEvaluateOnExitList_Override ¶
func NewBatchJobDefinitionRetryStrategyEvaluateOnExitList_Override(b BatchJobDefinitionRetryStrategyEvaluateOnExitList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewBatchJobDefinitionRetryStrategyEvaluateOnExitOutputReference_Override ¶
func NewBatchJobDefinitionRetryStrategyEvaluateOnExitOutputReference_Override(b BatchJobDefinitionRetryStrategyEvaluateOnExitOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewBatchJobDefinitionRetryStrategyOutputReference_Override ¶
func NewBatchJobDefinitionRetryStrategyOutputReference_Override(b BatchJobDefinitionRetryStrategyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBatchJobDefinitionTimeoutOutputReference_Override ¶
func NewBatchJobDefinitionTimeoutOutputReference_Override(b BatchJobDefinitionTimeoutOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBatchJobDefinition_Override ¶
func NewBatchJobDefinition_Override(b BatchJobDefinition, scope constructs.Construct, id *string, config *BatchJobDefinitionConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition aws_batch_job_definition} Resource.
Types ¶
type BatchJobDefinition ¶
type BatchJobDefinition interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ContainerProperties() *string
SetContainerProperties(val *string)
ContainerPropertiesInput() *string
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Parameters() *map[string]*string
SetParameters(val *map[string]*string)
ParametersInput() *map[string]*string
PlatformCapabilities() *[]*string
SetPlatformCapabilities(val *[]*string)
PlatformCapabilitiesInput() *[]*string
PropagateTags() interface{}
SetPropagateTags(val interface{})
PropagateTagsInput() interface{}
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RetryStrategy() BatchJobDefinitionRetryStrategyOutputReference
RetryStrategyInput() *BatchJobDefinitionRetryStrategy
Revision() *float64
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeout() BatchJobDefinitionTimeoutOutputReference
TimeoutInput() *BatchJobDefinitionTimeout
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutRetryStrategy(value *BatchJobDefinitionRetryStrategy)
PutTimeout(value *BatchJobDefinitionTimeout)
ResetContainerProperties()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetParameters()
ResetPlatformCapabilities()
ResetPropagateTags()
ResetRetryStrategy()
ResetTags()
ResetTagsAll()
ResetTimeout()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition aws_batch_job_definition}.
func NewBatchJobDefinition ¶
func NewBatchJobDefinition(scope constructs.Construct, id *string, config *BatchJobDefinitionConfig) BatchJobDefinition
Create a new {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition aws_batch_job_definition} Resource.
type BatchJobDefinitionConfig ¶
type BatchJobDefinitionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition#name BatchJobDefinition#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition#type BatchJobDefinition#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition#container_properties BatchJobDefinition#container_properties}.
ContainerProperties *string `field:"optional" json:"containerProperties" yaml:"containerProperties"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition#id BatchJobDefinition#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition#parameters BatchJobDefinition#parameters}.
Parameters *map[string]*string `field:"optional" json:"parameters" yaml:"parameters"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition#platform_capabilities BatchJobDefinition#platform_capabilities}.
PlatformCapabilities *[]*string `field:"optional" json:"platformCapabilities" yaml:"platformCapabilities"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition#propagate_tags BatchJobDefinition#propagate_tags}.
PropagateTags interface{} `field:"optional" json:"propagateTags" yaml:"propagateTags"`
// retry_strategy block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition#retry_strategy BatchJobDefinition#retry_strategy}
RetryStrategy *BatchJobDefinitionRetryStrategy `field:"optional" json:"retryStrategy" yaml:"retryStrategy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition#tags BatchJobDefinition#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition#tags_all BatchJobDefinition#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeout block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition#timeout BatchJobDefinition#timeout}
Timeout *BatchJobDefinitionTimeout `field:"optional" json:"timeout" yaml:"timeout"`
}
type BatchJobDefinitionRetryStrategy ¶
type BatchJobDefinitionRetryStrategy struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition#attempts BatchJobDefinition#attempts}.
Attempts *float64 `field:"optional" json:"attempts" yaml:"attempts"`
// evaluate_on_exit block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition#evaluate_on_exit BatchJobDefinition#evaluate_on_exit}
EvaluateOnExit interface{} `field:"optional" json:"evaluateOnExit" yaml:"evaluateOnExit"`
}
type BatchJobDefinitionRetryStrategyEvaluateOnExit ¶
type BatchJobDefinitionRetryStrategyEvaluateOnExit struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition#action BatchJobDefinition#action}.
Action *string `field:"required" json:"action" yaml:"action"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition#on_exit_code BatchJobDefinition#on_exit_code}.
OnExitCode *string `field:"optional" json:"onExitCode" yaml:"onExitCode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition#on_reason BatchJobDefinition#on_reason}.
OnReason *string `field:"optional" json:"onReason" yaml:"onReason"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition#on_status_reason BatchJobDefinition#on_status_reason}.
OnStatusReason *string `field:"optional" json:"onStatusReason" yaml:"onStatusReason"`
}
type BatchJobDefinitionRetryStrategyEvaluateOnExitList ¶
type BatchJobDefinitionRetryStrategyEvaluateOnExitList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) BatchJobDefinitionRetryStrategyEvaluateOnExitOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBatchJobDefinitionRetryStrategyEvaluateOnExitList ¶
func NewBatchJobDefinitionRetryStrategyEvaluateOnExitList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) BatchJobDefinitionRetryStrategyEvaluateOnExitList
type BatchJobDefinitionRetryStrategyEvaluateOnExitOutputReference ¶
type BatchJobDefinitionRetryStrategyEvaluateOnExitOutputReference interface {
cdktf.ComplexObject
Action() *string
SetAction(val *string)
ActionInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
OnExitCode() *string
SetOnExitCode(val *string)
OnExitCodeInput() *string
OnReason() *string
SetOnReason(val *string)
OnReasonInput() *string
OnStatusReason() *string
SetOnStatusReason(val *string)
OnStatusReasonInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetOnExitCode()
ResetOnReason()
ResetOnStatusReason()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBatchJobDefinitionRetryStrategyEvaluateOnExitOutputReference ¶
func NewBatchJobDefinitionRetryStrategyEvaluateOnExitOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) BatchJobDefinitionRetryStrategyEvaluateOnExitOutputReference
type BatchJobDefinitionRetryStrategyOutputReference ¶
type BatchJobDefinitionRetryStrategyOutputReference interface {
cdktf.ComplexObject
Attempts() *float64
SetAttempts(val *float64)
AttemptsInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EvaluateOnExit() BatchJobDefinitionRetryStrategyEvaluateOnExitList
EvaluateOnExitInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *BatchJobDefinitionRetryStrategy
SetInternalValue(val *BatchJobDefinitionRetryStrategy)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutEvaluateOnExit(value interface{})
ResetAttempts()
ResetEvaluateOnExit()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBatchJobDefinitionRetryStrategyOutputReference ¶
func NewBatchJobDefinitionRetryStrategyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BatchJobDefinitionRetryStrategyOutputReference
type BatchJobDefinitionTimeout ¶
type BatchJobDefinitionTimeout struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_job_definition#attempt_duration_seconds BatchJobDefinition#attempt_duration_seconds}.
AttemptDurationSeconds *float64 `field:"optional" json:"attemptDurationSeconds" yaml:"attemptDurationSeconds"`
}
type BatchJobDefinitionTimeoutOutputReference ¶
type BatchJobDefinitionTimeoutOutputReference interface {
cdktf.ComplexObject
AttemptDurationSeconds() *float64
SetAttemptDurationSeconds(val *float64)
AttemptDurationSecondsInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *BatchJobDefinitionTimeout
SetInternalValue(val *BatchJobDefinitionTimeout)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAttemptDurationSeconds()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBatchJobDefinitionTimeoutOutputReference ¶
func NewBatchJobDefinitionTimeoutOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BatchJobDefinitionTimeoutOutputReference
Source Files
¶
- BatchJobDefinition.go
- BatchJobDefinitionConfig.go
- BatchJobDefinitionRetryStrategy.go
- BatchJobDefinitionRetryStrategyEvaluateOnExit.go
- BatchJobDefinitionRetryStrategyEvaluateOnExitList.go
- BatchJobDefinitionRetryStrategyEvaluateOnExitList__checks.go
- BatchJobDefinitionRetryStrategyEvaluateOnExitOutputReference.go
- BatchJobDefinitionRetryStrategyEvaluateOnExitOutputReference__checks.go
- BatchJobDefinitionRetryStrategyOutputReference.go
- BatchJobDefinitionRetryStrategyOutputReference__checks.go
- BatchJobDefinitionTimeout.go
- BatchJobDefinitionTimeoutOutputReference.go
- BatchJobDefinitionTimeoutOutputReference__checks.go
- BatchJobDefinition__checks.go
- main.go