Documentation
¶
Index ¶
- func BatchSchedulingPolicy_IsConstruct(x interface{}) *bool
- func BatchSchedulingPolicy_IsTerraformElement(x interface{}) *bool
- func BatchSchedulingPolicy_IsTerraformResource(x interface{}) *bool
- func BatchSchedulingPolicy_TfResourceType() *string
- func NewBatchSchedulingPolicyFairSharePolicyOutputReference_Override(b BatchSchedulingPolicyFairSharePolicyOutputReference, ...)
- func NewBatchSchedulingPolicyFairSharePolicyShareDistributionList_Override(b BatchSchedulingPolicyFairSharePolicyShareDistributionList, ...)
- func NewBatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference_Override(b BatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference, ...)
- func NewBatchSchedulingPolicy_Override(b BatchSchedulingPolicy, scope constructs.Construct, id *string, ...)
- type BatchSchedulingPolicy
- type BatchSchedulingPolicyConfig
- type BatchSchedulingPolicyFairSharePolicy
- type BatchSchedulingPolicyFairSharePolicyOutputReference
- type BatchSchedulingPolicyFairSharePolicyShareDistribution
- type BatchSchedulingPolicyFairSharePolicyShareDistributionList
- type BatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BatchSchedulingPolicy_IsConstruct ¶
func BatchSchedulingPolicy_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func BatchSchedulingPolicy_IsTerraformElement ¶
func BatchSchedulingPolicy_IsTerraformElement(x interface{}) *bool
Experimental.
func BatchSchedulingPolicy_IsTerraformResource ¶
func BatchSchedulingPolicy_IsTerraformResource(x interface{}) *bool
Experimental.
func BatchSchedulingPolicy_TfResourceType ¶
func BatchSchedulingPolicy_TfResourceType() *string
func NewBatchSchedulingPolicyFairSharePolicyOutputReference_Override ¶
func NewBatchSchedulingPolicyFairSharePolicyOutputReference_Override(b BatchSchedulingPolicyFairSharePolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBatchSchedulingPolicyFairSharePolicyShareDistributionList_Override ¶
func NewBatchSchedulingPolicyFairSharePolicyShareDistributionList_Override(b BatchSchedulingPolicyFairSharePolicyShareDistributionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewBatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference_Override ¶
func NewBatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference_Override(b BatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewBatchSchedulingPolicy_Override ¶
func NewBatchSchedulingPolicy_Override(b BatchSchedulingPolicy, scope constructs.Construct, id *string, config *BatchSchedulingPolicyConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/batch_scheduling_policy aws_batch_scheduling_policy} Resource.
Types ¶
type BatchSchedulingPolicy ¶
type BatchSchedulingPolicy interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/batch_scheduling_policy aws_batch_scheduling_policy}.
func NewBatchSchedulingPolicy ¶
func NewBatchSchedulingPolicy(scope constructs.Construct, id *string, config *BatchSchedulingPolicyConfig) BatchSchedulingPolicy
Create a new {@link https://www.terraform.io/docs/providers/aws/r/batch_scheduling_policy aws_batch_scheduling_policy} Resource.
type BatchSchedulingPolicyConfig ¶
type BatchSchedulingPolicyConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_scheduling_policy#name BatchSchedulingPolicy#name}.
Name *string `field:"required" json:"name" yaml:"name"`
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_scheduling_policy#fair_share_policy BatchSchedulingPolicy#fair_share_policy}
FairSharePolicy *BatchSchedulingPolicyFairSharePolicy `field:"optional" json:"fairSharePolicy" yaml:"fairSharePolicy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_scheduling_policy#id BatchSchedulingPolicy#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_scheduling_policy#tags BatchSchedulingPolicy#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_scheduling_policy#tags_all BatchSchedulingPolicy#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type BatchSchedulingPolicyFairSharePolicy ¶
type BatchSchedulingPolicyFairSharePolicy struct {
ComputeReservation *float64 `field:"optional" json:"computeReservation" yaml:"computeReservation"`
ShareDecaySeconds *float64 `field:"optional" json:"shareDecaySeconds" yaml:"shareDecaySeconds"`
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_scheduling_policy#share_distribution BatchSchedulingPolicy#share_distribution}
ShareDistribution interface{} `field:"optional" json:"shareDistribution" yaml:"shareDistribution"`
}
type BatchSchedulingPolicyFairSharePolicyOutputReference ¶
type BatchSchedulingPolicyFairSharePolicyOutputReference interface {
cdktf.ComplexObject
// Experimental.
ComplexObjectIndex() interface{}
SetComplexObjectIndex(val interface{})
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
ComputeFqn() *string
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationAsList() cdktf.IResolvable
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBatchSchedulingPolicyFairSharePolicyOutputReference ¶
func NewBatchSchedulingPolicyFairSharePolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BatchSchedulingPolicyFairSharePolicyOutputReference
type BatchSchedulingPolicyFairSharePolicyShareDistributionList ¶
type BatchSchedulingPolicyFairSharePolicyShareDistributionList interface {
cdktf.ComplexList
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
// The attribute on the parent resource this class is referencing.
// The parent resource.
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBatchSchedulingPolicyFairSharePolicyShareDistributionList ¶
func NewBatchSchedulingPolicyFairSharePolicyShareDistributionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) BatchSchedulingPolicyFairSharePolicyShareDistributionList
type BatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference ¶
type BatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference interface {
cdktf.ComplexObject
// Experimental.
ComplexObjectIndex() interface{}
SetComplexObjectIndex(val interface{})
// Experimental.
ComplexObjectIsFromSet() *bool
SetComplexObjectIsFromSet(val *bool)
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
ComputeFqn() *string
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationAsList() cdktf.IResolvable
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference ¶
func NewBatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) BatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference
Source Files
¶
- BatchSchedulingPolicy.go
- BatchSchedulingPolicyConfig.go
- BatchSchedulingPolicyFairSharePolicy.go
- BatchSchedulingPolicyFairSharePolicyOutputReference.go
- BatchSchedulingPolicyFairSharePolicyOutputReference__checks.go
- BatchSchedulingPolicyFairSharePolicyShareDistribution.go
- BatchSchedulingPolicyFairSharePolicyShareDistributionList.go
- BatchSchedulingPolicyFairSharePolicyShareDistributionList__checks.go
- BatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference.go
- BatchSchedulingPolicyFairSharePolicyShareDistributionOutputReference__checks.go
- BatchSchedulingPolicy__checks.go
- main.go