Documentation
¶
Index ¶
- func BudgetsBudget_IsConstruct(x interface{}) *bool
- func BudgetsBudget_IsTerraformElement(x interface{}) *bool
- func BudgetsBudget_IsTerraformResource(x interface{}) *bool
- func BudgetsBudget_TfResourceType() *string
- func NewBudgetsBudgetAutoAdjustDataHistoricalOptionsOutputReference_Override(b BudgetsBudgetAutoAdjustDataHistoricalOptionsOutputReference, ...)
- func NewBudgetsBudgetAutoAdjustDataOutputReference_Override(b BudgetsBudgetAutoAdjustDataOutputReference, ...)
- func NewBudgetsBudgetCostFilterList_Override(b BudgetsBudgetCostFilterList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewBudgetsBudgetCostFilterOutputReference_Override(b BudgetsBudgetCostFilterOutputReference, ...)
- func NewBudgetsBudgetCostTypesOutputReference_Override(b BudgetsBudgetCostTypesOutputReference, ...)
- func NewBudgetsBudgetNotificationList_Override(b BudgetsBudgetNotificationList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewBudgetsBudgetNotificationOutputReference_Override(b BudgetsBudgetNotificationOutputReference, ...)
- func NewBudgetsBudgetPlannedLimitList_Override(b BudgetsBudgetPlannedLimitList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewBudgetsBudgetPlannedLimitOutputReference_Override(b BudgetsBudgetPlannedLimitOutputReference, ...)
- func NewBudgetsBudget_Override(b BudgetsBudget, scope constructs.Construct, id *string, ...)
- type BudgetsBudget
- type BudgetsBudgetAutoAdjustData
- type BudgetsBudgetAutoAdjustDataHistoricalOptions
- type BudgetsBudgetAutoAdjustDataHistoricalOptionsOutputReference
- type BudgetsBudgetAutoAdjustDataOutputReference
- type BudgetsBudgetConfig
- type BudgetsBudgetCostFilter
- type BudgetsBudgetCostFilterList
- type BudgetsBudgetCostFilterOutputReference
- type BudgetsBudgetCostTypes
- type BudgetsBudgetCostTypesOutputReference
- type BudgetsBudgetNotification
- type BudgetsBudgetNotificationList
- type BudgetsBudgetNotificationOutputReference
- type BudgetsBudgetPlannedLimit
- type BudgetsBudgetPlannedLimitList
- type BudgetsBudgetPlannedLimitOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BudgetsBudget_IsConstruct ¶
func BudgetsBudget_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func BudgetsBudget_IsTerraformElement ¶
func BudgetsBudget_IsTerraformElement(x interface{}) *bool
Experimental.
func BudgetsBudget_IsTerraformResource ¶
func BudgetsBudget_IsTerraformResource(x interface{}) *bool
Experimental.
func BudgetsBudget_TfResourceType ¶
func BudgetsBudget_TfResourceType() *string
func NewBudgetsBudgetAutoAdjustDataHistoricalOptionsOutputReference_Override ¶
func NewBudgetsBudgetAutoAdjustDataHistoricalOptionsOutputReference_Override(b BudgetsBudgetAutoAdjustDataHistoricalOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBudgetsBudgetAutoAdjustDataOutputReference_Override ¶
func NewBudgetsBudgetAutoAdjustDataOutputReference_Override(b BudgetsBudgetAutoAdjustDataOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBudgetsBudgetCostFilterList_Override ¶
func NewBudgetsBudgetCostFilterList_Override(b BudgetsBudgetCostFilterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewBudgetsBudgetCostFilterOutputReference_Override ¶
func NewBudgetsBudgetCostFilterOutputReference_Override(b BudgetsBudgetCostFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewBudgetsBudgetCostTypesOutputReference_Override ¶
func NewBudgetsBudgetCostTypesOutputReference_Override(b BudgetsBudgetCostTypesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBudgetsBudgetNotificationList_Override ¶
func NewBudgetsBudgetNotificationList_Override(b BudgetsBudgetNotificationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewBudgetsBudgetNotificationOutputReference_Override ¶
func NewBudgetsBudgetNotificationOutputReference_Override(b BudgetsBudgetNotificationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewBudgetsBudgetPlannedLimitList_Override ¶
func NewBudgetsBudgetPlannedLimitList_Override(b BudgetsBudgetPlannedLimitList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewBudgetsBudgetPlannedLimitOutputReference_Override ¶
func NewBudgetsBudgetPlannedLimitOutputReference_Override(b BudgetsBudgetPlannedLimitOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewBudgetsBudget_Override ¶
func NewBudgetsBudget_Override(b BudgetsBudget, scope constructs.Construct, id *string, config *BudgetsBudgetConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget aws_budgets_budget} Resource.
Types ¶
type BudgetsBudget ¶
type BudgetsBudget interface {
cdktf.TerraformResource
AccountId() *string
SetAccountId(val *string)
AccountIdInput() *string
Arn() *string
AutoAdjustData() BudgetsBudgetAutoAdjustDataOutputReference
AutoAdjustDataInput() *BudgetsBudgetAutoAdjustData
BudgetType() *string
SetBudgetType(val *string)
BudgetTypeInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
CostFilter() BudgetsBudgetCostFilterList
CostFilterInput() interface{}
CostFilters() *map[string]*string
SetCostFilters(val *map[string]*string)
CostFiltersInput() *map[string]*string
CostTypes() BudgetsBudgetCostTypesOutputReference
CostTypesInput() *BudgetsBudgetCostTypes
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LimitAmount() *string
SetLimitAmount(val *string)
LimitAmountInput() *string
LimitUnit() *string
SetLimitUnit(val *string)
LimitUnitInput() *string
Name() *string
SetName(val *string)
NameInput() *string
NamePrefix() *string
SetNamePrefix(val *string)
NamePrefixInput() *string
// The tree node.
Node() constructs.Node
Notification() BudgetsBudgetNotificationList
NotificationInput() interface{}
PlannedLimit() BudgetsBudgetPlannedLimitList
PlannedLimitInput() interface{}
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
TimePeriodEnd() *string
SetTimePeriodEnd(val *string)
TimePeriodEndInput() *string
TimePeriodStart() *string
SetTimePeriodStart(val *string)
TimePeriodStartInput() *string
TimeUnit() *string
SetTimeUnit(val *string)
TimeUnitInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAutoAdjustData(value *BudgetsBudgetAutoAdjustData)
PutCostFilter(value interface{})
PutCostTypes(value *BudgetsBudgetCostTypes)
PutNotification(value interface{})
PutPlannedLimit(value interface{})
ResetAccountId()
ResetAutoAdjustData()
ResetCostFilter()
ResetCostFilters()
ResetCostTypes()
ResetId()
ResetLimitAmount()
ResetLimitUnit()
ResetName()
ResetNamePrefix()
ResetNotification()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPlannedLimit()
ResetTimePeriodEnd()
ResetTimePeriodStart()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget aws_budgets_budget}.
func NewBudgetsBudget ¶
func NewBudgetsBudget(scope constructs.Construct, id *string, config *BudgetsBudgetConfig) BudgetsBudget
Create a new {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget aws_budgets_budget} Resource.
type BudgetsBudgetAutoAdjustData ¶
type BudgetsBudgetAutoAdjustData struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#auto_adjust_type BudgetsBudget#auto_adjust_type}.
AutoAdjustType *string `field:"required" json:"autoAdjustType" yaml:"autoAdjustType"`
// historical_options block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#historical_options BudgetsBudget#historical_options}
HistoricalOptions *BudgetsBudgetAutoAdjustDataHistoricalOptions `field:"optional" json:"historicalOptions" yaml:"historicalOptions"`
}
type BudgetsBudgetAutoAdjustDataHistoricalOptions ¶
type BudgetsBudgetAutoAdjustDataHistoricalOptions struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#budget_adjustment_period BudgetsBudget#budget_adjustment_period}.
BudgetAdjustmentPeriod *float64 `field:"required" json:"budgetAdjustmentPeriod" yaml:"budgetAdjustmentPeriod"`
}
type BudgetsBudgetAutoAdjustDataHistoricalOptionsOutputReference ¶
type BudgetsBudgetAutoAdjustDataHistoricalOptionsOutputReference interface {
cdktf.ComplexObject
BudgetAdjustmentPeriod() *float64
SetBudgetAdjustmentPeriod(val *float64)
BudgetAdjustmentPeriodInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *BudgetsBudgetAutoAdjustDataHistoricalOptions
SetInternalValue(val *BudgetsBudgetAutoAdjustDataHistoricalOptions)
LookbackAvailablePeriods() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBudgetsBudgetAutoAdjustDataHistoricalOptionsOutputReference ¶
func NewBudgetsBudgetAutoAdjustDataHistoricalOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BudgetsBudgetAutoAdjustDataHistoricalOptionsOutputReference
type BudgetsBudgetAutoAdjustDataOutputReference ¶
type BudgetsBudgetAutoAdjustDataOutputReference interface {
cdktf.ComplexObject
AutoAdjustType() *string
SetAutoAdjustType(val *string)
AutoAdjustTypeInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HistoricalOptions() BudgetsBudgetAutoAdjustDataHistoricalOptionsOutputReference
HistoricalOptionsInput() *BudgetsBudgetAutoAdjustDataHistoricalOptions
InternalValue() *BudgetsBudgetAutoAdjustData
SetInternalValue(val *BudgetsBudgetAutoAdjustData)
LastAutoAdjustTime() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutHistoricalOptions(value *BudgetsBudgetAutoAdjustDataHistoricalOptions)
ResetHistoricalOptions()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBudgetsBudgetAutoAdjustDataOutputReference ¶
func NewBudgetsBudgetAutoAdjustDataOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BudgetsBudgetAutoAdjustDataOutputReference
type BudgetsBudgetConfig ¶
type BudgetsBudgetConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#budget_type BudgetsBudget#budget_type}.
BudgetType *string `field:"required" json:"budgetType" yaml:"budgetType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#time_unit BudgetsBudget#time_unit}.
TimeUnit *string `field:"required" json:"timeUnit" yaml:"timeUnit"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#account_id BudgetsBudget#account_id}.
AccountId *string `field:"optional" json:"accountId" yaml:"accountId"`
// auto_adjust_data block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#auto_adjust_data BudgetsBudget#auto_adjust_data}
AutoAdjustData *BudgetsBudgetAutoAdjustData `field:"optional" json:"autoAdjustData" yaml:"autoAdjustData"`
// cost_filter block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#cost_filter BudgetsBudget#cost_filter}
CostFilter interface{} `field:"optional" json:"costFilter" yaml:"costFilter"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#cost_filters BudgetsBudget#cost_filters}.
CostFilters *map[string]*string `field:"optional" json:"costFilters" yaml:"costFilters"`
// cost_types block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#cost_types BudgetsBudget#cost_types}
CostTypes *BudgetsBudgetCostTypes `field:"optional" json:"costTypes" yaml:"costTypes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#id BudgetsBudget#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#limit_amount BudgetsBudget#limit_amount}.
LimitAmount *string `field:"optional" json:"limitAmount" yaml:"limitAmount"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#limit_unit BudgetsBudget#limit_unit}.
LimitUnit *string `field:"optional" json:"limitUnit" yaml:"limitUnit"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#name BudgetsBudget#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#name_prefix BudgetsBudget#name_prefix}.
NamePrefix *string `field:"optional" json:"namePrefix" yaml:"namePrefix"`
// notification block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#notification BudgetsBudget#notification}
Notification interface{} `field:"optional" json:"notification" yaml:"notification"`
// planned_limit block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#planned_limit BudgetsBudget#planned_limit}
PlannedLimit interface{} `field:"optional" json:"plannedLimit" yaml:"plannedLimit"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#time_period_end BudgetsBudget#time_period_end}.
TimePeriodEnd *string `field:"optional" json:"timePeriodEnd" yaml:"timePeriodEnd"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#time_period_start BudgetsBudget#time_period_start}.
TimePeriodStart *string `field:"optional" json:"timePeriodStart" yaml:"timePeriodStart"`
}
type BudgetsBudgetCostFilter ¶
type BudgetsBudgetCostFilter struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#name BudgetsBudget#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#values BudgetsBudget#values}.
Values *[]*string `field:"required" json:"values" yaml:"values"`
}
type BudgetsBudgetCostFilterList ¶
type BudgetsBudgetCostFilterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) BudgetsBudgetCostFilterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBudgetsBudgetCostFilterList ¶
func NewBudgetsBudgetCostFilterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) BudgetsBudgetCostFilterList
type BudgetsBudgetCostFilterOutputReference ¶
type BudgetsBudgetCostFilterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
SetValues(val *[]*string)
ValuesInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBudgetsBudgetCostFilterOutputReference ¶
func NewBudgetsBudgetCostFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) BudgetsBudgetCostFilterOutputReference
type BudgetsBudgetCostTypes ¶
type BudgetsBudgetCostTypes struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#include_credit BudgetsBudget#include_credit}.
IncludeCredit interface{} `field:"optional" json:"includeCredit" yaml:"includeCredit"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#include_discount BudgetsBudget#include_discount}.
IncludeDiscount interface{} `field:"optional" json:"includeDiscount" yaml:"includeDiscount"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#include_other_subscription BudgetsBudget#include_other_subscription}.
IncludeOtherSubscription interface{} `field:"optional" json:"includeOtherSubscription" yaml:"includeOtherSubscription"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#include_recurring BudgetsBudget#include_recurring}.
IncludeRecurring interface{} `field:"optional" json:"includeRecurring" yaml:"includeRecurring"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#include_refund BudgetsBudget#include_refund}.
IncludeRefund interface{} `field:"optional" json:"includeRefund" yaml:"includeRefund"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#include_subscription BudgetsBudget#include_subscription}.
IncludeSubscription interface{} `field:"optional" json:"includeSubscription" yaml:"includeSubscription"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#include_support BudgetsBudget#include_support}.
IncludeSupport interface{} `field:"optional" json:"includeSupport" yaml:"includeSupport"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#include_tax BudgetsBudget#include_tax}.
IncludeTax interface{} `field:"optional" json:"includeTax" yaml:"includeTax"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#include_upfront BudgetsBudget#include_upfront}.
IncludeUpfront interface{} `field:"optional" json:"includeUpfront" yaml:"includeUpfront"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#use_amortized BudgetsBudget#use_amortized}.
UseAmortized interface{} `field:"optional" json:"useAmortized" yaml:"useAmortized"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#use_blended BudgetsBudget#use_blended}.
UseBlended interface{} `field:"optional" json:"useBlended" yaml:"useBlended"`
}
type BudgetsBudgetCostTypesOutputReference ¶
type BudgetsBudgetCostTypesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IncludeCredit() interface{}
SetIncludeCredit(val interface{})
IncludeCreditInput() interface{}
IncludeDiscount() interface{}
SetIncludeDiscount(val interface{})
IncludeDiscountInput() interface{}
IncludeOtherSubscription() interface{}
SetIncludeOtherSubscription(val interface{})
IncludeOtherSubscriptionInput() interface{}
IncludeRecurring() interface{}
SetIncludeRecurring(val interface{})
IncludeRecurringInput() interface{}
IncludeRefund() interface{}
SetIncludeRefund(val interface{})
IncludeRefundInput() interface{}
IncludeSubscription() interface{}
SetIncludeSubscription(val interface{})
IncludeSubscriptionInput() interface{}
IncludeSupport() interface{}
SetIncludeSupport(val interface{})
IncludeSupportInput() interface{}
IncludeTax() interface{}
SetIncludeTax(val interface{})
IncludeTaxInput() interface{}
IncludeUpfront() interface{}
SetIncludeUpfront(val interface{})
IncludeUpfrontInput() interface{}
InternalValue() *BudgetsBudgetCostTypes
SetInternalValue(val *BudgetsBudgetCostTypes)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UseAmortized() interface{}
SetUseAmortized(val interface{})
UseAmortizedInput() interface{}
UseBlended() interface{}
SetUseBlended(val interface{})
UseBlendedInput() interface{}
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetIncludeCredit()
ResetIncludeDiscount()
ResetIncludeOtherSubscription()
ResetIncludeRecurring()
ResetIncludeRefund()
ResetIncludeSubscription()
ResetIncludeSupport()
ResetIncludeTax()
ResetIncludeUpfront()
ResetUseAmortized()
ResetUseBlended()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBudgetsBudgetCostTypesOutputReference ¶
func NewBudgetsBudgetCostTypesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BudgetsBudgetCostTypesOutputReference
type BudgetsBudgetNotification ¶
type BudgetsBudgetNotification struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#comparison_operator BudgetsBudget#comparison_operator}.
ComparisonOperator *string `field:"required" json:"comparisonOperator" yaml:"comparisonOperator"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#notification_type BudgetsBudget#notification_type}.
NotificationType *string `field:"required" json:"notificationType" yaml:"notificationType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#threshold BudgetsBudget#threshold}.
Threshold *float64 `field:"required" json:"threshold" yaml:"threshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#threshold_type BudgetsBudget#threshold_type}.
ThresholdType *string `field:"required" json:"thresholdType" yaml:"thresholdType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#subscriber_email_addresses BudgetsBudget#subscriber_email_addresses}.
SubscriberEmailAddresses *[]*string `field:"optional" json:"subscriberEmailAddresses" yaml:"subscriberEmailAddresses"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#subscriber_sns_topic_arns BudgetsBudget#subscriber_sns_topic_arns}.
SubscriberSnsTopicArns *[]*string `field:"optional" json:"subscriberSnsTopicArns" yaml:"subscriberSnsTopicArns"`
}
type BudgetsBudgetNotificationList ¶
type BudgetsBudgetNotificationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) BudgetsBudgetNotificationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBudgetsBudgetNotificationList ¶
func NewBudgetsBudgetNotificationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) BudgetsBudgetNotificationList
type BudgetsBudgetNotificationOutputReference ¶
type BudgetsBudgetNotificationOutputReference interface {
cdktf.ComplexObject
ComparisonOperator() *string
SetComparisonOperator(val *string)
ComparisonOperatorInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
NotificationType() *string
SetNotificationType(val *string)
NotificationTypeInput() *string
SubscriberEmailAddresses() *[]*string
SetSubscriberEmailAddresses(val *[]*string)
SubscriberEmailAddressesInput() *[]*string
SubscriberSnsTopicArns() *[]*string
SetSubscriberSnsTopicArns(val *[]*string)
SubscriberSnsTopicArnsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Threshold() *float64
SetThreshold(val *float64)
ThresholdInput() *float64
ThresholdType() *string
SetThresholdType(val *string)
ThresholdTypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetSubscriberEmailAddresses()
ResetSubscriberSnsTopicArns()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBudgetsBudgetNotificationOutputReference ¶
func NewBudgetsBudgetNotificationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) BudgetsBudgetNotificationOutputReference
type BudgetsBudgetPlannedLimit ¶
type BudgetsBudgetPlannedLimit struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#amount BudgetsBudget#amount}.
Amount *string `field:"required" json:"amount" yaml:"amount"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#start_time BudgetsBudget#start_time}.
StartTime *string `field:"required" json:"startTime" yaml:"startTime"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/budgets_budget#unit BudgetsBudget#unit}.
Unit *string `field:"required" json:"unit" yaml:"unit"`
}
type BudgetsBudgetPlannedLimitList ¶
type BudgetsBudgetPlannedLimitList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) BudgetsBudgetPlannedLimitOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBudgetsBudgetPlannedLimitList ¶
func NewBudgetsBudgetPlannedLimitList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) BudgetsBudgetPlannedLimitList
type BudgetsBudgetPlannedLimitOutputReference ¶
type BudgetsBudgetPlannedLimitOutputReference interface {
cdktf.ComplexObject
Amount() *string
SetAmount(val *string)
AmountInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
StartTime() *string
SetStartTime(val *string)
StartTimeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Unit() *string
SetUnit(val *string)
UnitInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBudgetsBudgetPlannedLimitOutputReference ¶
func NewBudgetsBudgetPlannedLimitOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) BudgetsBudgetPlannedLimitOutputReference
Source Files
¶
- BudgetsBudget.go
- BudgetsBudgetAutoAdjustData.go
- BudgetsBudgetAutoAdjustDataHistoricalOptions.go
- BudgetsBudgetAutoAdjustDataHistoricalOptionsOutputReference.go
- BudgetsBudgetAutoAdjustDataHistoricalOptionsOutputReference__checks.go
- BudgetsBudgetAutoAdjustDataOutputReference.go
- BudgetsBudgetAutoAdjustDataOutputReference__checks.go
- BudgetsBudgetConfig.go
- BudgetsBudgetCostFilter.go
- BudgetsBudgetCostFilterList.go
- BudgetsBudgetCostFilterList__checks.go
- BudgetsBudgetCostFilterOutputReference.go
- BudgetsBudgetCostFilterOutputReference__checks.go
- BudgetsBudgetCostTypes.go
- BudgetsBudgetCostTypesOutputReference.go
- BudgetsBudgetCostTypesOutputReference__checks.go
- BudgetsBudgetNotification.go
- BudgetsBudgetNotificationList.go
- BudgetsBudgetNotificationList__checks.go
- BudgetsBudgetNotificationOutputReference.go
- BudgetsBudgetNotificationOutputReference__checks.go
- BudgetsBudgetPlannedLimit.go
- BudgetsBudgetPlannedLimitList.go
- BudgetsBudgetPlannedLimitList__checks.go
- BudgetsBudgetPlannedLimitOutputReference.go
- BudgetsBudgetPlannedLimitOutputReference__checks.go
- BudgetsBudget__checks.go
- main.go