Documentation
¶
Index ¶
- func CloudfrontRealtimeLogConfig_IsConstruct(x interface{}) *bool
- func CloudfrontRealtimeLogConfig_IsTerraformElement(x interface{}) *bool
- func CloudfrontRealtimeLogConfig_IsTerraformResource(x interface{}) *bool
- func CloudfrontRealtimeLogConfig_TfResourceType() *string
- func NewCloudfrontRealtimeLogConfigEndpointKinesisStreamConfigOutputReference_Override(c CloudfrontRealtimeLogConfigEndpointKinesisStreamConfigOutputReference, ...)
- func NewCloudfrontRealtimeLogConfigEndpointOutputReference_Override(c CloudfrontRealtimeLogConfigEndpointOutputReference, ...)
- func NewCloudfrontRealtimeLogConfig_Override(c CloudfrontRealtimeLogConfig, scope constructs.Construct, id *string, ...)
- type CloudfrontRealtimeLogConfig
- type CloudfrontRealtimeLogConfigConfig
- type CloudfrontRealtimeLogConfigEndpoint
- type CloudfrontRealtimeLogConfigEndpointKinesisStreamConfig
- type CloudfrontRealtimeLogConfigEndpointKinesisStreamConfigOutputReference
- type CloudfrontRealtimeLogConfigEndpointOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CloudfrontRealtimeLogConfig_IsConstruct ¶
func CloudfrontRealtimeLogConfig_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func CloudfrontRealtimeLogConfig_IsTerraformElement ¶
func CloudfrontRealtimeLogConfig_IsTerraformElement(x interface{}) *bool
Experimental.
func CloudfrontRealtimeLogConfig_IsTerraformResource ¶
func CloudfrontRealtimeLogConfig_IsTerraformResource(x interface{}) *bool
Experimental.
func CloudfrontRealtimeLogConfig_TfResourceType ¶
func CloudfrontRealtimeLogConfig_TfResourceType() *string
func NewCloudfrontRealtimeLogConfigEndpointKinesisStreamConfigOutputReference_Override ¶
func NewCloudfrontRealtimeLogConfigEndpointKinesisStreamConfigOutputReference_Override(c CloudfrontRealtimeLogConfigEndpointKinesisStreamConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCloudfrontRealtimeLogConfigEndpointOutputReference_Override ¶
func NewCloudfrontRealtimeLogConfigEndpointOutputReference_Override(c CloudfrontRealtimeLogConfigEndpointOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCloudfrontRealtimeLogConfig_Override ¶
func NewCloudfrontRealtimeLogConfig_Override(c CloudfrontRealtimeLogConfig, scope constructs.Construct, id *string, config *CloudfrontRealtimeLogConfigConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_realtime_log_config aws_cloudfront_realtime_log_config} Resource.
Types ¶
type CloudfrontRealtimeLogConfig ¶
type CloudfrontRealtimeLogConfig interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Endpoint() CloudfrontRealtimeLogConfigEndpointOutputReference
EndpointInput() *CloudfrontRealtimeLogConfigEndpoint
Fields() *[]*string
SetFields(val *[]*string)
FieldsInput() *[]*string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SamplingRate() *float64
SetSamplingRate(val *float64)
SamplingRateInput() *float64
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutEndpoint(value *CloudfrontRealtimeLogConfigEndpoint)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_realtime_log_config aws_cloudfront_realtime_log_config}.
func NewCloudfrontRealtimeLogConfig ¶
func NewCloudfrontRealtimeLogConfig(scope constructs.Construct, id *string, config *CloudfrontRealtimeLogConfigConfig) CloudfrontRealtimeLogConfig
Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_realtime_log_config aws_cloudfront_realtime_log_config} Resource.
type CloudfrontRealtimeLogConfigConfig ¶
type CloudfrontRealtimeLogConfigConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// endpoint block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_realtime_log_config#endpoint CloudfrontRealtimeLogConfig#endpoint}
Endpoint *CloudfrontRealtimeLogConfigEndpoint `field:"required" json:"endpoint" yaml:"endpoint"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_realtime_log_config#fields CloudfrontRealtimeLogConfig#fields}.
Fields *[]*string `field:"required" json:"fields" yaml:"fields"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_realtime_log_config#name CloudfrontRealtimeLogConfig#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_realtime_log_config#sampling_rate CloudfrontRealtimeLogConfig#sampling_rate}.
SamplingRate *float64 `field:"required" json:"samplingRate" yaml:"samplingRate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_realtime_log_config#id CloudfrontRealtimeLogConfig#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type CloudfrontRealtimeLogConfigEndpoint ¶
type CloudfrontRealtimeLogConfigEndpoint struct {
// kinesis_stream_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_realtime_log_config#kinesis_stream_config CloudfrontRealtimeLogConfig#kinesis_stream_config}
KinesisStreamConfig *CloudfrontRealtimeLogConfigEndpointKinesisStreamConfig `field:"required" json:"kinesisStreamConfig" yaml:"kinesisStreamConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_realtime_log_config#stream_type CloudfrontRealtimeLogConfig#stream_type}.
StreamType *string `field:"required" json:"streamType" yaml:"streamType"`
}
type CloudfrontRealtimeLogConfigEndpointKinesisStreamConfig ¶
type CloudfrontRealtimeLogConfigEndpointKinesisStreamConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_realtime_log_config#role_arn CloudfrontRealtimeLogConfig#role_arn}.
RoleArn *string `field:"required" json:"roleArn" yaml:"roleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudfront_realtime_log_config#stream_arn CloudfrontRealtimeLogConfig#stream_arn}.
StreamArn *string `field:"required" json:"streamArn" yaml:"streamArn"`
}
type CloudfrontRealtimeLogConfigEndpointKinesisStreamConfigOutputReference ¶
type CloudfrontRealtimeLogConfigEndpointKinesisStreamConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *CloudfrontRealtimeLogConfigEndpointKinesisStreamConfig
SetInternalValue(val *CloudfrontRealtimeLogConfigEndpointKinesisStreamConfig)
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
StreamArn() *string
SetStreamArn(val *string)
StreamArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudfrontRealtimeLogConfigEndpointKinesisStreamConfigOutputReference ¶
func NewCloudfrontRealtimeLogConfigEndpointKinesisStreamConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CloudfrontRealtimeLogConfigEndpointKinesisStreamConfigOutputReference
type CloudfrontRealtimeLogConfigEndpointOutputReference ¶
type CloudfrontRealtimeLogConfigEndpointOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *CloudfrontRealtimeLogConfigEndpoint
SetInternalValue(val *CloudfrontRealtimeLogConfigEndpoint)
KinesisStreamConfig() CloudfrontRealtimeLogConfigEndpointKinesisStreamConfigOutputReference
KinesisStreamConfigInput() *CloudfrontRealtimeLogConfigEndpointKinesisStreamConfig
StreamType() *string
SetStreamType(val *string)
StreamTypeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutKinesisStreamConfig(value *CloudfrontRealtimeLogConfigEndpointKinesisStreamConfig)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudfrontRealtimeLogConfigEndpointOutputReference ¶
func NewCloudfrontRealtimeLogConfigEndpointOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CloudfrontRealtimeLogConfigEndpointOutputReference
Source Files
¶
- CloudfrontRealtimeLogConfig.go
- CloudfrontRealtimeLogConfigConfig.go
- CloudfrontRealtimeLogConfigEndpoint.go
- CloudfrontRealtimeLogConfigEndpointKinesisStreamConfig.go
- CloudfrontRealtimeLogConfigEndpointKinesisStreamConfigOutputReference.go
- CloudfrontRealtimeLogConfigEndpointKinesisStreamConfigOutputReference__checks.go
- CloudfrontRealtimeLogConfigEndpointOutputReference.go
- CloudfrontRealtimeLogConfigEndpointOutputReference__checks.go
- CloudfrontRealtimeLogConfig__checks.go
- main.go