Documentation
¶
Index ¶
- func Cloudtrail_IsConstruct(x interface{}) *bool
- func Cloudtrail_IsTerraformElement(x interface{}) *bool
- func Cloudtrail_IsTerraformResource(x interface{}) *bool
- func Cloudtrail_TfResourceType() *string
- func NewCloudtrailAdvancedEventSelectorFieldSelectorList_Override(c CloudtrailAdvancedEventSelectorFieldSelectorList, ...)
- func NewCloudtrailAdvancedEventSelectorFieldSelectorOutputReference_Override(c CloudtrailAdvancedEventSelectorFieldSelectorOutputReference, ...)
- func NewCloudtrailAdvancedEventSelectorList_Override(c CloudtrailAdvancedEventSelectorList, ...)
- func NewCloudtrailAdvancedEventSelectorOutputReference_Override(c CloudtrailAdvancedEventSelectorOutputReference, ...)
- func NewCloudtrailEventSelectorDataResourceList_Override(c CloudtrailEventSelectorDataResourceList, ...)
- func NewCloudtrailEventSelectorDataResourceOutputReference_Override(c CloudtrailEventSelectorDataResourceOutputReference, ...)
- func NewCloudtrailEventSelectorList_Override(c CloudtrailEventSelectorList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewCloudtrailEventSelectorOutputReference_Override(c CloudtrailEventSelectorOutputReference, ...)
- func NewCloudtrailInsightSelectorList_Override(c CloudtrailInsightSelectorList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewCloudtrailInsightSelectorOutputReference_Override(c CloudtrailInsightSelectorOutputReference, ...)
- func NewCloudtrail_Override(c Cloudtrail, scope constructs.Construct, id *string, config *CloudtrailConfig)
- type Cloudtrail
- type CloudtrailAdvancedEventSelector
- type CloudtrailAdvancedEventSelectorFieldSelector
- type CloudtrailAdvancedEventSelectorFieldSelectorList
- type CloudtrailAdvancedEventSelectorFieldSelectorOutputReference
- type CloudtrailAdvancedEventSelectorList
- type CloudtrailAdvancedEventSelectorOutputReference
- type CloudtrailConfig
- type CloudtrailEventSelector
- type CloudtrailEventSelectorDataResource
- type CloudtrailEventSelectorDataResourceList
- type CloudtrailEventSelectorDataResourceOutputReference
- type CloudtrailEventSelectorList
- type CloudtrailEventSelectorOutputReference
- type CloudtrailInsightSelector
- type CloudtrailInsightSelectorList
- type CloudtrailInsightSelectorOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Cloudtrail_IsConstruct ¶
func Cloudtrail_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func Cloudtrail_IsTerraformElement ¶
func Cloudtrail_IsTerraformElement(x interface{}) *bool
Experimental.
func Cloudtrail_IsTerraformResource ¶
func Cloudtrail_IsTerraformResource(x interface{}) *bool
Experimental.
func Cloudtrail_TfResourceType ¶
func Cloudtrail_TfResourceType() *string
func NewCloudtrailAdvancedEventSelectorFieldSelectorList_Override ¶
func NewCloudtrailAdvancedEventSelectorFieldSelectorList_Override(c CloudtrailAdvancedEventSelectorFieldSelectorList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCloudtrailAdvancedEventSelectorFieldSelectorOutputReference_Override ¶
func NewCloudtrailAdvancedEventSelectorFieldSelectorOutputReference_Override(c CloudtrailAdvancedEventSelectorFieldSelectorOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCloudtrailAdvancedEventSelectorList_Override ¶
func NewCloudtrailAdvancedEventSelectorList_Override(c CloudtrailAdvancedEventSelectorList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCloudtrailAdvancedEventSelectorOutputReference_Override ¶
func NewCloudtrailAdvancedEventSelectorOutputReference_Override(c CloudtrailAdvancedEventSelectorOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCloudtrailEventSelectorDataResourceList_Override ¶
func NewCloudtrailEventSelectorDataResourceList_Override(c CloudtrailEventSelectorDataResourceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCloudtrailEventSelectorDataResourceOutputReference_Override ¶
func NewCloudtrailEventSelectorDataResourceOutputReference_Override(c CloudtrailEventSelectorDataResourceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCloudtrailEventSelectorList_Override ¶
func NewCloudtrailEventSelectorList_Override(c CloudtrailEventSelectorList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCloudtrailEventSelectorOutputReference_Override ¶
func NewCloudtrailEventSelectorOutputReference_Override(c CloudtrailEventSelectorOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCloudtrailInsightSelectorList_Override ¶
func NewCloudtrailInsightSelectorList_Override(c CloudtrailInsightSelectorList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCloudtrailInsightSelectorOutputReference_Override ¶
func NewCloudtrailInsightSelectorOutputReference_Override(c CloudtrailInsightSelectorOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCloudtrail_Override ¶
func NewCloudtrail_Override(c Cloudtrail, scope constructs.Construct, id *string, config *CloudtrailConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail aws_cloudtrail} Resource.
Types ¶
type Cloudtrail ¶
type Cloudtrail interface {
cdktf.TerraformResource
AdvancedEventSelector() CloudtrailAdvancedEventSelectorList
AdvancedEventSelectorInput() interface{}
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CloudWatchLogsGroupArn() *string
SetCloudWatchLogsGroupArn(val *string)
CloudWatchLogsGroupArnInput() *string
CloudWatchLogsRoleArn() *string
SetCloudWatchLogsRoleArn(val *string)
CloudWatchLogsRoleArnInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EnableLogFileValidation() interface{}
SetEnableLogFileValidation(val interface{})
EnableLogFileValidationInput() interface{}
EnableLogging() interface{}
SetEnableLogging(val interface{})
EnableLoggingInput() interface{}
EventSelector() CloudtrailEventSelectorList
EventSelectorInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HomeRegion() *string
Id() *string
SetId(val *string)
IdInput() *string
IncludeGlobalServiceEvents() interface{}
SetIncludeGlobalServiceEvents(val interface{})
IncludeGlobalServiceEventsInput() interface{}
InsightSelector() CloudtrailInsightSelectorList
InsightSelectorInput() interface{}
IsMultiRegionTrail() interface{}
SetIsMultiRegionTrail(val interface{})
IsMultiRegionTrailInput() interface{}
IsOrganizationTrail() interface{}
SetIsOrganizationTrail(val interface{})
IsOrganizationTrailInput() interface{}
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
S3BucketName() *string
SetS3BucketName(val *string)
S3BucketNameInput() *string
S3KeyPrefix() *string
SetS3KeyPrefix(val *string)
S3KeyPrefixInput() *string
SnsTopicName() *string
SetSnsTopicName(val *string)
SnsTopicNameInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAdvancedEventSelector(value interface{})
PutEventSelector(value interface{})
PutInsightSelector(value interface{})
ResetAdvancedEventSelector()
ResetCloudWatchLogsGroupArn()
ResetCloudWatchLogsRoleArn()
ResetEnableLogFileValidation()
ResetEnableLogging()
ResetEventSelector()
ResetId()
ResetIncludeGlobalServiceEvents()
ResetInsightSelector()
ResetIsMultiRegionTrail()
ResetIsOrganizationTrail()
ResetKmsKeyId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetS3KeyPrefix()
ResetSnsTopicName()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail aws_cloudtrail}.
func NewCloudtrail ¶
func NewCloudtrail(scope constructs.Construct, id *string, config *CloudtrailConfig) Cloudtrail
Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail aws_cloudtrail} Resource.
type CloudtrailAdvancedEventSelector ¶
type CloudtrailAdvancedEventSelector struct {
// field_selector block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#field_selector Cloudtrail#field_selector}
FieldSelector interface{} `field:"required" json:"fieldSelector" yaml:"fieldSelector"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#name Cloudtrail#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
}
type CloudtrailAdvancedEventSelectorFieldSelector ¶
type CloudtrailAdvancedEventSelectorFieldSelector struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#field Cloudtrail#field}.
Field *string `field:"required" json:"field" yaml:"field"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#ends_with Cloudtrail#ends_with}.
EndsWith *[]*string `field:"optional" json:"endsWith" yaml:"endsWith"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#equals Cloudtrail#equals}.
EqualTo *[]*string `field:"optional" json:"equalTo" yaml:"equalTo"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#not_ends_with Cloudtrail#not_ends_with}.
NotEndsWith *[]*string `field:"optional" json:"notEndsWith" yaml:"notEndsWith"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#not_equals Cloudtrail#not_equals}.
NotEquals *[]*string `field:"optional" json:"notEquals" yaml:"notEquals"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#not_starts_with Cloudtrail#not_starts_with}.
NotStartsWith *[]*string `field:"optional" json:"notStartsWith" yaml:"notStartsWith"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#starts_with Cloudtrail#starts_with}.
StartsWith *[]*string `field:"optional" json:"startsWith" yaml:"startsWith"`
}
type CloudtrailAdvancedEventSelectorFieldSelectorList ¶
type CloudtrailAdvancedEventSelectorFieldSelectorList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CloudtrailAdvancedEventSelectorFieldSelectorOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudtrailAdvancedEventSelectorFieldSelectorList ¶
func NewCloudtrailAdvancedEventSelectorFieldSelectorList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CloudtrailAdvancedEventSelectorFieldSelectorList
type CloudtrailAdvancedEventSelectorFieldSelectorOutputReference ¶
type CloudtrailAdvancedEventSelectorFieldSelectorOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EndsWith() *[]*string
SetEndsWith(val *[]*string)
EndsWithInput() *[]*string
EqualTo() *[]*string
SetEqualTo(val *[]*string)
EqualToInput() *[]*string
Field() *string
SetField(val *string)
FieldInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
NotEndsWith() *[]*string
SetNotEndsWith(val *[]*string)
NotEndsWithInput() *[]*string
NotEquals() *[]*string
SetNotEquals(val *[]*string)
NotEqualsInput() *[]*string
NotStartsWith() *[]*string
SetNotStartsWith(val *[]*string)
NotStartsWithInput() *[]*string
StartsWith() *[]*string
SetStartsWith(val *[]*string)
StartsWithInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEndsWith()
ResetEqualTo()
ResetNotEndsWith()
ResetNotEquals()
ResetNotStartsWith()
ResetStartsWith()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudtrailAdvancedEventSelectorFieldSelectorOutputReference ¶
func NewCloudtrailAdvancedEventSelectorFieldSelectorOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CloudtrailAdvancedEventSelectorFieldSelectorOutputReference
type CloudtrailAdvancedEventSelectorList ¶
type CloudtrailAdvancedEventSelectorList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CloudtrailAdvancedEventSelectorOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudtrailAdvancedEventSelectorList ¶
func NewCloudtrailAdvancedEventSelectorList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CloudtrailAdvancedEventSelectorList
type CloudtrailAdvancedEventSelectorOutputReference ¶
type CloudtrailAdvancedEventSelectorOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FieldSelector() CloudtrailAdvancedEventSelectorFieldSelectorList
FieldSelectorInput() interface{}
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutFieldSelector(value interface{})
ResetName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudtrailAdvancedEventSelectorOutputReference ¶
func NewCloudtrailAdvancedEventSelectorOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CloudtrailAdvancedEventSelectorOutputReference
type CloudtrailConfig ¶
type CloudtrailConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#name Cloudtrail#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#s3_bucket_name Cloudtrail#s3_bucket_name}.
S3BucketName *string `field:"required" json:"s3BucketName" yaml:"s3BucketName"`
// advanced_event_selector block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#advanced_event_selector Cloudtrail#advanced_event_selector}
AdvancedEventSelector interface{} `field:"optional" json:"advancedEventSelector" yaml:"advancedEventSelector"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#cloud_watch_logs_group_arn Cloudtrail#cloud_watch_logs_group_arn}.
CloudWatchLogsGroupArn *string `field:"optional" json:"cloudWatchLogsGroupArn" yaml:"cloudWatchLogsGroupArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#cloud_watch_logs_role_arn Cloudtrail#cloud_watch_logs_role_arn}.
CloudWatchLogsRoleArn *string `field:"optional" json:"cloudWatchLogsRoleArn" yaml:"cloudWatchLogsRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#enable_log_file_validation Cloudtrail#enable_log_file_validation}.
EnableLogFileValidation interface{} `field:"optional" json:"enableLogFileValidation" yaml:"enableLogFileValidation"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#enable_logging Cloudtrail#enable_logging}.
EnableLogging interface{} `field:"optional" json:"enableLogging" yaml:"enableLogging"`
// event_selector block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#event_selector Cloudtrail#event_selector}
EventSelector interface{} `field:"optional" json:"eventSelector" yaml:"eventSelector"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#id Cloudtrail#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#include_global_service_events Cloudtrail#include_global_service_events}.
IncludeGlobalServiceEvents interface{} `field:"optional" json:"includeGlobalServiceEvents" yaml:"includeGlobalServiceEvents"`
// insight_selector block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#insight_selector Cloudtrail#insight_selector}
InsightSelector interface{} `field:"optional" json:"insightSelector" yaml:"insightSelector"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#is_multi_region_trail Cloudtrail#is_multi_region_trail}.
IsMultiRegionTrail interface{} `field:"optional" json:"isMultiRegionTrail" yaml:"isMultiRegionTrail"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#is_organization_trail Cloudtrail#is_organization_trail}.
IsOrganizationTrail interface{} `field:"optional" json:"isOrganizationTrail" yaml:"isOrganizationTrail"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#kms_key_id Cloudtrail#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#s3_key_prefix Cloudtrail#s3_key_prefix}.
S3KeyPrefix *string `field:"optional" json:"s3KeyPrefix" yaml:"s3KeyPrefix"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#sns_topic_name Cloudtrail#sns_topic_name}.
SnsTopicName *string `field:"optional" json:"snsTopicName" yaml:"snsTopicName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#tags Cloudtrail#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#tags_all Cloudtrail#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type CloudtrailEventSelector ¶
type CloudtrailEventSelector struct {
// data_resource block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#data_resource Cloudtrail#data_resource}
DataResource interface{} `field:"optional" json:"dataResource" yaml:"dataResource"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#exclude_management_event_sources Cloudtrail#exclude_management_event_sources}.
ExcludeManagementEventSources *[]*string `field:"optional" json:"excludeManagementEventSources" yaml:"excludeManagementEventSources"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#include_management_events Cloudtrail#include_management_events}.
IncludeManagementEvents interface{} `field:"optional" json:"includeManagementEvents" yaml:"includeManagementEvents"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#read_write_type Cloudtrail#read_write_type}.
ReadWriteType *string `field:"optional" json:"readWriteType" yaml:"readWriteType"`
}
type CloudtrailEventSelectorDataResource ¶
type CloudtrailEventSelectorDataResource struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#type Cloudtrail#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#values Cloudtrail#values}.
Values *[]*string `field:"required" json:"values" yaml:"values"`
}
type CloudtrailEventSelectorDataResourceList ¶
type CloudtrailEventSelectorDataResourceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CloudtrailEventSelectorDataResourceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudtrailEventSelectorDataResourceList ¶
func NewCloudtrailEventSelectorDataResourceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CloudtrailEventSelectorDataResourceList
type CloudtrailEventSelectorDataResourceOutputReference ¶
type CloudtrailEventSelectorDataResourceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
Values() *[]*string
SetValues(val *[]*string)
ValuesInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudtrailEventSelectorDataResourceOutputReference ¶
func NewCloudtrailEventSelectorDataResourceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CloudtrailEventSelectorDataResourceOutputReference
type CloudtrailEventSelectorList ¶
type CloudtrailEventSelectorList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CloudtrailEventSelectorOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudtrailEventSelectorList ¶
func NewCloudtrailEventSelectorList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CloudtrailEventSelectorList
type CloudtrailEventSelectorOutputReference ¶
type CloudtrailEventSelectorOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DataResource() CloudtrailEventSelectorDataResourceList
DataResourceInput() interface{}
ExcludeManagementEventSources() *[]*string
SetExcludeManagementEventSources(val *[]*string)
ExcludeManagementEventSourcesInput() *[]*string
// Experimental.
Fqn() *string
IncludeManagementEvents() interface{}
SetIncludeManagementEvents(val interface{})
IncludeManagementEventsInput() interface{}
InternalValue() interface{}
SetInternalValue(val interface{})
ReadWriteType() *string
SetReadWriteType(val *string)
ReadWriteTypeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutDataResource(value interface{})
ResetDataResource()
ResetExcludeManagementEventSources()
ResetIncludeManagementEvents()
ResetReadWriteType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudtrailEventSelectorOutputReference ¶
func NewCloudtrailEventSelectorOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CloudtrailEventSelectorOutputReference
type CloudtrailInsightSelector ¶
type CloudtrailInsightSelector struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudtrail#insight_type Cloudtrail#insight_type}.
InsightType *string `field:"required" json:"insightType" yaml:"insightType"`
}
type CloudtrailInsightSelectorList ¶
type CloudtrailInsightSelectorList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CloudtrailInsightSelectorOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudtrailInsightSelectorList ¶
func NewCloudtrailInsightSelectorList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CloudtrailInsightSelectorList
type CloudtrailInsightSelectorOutputReference ¶
type CloudtrailInsightSelectorOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InsightType() *string
SetInsightType(val *string)
InsightTypeInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudtrailInsightSelectorOutputReference ¶
func NewCloudtrailInsightSelectorOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CloudtrailInsightSelectorOutputReference
Source Files
¶
- Cloudtrail.go
- CloudtrailAdvancedEventSelector.go
- CloudtrailAdvancedEventSelectorFieldSelector.go
- CloudtrailAdvancedEventSelectorFieldSelectorList.go
- CloudtrailAdvancedEventSelectorFieldSelectorList__checks.go
- CloudtrailAdvancedEventSelectorFieldSelectorOutputReference.go
- CloudtrailAdvancedEventSelectorFieldSelectorOutputReference__checks.go
- CloudtrailAdvancedEventSelectorList.go
- CloudtrailAdvancedEventSelectorList__checks.go
- CloudtrailAdvancedEventSelectorOutputReference.go
- CloudtrailAdvancedEventSelectorOutputReference__checks.go
- CloudtrailConfig.go
- CloudtrailEventSelector.go
- CloudtrailEventSelectorDataResource.go
- CloudtrailEventSelectorDataResourceList.go
- CloudtrailEventSelectorDataResourceList__checks.go
- CloudtrailEventSelectorDataResourceOutputReference.go
- CloudtrailEventSelectorDataResourceOutputReference__checks.go
- CloudtrailEventSelectorList.go
- CloudtrailEventSelectorList__checks.go
- CloudtrailEventSelectorOutputReference.go
- CloudtrailEventSelectorOutputReference__checks.go
- CloudtrailInsightSelector.go
- CloudtrailInsightSelectorList.go
- CloudtrailInsightSelectorList__checks.go
- CloudtrailInsightSelectorOutputReference.go
- CloudtrailInsightSelectorOutputReference__checks.go
- Cloudtrail__checks.go
- main.go