Documentation
¶
Index ¶
- func CloudwatchLogMetricFilter_IsConstruct(x interface{}) *bool
- func CloudwatchLogMetricFilter_IsTerraformElement(x interface{}) *bool
- func CloudwatchLogMetricFilter_IsTerraformResource(x interface{}) *bool
- func CloudwatchLogMetricFilter_TfResourceType() *string
- func NewCloudwatchLogMetricFilterMetricTransformationOutputReference_Override(c CloudwatchLogMetricFilterMetricTransformationOutputReference, ...)
- func NewCloudwatchLogMetricFilter_Override(c CloudwatchLogMetricFilter, scope constructs.Construct, id *string, ...)
- type CloudwatchLogMetricFilter
- type CloudwatchLogMetricFilterConfig
- type CloudwatchLogMetricFilterMetricTransformation
- type CloudwatchLogMetricFilterMetricTransformationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CloudwatchLogMetricFilter_IsConstruct ¶
func CloudwatchLogMetricFilter_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func CloudwatchLogMetricFilter_IsTerraformElement ¶
func CloudwatchLogMetricFilter_IsTerraformElement(x interface{}) *bool
Experimental.
func CloudwatchLogMetricFilter_IsTerraformResource ¶
func CloudwatchLogMetricFilter_IsTerraformResource(x interface{}) *bool
Experimental.
func CloudwatchLogMetricFilter_TfResourceType ¶
func CloudwatchLogMetricFilter_TfResourceType() *string
func NewCloudwatchLogMetricFilterMetricTransformationOutputReference_Override ¶
func NewCloudwatchLogMetricFilterMetricTransformationOutputReference_Override(c CloudwatchLogMetricFilterMetricTransformationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCloudwatchLogMetricFilter_Override ¶
func NewCloudwatchLogMetricFilter_Override(c CloudwatchLogMetricFilter, scope constructs.Construct, id *string, config *CloudwatchLogMetricFilterConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_log_metric_filter aws_cloudwatch_log_metric_filter} Resource.
Types ¶
type CloudwatchLogMetricFilter ¶
type CloudwatchLogMetricFilter interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LogGroupName() *string
SetLogGroupName(val *string)
LogGroupNameInput() *string
MetricTransformation() CloudwatchLogMetricFilterMetricTransformationOutputReference
MetricTransformationInput() *CloudwatchLogMetricFilterMetricTransformation
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Pattern() *string
SetPattern(val *string)
PatternInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutMetricTransformation(value *CloudwatchLogMetricFilterMetricTransformation)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_log_metric_filter aws_cloudwatch_log_metric_filter}.
func NewCloudwatchLogMetricFilter ¶
func NewCloudwatchLogMetricFilter(scope constructs.Construct, id *string, config *CloudwatchLogMetricFilterConfig) CloudwatchLogMetricFilter
Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_log_metric_filter aws_cloudwatch_log_metric_filter} Resource.
type CloudwatchLogMetricFilterConfig ¶
type CloudwatchLogMetricFilterConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_log_metric_filter#log_group_name CloudwatchLogMetricFilter#log_group_name}.
LogGroupName *string `field:"required" json:"logGroupName" yaml:"logGroupName"`
// metric_transformation block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_log_metric_filter#metric_transformation CloudwatchLogMetricFilter#metric_transformation}
MetricTransformation *CloudwatchLogMetricFilterMetricTransformation `field:"required" json:"metricTransformation" yaml:"metricTransformation"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_log_metric_filter#name CloudwatchLogMetricFilter#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_log_metric_filter#pattern CloudwatchLogMetricFilter#pattern}.
Pattern *string `field:"required" json:"pattern" yaml:"pattern"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_log_metric_filter#id CloudwatchLogMetricFilter#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type CloudwatchLogMetricFilterMetricTransformation ¶
type CloudwatchLogMetricFilterMetricTransformation struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_log_metric_filter#name CloudwatchLogMetricFilter#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_log_metric_filter#namespace CloudwatchLogMetricFilter#namespace}.
Namespace *string `field:"required" json:"namespace" yaml:"namespace"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_log_metric_filter#value CloudwatchLogMetricFilter#value}.
Value *string `field:"required" json:"value" yaml:"value"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_log_metric_filter#default_value CloudwatchLogMetricFilter#default_value}.
DefaultValue *string `field:"optional" json:"defaultValue" yaml:"defaultValue"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_log_metric_filter#dimensions CloudwatchLogMetricFilter#dimensions}.
Dimensions *map[string]*string `field:"optional" json:"dimensions" yaml:"dimensions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudwatch_log_metric_filter#unit CloudwatchLogMetricFilter#unit}.
Unit *string `field:"optional" json:"unit" yaml:"unit"`
}
type CloudwatchLogMetricFilterMetricTransformationOutputReference ¶
type CloudwatchLogMetricFilterMetricTransformationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DefaultValue() *string
SetDefaultValue(val *string)
DefaultValueInput() *string
Dimensions() *map[string]*string
SetDimensions(val *map[string]*string)
DimensionsInput() *map[string]*string
// Experimental.
Fqn() *string
InternalValue() *CloudwatchLogMetricFilterMetricTransformation
SetInternalValue(val *CloudwatchLogMetricFilterMetricTransformation)
Name() *string
SetName(val *string)
NameInput() *string
Namespace() *string
SetNamespace(val *string)
NamespaceInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Unit() *string
SetUnit(val *string)
UnitInput() *string
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDefaultValue()
ResetDimensions()
ResetUnit()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudwatchLogMetricFilterMetricTransformationOutputReference ¶
func NewCloudwatchLogMetricFilterMetricTransformationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CloudwatchLogMetricFilterMetricTransformationOutputReference