Documentation
¶
Index ¶
- func CodebuildReportGroup_IsConstruct(x interface{}) *bool
- func CodebuildReportGroup_IsTerraformElement(x interface{}) *bool
- func CodebuildReportGroup_IsTerraformResource(x interface{}) *bool
- func CodebuildReportGroup_TfResourceType() *string
- func NewCodebuildReportGroupExportConfigOutputReference_Override(c CodebuildReportGroupExportConfigOutputReference, ...)
- func NewCodebuildReportGroupExportConfigS3DestinationOutputReference_Override(c CodebuildReportGroupExportConfigS3DestinationOutputReference, ...)
- func NewCodebuildReportGroup_Override(c CodebuildReportGroup, scope constructs.Construct, id *string, ...)
- type CodebuildReportGroup
- type CodebuildReportGroupConfig
- type CodebuildReportGroupExportConfig
- type CodebuildReportGroupExportConfigOutputReference
- type CodebuildReportGroupExportConfigS3Destination
- type CodebuildReportGroupExportConfigS3DestinationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CodebuildReportGroup_IsConstruct ¶
func CodebuildReportGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func CodebuildReportGroup_IsTerraformElement ¶
func CodebuildReportGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func CodebuildReportGroup_IsTerraformResource ¶
func CodebuildReportGroup_IsTerraformResource(x interface{}) *bool
Experimental.
func CodebuildReportGroup_TfResourceType ¶
func CodebuildReportGroup_TfResourceType() *string
func NewCodebuildReportGroupExportConfigOutputReference_Override ¶
func NewCodebuildReportGroupExportConfigOutputReference_Override(c CodebuildReportGroupExportConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCodebuildReportGroupExportConfigS3DestinationOutputReference_Override ¶
func NewCodebuildReportGroupExportConfigS3DestinationOutputReference_Override(c CodebuildReportGroupExportConfigS3DestinationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCodebuildReportGroup_Override ¶
func NewCodebuildReportGroup_Override(c CodebuildReportGroup, scope constructs.Construct, id *string, config *CodebuildReportGroupConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/codebuild_report_group aws_codebuild_report_group} Resource.
Types ¶
type CodebuildReportGroup ¶
type CodebuildReportGroup interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
Created() *string
DeleteReports() interface{}
SetDeleteReports(val interface{})
DeleteReportsInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
ExportConfig() CodebuildReportGroupExportConfigOutputReference
ExportConfigInput() *CodebuildReportGroupExportConfig
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutExportConfig(value *CodebuildReportGroupExportConfig)
ResetDeleteReports()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/codebuild_report_group aws_codebuild_report_group}.
func NewCodebuildReportGroup ¶
func NewCodebuildReportGroup(scope constructs.Construct, id *string, config *CodebuildReportGroupConfig) CodebuildReportGroup
Create a new {@link https://www.terraform.io/docs/providers/aws/r/codebuild_report_group aws_codebuild_report_group} Resource.
type CodebuildReportGroupConfig ¶
type CodebuildReportGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// export_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codebuild_report_group#export_config CodebuildReportGroup#export_config}
ExportConfig *CodebuildReportGroupExportConfig `field:"required" json:"exportConfig" yaml:"exportConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codebuild_report_group#name CodebuildReportGroup#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codebuild_report_group#type CodebuildReportGroup#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codebuild_report_group#delete_reports CodebuildReportGroup#delete_reports}.
DeleteReports interface{} `field:"optional" json:"deleteReports" yaml:"deleteReports"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codebuild_report_group#id CodebuildReportGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codebuild_report_group#tags CodebuildReportGroup#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codebuild_report_group#tags_all CodebuildReportGroup#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type CodebuildReportGroupExportConfig ¶
type CodebuildReportGroupExportConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codebuild_report_group#type CodebuildReportGroup#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// s3_destination block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codebuild_report_group#s3_destination CodebuildReportGroup#s3_destination}
S3Destination *CodebuildReportGroupExportConfigS3Destination `field:"optional" json:"s3Destination" yaml:"s3Destination"`
}
type CodebuildReportGroupExportConfigOutputReference ¶
type CodebuildReportGroupExportConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *CodebuildReportGroupExportConfig
SetInternalValue(val *CodebuildReportGroupExportConfig)
S3Destination() CodebuildReportGroupExportConfigS3DestinationOutputReference
S3DestinationInput() *CodebuildReportGroupExportConfigS3Destination
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutS3Destination(value *CodebuildReportGroupExportConfigS3Destination)
ResetS3Destination()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCodebuildReportGroupExportConfigOutputReference ¶
func NewCodebuildReportGroupExportConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CodebuildReportGroupExportConfigOutputReference
type CodebuildReportGroupExportConfigS3Destination ¶
type CodebuildReportGroupExportConfigS3Destination struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codebuild_report_group#bucket CodebuildReportGroup#bucket}.
Bucket *string `field:"required" json:"bucket" yaml:"bucket"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codebuild_report_group#encryption_key CodebuildReportGroup#encryption_key}.
EncryptionKey *string `field:"required" json:"encryptionKey" yaml:"encryptionKey"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codebuild_report_group#encryption_disabled CodebuildReportGroup#encryption_disabled}.
EncryptionDisabled interface{} `field:"optional" json:"encryptionDisabled" yaml:"encryptionDisabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codebuild_report_group#packaging CodebuildReportGroup#packaging}.
Packaging *string `field:"optional" json:"packaging" yaml:"packaging"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codebuild_report_group#path CodebuildReportGroup#path}.
Path *string `field:"optional" json:"path" yaml:"path"`
}
type CodebuildReportGroupExportConfigS3DestinationOutputReference ¶
type CodebuildReportGroupExportConfigS3DestinationOutputReference interface {
cdktf.ComplexObject
Bucket() *string
SetBucket(val *string)
BucketInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EncryptionDisabled() interface{}
SetEncryptionDisabled(val interface{})
EncryptionDisabledInput() interface{}
EncryptionKey() *string
SetEncryptionKey(val *string)
EncryptionKeyInput() *string
// Experimental.
Fqn() *string
InternalValue() *CodebuildReportGroupExportConfigS3Destination
SetInternalValue(val *CodebuildReportGroupExportConfigS3Destination)
Packaging() *string
SetPackaging(val *string)
PackagingInput() *string
Path() *string
SetPath(val *string)
PathInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEncryptionDisabled()
ResetPackaging()
ResetPath()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCodebuildReportGroupExportConfigS3DestinationOutputReference ¶
func NewCodebuildReportGroupExportConfigS3DestinationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CodebuildReportGroupExportConfigS3DestinationOutputReference
Source Files
¶
- CodebuildReportGroup.go
- CodebuildReportGroupConfig.go
- CodebuildReportGroupExportConfig.go
- CodebuildReportGroupExportConfigOutputReference.go
- CodebuildReportGroupExportConfigOutputReference__checks.go
- CodebuildReportGroupExportConfigS3Destination.go
- CodebuildReportGroupExportConfigS3DestinationOutputReference.go
- CodebuildReportGroupExportConfigS3DestinationOutputReference__checks.go
- CodebuildReportGroup__checks.go
- main.go