Documentation
¶
Index ¶
- func CodepipelineCustomActionType_IsConstruct(x interface{}) *bool
- func CodepipelineCustomActionType_IsTerraformElement(x interface{}) *bool
- func CodepipelineCustomActionType_IsTerraformResource(x interface{}) *bool
- func CodepipelineCustomActionType_TfResourceType() *string
- func NewCodepipelineCustomActionTypeConfigurationPropertyList_Override(c CodepipelineCustomActionTypeConfigurationPropertyList, ...)
- func NewCodepipelineCustomActionTypeConfigurationPropertyOutputReference_Override(c CodepipelineCustomActionTypeConfigurationPropertyOutputReference, ...)
- func NewCodepipelineCustomActionTypeInputArtifactDetailsOutputReference_Override(c CodepipelineCustomActionTypeInputArtifactDetailsOutputReference, ...)
- func NewCodepipelineCustomActionTypeOutputArtifactDetailsOutputReference_Override(c CodepipelineCustomActionTypeOutputArtifactDetailsOutputReference, ...)
- func NewCodepipelineCustomActionTypeSettingsOutputReference_Override(c CodepipelineCustomActionTypeSettingsOutputReference, ...)
- func NewCodepipelineCustomActionType_Override(c CodepipelineCustomActionType, scope constructs.Construct, id *string, ...)
- type CodepipelineCustomActionType
- type CodepipelineCustomActionTypeConfig
- type CodepipelineCustomActionTypeConfigurationProperty
- type CodepipelineCustomActionTypeConfigurationPropertyList
- type CodepipelineCustomActionTypeConfigurationPropertyOutputReference
- type CodepipelineCustomActionTypeInputArtifactDetails
- type CodepipelineCustomActionTypeInputArtifactDetailsOutputReference
- type CodepipelineCustomActionTypeOutputArtifactDetails
- type CodepipelineCustomActionTypeOutputArtifactDetailsOutputReference
- type CodepipelineCustomActionTypeSettings
- type CodepipelineCustomActionTypeSettingsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CodepipelineCustomActionType_IsConstruct ¶
func CodepipelineCustomActionType_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func CodepipelineCustomActionType_IsTerraformElement ¶
func CodepipelineCustomActionType_IsTerraformElement(x interface{}) *bool
Experimental.
func CodepipelineCustomActionType_IsTerraformResource ¶
func CodepipelineCustomActionType_IsTerraformResource(x interface{}) *bool
Experimental.
func CodepipelineCustomActionType_TfResourceType ¶
func CodepipelineCustomActionType_TfResourceType() *string
func NewCodepipelineCustomActionTypeConfigurationPropertyList_Override ¶
func NewCodepipelineCustomActionTypeConfigurationPropertyList_Override(c CodepipelineCustomActionTypeConfigurationPropertyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCodepipelineCustomActionTypeConfigurationPropertyOutputReference_Override ¶
func NewCodepipelineCustomActionTypeConfigurationPropertyOutputReference_Override(c CodepipelineCustomActionTypeConfigurationPropertyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCodepipelineCustomActionTypeInputArtifactDetailsOutputReference_Override ¶
func NewCodepipelineCustomActionTypeInputArtifactDetailsOutputReference_Override(c CodepipelineCustomActionTypeInputArtifactDetailsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCodepipelineCustomActionTypeOutputArtifactDetailsOutputReference_Override ¶
func NewCodepipelineCustomActionTypeOutputArtifactDetailsOutputReference_Override(c CodepipelineCustomActionTypeOutputArtifactDetailsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCodepipelineCustomActionTypeSettingsOutputReference_Override ¶
func NewCodepipelineCustomActionTypeSettingsOutputReference_Override(c CodepipelineCustomActionTypeSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCodepipelineCustomActionType_Override ¶
func NewCodepipelineCustomActionType_Override(c CodepipelineCustomActionType, scope constructs.Construct, id *string, config *CodepipelineCustomActionTypeConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type aws_codepipeline_custom_action_type} Resource.
Types ¶
type CodepipelineCustomActionType ¶
type CodepipelineCustomActionType interface {
cdktf.TerraformResource
Arn() *string
Category() *string
SetCategory(val *string)
CategoryInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ConfigurationProperty() CodepipelineCustomActionTypeConfigurationPropertyList
ConfigurationPropertyInput() interface{}
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InputArtifactDetails() CodepipelineCustomActionTypeInputArtifactDetailsOutputReference
InputArtifactDetailsInput() *CodepipelineCustomActionTypeInputArtifactDetails
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
OutputArtifactDetails() CodepipelineCustomActionTypeOutputArtifactDetailsOutputReference
OutputArtifactDetailsInput() *CodepipelineCustomActionTypeOutputArtifactDetails
Owner() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
ProviderName() *string
SetProviderName(val *string)
ProviderNameInput() *string
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Settings() CodepipelineCustomActionTypeSettingsOutputReference
SettingsInput() *CodepipelineCustomActionTypeSettings
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Version() *string
SetVersion(val *string)
VersionInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutConfigurationProperty(value interface{})
PutInputArtifactDetails(value *CodepipelineCustomActionTypeInputArtifactDetails)
PutOutputArtifactDetails(value *CodepipelineCustomActionTypeOutputArtifactDetails)
PutSettings(value *CodepipelineCustomActionTypeSettings)
ResetConfigurationProperty()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSettings()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type aws_codepipeline_custom_action_type}.
func NewCodepipelineCustomActionType ¶
func NewCodepipelineCustomActionType(scope constructs.Construct, id *string, config *CodepipelineCustomActionTypeConfig) CodepipelineCustomActionType
Create a new {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type aws_codepipeline_custom_action_type} Resource.
type CodepipelineCustomActionTypeConfig ¶
type CodepipelineCustomActionTypeConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#category CodepipelineCustomActionType#category}.
Category *string `field:"required" json:"category" yaml:"category"`
// input_artifact_details block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#input_artifact_details CodepipelineCustomActionType#input_artifact_details}
InputArtifactDetails *CodepipelineCustomActionTypeInputArtifactDetails `field:"required" json:"inputArtifactDetails" yaml:"inputArtifactDetails"`
// output_artifact_details block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#output_artifact_details CodepipelineCustomActionType#output_artifact_details}
OutputArtifactDetails *CodepipelineCustomActionTypeOutputArtifactDetails `field:"required" json:"outputArtifactDetails" yaml:"outputArtifactDetails"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#provider_name CodepipelineCustomActionType#provider_name}.
ProviderName *string `field:"required" json:"providerName" yaml:"providerName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#version CodepipelineCustomActionType#version}.
Version *string `field:"required" json:"version" yaml:"version"`
// configuration_property block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#configuration_property CodepipelineCustomActionType#configuration_property}
ConfigurationProperty interface{} `field:"optional" json:"configurationProperty" yaml:"configurationProperty"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#id CodepipelineCustomActionType#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// settings block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#settings CodepipelineCustomActionType#settings}
Settings *CodepipelineCustomActionTypeSettings `field:"optional" json:"settings" yaml:"settings"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#tags CodepipelineCustomActionType#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#tags_all CodepipelineCustomActionType#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type CodepipelineCustomActionTypeConfigurationProperty ¶
type CodepipelineCustomActionTypeConfigurationProperty struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#key CodepipelineCustomActionType#key}.
Key interface{} `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#name CodepipelineCustomActionType#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#required CodepipelineCustomActionType#required}.
Required interface{} `field:"required" json:"required" yaml:"required"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#secret CodepipelineCustomActionType#secret}.
Secret interface{} `field:"required" json:"secret" yaml:"secret"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#description CodepipelineCustomActionType#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#queryable CodepipelineCustomActionType#queryable}.
Queryable interface{} `field:"optional" json:"queryable" yaml:"queryable"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#type CodepipelineCustomActionType#type}.
Type *string `field:"optional" json:"type" yaml:"type"`
}
type CodepipelineCustomActionTypeConfigurationPropertyList ¶
type CodepipelineCustomActionTypeConfigurationPropertyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CodepipelineCustomActionTypeConfigurationPropertyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCodepipelineCustomActionTypeConfigurationPropertyList ¶
func NewCodepipelineCustomActionTypeConfigurationPropertyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CodepipelineCustomActionTypeConfigurationPropertyList
type CodepipelineCustomActionTypeConfigurationPropertyOutputReference ¶
type CodepipelineCustomActionTypeConfigurationPropertyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Key() interface{}
SetKey(val interface{})
KeyInput() interface{}
Name() *string
SetName(val *string)
NameInput() *string
Queryable() interface{}
SetQueryable(val interface{})
QueryableInput() interface{}
Required() interface{}
SetRequired(val interface{})
RequiredInput() interface{}
Secret() interface{}
SetSecret(val interface{})
SecretInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDescription()
ResetQueryable()
ResetType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCodepipelineCustomActionTypeConfigurationPropertyOutputReference ¶
func NewCodepipelineCustomActionTypeConfigurationPropertyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CodepipelineCustomActionTypeConfigurationPropertyOutputReference
type CodepipelineCustomActionTypeInputArtifactDetails ¶
type CodepipelineCustomActionTypeInputArtifactDetails struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#maximum_count CodepipelineCustomActionType#maximum_count}.
MaximumCount *float64 `field:"required" json:"maximumCount" yaml:"maximumCount"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#minimum_count CodepipelineCustomActionType#minimum_count}.
MinimumCount *float64 `field:"required" json:"minimumCount" yaml:"minimumCount"`
}
type CodepipelineCustomActionTypeInputArtifactDetailsOutputReference ¶
type CodepipelineCustomActionTypeInputArtifactDetailsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *CodepipelineCustomActionTypeInputArtifactDetails
SetInternalValue(val *CodepipelineCustomActionTypeInputArtifactDetails)
MaximumCount() *float64
SetMaximumCount(val *float64)
MaximumCountInput() *float64
MinimumCount() *float64
SetMinimumCount(val *float64)
MinimumCountInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCodepipelineCustomActionTypeInputArtifactDetailsOutputReference ¶
func NewCodepipelineCustomActionTypeInputArtifactDetailsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CodepipelineCustomActionTypeInputArtifactDetailsOutputReference
type CodepipelineCustomActionTypeOutputArtifactDetails ¶
type CodepipelineCustomActionTypeOutputArtifactDetails struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#maximum_count CodepipelineCustomActionType#maximum_count}.
MaximumCount *float64 `field:"required" json:"maximumCount" yaml:"maximumCount"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#minimum_count CodepipelineCustomActionType#minimum_count}.
MinimumCount *float64 `field:"required" json:"minimumCount" yaml:"minimumCount"`
}
type CodepipelineCustomActionTypeOutputArtifactDetailsOutputReference ¶
type CodepipelineCustomActionTypeOutputArtifactDetailsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *CodepipelineCustomActionTypeOutputArtifactDetails
SetInternalValue(val *CodepipelineCustomActionTypeOutputArtifactDetails)
MaximumCount() *float64
SetMaximumCount(val *float64)
MaximumCountInput() *float64
MinimumCount() *float64
SetMinimumCount(val *float64)
MinimumCountInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCodepipelineCustomActionTypeOutputArtifactDetailsOutputReference ¶
func NewCodepipelineCustomActionTypeOutputArtifactDetailsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CodepipelineCustomActionTypeOutputArtifactDetailsOutputReference
type CodepipelineCustomActionTypeSettings ¶
type CodepipelineCustomActionTypeSettings struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#entity_url_template CodepipelineCustomActionType#entity_url_template}.
EntityUrlTemplate *string `field:"optional" json:"entityUrlTemplate" yaml:"entityUrlTemplate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#execution_url_template CodepipelineCustomActionType#execution_url_template}.
ExecutionUrlTemplate *string `field:"optional" json:"executionUrlTemplate" yaml:"executionUrlTemplate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#revision_url_template CodepipelineCustomActionType#revision_url_template}.
RevisionUrlTemplate *string `field:"optional" json:"revisionUrlTemplate" yaml:"revisionUrlTemplate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_custom_action_type#third_party_configuration_url CodepipelineCustomActionType#third_party_configuration_url}.
ThirdPartyConfigurationUrl *string `field:"optional" json:"thirdPartyConfigurationUrl" yaml:"thirdPartyConfigurationUrl"`
}
type CodepipelineCustomActionTypeSettingsOutputReference ¶
type CodepipelineCustomActionTypeSettingsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EntityUrlTemplate() *string
SetEntityUrlTemplate(val *string)
EntityUrlTemplateInput() *string
ExecutionUrlTemplate() *string
SetExecutionUrlTemplate(val *string)
ExecutionUrlTemplateInput() *string
// Experimental.
Fqn() *string
InternalValue() *CodepipelineCustomActionTypeSettings
SetInternalValue(val *CodepipelineCustomActionTypeSettings)
RevisionUrlTemplate() *string
SetRevisionUrlTemplate(val *string)
RevisionUrlTemplateInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ThirdPartyConfigurationUrl() *string
SetThirdPartyConfigurationUrl(val *string)
ThirdPartyConfigurationUrlInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEntityUrlTemplate()
ResetExecutionUrlTemplate()
ResetRevisionUrlTemplate()
ResetThirdPartyConfigurationUrl()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCodepipelineCustomActionTypeSettingsOutputReference ¶
func NewCodepipelineCustomActionTypeSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CodepipelineCustomActionTypeSettingsOutputReference
Source Files
¶
- CodepipelineCustomActionType.go
- CodepipelineCustomActionTypeConfig.go
- CodepipelineCustomActionTypeConfigurationProperty.go
- CodepipelineCustomActionTypeConfigurationPropertyList.go
- CodepipelineCustomActionTypeConfigurationPropertyList__checks.go
- CodepipelineCustomActionTypeConfigurationPropertyOutputReference.go
- CodepipelineCustomActionTypeConfigurationPropertyOutputReference__checks.go
- CodepipelineCustomActionTypeInputArtifactDetails.go
- CodepipelineCustomActionTypeInputArtifactDetailsOutputReference.go
- CodepipelineCustomActionTypeInputArtifactDetailsOutputReference__checks.go
- CodepipelineCustomActionTypeOutputArtifactDetails.go
- CodepipelineCustomActionTypeOutputArtifactDetailsOutputReference.go
- CodepipelineCustomActionTypeOutputArtifactDetailsOutputReference__checks.go
- CodepipelineCustomActionTypeSettings.go
- CodepipelineCustomActionTypeSettingsOutputReference.go
- CodepipelineCustomActionTypeSettingsOutputReference__checks.go
- CodepipelineCustomActionType__checks.go
- main.go