Documentation
¶
Index ¶
- func ConnectUser_IsConstruct(x interface{}) *bool
- func ConnectUser_IsTerraformElement(x interface{}) *bool
- func ConnectUser_IsTerraformResource(x interface{}) *bool
- func ConnectUser_TfResourceType() *string
- func NewConnectUserIdentityInfoOutputReference_Override(c ConnectUserIdentityInfoOutputReference, ...)
- func NewConnectUserPhoneConfigOutputReference_Override(c ConnectUserPhoneConfigOutputReference, ...)
- func NewConnectUser_Override(c ConnectUser, scope constructs.Construct, id *string, ...)
- type ConnectUser
- type ConnectUserConfig
- type ConnectUserIdentityInfo
- type ConnectUserIdentityInfoOutputReference
- type ConnectUserPhoneConfig
- type ConnectUserPhoneConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConnectUser_IsConstruct ¶
func ConnectUser_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ConnectUser_IsTerraformElement ¶
func ConnectUser_IsTerraformElement(x interface{}) *bool
Experimental.
func ConnectUser_IsTerraformResource ¶
func ConnectUser_IsTerraformResource(x interface{}) *bool
Experimental.
func ConnectUser_TfResourceType ¶
func ConnectUser_TfResourceType() *string
func NewConnectUserIdentityInfoOutputReference_Override ¶
func NewConnectUserIdentityInfoOutputReference_Override(c ConnectUserIdentityInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewConnectUserPhoneConfigOutputReference_Override ¶
func NewConnectUserPhoneConfigOutputReference_Override(c ConnectUserPhoneConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewConnectUser_Override ¶
func NewConnectUser_Override(c ConnectUser, scope constructs.Construct, id *string, config *ConnectUserConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/connect_user aws_connect_user} Resource.
Types ¶
type ConnectUser ¶
type ConnectUser interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DirectoryUserId() *string
SetDirectoryUserId(val *string)
DirectoryUserIdInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HierarchyGroupId() *string
SetHierarchyGroupId(val *string)
HierarchyGroupIdInput() *string
Id() *string
SetId(val *string)
IdentityInfo() ConnectUserIdentityInfoOutputReference
IdentityInfoInput() *ConnectUserIdentityInfo
IdInput() *string
InstanceId() *string
SetInstanceId(val *string)
InstanceIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Password() *string
SetPassword(val *string)
PasswordInput() *string
PhoneConfig() ConnectUserPhoneConfigOutputReference
PhoneConfigInput() *ConnectUserPhoneConfig
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RoutingProfileId() *string
SetRoutingProfileId(val *string)
RoutingProfileIdInput() *string
SecurityProfileIds() *[]*string
SetSecurityProfileIds(val *[]*string)
SecurityProfileIdsInput() *[]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
UserId() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutIdentityInfo(value *ConnectUserIdentityInfo)
PutPhoneConfig(value *ConnectUserPhoneConfig)
ResetDirectoryUserId()
ResetHierarchyGroupId()
ResetId()
ResetIdentityInfo()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPassword()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/connect_user aws_connect_user}.
func NewConnectUser ¶
func NewConnectUser(scope constructs.Construct, id *string, config *ConnectUserConfig) ConnectUser
Create a new {@link https://www.terraform.io/docs/providers/aws/r/connect_user aws_connect_user} Resource.
type ConnectUserConfig ¶
type ConnectUserConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user#instance_id ConnectUser#instance_id}.
InstanceId *string `field:"required" json:"instanceId" yaml:"instanceId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user#name ConnectUser#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// phone_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user#phone_config ConnectUser#phone_config}
PhoneConfig *ConnectUserPhoneConfig `field:"required" json:"phoneConfig" yaml:"phoneConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user#routing_profile_id ConnectUser#routing_profile_id}.
RoutingProfileId *string `field:"required" json:"routingProfileId" yaml:"routingProfileId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user#security_profile_ids ConnectUser#security_profile_ids}.
SecurityProfileIds *[]*string `field:"required" json:"securityProfileIds" yaml:"securityProfileIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user#directory_user_id ConnectUser#directory_user_id}.
DirectoryUserId *string `field:"optional" json:"directoryUserId" yaml:"directoryUserId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user#hierarchy_group_id ConnectUser#hierarchy_group_id}.
HierarchyGroupId *string `field:"optional" json:"hierarchyGroupId" yaml:"hierarchyGroupId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user#id ConnectUser#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// identity_info block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user#identity_info ConnectUser#identity_info}
IdentityInfo *ConnectUserIdentityInfo `field:"optional" json:"identityInfo" yaml:"identityInfo"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user#password ConnectUser#password}.
Password *string `field:"optional" json:"password" yaml:"password"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user#tags ConnectUser#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user#tags_all ConnectUser#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type ConnectUserIdentityInfo ¶
type ConnectUserIdentityInfo struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user#email ConnectUser#email}.
Email *string `field:"optional" json:"email" yaml:"email"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user#first_name ConnectUser#first_name}.
FirstName *string `field:"optional" json:"firstName" yaml:"firstName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user#last_name ConnectUser#last_name}.
LastName *string `field:"optional" json:"lastName" yaml:"lastName"`
}
type ConnectUserIdentityInfoOutputReference ¶
type ConnectUserIdentityInfoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Email() *string
SetEmail(val *string)
EmailInput() *string
FirstName() *string
SetFirstName(val *string)
FirstNameInput() *string
// Experimental.
Fqn() *string
InternalValue() *ConnectUserIdentityInfo
SetInternalValue(val *ConnectUserIdentityInfo)
LastName() *string
SetLastName(val *string)
LastNameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEmail()
ResetFirstName()
ResetLastName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectUserIdentityInfoOutputReference ¶
func NewConnectUserIdentityInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ConnectUserIdentityInfoOutputReference
type ConnectUserPhoneConfig ¶
type ConnectUserPhoneConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user#phone_type ConnectUser#phone_type}.
PhoneType *string `field:"required" json:"phoneType" yaml:"phoneType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user#after_contact_work_time_limit ConnectUser#after_contact_work_time_limit}.
AfterContactWorkTimeLimit *float64 `field:"optional" json:"afterContactWorkTimeLimit" yaml:"afterContactWorkTimeLimit"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user#auto_accept ConnectUser#auto_accept}.
AutoAccept interface{} `field:"optional" json:"autoAccept" yaml:"autoAccept"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user#desk_phone_number ConnectUser#desk_phone_number}.
DeskPhoneNumber *string `field:"optional" json:"deskPhoneNumber" yaml:"deskPhoneNumber"`
}
type ConnectUserPhoneConfigOutputReference ¶
type ConnectUserPhoneConfigOutputReference interface {
cdktf.ComplexObject
AfterContactWorkTimeLimit() *float64
SetAfterContactWorkTimeLimit(val *float64)
AfterContactWorkTimeLimitInput() *float64
AutoAccept() interface{}
SetAutoAccept(val interface{})
AutoAcceptInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeskPhoneNumber() *string
SetDeskPhoneNumber(val *string)
DeskPhoneNumberInput() *string
// Experimental.
Fqn() *string
InternalValue() *ConnectUserPhoneConfig
SetInternalValue(val *ConnectUserPhoneConfig)
PhoneType() *string
SetPhoneType(val *string)
PhoneTypeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAfterContactWorkTimeLimit()
ResetAutoAccept()
ResetDeskPhoneNumber()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectUserPhoneConfigOutputReference ¶
func NewConnectUserPhoneConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ConnectUserPhoneConfigOutputReference