Documentation
¶
Index ¶
- func DataAwsCloudfrontOriginRequestPolicy_IsConstruct(x interface{}) *bool
- func DataAwsCloudfrontOriginRequestPolicy_IsTerraformDataSource(x interface{}) *bool
- func DataAwsCloudfrontOriginRequestPolicy_IsTerraformElement(x interface{}) *bool
- func DataAwsCloudfrontOriginRequestPolicy_TfResourceType() *string
- func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesList_Override(d DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesList, ...)
- func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesOutputReference_Override(d DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesOutputReference, ...)
- func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigList_Override(d DataAwsCloudfrontOriginRequestPolicyCookiesConfigList, ...)
- func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigOutputReference_Override(d DataAwsCloudfrontOriginRequestPolicyCookiesConfigOutputReference, ...)
- func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersList_Override(d DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersList, ...)
- func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersOutputReference_Override(d DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersOutputReference, ...)
- func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigList_Override(d DataAwsCloudfrontOriginRequestPolicyHeadersConfigList, ...)
- func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigOutputReference_Override(d DataAwsCloudfrontOriginRequestPolicyHeadersConfigOutputReference, ...)
- func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigList_Override(d DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigList, ...)
- func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigOutputReference_Override(d DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigOutputReference, ...)
- func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsList_Override(d DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsList, ...)
- func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsOutputReference_Override(...)
- func NewDataAwsCloudfrontOriginRequestPolicy_Override(d DataAwsCloudfrontOriginRequestPolicy, scope constructs.Construct, id *string, ...)
- type DataAwsCloudfrontOriginRequestPolicy
- type DataAwsCloudfrontOriginRequestPolicyConfig
- type DataAwsCloudfrontOriginRequestPolicyCookiesConfig
- type DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookies
- type DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesList
- type DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesOutputReference
- type DataAwsCloudfrontOriginRequestPolicyCookiesConfigList
- type DataAwsCloudfrontOriginRequestPolicyCookiesConfigOutputReference
- type DataAwsCloudfrontOriginRequestPolicyHeadersConfig
- type DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeaders
- type DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersList
- type DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersOutputReference
- type DataAwsCloudfrontOriginRequestPolicyHeadersConfigList
- type DataAwsCloudfrontOriginRequestPolicyHeadersConfigOutputReference
- type DataAwsCloudfrontOriginRequestPolicyQueryStringsConfig
- type DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigList
- type DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigOutputReference
- type DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStrings
- type DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsList
- type DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsCloudfrontOriginRequestPolicy_IsConstruct ¶
func DataAwsCloudfrontOriginRequestPolicy_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsCloudfrontOriginRequestPolicy_IsTerraformDataSource ¶
func DataAwsCloudfrontOriginRequestPolicy_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsCloudfrontOriginRequestPolicy_IsTerraformElement ¶
func DataAwsCloudfrontOriginRequestPolicy_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsCloudfrontOriginRequestPolicy_TfResourceType ¶
func DataAwsCloudfrontOriginRequestPolicy_TfResourceType() *string
func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesList_Override ¶
func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesList_Override(d DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesOutputReference_Override ¶
func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesOutputReference_Override(d DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigList_Override ¶
func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigList_Override(d DataAwsCloudfrontOriginRequestPolicyCookiesConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigOutputReference_Override ¶
func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigOutputReference_Override(d DataAwsCloudfrontOriginRequestPolicyCookiesConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersList_Override ¶
func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersList_Override(d DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersOutputReference_Override ¶
func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersOutputReference_Override(d DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigList_Override ¶
func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigList_Override(d DataAwsCloudfrontOriginRequestPolicyHeadersConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigOutputReference_Override ¶
func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigOutputReference_Override(d DataAwsCloudfrontOriginRequestPolicyHeadersConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigList_Override ¶
func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigList_Override(d DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigOutputReference_Override ¶
func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigOutputReference_Override(d DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsList_Override ¶
func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsList_Override(d DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsOutputReference_Override ¶
func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsOutputReference_Override(d DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsCloudfrontOriginRequestPolicy_Override ¶
func NewDataAwsCloudfrontOriginRequestPolicy_Override(d DataAwsCloudfrontOriginRequestPolicy, scope constructs.Construct, id *string, config *DataAwsCloudfrontOriginRequestPolicyConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/cloudfront_origin_request_policy aws_cloudfront_origin_request_policy} Data Source.
Types ¶
type DataAwsCloudfrontOriginRequestPolicy ¶
type DataAwsCloudfrontOriginRequestPolicy interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
Comment() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
CookiesConfig() DataAwsCloudfrontOriginRequestPolicyCookiesConfigList
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Etag() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HeadersConfig() DataAwsCloudfrontOriginRequestPolicyHeadersConfigList
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
QueryStringsConfig() DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigList
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
ResetName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/cloudfront_origin_request_policy aws_cloudfront_origin_request_policy}.
func NewDataAwsCloudfrontOriginRequestPolicy ¶
func NewDataAwsCloudfrontOriginRequestPolicy(scope constructs.Construct, id *string, config *DataAwsCloudfrontOriginRequestPolicyConfig) DataAwsCloudfrontOriginRequestPolicy
Create a new {@link https://www.terraform.io/docs/providers/aws/d/cloudfront_origin_request_policy aws_cloudfront_origin_request_policy} Data Source.
type DataAwsCloudfrontOriginRequestPolicyConfig ¶
type DataAwsCloudfrontOriginRequestPolicyConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/cloudfront_origin_request_policy#id DataAwsCloudfrontOriginRequestPolicy#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/cloudfront_origin_request_policy#name DataAwsCloudfrontOriginRequestPolicy#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
}
type DataAwsCloudfrontOriginRequestPolicyCookiesConfig ¶
type DataAwsCloudfrontOriginRequestPolicyCookiesConfig struct {
}
type DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookies ¶
type DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookies struct {
}
type DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesList ¶
type DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesList ¶
func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesList
type DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesOutputReference ¶
type DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookies
SetInternalValue(val *DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookies)
Items() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesOutputReference ¶
func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesOutputReference
type DataAwsCloudfrontOriginRequestPolicyCookiesConfigList ¶
type DataAwsCloudfrontOriginRequestPolicyCookiesConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsCloudfrontOriginRequestPolicyCookiesConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigList ¶
func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsCloudfrontOriginRequestPolicyCookiesConfigList
type DataAwsCloudfrontOriginRequestPolicyCookiesConfigOutputReference ¶
type DataAwsCloudfrontOriginRequestPolicyCookiesConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CookieBehavior() *string
Cookies() DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsCloudfrontOriginRequestPolicyCookiesConfig
SetInternalValue(val *DataAwsCloudfrontOriginRequestPolicyCookiesConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigOutputReference ¶
func NewDataAwsCloudfrontOriginRequestPolicyCookiesConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsCloudfrontOriginRequestPolicyCookiesConfigOutputReference
type DataAwsCloudfrontOriginRequestPolicyHeadersConfig ¶
type DataAwsCloudfrontOriginRequestPolicyHeadersConfig struct {
}
type DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeaders ¶
type DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeaders struct {
}
type DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersList ¶
type DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersList ¶
func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersList
type DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersOutputReference ¶
type DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeaders
SetInternalValue(val *DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeaders)
Items() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersOutputReference ¶
func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersOutputReference
type DataAwsCloudfrontOriginRequestPolicyHeadersConfigList ¶
type DataAwsCloudfrontOriginRequestPolicyHeadersConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsCloudfrontOriginRequestPolicyHeadersConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigList ¶
func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsCloudfrontOriginRequestPolicyHeadersConfigList
type DataAwsCloudfrontOriginRequestPolicyHeadersConfigOutputReference ¶
type DataAwsCloudfrontOriginRequestPolicyHeadersConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HeaderBehavior() *string
Headers() DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersList
InternalValue() *DataAwsCloudfrontOriginRequestPolicyHeadersConfig
SetInternalValue(val *DataAwsCloudfrontOriginRequestPolicyHeadersConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigOutputReference ¶
func NewDataAwsCloudfrontOriginRequestPolicyHeadersConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsCloudfrontOriginRequestPolicyHeadersConfigOutputReference
type DataAwsCloudfrontOriginRequestPolicyQueryStringsConfig ¶
type DataAwsCloudfrontOriginRequestPolicyQueryStringsConfig struct {
}
type DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigList ¶
type DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigList ¶
func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigList
type DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigOutputReference ¶
type DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsCloudfrontOriginRequestPolicyQueryStringsConfig
SetInternalValue(val *DataAwsCloudfrontOriginRequestPolicyQueryStringsConfig)
QueryStringBehavior() *string
QueryStrings() DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigOutputReference ¶
func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigOutputReference
type DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStrings ¶
type DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStrings struct {
}
type DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsList ¶
type DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsList ¶
func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsList
type DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsOutputReference ¶
type DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStrings
SetInternalValue(val *DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStrings)
Items() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsOutputReference ¶
func NewDataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsOutputReference
Source Files
¶
- DataAwsCloudfrontOriginRequestPolicy.go
- DataAwsCloudfrontOriginRequestPolicyConfig.go
- DataAwsCloudfrontOriginRequestPolicyCookiesConfig.go
- DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookies.go
- DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesList.go
- DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesList__checks.go
- DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesOutputReference.go
- DataAwsCloudfrontOriginRequestPolicyCookiesConfigCookiesOutputReference__checks.go
- DataAwsCloudfrontOriginRequestPolicyCookiesConfigList.go
- DataAwsCloudfrontOriginRequestPolicyCookiesConfigList__checks.go
- DataAwsCloudfrontOriginRequestPolicyCookiesConfigOutputReference.go
- DataAwsCloudfrontOriginRequestPolicyCookiesConfigOutputReference__checks.go
- DataAwsCloudfrontOriginRequestPolicyHeadersConfig.go
- DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeaders.go
- DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersList.go
- DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersList__checks.go
- DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersOutputReference.go
- DataAwsCloudfrontOriginRequestPolicyHeadersConfigHeadersOutputReference__checks.go
- DataAwsCloudfrontOriginRequestPolicyHeadersConfigList.go
- DataAwsCloudfrontOriginRequestPolicyHeadersConfigList__checks.go
- DataAwsCloudfrontOriginRequestPolicyHeadersConfigOutputReference.go
- DataAwsCloudfrontOriginRequestPolicyHeadersConfigOutputReference__checks.go
- DataAwsCloudfrontOriginRequestPolicyQueryStringsConfig.go
- DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigList.go
- DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigList__checks.go
- DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigOutputReference.go
- DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigOutputReference__checks.go
- DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStrings.go
- DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsList.go
- DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsList__checks.go
- DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsOutputReference.go
- DataAwsCloudfrontOriginRequestPolicyQueryStringsConfigQueryStringsOutputReference__checks.go
- DataAwsCloudfrontOriginRequestPolicy__checks.go
- main.go