Documentation
¶
Index ¶
- func DataAwsEc2TransitGatewayVpcAttachments_IsConstruct(x interface{}) *bool
- func DataAwsEc2TransitGatewayVpcAttachments_IsTerraformDataSource(x interface{}) *bool
- func DataAwsEc2TransitGatewayVpcAttachments_IsTerraformElement(x interface{}) *bool
- func DataAwsEc2TransitGatewayVpcAttachments_TfResourceType() *string
- func NewDataAwsEc2TransitGatewayVpcAttachmentsFilterList_Override(d DataAwsEc2TransitGatewayVpcAttachmentsFilterList, ...)
- func NewDataAwsEc2TransitGatewayVpcAttachmentsFilterOutputReference_Override(d DataAwsEc2TransitGatewayVpcAttachmentsFilterOutputReference, ...)
- func NewDataAwsEc2TransitGatewayVpcAttachmentsTimeoutsOutputReference_Override(d DataAwsEc2TransitGatewayVpcAttachmentsTimeoutsOutputReference, ...)
- func NewDataAwsEc2TransitGatewayVpcAttachments_Override(d DataAwsEc2TransitGatewayVpcAttachments, scope constructs.Construct, ...)
- type DataAwsEc2TransitGatewayVpcAttachments
- type DataAwsEc2TransitGatewayVpcAttachmentsConfig
- type DataAwsEc2TransitGatewayVpcAttachmentsFilter
- type DataAwsEc2TransitGatewayVpcAttachmentsFilterList
- type DataAwsEc2TransitGatewayVpcAttachmentsFilterOutputReference
- type DataAwsEc2TransitGatewayVpcAttachmentsTimeouts
- type DataAwsEc2TransitGatewayVpcAttachmentsTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsEc2TransitGatewayVpcAttachments_IsConstruct ¶
func DataAwsEc2TransitGatewayVpcAttachments_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsEc2TransitGatewayVpcAttachments_IsTerraformDataSource ¶
func DataAwsEc2TransitGatewayVpcAttachments_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsEc2TransitGatewayVpcAttachments_IsTerraformElement ¶
func DataAwsEc2TransitGatewayVpcAttachments_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsEc2TransitGatewayVpcAttachments_TfResourceType ¶
func DataAwsEc2TransitGatewayVpcAttachments_TfResourceType() *string
func NewDataAwsEc2TransitGatewayVpcAttachmentsFilterList_Override ¶
func NewDataAwsEc2TransitGatewayVpcAttachmentsFilterList_Override(d DataAwsEc2TransitGatewayVpcAttachmentsFilterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEc2TransitGatewayVpcAttachmentsFilterOutputReference_Override ¶
func NewDataAwsEc2TransitGatewayVpcAttachmentsFilterOutputReference_Override(d DataAwsEc2TransitGatewayVpcAttachmentsFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEc2TransitGatewayVpcAttachmentsTimeoutsOutputReference_Override ¶
func NewDataAwsEc2TransitGatewayVpcAttachmentsTimeoutsOutputReference_Override(d DataAwsEc2TransitGatewayVpcAttachmentsTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsEc2TransitGatewayVpcAttachments_Override ¶
func NewDataAwsEc2TransitGatewayVpcAttachments_Override(d DataAwsEc2TransitGatewayVpcAttachments, scope constructs.Construct, id *string, config *DataAwsEc2TransitGatewayVpcAttachmentsConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/ec2_transit_gateway_vpc_attachments aws_ec2_transit_gateway_vpc_attachments} Data Source.
Types ¶
type DataAwsEc2TransitGatewayVpcAttachments ¶
type DataAwsEc2TransitGatewayVpcAttachments interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Filter() DataAwsEc2TransitGatewayVpcAttachmentsFilterList
FilterInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Ids() *[]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DataAwsEc2TransitGatewayVpcAttachmentsTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutFilter(value interface{})
PutTimeouts(value *DataAwsEc2TransitGatewayVpcAttachmentsTimeouts)
ResetFilter()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/ec2_transit_gateway_vpc_attachments aws_ec2_transit_gateway_vpc_attachments}.
func NewDataAwsEc2TransitGatewayVpcAttachments ¶
func NewDataAwsEc2TransitGatewayVpcAttachments(scope constructs.Construct, id *string, config *DataAwsEc2TransitGatewayVpcAttachmentsConfig) DataAwsEc2TransitGatewayVpcAttachments
Create a new {@link https://www.terraform.io/docs/providers/aws/d/ec2_transit_gateway_vpc_attachments aws_ec2_transit_gateway_vpc_attachments} Data Source.
type DataAwsEc2TransitGatewayVpcAttachmentsConfig ¶
type DataAwsEc2TransitGatewayVpcAttachmentsConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// filter block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_transit_gateway_vpc_attachments#filter DataAwsEc2TransitGatewayVpcAttachments#filter}
Filter interface{} `field:"optional" json:"filter" yaml:"filter"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_transit_gateway_vpc_attachments#id DataAwsEc2TransitGatewayVpcAttachments#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_transit_gateway_vpc_attachments#timeouts DataAwsEc2TransitGatewayVpcAttachments#timeouts}
Timeouts *DataAwsEc2TransitGatewayVpcAttachmentsTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type DataAwsEc2TransitGatewayVpcAttachmentsFilter ¶
type DataAwsEc2TransitGatewayVpcAttachmentsFilter struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_transit_gateway_vpc_attachments#name DataAwsEc2TransitGatewayVpcAttachments#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_transit_gateway_vpc_attachments#values DataAwsEc2TransitGatewayVpcAttachments#values}.
Values *[]*string `field:"required" json:"values" yaml:"values"`
}
type DataAwsEc2TransitGatewayVpcAttachmentsFilterList ¶
type DataAwsEc2TransitGatewayVpcAttachmentsFilterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEc2TransitGatewayVpcAttachmentsFilterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2TransitGatewayVpcAttachmentsFilterList ¶
func NewDataAwsEc2TransitGatewayVpcAttachmentsFilterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEc2TransitGatewayVpcAttachmentsFilterList
type DataAwsEc2TransitGatewayVpcAttachmentsFilterOutputReference ¶
type DataAwsEc2TransitGatewayVpcAttachmentsFilterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
SetValues(val *[]*string)
ValuesInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2TransitGatewayVpcAttachmentsFilterOutputReference ¶
func NewDataAwsEc2TransitGatewayVpcAttachmentsFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEc2TransitGatewayVpcAttachmentsFilterOutputReference
type DataAwsEc2TransitGatewayVpcAttachmentsTimeouts ¶
type DataAwsEc2TransitGatewayVpcAttachmentsTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_transit_gateway_vpc_attachments#read DataAwsEc2TransitGatewayVpcAttachments#read}.
Read *string `field:"optional" json:"read" yaml:"read"`
}
type DataAwsEc2TransitGatewayVpcAttachmentsTimeoutsOutputReference ¶
type DataAwsEc2TransitGatewayVpcAttachmentsTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Read() *string
SetRead(val *string)
ReadInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetRead()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2TransitGatewayVpcAttachmentsTimeoutsOutputReference ¶
func NewDataAwsEc2TransitGatewayVpcAttachmentsTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsEc2TransitGatewayVpcAttachmentsTimeoutsOutputReference
Source Files
¶
- DataAwsEc2TransitGatewayVpcAttachments.go
- DataAwsEc2TransitGatewayVpcAttachmentsConfig.go
- DataAwsEc2TransitGatewayVpcAttachmentsFilter.go
- DataAwsEc2TransitGatewayVpcAttachmentsFilterList.go
- DataAwsEc2TransitGatewayVpcAttachmentsFilterList__checks.go
- DataAwsEc2TransitGatewayVpcAttachmentsFilterOutputReference.go
- DataAwsEc2TransitGatewayVpcAttachmentsFilterOutputReference__checks.go
- DataAwsEc2TransitGatewayVpcAttachmentsTimeouts.go
- DataAwsEc2TransitGatewayVpcAttachmentsTimeoutsOutputReference.go
- DataAwsEc2TransitGatewayVpcAttachmentsTimeoutsOutputReference__checks.go
- DataAwsEc2TransitGatewayVpcAttachments__checks.go
- main.go