Documentation
¶
Index ¶
- func DataAwsEcrRepository_IsConstruct(x interface{}) *bool
- func DataAwsEcrRepository_IsTerraformDataSource(x interface{}) *bool
- func DataAwsEcrRepository_IsTerraformElement(x interface{}) *bool
- func DataAwsEcrRepository_TfResourceType() *string
- func NewDataAwsEcrRepositoryEncryptionConfigurationList_Override(d DataAwsEcrRepositoryEncryptionConfigurationList, ...)
- func NewDataAwsEcrRepositoryEncryptionConfigurationOutputReference_Override(d DataAwsEcrRepositoryEncryptionConfigurationOutputReference, ...)
- func NewDataAwsEcrRepositoryImageScanningConfigurationList_Override(d DataAwsEcrRepositoryImageScanningConfigurationList, ...)
- func NewDataAwsEcrRepositoryImageScanningConfigurationOutputReference_Override(d DataAwsEcrRepositoryImageScanningConfigurationOutputReference, ...)
- func NewDataAwsEcrRepository_Override(d DataAwsEcrRepository, scope constructs.Construct, id *string, ...)
- type DataAwsEcrRepository
- type DataAwsEcrRepositoryConfig
- type DataAwsEcrRepositoryEncryptionConfiguration
- type DataAwsEcrRepositoryEncryptionConfigurationList
- type DataAwsEcrRepositoryEncryptionConfigurationOutputReference
- type DataAwsEcrRepositoryImageScanningConfiguration
- type DataAwsEcrRepositoryImageScanningConfigurationList
- type DataAwsEcrRepositoryImageScanningConfigurationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsEcrRepository_IsConstruct ¶
func DataAwsEcrRepository_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsEcrRepository_IsTerraformDataSource ¶
func DataAwsEcrRepository_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsEcrRepository_IsTerraformElement ¶
func DataAwsEcrRepository_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsEcrRepository_TfResourceType ¶
func DataAwsEcrRepository_TfResourceType() *string
func NewDataAwsEcrRepositoryEncryptionConfigurationList_Override ¶
func NewDataAwsEcrRepositoryEncryptionConfigurationList_Override(d DataAwsEcrRepositoryEncryptionConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEcrRepositoryEncryptionConfigurationOutputReference_Override ¶
func NewDataAwsEcrRepositoryEncryptionConfigurationOutputReference_Override(d DataAwsEcrRepositoryEncryptionConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEcrRepositoryImageScanningConfigurationList_Override ¶
func NewDataAwsEcrRepositoryImageScanningConfigurationList_Override(d DataAwsEcrRepositoryImageScanningConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEcrRepositoryImageScanningConfigurationOutputReference_Override ¶
func NewDataAwsEcrRepositoryImageScanningConfigurationOutputReference_Override(d DataAwsEcrRepositoryImageScanningConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEcrRepository_Override ¶
func NewDataAwsEcrRepository_Override(d DataAwsEcrRepository, scope constructs.Construct, id *string, config *DataAwsEcrRepositoryConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/ecr_repository aws_ecr_repository} Data Source.
Types ¶
type DataAwsEcrRepository ¶
type DataAwsEcrRepository interface {
cdktf.TerraformDataSource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EncryptionConfiguration() DataAwsEcrRepositoryEncryptionConfigurationList
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
ImageScanningConfiguration() DataAwsEcrRepositoryImageScanningConfigurationList
ImageTagMutability() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MostRecentImageTags() *[]*string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
RegistryId() *string
SetRegistryId(val *string)
RegistryIdInput() *string
RepositoryUrl() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRegistryId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/ecr_repository aws_ecr_repository}.
func NewDataAwsEcrRepository ¶
func NewDataAwsEcrRepository(scope constructs.Construct, id *string, config *DataAwsEcrRepositoryConfig) DataAwsEcrRepository
Create a new {@link https://www.terraform.io/docs/providers/aws/d/ecr_repository aws_ecr_repository} Data Source.
type DataAwsEcrRepositoryConfig ¶
type DataAwsEcrRepositoryConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ecr_repository#name DataAwsEcrRepository#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ecr_repository#id DataAwsEcrRepository#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ecr_repository#registry_id DataAwsEcrRepository#registry_id}.
RegistryId *string `field:"optional" json:"registryId" yaml:"registryId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ecr_repository#tags DataAwsEcrRepository#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsEcrRepositoryEncryptionConfiguration ¶
type DataAwsEcrRepositoryEncryptionConfiguration struct {
}
type DataAwsEcrRepositoryEncryptionConfigurationList ¶
type DataAwsEcrRepositoryEncryptionConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEcrRepositoryEncryptionConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEcrRepositoryEncryptionConfigurationList ¶
func NewDataAwsEcrRepositoryEncryptionConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEcrRepositoryEncryptionConfigurationList
type DataAwsEcrRepositoryEncryptionConfigurationOutputReference ¶
type DataAwsEcrRepositoryEncryptionConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EncryptionType() *string
// Experimental.
Fqn() *string
InternalValue() *DataAwsEcrRepositoryEncryptionConfiguration
SetInternalValue(val *DataAwsEcrRepositoryEncryptionConfiguration)
KmsKey() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEcrRepositoryEncryptionConfigurationOutputReference ¶
func NewDataAwsEcrRepositoryEncryptionConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEcrRepositoryEncryptionConfigurationOutputReference
type DataAwsEcrRepositoryImageScanningConfiguration ¶
type DataAwsEcrRepositoryImageScanningConfiguration struct {
}
type DataAwsEcrRepositoryImageScanningConfigurationList ¶
type DataAwsEcrRepositoryImageScanningConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEcrRepositoryImageScanningConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEcrRepositoryImageScanningConfigurationList ¶
func NewDataAwsEcrRepositoryImageScanningConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEcrRepositoryImageScanningConfigurationList
type DataAwsEcrRepositoryImageScanningConfigurationOutputReference ¶
type DataAwsEcrRepositoryImageScanningConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsEcrRepositoryImageScanningConfiguration
SetInternalValue(val *DataAwsEcrRepositoryImageScanningConfiguration)
ScanOnPush() cdktf.IResolvable
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEcrRepositoryImageScanningConfigurationOutputReference ¶
func NewDataAwsEcrRepositoryImageScanningConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEcrRepositoryImageScanningConfigurationOutputReference
Source Files
¶
- DataAwsEcrRepository.go
- DataAwsEcrRepositoryConfig.go
- DataAwsEcrRepositoryEncryptionConfiguration.go
- DataAwsEcrRepositoryEncryptionConfigurationList.go
- DataAwsEcrRepositoryEncryptionConfigurationList__checks.go
- DataAwsEcrRepositoryEncryptionConfigurationOutputReference.go
- DataAwsEcrRepositoryEncryptionConfigurationOutputReference__checks.go
- DataAwsEcrRepositoryImageScanningConfiguration.go
- DataAwsEcrRepositoryImageScanningConfigurationList.go
- DataAwsEcrRepositoryImageScanningConfigurationList__checks.go
- DataAwsEcrRepositoryImageScanningConfigurationOutputReference.go
- DataAwsEcrRepositoryImageScanningConfigurationOutputReference__checks.go
- DataAwsEcrRepository__checks.go
- main.go