Documentation
¶
Index ¶
- func DataAwsIamPolicyDocument_IsConstruct(x interface{}) *bool
- func DataAwsIamPolicyDocument_IsTerraformDataSource(x interface{}) *bool
- func DataAwsIamPolicyDocument_IsTerraformElement(x interface{}) *bool
- func DataAwsIamPolicyDocument_TfResourceType() *string
- func NewDataAwsIamPolicyDocumentStatementConditionList_Override(d DataAwsIamPolicyDocumentStatementConditionList, ...)
- func NewDataAwsIamPolicyDocumentStatementConditionOutputReference_Override(d DataAwsIamPolicyDocumentStatementConditionOutputReference, ...)
- func NewDataAwsIamPolicyDocumentStatementList_Override(d DataAwsIamPolicyDocumentStatementList, ...)
- func NewDataAwsIamPolicyDocumentStatementNotPrincipalsList_Override(d DataAwsIamPolicyDocumentStatementNotPrincipalsList, ...)
- func NewDataAwsIamPolicyDocumentStatementNotPrincipalsOutputReference_Override(d DataAwsIamPolicyDocumentStatementNotPrincipalsOutputReference, ...)
- func NewDataAwsIamPolicyDocumentStatementOutputReference_Override(d DataAwsIamPolicyDocumentStatementOutputReference, ...)
- func NewDataAwsIamPolicyDocumentStatementPrincipalsList_Override(d DataAwsIamPolicyDocumentStatementPrincipalsList, ...)
- func NewDataAwsIamPolicyDocumentStatementPrincipalsOutputReference_Override(d DataAwsIamPolicyDocumentStatementPrincipalsOutputReference, ...)
- func NewDataAwsIamPolicyDocument_Override(d DataAwsIamPolicyDocument, scope constructs.Construct, id *string, ...)
- type DataAwsIamPolicyDocument
- type DataAwsIamPolicyDocumentConfig
- type DataAwsIamPolicyDocumentStatement
- type DataAwsIamPolicyDocumentStatementCondition
- type DataAwsIamPolicyDocumentStatementConditionList
- type DataAwsIamPolicyDocumentStatementConditionOutputReference
- type DataAwsIamPolicyDocumentStatementList
- type DataAwsIamPolicyDocumentStatementNotPrincipals
- type DataAwsIamPolicyDocumentStatementNotPrincipalsList
- type DataAwsIamPolicyDocumentStatementNotPrincipalsOutputReference
- type DataAwsIamPolicyDocumentStatementOutputReference
- type DataAwsIamPolicyDocumentStatementPrincipals
- type DataAwsIamPolicyDocumentStatementPrincipalsList
- type DataAwsIamPolicyDocumentStatementPrincipalsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsIamPolicyDocument_IsConstruct ¶
func DataAwsIamPolicyDocument_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsIamPolicyDocument_IsTerraformDataSource ¶
func DataAwsIamPolicyDocument_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsIamPolicyDocument_IsTerraformElement ¶
func DataAwsIamPolicyDocument_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsIamPolicyDocument_TfResourceType ¶
func DataAwsIamPolicyDocument_TfResourceType() *string
func NewDataAwsIamPolicyDocumentStatementConditionList_Override ¶
func NewDataAwsIamPolicyDocumentStatementConditionList_Override(d DataAwsIamPolicyDocumentStatementConditionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsIamPolicyDocumentStatementConditionOutputReference_Override ¶
func NewDataAwsIamPolicyDocumentStatementConditionOutputReference_Override(d DataAwsIamPolicyDocumentStatementConditionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsIamPolicyDocumentStatementList_Override ¶
func NewDataAwsIamPolicyDocumentStatementList_Override(d DataAwsIamPolicyDocumentStatementList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsIamPolicyDocumentStatementNotPrincipalsList_Override ¶
func NewDataAwsIamPolicyDocumentStatementNotPrincipalsList_Override(d DataAwsIamPolicyDocumentStatementNotPrincipalsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsIamPolicyDocumentStatementNotPrincipalsOutputReference_Override ¶
func NewDataAwsIamPolicyDocumentStatementNotPrincipalsOutputReference_Override(d DataAwsIamPolicyDocumentStatementNotPrincipalsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsIamPolicyDocumentStatementOutputReference_Override ¶
func NewDataAwsIamPolicyDocumentStatementOutputReference_Override(d DataAwsIamPolicyDocumentStatementOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsIamPolicyDocumentStatementPrincipalsList_Override ¶
func NewDataAwsIamPolicyDocumentStatementPrincipalsList_Override(d DataAwsIamPolicyDocumentStatementPrincipalsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsIamPolicyDocumentStatementPrincipalsOutputReference_Override ¶
func NewDataAwsIamPolicyDocumentStatementPrincipalsOutputReference_Override(d DataAwsIamPolicyDocumentStatementPrincipalsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsIamPolicyDocument_Override ¶
func NewDataAwsIamPolicyDocument_Override(d DataAwsIamPolicyDocument, scope constructs.Construct, id *string, config *DataAwsIamPolicyDocumentConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document aws_iam_policy_document} Data Source.
Types ¶
type DataAwsIamPolicyDocument ¶
type DataAwsIamPolicyDocument interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Json() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
OverrideJson() *string
SetOverrideJson(val *string)
OverrideJsonInput() *string
OverridePolicyDocuments() *[]*string
SetOverridePolicyDocuments(val *[]*string)
OverridePolicyDocumentsInput() *[]*string
PolicyId() *string
SetPolicyId(val *string)
PolicyIdInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
SourceJson() *string
SetSourceJson(val *string)
SourceJsonInput() *string
SourcePolicyDocuments() *[]*string
SetSourcePolicyDocuments(val *[]*string)
SourcePolicyDocumentsInput() *[]*string
Statement() DataAwsIamPolicyDocumentStatementList
StatementInput() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Version() *string
SetVersion(val *string)
VersionInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutStatement(value interface{})
ResetId()
ResetOverrideJson()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetOverridePolicyDocuments()
ResetPolicyId()
ResetSourceJson()
ResetSourcePolicyDocuments()
ResetStatement()
ResetVersion()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document aws_iam_policy_document}.
func NewDataAwsIamPolicyDocument ¶
func NewDataAwsIamPolicyDocument(scope constructs.Construct, id *string, config *DataAwsIamPolicyDocumentConfig) DataAwsIamPolicyDocument
Create a new {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document aws_iam_policy_document} Data Source.
type DataAwsIamPolicyDocumentConfig ¶
type DataAwsIamPolicyDocumentConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#id DataAwsIamPolicyDocument#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#override_json DataAwsIamPolicyDocument#override_json}.
OverrideJson *string `field:"optional" json:"overrideJson" yaml:"overrideJson"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#override_policy_documents DataAwsIamPolicyDocument#override_policy_documents}.
OverridePolicyDocuments *[]*string `field:"optional" json:"overridePolicyDocuments" yaml:"overridePolicyDocuments"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#policy_id DataAwsIamPolicyDocument#policy_id}.
PolicyId *string `field:"optional" json:"policyId" yaml:"policyId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#source_json DataAwsIamPolicyDocument#source_json}.
SourceJson *string `field:"optional" json:"sourceJson" yaml:"sourceJson"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#source_policy_documents DataAwsIamPolicyDocument#source_policy_documents}.
SourcePolicyDocuments *[]*string `field:"optional" json:"sourcePolicyDocuments" yaml:"sourcePolicyDocuments"`
// statement block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#statement DataAwsIamPolicyDocument#statement}
Statement interface{} `field:"optional" json:"statement" yaml:"statement"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#version DataAwsIamPolicyDocument#version}.
Version *string `field:"optional" json:"version" yaml:"version"`
}
type DataAwsIamPolicyDocumentStatement ¶
type DataAwsIamPolicyDocumentStatement struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#actions DataAwsIamPolicyDocument#actions}.
Actions *[]*string `field:"optional" json:"actions" yaml:"actions"`
// condition block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#condition DataAwsIamPolicyDocument#condition}
Condition interface{} `field:"optional" json:"condition" yaml:"condition"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#effect DataAwsIamPolicyDocument#effect}.
Effect *string `field:"optional" json:"effect" yaml:"effect"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#not_actions DataAwsIamPolicyDocument#not_actions}.
NotActions *[]*string `field:"optional" json:"notActions" yaml:"notActions"`
// not_principals block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#not_principals DataAwsIamPolicyDocument#not_principals}
NotPrincipals interface{} `field:"optional" json:"notPrincipals" yaml:"notPrincipals"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#not_resources DataAwsIamPolicyDocument#not_resources}.
NotResources *[]*string `field:"optional" json:"notResources" yaml:"notResources"`
// principals block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#principals DataAwsIamPolicyDocument#principals}
Principals interface{} `field:"optional" json:"principals" yaml:"principals"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#resources DataAwsIamPolicyDocument#resources}.
Resources *[]*string `field:"optional" json:"resources" yaml:"resources"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#sid DataAwsIamPolicyDocument#sid}.
Sid *string `field:"optional" json:"sid" yaml:"sid"`
}
type DataAwsIamPolicyDocumentStatementCondition ¶
type DataAwsIamPolicyDocumentStatementCondition struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#test DataAwsIamPolicyDocument#test}.
Test *string `field:"required" json:"test" yaml:"test"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#values DataAwsIamPolicyDocument#values}.
Values *[]*string `field:"required" json:"values" yaml:"values"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#variable DataAwsIamPolicyDocument#variable}.
Variable *string `field:"required" json:"variable" yaml:"variable"`
}
type DataAwsIamPolicyDocumentStatementConditionList ¶
type DataAwsIamPolicyDocumentStatementConditionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsIamPolicyDocumentStatementConditionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsIamPolicyDocumentStatementConditionList ¶
func NewDataAwsIamPolicyDocumentStatementConditionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsIamPolicyDocumentStatementConditionList
type DataAwsIamPolicyDocumentStatementConditionOutputReference ¶
type DataAwsIamPolicyDocumentStatementConditionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Test() *string
SetTest(val *string)
TestInput() *string
Values() *[]*string
SetValues(val *[]*string)
ValuesInput() *[]*string
Variable() *string
SetVariable(val *string)
VariableInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsIamPolicyDocumentStatementConditionOutputReference ¶
func NewDataAwsIamPolicyDocumentStatementConditionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsIamPolicyDocumentStatementConditionOutputReference
type DataAwsIamPolicyDocumentStatementList ¶
type DataAwsIamPolicyDocumentStatementList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsIamPolicyDocumentStatementOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsIamPolicyDocumentStatementList ¶
func NewDataAwsIamPolicyDocumentStatementList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsIamPolicyDocumentStatementList
type DataAwsIamPolicyDocumentStatementNotPrincipals ¶
type DataAwsIamPolicyDocumentStatementNotPrincipals struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#identifiers DataAwsIamPolicyDocument#identifiers}.
Identifiers *[]*string `field:"required" json:"identifiers" yaml:"identifiers"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#type DataAwsIamPolicyDocument#type}.
Type *string `field:"required" json:"type" yaml:"type"`
}
type DataAwsIamPolicyDocumentStatementNotPrincipalsList ¶
type DataAwsIamPolicyDocumentStatementNotPrincipalsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsIamPolicyDocumentStatementNotPrincipalsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsIamPolicyDocumentStatementNotPrincipalsList ¶
func NewDataAwsIamPolicyDocumentStatementNotPrincipalsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsIamPolicyDocumentStatementNotPrincipalsList
type DataAwsIamPolicyDocumentStatementNotPrincipalsOutputReference ¶
type DataAwsIamPolicyDocumentStatementNotPrincipalsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Identifiers() *[]*string
SetIdentifiers(val *[]*string)
IdentifiersInput() *[]*string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsIamPolicyDocumentStatementNotPrincipalsOutputReference ¶
func NewDataAwsIamPolicyDocumentStatementNotPrincipalsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsIamPolicyDocumentStatementNotPrincipalsOutputReference
type DataAwsIamPolicyDocumentStatementOutputReference ¶
type DataAwsIamPolicyDocumentStatementOutputReference interface {
cdktf.ComplexObject
Actions() *[]*string
SetActions(val *[]*string)
ActionsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Condition() DataAwsIamPolicyDocumentStatementConditionList
ConditionInput() interface{}
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Effect() *string
SetEffect(val *string)
EffectInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
NotActions() *[]*string
SetNotActions(val *[]*string)
NotActionsInput() *[]*string
NotPrincipals() DataAwsIamPolicyDocumentStatementNotPrincipalsList
NotPrincipalsInput() interface{}
NotResources() *[]*string
SetNotResources(val *[]*string)
NotResourcesInput() *[]*string
Principals() DataAwsIamPolicyDocumentStatementPrincipalsList
PrincipalsInput() interface{}
Resources() *[]*string
SetResources(val *[]*string)
ResourcesInput() *[]*string
Sid() *string
SetSid(val *string)
SidInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutCondition(value interface{})
PutNotPrincipals(value interface{})
PutPrincipals(value interface{})
ResetActions()
ResetCondition()
ResetEffect()
ResetNotActions()
ResetNotPrincipals()
ResetNotResources()
ResetPrincipals()
ResetResources()
ResetSid()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsIamPolicyDocumentStatementOutputReference ¶
func NewDataAwsIamPolicyDocumentStatementOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsIamPolicyDocumentStatementOutputReference
type DataAwsIamPolicyDocumentStatementPrincipals ¶
type DataAwsIamPolicyDocumentStatementPrincipals struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#identifiers DataAwsIamPolicyDocument#identifiers}.
Identifiers *[]*string `field:"required" json:"identifiers" yaml:"identifiers"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document#type DataAwsIamPolicyDocument#type}.
Type *string `field:"required" json:"type" yaml:"type"`
}
type DataAwsIamPolicyDocumentStatementPrincipalsList ¶
type DataAwsIamPolicyDocumentStatementPrincipalsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsIamPolicyDocumentStatementPrincipalsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsIamPolicyDocumentStatementPrincipalsList ¶
func NewDataAwsIamPolicyDocumentStatementPrincipalsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsIamPolicyDocumentStatementPrincipalsList
type DataAwsIamPolicyDocumentStatementPrincipalsOutputReference ¶
type DataAwsIamPolicyDocumentStatementPrincipalsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Identifiers() *[]*string
SetIdentifiers(val *[]*string)
IdentifiersInput() *[]*string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsIamPolicyDocumentStatementPrincipalsOutputReference ¶
func NewDataAwsIamPolicyDocumentStatementPrincipalsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsIamPolicyDocumentStatementPrincipalsOutputReference
Source Files
¶
- DataAwsIamPolicyDocument.go
- DataAwsIamPolicyDocumentConfig.go
- DataAwsIamPolicyDocumentStatement.go
- DataAwsIamPolicyDocumentStatementCondition.go
- DataAwsIamPolicyDocumentStatementConditionList.go
- DataAwsIamPolicyDocumentStatementConditionList__checks.go
- DataAwsIamPolicyDocumentStatementConditionOutputReference.go
- DataAwsIamPolicyDocumentStatementConditionOutputReference__checks.go
- DataAwsIamPolicyDocumentStatementList.go
- DataAwsIamPolicyDocumentStatementList__checks.go
- DataAwsIamPolicyDocumentStatementNotPrincipals.go
- DataAwsIamPolicyDocumentStatementNotPrincipalsList.go
- DataAwsIamPolicyDocumentStatementNotPrincipalsList__checks.go
- DataAwsIamPolicyDocumentStatementNotPrincipalsOutputReference.go
- DataAwsIamPolicyDocumentStatementNotPrincipalsOutputReference__checks.go
- DataAwsIamPolicyDocumentStatementOutputReference.go
- DataAwsIamPolicyDocumentStatementOutputReference__checks.go
- DataAwsIamPolicyDocumentStatementPrincipals.go
- DataAwsIamPolicyDocumentStatementPrincipalsList.go
- DataAwsIamPolicyDocumentStatementPrincipalsList__checks.go
- DataAwsIamPolicyDocumentStatementPrincipalsOutputReference.go
- DataAwsIamPolicyDocumentStatementPrincipalsOutputReference__checks.go
- DataAwsIamPolicyDocument__checks.go
- main.go