Documentation
¶
Index ¶
- func DataAwsImagebuilderImageRecipe_IsConstruct(x interface{}) *bool
- func DataAwsImagebuilderImageRecipe_IsTerraformDataSource(x interface{}) *bool
- func DataAwsImagebuilderImageRecipe_IsTerraformElement(x interface{}) *bool
- func DataAwsImagebuilderImageRecipe_TfResourceType() *string
- func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingEbsList_Override(d DataAwsImagebuilderImageRecipeBlockDeviceMappingEbsList, ...)
- func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingEbsOutputReference_Override(d DataAwsImagebuilderImageRecipeBlockDeviceMappingEbsOutputReference, ...)
- func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingList_Override(d DataAwsImagebuilderImageRecipeBlockDeviceMappingList, ...)
- func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingOutputReference_Override(d DataAwsImagebuilderImageRecipeBlockDeviceMappingOutputReference, ...)
- func NewDataAwsImagebuilderImageRecipeComponentList_Override(d DataAwsImagebuilderImageRecipeComponentList, ...)
- func NewDataAwsImagebuilderImageRecipeComponentOutputReference_Override(d DataAwsImagebuilderImageRecipeComponentOutputReference, ...)
- func NewDataAwsImagebuilderImageRecipeComponentParameterList_Override(d DataAwsImagebuilderImageRecipeComponentParameterList, ...)
- func NewDataAwsImagebuilderImageRecipeComponentParameterOutputReference_Override(d DataAwsImagebuilderImageRecipeComponentParameterOutputReference, ...)
- func NewDataAwsImagebuilderImageRecipe_Override(d DataAwsImagebuilderImageRecipe, scope constructs.Construct, id *string, ...)
- type DataAwsImagebuilderImageRecipe
- type DataAwsImagebuilderImageRecipeBlockDeviceMapping
- type DataAwsImagebuilderImageRecipeBlockDeviceMappingEbs
- type DataAwsImagebuilderImageRecipeBlockDeviceMappingEbsList
- type DataAwsImagebuilderImageRecipeBlockDeviceMappingEbsOutputReference
- type DataAwsImagebuilderImageRecipeBlockDeviceMappingList
- type DataAwsImagebuilderImageRecipeBlockDeviceMappingOutputReference
- type DataAwsImagebuilderImageRecipeComponent
- type DataAwsImagebuilderImageRecipeComponentList
- type DataAwsImagebuilderImageRecipeComponentOutputReference
- type DataAwsImagebuilderImageRecipeComponentParameter
- type DataAwsImagebuilderImageRecipeComponentParameterList
- type DataAwsImagebuilderImageRecipeComponentParameterOutputReference
- type DataAwsImagebuilderImageRecipeConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsImagebuilderImageRecipe_IsConstruct ¶
func DataAwsImagebuilderImageRecipe_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsImagebuilderImageRecipe_IsTerraformDataSource ¶
func DataAwsImagebuilderImageRecipe_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsImagebuilderImageRecipe_IsTerraformElement ¶
func DataAwsImagebuilderImageRecipe_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsImagebuilderImageRecipe_TfResourceType ¶
func DataAwsImagebuilderImageRecipe_TfResourceType() *string
func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingEbsList_Override ¶
func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingEbsList_Override(d DataAwsImagebuilderImageRecipeBlockDeviceMappingEbsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingEbsOutputReference_Override ¶
func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingEbsOutputReference_Override(d DataAwsImagebuilderImageRecipeBlockDeviceMappingEbsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingList_Override ¶
func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingList_Override(d DataAwsImagebuilderImageRecipeBlockDeviceMappingList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingOutputReference_Override ¶
func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingOutputReference_Override(d DataAwsImagebuilderImageRecipeBlockDeviceMappingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsImagebuilderImageRecipeComponentList_Override ¶
func NewDataAwsImagebuilderImageRecipeComponentList_Override(d DataAwsImagebuilderImageRecipeComponentList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsImagebuilderImageRecipeComponentOutputReference_Override ¶
func NewDataAwsImagebuilderImageRecipeComponentOutputReference_Override(d DataAwsImagebuilderImageRecipeComponentOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsImagebuilderImageRecipeComponentParameterList_Override ¶
func NewDataAwsImagebuilderImageRecipeComponentParameterList_Override(d DataAwsImagebuilderImageRecipeComponentParameterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsImagebuilderImageRecipeComponentParameterOutputReference_Override ¶
func NewDataAwsImagebuilderImageRecipeComponentParameterOutputReference_Override(d DataAwsImagebuilderImageRecipeComponentParameterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsImagebuilderImageRecipe_Override ¶
func NewDataAwsImagebuilderImageRecipe_Override(d DataAwsImagebuilderImageRecipe, scope constructs.Construct, id *string, config *DataAwsImagebuilderImageRecipeConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/imagebuilder_image_recipe aws_imagebuilder_image_recipe} Data Source.
Types ¶
type DataAwsImagebuilderImageRecipe ¶
type DataAwsImagebuilderImageRecipe interface {
cdktf.TerraformDataSource
Arn() *string
SetArn(val *string)
ArnInput() *string
BlockDeviceMapping() DataAwsImagebuilderImageRecipeBlockDeviceMappingList
// Experimental.
CdktfStack() cdktf.TerraformStack
Component() DataAwsImagebuilderImageRecipeComponentList
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DateCreated() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
Owner() *string
ParentImage() *string
Platform() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
UserDataBase64() *string
Version() *string
WorkingDirectory() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/imagebuilder_image_recipe aws_imagebuilder_image_recipe}.
func NewDataAwsImagebuilderImageRecipe ¶
func NewDataAwsImagebuilderImageRecipe(scope constructs.Construct, id *string, config *DataAwsImagebuilderImageRecipeConfig) DataAwsImagebuilderImageRecipe
Create a new {@link https://www.terraform.io/docs/providers/aws/d/imagebuilder_image_recipe aws_imagebuilder_image_recipe} Data Source.
type DataAwsImagebuilderImageRecipeBlockDeviceMapping ¶
type DataAwsImagebuilderImageRecipeBlockDeviceMapping struct {
}
type DataAwsImagebuilderImageRecipeBlockDeviceMappingEbs ¶
type DataAwsImagebuilderImageRecipeBlockDeviceMappingEbs struct {
}
type DataAwsImagebuilderImageRecipeBlockDeviceMappingEbsList ¶
type DataAwsImagebuilderImageRecipeBlockDeviceMappingEbsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsImagebuilderImageRecipeBlockDeviceMappingEbsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingEbsList ¶
func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingEbsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsImagebuilderImageRecipeBlockDeviceMappingEbsList
type DataAwsImagebuilderImageRecipeBlockDeviceMappingEbsOutputReference ¶
type DataAwsImagebuilderImageRecipeBlockDeviceMappingEbsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeleteOnTermination() cdktf.IResolvable
Encrypted() cdktf.IResolvable
// Experimental.
Fqn() *string
InternalValue() *DataAwsImagebuilderImageRecipeBlockDeviceMappingEbs
SetInternalValue(val *DataAwsImagebuilderImageRecipeBlockDeviceMappingEbs)
Iops() *float64
KmsKeyId() *string
SnapshotId() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Throughput() *float64
VolumeSize() *float64
VolumeType() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingEbsOutputReference ¶
func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingEbsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsImagebuilderImageRecipeBlockDeviceMappingEbsOutputReference
type DataAwsImagebuilderImageRecipeBlockDeviceMappingList ¶
type DataAwsImagebuilderImageRecipeBlockDeviceMappingList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsImagebuilderImageRecipeBlockDeviceMappingOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingList ¶
func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsImagebuilderImageRecipeBlockDeviceMappingList
type DataAwsImagebuilderImageRecipeBlockDeviceMappingOutputReference ¶
type DataAwsImagebuilderImageRecipeBlockDeviceMappingOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeviceName() *string
Ebs() DataAwsImagebuilderImageRecipeBlockDeviceMappingEbsList
// Experimental.
Fqn() *string
InternalValue() *DataAwsImagebuilderImageRecipeBlockDeviceMapping
SetInternalValue(val *DataAwsImagebuilderImageRecipeBlockDeviceMapping)
NoDevice() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VirtualName() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingOutputReference ¶
func NewDataAwsImagebuilderImageRecipeBlockDeviceMappingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsImagebuilderImageRecipeBlockDeviceMappingOutputReference
type DataAwsImagebuilderImageRecipeComponent ¶
type DataAwsImagebuilderImageRecipeComponent struct {
}
type DataAwsImagebuilderImageRecipeComponentList ¶
type DataAwsImagebuilderImageRecipeComponentList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsImagebuilderImageRecipeComponentOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsImagebuilderImageRecipeComponentList ¶
func NewDataAwsImagebuilderImageRecipeComponentList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsImagebuilderImageRecipeComponentList
type DataAwsImagebuilderImageRecipeComponentOutputReference ¶
type DataAwsImagebuilderImageRecipeComponentOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ComponentArn() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsImagebuilderImageRecipeComponent
SetInternalValue(val *DataAwsImagebuilderImageRecipeComponent)
Parameter() DataAwsImagebuilderImageRecipeComponentParameterList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsImagebuilderImageRecipeComponentOutputReference ¶
func NewDataAwsImagebuilderImageRecipeComponentOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsImagebuilderImageRecipeComponentOutputReference
type DataAwsImagebuilderImageRecipeComponentParameter ¶
type DataAwsImagebuilderImageRecipeComponentParameter struct {
}
type DataAwsImagebuilderImageRecipeComponentParameterList ¶
type DataAwsImagebuilderImageRecipeComponentParameterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsImagebuilderImageRecipeComponentParameterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsImagebuilderImageRecipeComponentParameterList ¶
func NewDataAwsImagebuilderImageRecipeComponentParameterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsImagebuilderImageRecipeComponentParameterList
type DataAwsImagebuilderImageRecipeComponentParameterOutputReference ¶
type DataAwsImagebuilderImageRecipeComponentParameterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsImagebuilderImageRecipeComponentParameter
SetInternalValue(val *DataAwsImagebuilderImageRecipeComponentParameter)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsImagebuilderImageRecipeComponentParameterOutputReference ¶
func NewDataAwsImagebuilderImageRecipeComponentParameterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsImagebuilderImageRecipeComponentParameterOutputReference
type DataAwsImagebuilderImageRecipeConfig ¶
type DataAwsImagebuilderImageRecipeConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/imagebuilder_image_recipe#arn DataAwsImagebuilderImageRecipe#arn}.
Arn *string `field:"required" json:"arn" yaml:"arn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/imagebuilder_image_recipe#id DataAwsImagebuilderImageRecipe#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/imagebuilder_image_recipe#tags DataAwsImagebuilderImageRecipe#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
Source Files
¶
- DataAwsImagebuilderImageRecipe.go
- DataAwsImagebuilderImageRecipeBlockDeviceMapping.go
- DataAwsImagebuilderImageRecipeBlockDeviceMappingEbs.go
- DataAwsImagebuilderImageRecipeBlockDeviceMappingEbsList.go
- DataAwsImagebuilderImageRecipeBlockDeviceMappingEbsList__checks.go
- DataAwsImagebuilderImageRecipeBlockDeviceMappingEbsOutputReference.go
- DataAwsImagebuilderImageRecipeBlockDeviceMappingEbsOutputReference__checks.go
- DataAwsImagebuilderImageRecipeBlockDeviceMappingList.go
- DataAwsImagebuilderImageRecipeBlockDeviceMappingList__checks.go
- DataAwsImagebuilderImageRecipeBlockDeviceMappingOutputReference.go
- DataAwsImagebuilderImageRecipeBlockDeviceMappingOutputReference__checks.go
- DataAwsImagebuilderImageRecipeComponent.go
- DataAwsImagebuilderImageRecipeComponentList.go
- DataAwsImagebuilderImageRecipeComponentList__checks.go
- DataAwsImagebuilderImageRecipeComponentOutputReference.go
- DataAwsImagebuilderImageRecipeComponentOutputReference__checks.go
- DataAwsImagebuilderImageRecipeComponentParameter.go
- DataAwsImagebuilderImageRecipeComponentParameterList.go
- DataAwsImagebuilderImageRecipeComponentParameterList__checks.go
- DataAwsImagebuilderImageRecipeComponentParameterOutputReference.go
- DataAwsImagebuilderImageRecipeComponentParameterOutputReference__checks.go
- DataAwsImagebuilderImageRecipeConfig.go
- DataAwsImagebuilderImageRecipe__checks.go
- main.go