Documentation
¶
Index ¶
- func DataAwsImagebuilderInfrastructureConfiguration_IsConstruct(x interface{}) *bool
- func DataAwsImagebuilderInfrastructureConfiguration_IsTerraformDataSource(x interface{}) *bool
- func DataAwsImagebuilderInfrastructureConfiguration_IsTerraformElement(x interface{}) *bool
- func DataAwsImagebuilderInfrastructureConfiguration_TfResourceType() *string
- func NewDataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsList_Override(d DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsList, ...)
- func NewDataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference_Override(...)
- func NewDataAwsImagebuilderInfrastructureConfigurationLoggingList_Override(d DataAwsImagebuilderInfrastructureConfigurationLoggingList, ...)
- func NewDataAwsImagebuilderInfrastructureConfigurationLoggingOutputReference_Override(d DataAwsImagebuilderInfrastructureConfigurationLoggingOutputReference, ...)
- func NewDataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsList_Override(d DataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsList, ...)
- func NewDataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference_Override(d DataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference, ...)
- func NewDataAwsImagebuilderInfrastructureConfiguration_Override(d DataAwsImagebuilderInfrastructureConfiguration, scope constructs.Construct, ...)
- type DataAwsImagebuilderInfrastructureConfiguration
- type DataAwsImagebuilderInfrastructureConfigurationConfig
- type DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptions
- type DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsList
- type DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference
- type DataAwsImagebuilderInfrastructureConfigurationLogging
- type DataAwsImagebuilderInfrastructureConfigurationLoggingList
- type DataAwsImagebuilderInfrastructureConfigurationLoggingOutputReference
- type DataAwsImagebuilderInfrastructureConfigurationLoggingS3Logs
- type DataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsList
- type DataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsImagebuilderInfrastructureConfiguration_IsConstruct ¶
func DataAwsImagebuilderInfrastructureConfiguration_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsImagebuilderInfrastructureConfiguration_IsTerraformDataSource ¶
func DataAwsImagebuilderInfrastructureConfiguration_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsImagebuilderInfrastructureConfiguration_IsTerraformElement ¶
func DataAwsImagebuilderInfrastructureConfiguration_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsImagebuilderInfrastructureConfiguration_TfResourceType ¶
func DataAwsImagebuilderInfrastructureConfiguration_TfResourceType() *string
func NewDataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsList_Override ¶
func NewDataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsList_Override(d DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference_Override ¶
func NewDataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference_Override(d DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsImagebuilderInfrastructureConfigurationLoggingList_Override ¶
func NewDataAwsImagebuilderInfrastructureConfigurationLoggingList_Override(d DataAwsImagebuilderInfrastructureConfigurationLoggingList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsImagebuilderInfrastructureConfigurationLoggingOutputReference_Override ¶
func NewDataAwsImagebuilderInfrastructureConfigurationLoggingOutputReference_Override(d DataAwsImagebuilderInfrastructureConfigurationLoggingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsList_Override ¶
func NewDataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsList_Override(d DataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference_Override ¶
func NewDataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference_Override(d DataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsImagebuilderInfrastructureConfiguration_Override ¶
func NewDataAwsImagebuilderInfrastructureConfiguration_Override(d DataAwsImagebuilderInfrastructureConfiguration, scope constructs.Construct, id *string, config *DataAwsImagebuilderInfrastructureConfigurationConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/imagebuilder_infrastructure_configuration aws_imagebuilder_infrastructure_configuration} Data Source.
Types ¶
type DataAwsImagebuilderInfrastructureConfiguration ¶
type DataAwsImagebuilderInfrastructureConfiguration interface {
cdktf.TerraformDataSource
Arn() *string
SetArn(val *string)
ArnInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DateCreated() *string
DateUpdated() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InstanceMetadataOptions() DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsList
InstanceProfileName() *string
InstanceTypes() *[]*string
KeyPair() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Logging() DataAwsImagebuilderInfrastructureConfigurationLoggingList
Name() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
ResourceTags() *map[string]*string
SetResourceTags(val *map[string]*string)
ResourceTagsInput() *map[string]*string
SecurityGroupIds() *[]*string
SnsTopicArn() *string
SubnetId() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
TerminateInstanceOnFailure() cdktf.IResolvable
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetResourceTags()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/imagebuilder_infrastructure_configuration aws_imagebuilder_infrastructure_configuration}.
func NewDataAwsImagebuilderInfrastructureConfiguration ¶
func NewDataAwsImagebuilderInfrastructureConfiguration(scope constructs.Construct, id *string, config *DataAwsImagebuilderInfrastructureConfigurationConfig) DataAwsImagebuilderInfrastructureConfiguration
Create a new {@link https://www.terraform.io/docs/providers/aws/d/imagebuilder_infrastructure_configuration aws_imagebuilder_infrastructure_configuration} Data Source.
type DataAwsImagebuilderInfrastructureConfigurationConfig ¶
type DataAwsImagebuilderInfrastructureConfigurationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/imagebuilder_infrastructure_configuration#arn DataAwsImagebuilderInfrastructureConfiguration#arn}.
Arn *string `field:"required" json:"arn" yaml:"arn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/imagebuilder_infrastructure_configuration#id DataAwsImagebuilderInfrastructureConfiguration#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/imagebuilder_infrastructure_configuration#resource_tags DataAwsImagebuilderInfrastructureConfiguration#resource_tags}.
ResourceTags *map[string]*string `field:"optional" json:"resourceTags" yaml:"resourceTags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/imagebuilder_infrastructure_configuration#tags DataAwsImagebuilderInfrastructureConfiguration#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptions ¶
type DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptions struct {
}
type DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsList ¶
type DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsList ¶
func NewDataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsList
type DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference ¶
type DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HttpPutResponseHopLimit() *float64
HttpTokens() *string
InternalValue() *DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptions
SetInternalValue(val *DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference ¶
func NewDataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference
type DataAwsImagebuilderInfrastructureConfigurationLogging ¶
type DataAwsImagebuilderInfrastructureConfigurationLogging struct {
}
type DataAwsImagebuilderInfrastructureConfigurationLoggingList ¶
type DataAwsImagebuilderInfrastructureConfigurationLoggingList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsImagebuilderInfrastructureConfigurationLoggingOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsImagebuilderInfrastructureConfigurationLoggingList ¶
func NewDataAwsImagebuilderInfrastructureConfigurationLoggingList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsImagebuilderInfrastructureConfigurationLoggingList
type DataAwsImagebuilderInfrastructureConfigurationLoggingOutputReference ¶
type DataAwsImagebuilderInfrastructureConfigurationLoggingOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsImagebuilderInfrastructureConfigurationLogging
SetInternalValue(val *DataAwsImagebuilderInfrastructureConfigurationLogging)
S3Logs() DataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsImagebuilderInfrastructureConfigurationLoggingOutputReference ¶
func NewDataAwsImagebuilderInfrastructureConfigurationLoggingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsImagebuilderInfrastructureConfigurationLoggingOutputReference
type DataAwsImagebuilderInfrastructureConfigurationLoggingS3Logs ¶
type DataAwsImagebuilderInfrastructureConfigurationLoggingS3Logs struct {
}
type DataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsList ¶
type DataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsList ¶
func NewDataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsList
type DataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference ¶
type DataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsImagebuilderInfrastructureConfigurationLoggingS3Logs
SetInternalValue(val *DataAwsImagebuilderInfrastructureConfigurationLoggingS3Logs)
S3BucketName() *string
S3KeyPrefix() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference ¶
func NewDataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference
Source Files
¶
- DataAwsImagebuilderInfrastructureConfiguration.go
- DataAwsImagebuilderInfrastructureConfigurationConfig.go
- DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptions.go
- DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsList.go
- DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsList__checks.go
- DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference.go
- DataAwsImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference__checks.go
- DataAwsImagebuilderInfrastructureConfigurationLogging.go
- DataAwsImagebuilderInfrastructureConfigurationLoggingList.go
- DataAwsImagebuilderInfrastructureConfigurationLoggingList__checks.go
- DataAwsImagebuilderInfrastructureConfigurationLoggingOutputReference.go
- DataAwsImagebuilderInfrastructureConfigurationLoggingOutputReference__checks.go
- DataAwsImagebuilderInfrastructureConfigurationLoggingS3Logs.go
- DataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsList.go
- DataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsList__checks.go
- DataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference.go
- DataAwsImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference__checks.go
- DataAwsImagebuilderInfrastructureConfiguration__checks.go
- main.go