Documentation
¶
Index ¶
- func DataAwsLbListener_IsConstruct(x interface{}) *bool
- func DataAwsLbListener_IsTerraformDataSource(x interface{}) *bool
- func DataAwsLbListener_IsTerraformElement(x interface{}) *bool
- func DataAwsLbListener_TfResourceType() *string
- func NewDataAwsLbListenerDefaultActionAuthenticateCognitoList_Override(d DataAwsLbListenerDefaultActionAuthenticateCognitoList, ...)
- func NewDataAwsLbListenerDefaultActionAuthenticateCognitoOutputReference_Override(d DataAwsLbListenerDefaultActionAuthenticateCognitoOutputReference, ...)
- func NewDataAwsLbListenerDefaultActionAuthenticateOidcList_Override(d DataAwsLbListenerDefaultActionAuthenticateOidcList, ...)
- func NewDataAwsLbListenerDefaultActionAuthenticateOidcOutputReference_Override(d DataAwsLbListenerDefaultActionAuthenticateOidcOutputReference, ...)
- func NewDataAwsLbListenerDefaultActionFixedResponseList_Override(d DataAwsLbListenerDefaultActionFixedResponseList, ...)
- func NewDataAwsLbListenerDefaultActionFixedResponseOutputReference_Override(d DataAwsLbListenerDefaultActionFixedResponseOutputReference, ...)
- func NewDataAwsLbListenerDefaultActionForwardList_Override(d DataAwsLbListenerDefaultActionForwardList, ...)
- func NewDataAwsLbListenerDefaultActionForwardOutputReference_Override(d DataAwsLbListenerDefaultActionForwardOutputReference, ...)
- func NewDataAwsLbListenerDefaultActionForwardStickinessList_Override(d DataAwsLbListenerDefaultActionForwardStickinessList, ...)
- func NewDataAwsLbListenerDefaultActionForwardStickinessOutputReference_Override(d DataAwsLbListenerDefaultActionForwardStickinessOutputReference, ...)
- func NewDataAwsLbListenerDefaultActionForwardTargetGroupList_Override(d DataAwsLbListenerDefaultActionForwardTargetGroupList, ...)
- func NewDataAwsLbListenerDefaultActionForwardTargetGroupOutputReference_Override(d DataAwsLbListenerDefaultActionForwardTargetGroupOutputReference, ...)
- func NewDataAwsLbListenerDefaultActionList_Override(d DataAwsLbListenerDefaultActionList, ...)
- func NewDataAwsLbListenerDefaultActionOutputReference_Override(d DataAwsLbListenerDefaultActionOutputReference, ...)
- func NewDataAwsLbListenerDefaultActionRedirectList_Override(d DataAwsLbListenerDefaultActionRedirectList, ...)
- func NewDataAwsLbListenerDefaultActionRedirectOutputReference_Override(d DataAwsLbListenerDefaultActionRedirectOutputReference, ...)
- func NewDataAwsLbListenerTimeoutsOutputReference_Override(d DataAwsLbListenerTimeoutsOutputReference, ...)
- func NewDataAwsLbListener_Override(d DataAwsLbListener, scope constructs.Construct, id *string, ...)
- type DataAwsLbListener
- type DataAwsLbListenerConfig
- type DataAwsLbListenerDefaultAction
- type DataAwsLbListenerDefaultActionAuthenticateCognito
- type DataAwsLbListenerDefaultActionAuthenticateCognitoList
- type DataAwsLbListenerDefaultActionAuthenticateCognitoOutputReference
- type DataAwsLbListenerDefaultActionAuthenticateOidc
- type DataAwsLbListenerDefaultActionAuthenticateOidcList
- type DataAwsLbListenerDefaultActionAuthenticateOidcOutputReference
- type DataAwsLbListenerDefaultActionFixedResponse
- type DataAwsLbListenerDefaultActionFixedResponseList
- type DataAwsLbListenerDefaultActionFixedResponseOutputReference
- type DataAwsLbListenerDefaultActionForward
- type DataAwsLbListenerDefaultActionForwardList
- type DataAwsLbListenerDefaultActionForwardOutputReference
- type DataAwsLbListenerDefaultActionForwardStickiness
- type DataAwsLbListenerDefaultActionForwardStickinessList
- type DataAwsLbListenerDefaultActionForwardStickinessOutputReference
- type DataAwsLbListenerDefaultActionForwardTargetGroup
- type DataAwsLbListenerDefaultActionForwardTargetGroupList
- type DataAwsLbListenerDefaultActionForwardTargetGroupOutputReference
- type DataAwsLbListenerDefaultActionList
- type DataAwsLbListenerDefaultActionOutputReference
- type DataAwsLbListenerDefaultActionRedirect
- type DataAwsLbListenerDefaultActionRedirectList
- type DataAwsLbListenerDefaultActionRedirectOutputReference
- type DataAwsLbListenerTimeouts
- type DataAwsLbListenerTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsLbListener_IsConstruct ¶
func DataAwsLbListener_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsLbListener_IsTerraformDataSource ¶
func DataAwsLbListener_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsLbListener_IsTerraformElement ¶
func DataAwsLbListener_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsLbListener_TfResourceType ¶
func DataAwsLbListener_TfResourceType() *string
func NewDataAwsLbListenerDefaultActionAuthenticateCognitoList_Override ¶
func NewDataAwsLbListenerDefaultActionAuthenticateCognitoList_Override(d DataAwsLbListenerDefaultActionAuthenticateCognitoList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLbListenerDefaultActionAuthenticateCognitoOutputReference_Override ¶
func NewDataAwsLbListenerDefaultActionAuthenticateCognitoOutputReference_Override(d DataAwsLbListenerDefaultActionAuthenticateCognitoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLbListenerDefaultActionAuthenticateOidcList_Override ¶
func NewDataAwsLbListenerDefaultActionAuthenticateOidcList_Override(d DataAwsLbListenerDefaultActionAuthenticateOidcList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLbListenerDefaultActionAuthenticateOidcOutputReference_Override ¶
func NewDataAwsLbListenerDefaultActionAuthenticateOidcOutputReference_Override(d DataAwsLbListenerDefaultActionAuthenticateOidcOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLbListenerDefaultActionFixedResponseList_Override ¶
func NewDataAwsLbListenerDefaultActionFixedResponseList_Override(d DataAwsLbListenerDefaultActionFixedResponseList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLbListenerDefaultActionFixedResponseOutputReference_Override ¶
func NewDataAwsLbListenerDefaultActionFixedResponseOutputReference_Override(d DataAwsLbListenerDefaultActionFixedResponseOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLbListenerDefaultActionForwardList_Override ¶
func NewDataAwsLbListenerDefaultActionForwardList_Override(d DataAwsLbListenerDefaultActionForwardList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLbListenerDefaultActionForwardOutputReference_Override ¶
func NewDataAwsLbListenerDefaultActionForwardOutputReference_Override(d DataAwsLbListenerDefaultActionForwardOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLbListenerDefaultActionForwardStickinessList_Override ¶
func NewDataAwsLbListenerDefaultActionForwardStickinessList_Override(d DataAwsLbListenerDefaultActionForwardStickinessList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLbListenerDefaultActionForwardStickinessOutputReference_Override ¶
func NewDataAwsLbListenerDefaultActionForwardStickinessOutputReference_Override(d DataAwsLbListenerDefaultActionForwardStickinessOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLbListenerDefaultActionForwardTargetGroupList_Override ¶
func NewDataAwsLbListenerDefaultActionForwardTargetGroupList_Override(d DataAwsLbListenerDefaultActionForwardTargetGroupList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLbListenerDefaultActionForwardTargetGroupOutputReference_Override ¶
func NewDataAwsLbListenerDefaultActionForwardTargetGroupOutputReference_Override(d DataAwsLbListenerDefaultActionForwardTargetGroupOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLbListenerDefaultActionList_Override ¶
func NewDataAwsLbListenerDefaultActionList_Override(d DataAwsLbListenerDefaultActionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLbListenerDefaultActionOutputReference_Override ¶
func NewDataAwsLbListenerDefaultActionOutputReference_Override(d DataAwsLbListenerDefaultActionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLbListenerDefaultActionRedirectList_Override ¶
func NewDataAwsLbListenerDefaultActionRedirectList_Override(d DataAwsLbListenerDefaultActionRedirectList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLbListenerDefaultActionRedirectOutputReference_Override ¶
func NewDataAwsLbListenerDefaultActionRedirectOutputReference_Override(d DataAwsLbListenerDefaultActionRedirectOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLbListenerTimeoutsOutputReference_Override ¶
func NewDataAwsLbListenerTimeoutsOutputReference_Override(d DataAwsLbListenerTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsLbListener_Override ¶
func NewDataAwsLbListener_Override(d DataAwsLbListener, scope constructs.Construct, id *string, config *DataAwsLbListenerConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/lb_listener aws_lb_listener} Data Source.
Types ¶
type DataAwsLbListener ¶
type DataAwsLbListener interface {
cdktf.TerraformDataSource
AlpnPolicy() *string
Arn() *string
SetArn(val *string)
ArnInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CertificateArn() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DefaultAction() DataAwsLbListenerDefaultActionList
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LoadBalancerArn() *string
SetLoadBalancerArn(val *string)
LoadBalancerArnInput() *string
// The tree node.
Node() constructs.Node
Port() *float64
SetPort(val *float64)
PortInput() *float64
Protocol() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
SslPolicy() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DataAwsLbListenerTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *DataAwsLbListenerTimeouts)
ResetArn()
ResetId()
ResetLoadBalancerArn()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPort()
ResetTags()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/lb_listener aws_lb_listener}.
func NewDataAwsLbListener ¶
func NewDataAwsLbListener(scope constructs.Construct, id *string, config *DataAwsLbListenerConfig) DataAwsLbListener
Create a new {@link https://www.terraform.io/docs/providers/aws/d/lb_listener aws_lb_listener} Data Source.
type DataAwsLbListenerConfig ¶
type DataAwsLbListenerConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb_listener#arn DataAwsLbListener#arn}.
Arn *string `field:"optional" json:"arn" yaml:"arn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb_listener#id DataAwsLbListener#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb_listener#load_balancer_arn DataAwsLbListener#load_balancer_arn}.
LoadBalancerArn *string `field:"optional" json:"loadBalancerArn" yaml:"loadBalancerArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb_listener#port DataAwsLbListener#port}.
Port *float64 `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb_listener#tags DataAwsLbListener#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb_listener#timeouts DataAwsLbListener#timeouts}
Timeouts *DataAwsLbListenerTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type DataAwsLbListenerDefaultAction ¶
type DataAwsLbListenerDefaultAction struct {
}
type DataAwsLbListenerDefaultActionAuthenticateCognito ¶
type DataAwsLbListenerDefaultActionAuthenticateCognito struct {
}
type DataAwsLbListenerDefaultActionAuthenticateCognitoList ¶
type DataAwsLbListenerDefaultActionAuthenticateCognitoList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLbListenerDefaultActionAuthenticateCognitoOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbListenerDefaultActionAuthenticateCognitoList ¶
func NewDataAwsLbListenerDefaultActionAuthenticateCognitoList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLbListenerDefaultActionAuthenticateCognitoList
type DataAwsLbListenerDefaultActionAuthenticateCognitoOutputReference ¶
type DataAwsLbListenerDefaultActionAuthenticateCognitoOutputReference interface {
cdktf.ComplexObject
AuthenticationRequestExtraParams() cdktf.StringMap
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLbListenerDefaultActionAuthenticateCognito
SetInternalValue(val *DataAwsLbListenerDefaultActionAuthenticateCognito)
OnUnauthenticatedRequest() *string
Scope() *string
SessionCookieName() *string
SessionTimeout() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UserPoolArn() *string
UserPoolClientId() *string
UserPoolDomain() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbListenerDefaultActionAuthenticateCognitoOutputReference ¶
func NewDataAwsLbListenerDefaultActionAuthenticateCognitoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLbListenerDefaultActionAuthenticateCognitoOutputReference
type DataAwsLbListenerDefaultActionAuthenticateOidc ¶
type DataAwsLbListenerDefaultActionAuthenticateOidc struct {
}
type DataAwsLbListenerDefaultActionAuthenticateOidcList ¶
type DataAwsLbListenerDefaultActionAuthenticateOidcList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLbListenerDefaultActionAuthenticateOidcOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbListenerDefaultActionAuthenticateOidcList ¶
func NewDataAwsLbListenerDefaultActionAuthenticateOidcList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLbListenerDefaultActionAuthenticateOidcList
type DataAwsLbListenerDefaultActionAuthenticateOidcOutputReference ¶
type DataAwsLbListenerDefaultActionAuthenticateOidcOutputReference interface {
cdktf.ComplexObject
AuthenticationRequestExtraParams() cdktf.StringMap
AuthorizationEndpoint() *string
ClientId() *string
ClientSecret() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLbListenerDefaultActionAuthenticateOidc
SetInternalValue(val *DataAwsLbListenerDefaultActionAuthenticateOidc)
Issuer() *string
OnUnauthenticatedRequest() *string
Scope() *string
SessionCookieName() *string
SessionTimeout() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TokenEndpoint() *string
UserInfoEndpoint() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbListenerDefaultActionAuthenticateOidcOutputReference ¶
func NewDataAwsLbListenerDefaultActionAuthenticateOidcOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLbListenerDefaultActionAuthenticateOidcOutputReference
type DataAwsLbListenerDefaultActionFixedResponse ¶
type DataAwsLbListenerDefaultActionFixedResponse struct {
}
type DataAwsLbListenerDefaultActionFixedResponseList ¶
type DataAwsLbListenerDefaultActionFixedResponseList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLbListenerDefaultActionFixedResponseOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbListenerDefaultActionFixedResponseList ¶
func NewDataAwsLbListenerDefaultActionFixedResponseList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLbListenerDefaultActionFixedResponseList
type DataAwsLbListenerDefaultActionFixedResponseOutputReference ¶
type DataAwsLbListenerDefaultActionFixedResponseOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ContentType() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLbListenerDefaultActionFixedResponse
SetInternalValue(val *DataAwsLbListenerDefaultActionFixedResponse)
MessageBody() *string
StatusCode() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbListenerDefaultActionFixedResponseOutputReference ¶
func NewDataAwsLbListenerDefaultActionFixedResponseOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLbListenerDefaultActionFixedResponseOutputReference
type DataAwsLbListenerDefaultActionForward ¶
type DataAwsLbListenerDefaultActionForward struct {
}
type DataAwsLbListenerDefaultActionForwardList ¶
type DataAwsLbListenerDefaultActionForwardList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLbListenerDefaultActionForwardOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbListenerDefaultActionForwardList ¶
func NewDataAwsLbListenerDefaultActionForwardList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLbListenerDefaultActionForwardList
type DataAwsLbListenerDefaultActionForwardOutputReference ¶
type DataAwsLbListenerDefaultActionForwardOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLbListenerDefaultActionForward
SetInternalValue(val *DataAwsLbListenerDefaultActionForward)
Stickiness() DataAwsLbListenerDefaultActionForwardStickinessList
TargetGroup() DataAwsLbListenerDefaultActionForwardTargetGroupList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbListenerDefaultActionForwardOutputReference ¶
func NewDataAwsLbListenerDefaultActionForwardOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLbListenerDefaultActionForwardOutputReference
type DataAwsLbListenerDefaultActionForwardStickiness ¶
type DataAwsLbListenerDefaultActionForwardStickiness struct {
}
type DataAwsLbListenerDefaultActionForwardStickinessList ¶
type DataAwsLbListenerDefaultActionForwardStickinessList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLbListenerDefaultActionForwardStickinessOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbListenerDefaultActionForwardStickinessList ¶
func NewDataAwsLbListenerDefaultActionForwardStickinessList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLbListenerDefaultActionForwardStickinessList
type DataAwsLbListenerDefaultActionForwardStickinessOutputReference ¶
type DataAwsLbListenerDefaultActionForwardStickinessOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Duration() *float64
Enabled() cdktf.IResolvable
// Experimental.
Fqn() *string
InternalValue() *DataAwsLbListenerDefaultActionForwardStickiness
SetInternalValue(val *DataAwsLbListenerDefaultActionForwardStickiness)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbListenerDefaultActionForwardStickinessOutputReference ¶
func NewDataAwsLbListenerDefaultActionForwardStickinessOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLbListenerDefaultActionForwardStickinessOutputReference
type DataAwsLbListenerDefaultActionForwardTargetGroup ¶
type DataAwsLbListenerDefaultActionForwardTargetGroup struct {
}
type DataAwsLbListenerDefaultActionForwardTargetGroupList ¶
type DataAwsLbListenerDefaultActionForwardTargetGroupList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLbListenerDefaultActionForwardTargetGroupOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbListenerDefaultActionForwardTargetGroupList ¶
func NewDataAwsLbListenerDefaultActionForwardTargetGroupList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLbListenerDefaultActionForwardTargetGroupList
type DataAwsLbListenerDefaultActionForwardTargetGroupOutputReference ¶
type DataAwsLbListenerDefaultActionForwardTargetGroupOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLbListenerDefaultActionForwardTargetGroup
SetInternalValue(val *DataAwsLbListenerDefaultActionForwardTargetGroup)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Weight() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbListenerDefaultActionForwardTargetGroupOutputReference ¶
func NewDataAwsLbListenerDefaultActionForwardTargetGroupOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLbListenerDefaultActionForwardTargetGroupOutputReference
type DataAwsLbListenerDefaultActionList ¶
type DataAwsLbListenerDefaultActionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLbListenerDefaultActionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbListenerDefaultActionList ¶
func NewDataAwsLbListenerDefaultActionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLbListenerDefaultActionList
type DataAwsLbListenerDefaultActionOutputReference ¶
type DataAwsLbListenerDefaultActionOutputReference interface {
cdktf.ComplexObject
AuthenticateCognito() DataAwsLbListenerDefaultActionAuthenticateCognitoList
AuthenticateOidc() DataAwsLbListenerDefaultActionAuthenticateOidcList
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FixedResponse() DataAwsLbListenerDefaultActionFixedResponseList
Forward() DataAwsLbListenerDefaultActionForwardList
// Experimental.
Fqn() *string
InternalValue() *DataAwsLbListenerDefaultAction
SetInternalValue(val *DataAwsLbListenerDefaultAction)
Order() *float64
Redirect() DataAwsLbListenerDefaultActionRedirectList
TargetGroupArn() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbListenerDefaultActionOutputReference ¶
func NewDataAwsLbListenerDefaultActionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLbListenerDefaultActionOutputReference
type DataAwsLbListenerDefaultActionRedirect ¶
type DataAwsLbListenerDefaultActionRedirect struct {
}
type DataAwsLbListenerDefaultActionRedirectList ¶
type DataAwsLbListenerDefaultActionRedirectList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLbListenerDefaultActionRedirectOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbListenerDefaultActionRedirectList ¶
func NewDataAwsLbListenerDefaultActionRedirectList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLbListenerDefaultActionRedirectList
type DataAwsLbListenerDefaultActionRedirectOutputReference ¶
type DataAwsLbListenerDefaultActionRedirectOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Host() *string
InternalValue() *DataAwsLbListenerDefaultActionRedirect
SetInternalValue(val *DataAwsLbListenerDefaultActionRedirect)
Path() *string
Port() *string
Protocol() *string
Query() *string
StatusCode() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbListenerDefaultActionRedirectOutputReference ¶
func NewDataAwsLbListenerDefaultActionRedirectOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLbListenerDefaultActionRedirectOutputReference
type DataAwsLbListenerTimeouts ¶
type DataAwsLbListenerTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb_listener#read DataAwsLbListener#read}.
Read *string `field:"optional" json:"read" yaml:"read"`
}
type DataAwsLbListenerTimeoutsOutputReference ¶
type DataAwsLbListenerTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Read() *string
SetRead(val *string)
ReadInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetRead()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbListenerTimeoutsOutputReference ¶
func NewDataAwsLbListenerTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsLbListenerTimeoutsOutputReference
Source Files
¶
- DataAwsLbListener.go
- DataAwsLbListenerConfig.go
- DataAwsLbListenerDefaultAction.go
- DataAwsLbListenerDefaultActionAuthenticateCognito.go
- DataAwsLbListenerDefaultActionAuthenticateCognitoList.go
- DataAwsLbListenerDefaultActionAuthenticateCognitoList__checks.go
- DataAwsLbListenerDefaultActionAuthenticateCognitoOutputReference.go
- DataAwsLbListenerDefaultActionAuthenticateCognitoOutputReference__checks.go
- DataAwsLbListenerDefaultActionAuthenticateOidc.go
- DataAwsLbListenerDefaultActionAuthenticateOidcList.go
- DataAwsLbListenerDefaultActionAuthenticateOidcList__checks.go
- DataAwsLbListenerDefaultActionAuthenticateOidcOutputReference.go
- DataAwsLbListenerDefaultActionAuthenticateOidcOutputReference__checks.go
- DataAwsLbListenerDefaultActionFixedResponse.go
- DataAwsLbListenerDefaultActionFixedResponseList.go
- DataAwsLbListenerDefaultActionFixedResponseList__checks.go
- DataAwsLbListenerDefaultActionFixedResponseOutputReference.go
- DataAwsLbListenerDefaultActionFixedResponseOutputReference__checks.go
- DataAwsLbListenerDefaultActionForward.go
- DataAwsLbListenerDefaultActionForwardList.go
- DataAwsLbListenerDefaultActionForwardList__checks.go
- DataAwsLbListenerDefaultActionForwardOutputReference.go
- DataAwsLbListenerDefaultActionForwardOutputReference__checks.go
- DataAwsLbListenerDefaultActionForwardStickiness.go
- DataAwsLbListenerDefaultActionForwardStickinessList.go
- DataAwsLbListenerDefaultActionForwardStickinessList__checks.go
- DataAwsLbListenerDefaultActionForwardStickinessOutputReference.go
- DataAwsLbListenerDefaultActionForwardStickinessOutputReference__checks.go
- DataAwsLbListenerDefaultActionForwardTargetGroup.go
- DataAwsLbListenerDefaultActionForwardTargetGroupList.go
- DataAwsLbListenerDefaultActionForwardTargetGroupList__checks.go
- DataAwsLbListenerDefaultActionForwardTargetGroupOutputReference.go
- DataAwsLbListenerDefaultActionForwardTargetGroupOutputReference__checks.go
- DataAwsLbListenerDefaultActionList.go
- DataAwsLbListenerDefaultActionList__checks.go
- DataAwsLbListenerDefaultActionOutputReference.go
- DataAwsLbListenerDefaultActionOutputReference__checks.go
- DataAwsLbListenerDefaultActionRedirect.go
- DataAwsLbListenerDefaultActionRedirectList.go
- DataAwsLbListenerDefaultActionRedirectList__checks.go
- DataAwsLbListenerDefaultActionRedirectOutputReference.go
- DataAwsLbListenerDefaultActionRedirectOutputReference__checks.go
- DataAwsLbListenerTimeouts.go
- DataAwsLbListenerTimeoutsOutputReference.go
- DataAwsLbListenerTimeoutsOutputReference__checks.go
- DataAwsLbListener__checks.go
- main.go