Documentation
¶
Index ¶
- func DataAwsLbTargetGroup_IsConstruct(x interface{}) *bool
- func DataAwsLbTargetGroup_IsTerraformDataSource(x interface{}) *bool
- func DataAwsLbTargetGroup_IsTerraformElement(x interface{}) *bool
- func DataAwsLbTargetGroup_TfResourceType() *string
- func NewDataAwsLbTargetGroupHealthCheckList_Override(d DataAwsLbTargetGroupHealthCheckList, ...)
- func NewDataAwsLbTargetGroupHealthCheckOutputReference_Override(d DataAwsLbTargetGroupHealthCheckOutputReference, ...)
- func NewDataAwsLbTargetGroupStickinessList_Override(d DataAwsLbTargetGroupStickinessList, ...)
- func NewDataAwsLbTargetGroupStickinessOutputReference_Override(d DataAwsLbTargetGroupStickinessOutputReference, ...)
- func NewDataAwsLbTargetGroupTimeoutsOutputReference_Override(d DataAwsLbTargetGroupTimeoutsOutputReference, ...)
- func NewDataAwsLbTargetGroup_Override(d DataAwsLbTargetGroup, scope constructs.Construct, id *string, ...)
- type DataAwsLbTargetGroup
- type DataAwsLbTargetGroupConfig
- type DataAwsLbTargetGroupHealthCheck
- type DataAwsLbTargetGroupHealthCheckList
- type DataAwsLbTargetGroupHealthCheckOutputReference
- type DataAwsLbTargetGroupStickiness
- type DataAwsLbTargetGroupStickinessList
- type DataAwsLbTargetGroupStickinessOutputReference
- type DataAwsLbTargetGroupTimeouts
- type DataAwsLbTargetGroupTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsLbTargetGroup_IsConstruct ¶
func DataAwsLbTargetGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsLbTargetGroup_IsTerraformDataSource ¶
func DataAwsLbTargetGroup_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsLbTargetGroup_IsTerraformElement ¶
func DataAwsLbTargetGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsLbTargetGroup_TfResourceType ¶
func DataAwsLbTargetGroup_TfResourceType() *string
func NewDataAwsLbTargetGroupHealthCheckList_Override ¶
func NewDataAwsLbTargetGroupHealthCheckList_Override(d DataAwsLbTargetGroupHealthCheckList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLbTargetGroupHealthCheckOutputReference_Override ¶
func NewDataAwsLbTargetGroupHealthCheckOutputReference_Override(d DataAwsLbTargetGroupHealthCheckOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLbTargetGroupStickinessList_Override ¶
func NewDataAwsLbTargetGroupStickinessList_Override(d DataAwsLbTargetGroupStickinessList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLbTargetGroupStickinessOutputReference_Override ¶
func NewDataAwsLbTargetGroupStickinessOutputReference_Override(d DataAwsLbTargetGroupStickinessOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLbTargetGroupTimeoutsOutputReference_Override ¶
func NewDataAwsLbTargetGroupTimeoutsOutputReference_Override(d DataAwsLbTargetGroupTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsLbTargetGroup_Override ¶
func NewDataAwsLbTargetGroup_Override(d DataAwsLbTargetGroup, scope constructs.Construct, id *string, config *DataAwsLbTargetGroupConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/lb_target_group aws_lb_target_group} Data Source.
Types ¶
type DataAwsLbTargetGroup ¶
type DataAwsLbTargetGroup interface {
cdktf.TerraformDataSource
Arn() *string
SetArn(val *string)
ArnInput() *string
ArnSuffix() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ConnectionTermination() cdktf.IResolvable
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeregistrationDelay() *float64
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HealthCheck() DataAwsLbTargetGroupHealthCheckList
Id() *string
SetId(val *string)
IdInput() *string
LambdaMultiValueHeadersEnabled() cdktf.IResolvable
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LoadBalancingAlgorithmType() *string
LoadBalancingCrossZoneEnabled() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Port() *float64
PreserveClientIp() *string
Protocol() *string
ProtocolVersion() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
ProxyProtocolV2() cdktf.IResolvable
// Experimental.
RawOverrides() interface{}
SlowStart() *float64
Stickiness() DataAwsLbTargetGroupStickinessList
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
TargetType() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DataAwsLbTargetGroupTimeoutsOutputReference
TimeoutsInput() interface{}
VpcId() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *DataAwsLbTargetGroupTimeouts)
ResetArn()
ResetId()
ResetName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/lb_target_group aws_lb_target_group}.
func NewDataAwsLbTargetGroup ¶
func NewDataAwsLbTargetGroup(scope constructs.Construct, id *string, config *DataAwsLbTargetGroupConfig) DataAwsLbTargetGroup
Create a new {@link https://www.terraform.io/docs/providers/aws/d/lb_target_group aws_lb_target_group} Data Source.
type DataAwsLbTargetGroupConfig ¶
type DataAwsLbTargetGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb_target_group#arn DataAwsLbTargetGroup#arn}.
Arn *string `field:"optional" json:"arn" yaml:"arn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb_target_group#id DataAwsLbTargetGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb_target_group#name DataAwsLbTargetGroup#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb_target_group#tags DataAwsLbTargetGroup#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb_target_group#timeouts DataAwsLbTargetGroup#timeouts}
Timeouts *DataAwsLbTargetGroupTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type DataAwsLbTargetGroupHealthCheck ¶
type DataAwsLbTargetGroupHealthCheck struct {
}
type DataAwsLbTargetGroupHealthCheckList ¶
type DataAwsLbTargetGroupHealthCheckList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLbTargetGroupHealthCheckOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbTargetGroupHealthCheckList ¶
func NewDataAwsLbTargetGroupHealthCheckList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLbTargetGroupHealthCheckList
type DataAwsLbTargetGroupHealthCheckOutputReference ¶
type DataAwsLbTargetGroupHealthCheckOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() cdktf.IResolvable
// Experimental.
Fqn() *string
HealthyThreshold() *float64
InternalValue() *DataAwsLbTargetGroupHealthCheck
SetInternalValue(val *DataAwsLbTargetGroupHealthCheck)
Interval() *float64
Matcher() *string
Path() *string
Port() *string
Protocol() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Timeout() *float64
UnhealthyThreshold() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbTargetGroupHealthCheckOutputReference ¶
func NewDataAwsLbTargetGroupHealthCheckOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLbTargetGroupHealthCheckOutputReference
type DataAwsLbTargetGroupStickiness ¶
type DataAwsLbTargetGroupStickiness struct {
}
type DataAwsLbTargetGroupStickinessList ¶
type DataAwsLbTargetGroupStickinessList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLbTargetGroupStickinessOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbTargetGroupStickinessList ¶
func NewDataAwsLbTargetGroupStickinessList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLbTargetGroupStickinessList
type DataAwsLbTargetGroupStickinessOutputReference ¶
type DataAwsLbTargetGroupStickinessOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CookieDuration() *float64
CookieName() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() cdktf.IResolvable
// Experimental.
Fqn() *string
InternalValue() *DataAwsLbTargetGroupStickiness
SetInternalValue(val *DataAwsLbTargetGroupStickiness)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbTargetGroupStickinessOutputReference ¶
func NewDataAwsLbTargetGroupStickinessOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLbTargetGroupStickinessOutputReference
type DataAwsLbTargetGroupTimeouts ¶
type DataAwsLbTargetGroupTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb_target_group#read DataAwsLbTargetGroup#read}.
Read *string `field:"optional" json:"read" yaml:"read"`
}
type DataAwsLbTargetGroupTimeoutsOutputReference ¶
type DataAwsLbTargetGroupTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Read() *string
SetRead(val *string)
ReadInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetRead()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLbTargetGroupTimeoutsOutputReference ¶
func NewDataAwsLbTargetGroupTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsLbTargetGroupTimeoutsOutputReference
Source Files
¶
- DataAwsLbTargetGroup.go
- DataAwsLbTargetGroupConfig.go
- DataAwsLbTargetGroupHealthCheck.go
- DataAwsLbTargetGroupHealthCheckList.go
- DataAwsLbTargetGroupHealthCheckList__checks.go
- DataAwsLbTargetGroupHealthCheckOutputReference.go
- DataAwsLbTargetGroupHealthCheckOutputReference__checks.go
- DataAwsLbTargetGroupStickiness.go
- DataAwsLbTargetGroupStickinessList.go
- DataAwsLbTargetGroupStickinessList__checks.go
- DataAwsLbTargetGroupStickinessOutputReference.go
- DataAwsLbTargetGroupStickinessOutputReference__checks.go
- DataAwsLbTargetGroupTimeouts.go
- DataAwsLbTargetGroupTimeoutsOutputReference.go
- DataAwsLbTargetGroupTimeoutsOutputReference__checks.go
- DataAwsLbTargetGroup__checks.go
- main.go