Documentation
¶
Index ¶
- func DataAwsMqBroker_IsConstruct(x interface{}) *bool
- func DataAwsMqBroker_IsTerraformDataSource(x interface{}) *bool
- func DataAwsMqBroker_IsTerraformElement(x interface{}) *bool
- func DataAwsMqBroker_TfResourceType() *string
- func NewDataAwsMqBrokerConfigurationList_Override(d DataAwsMqBrokerConfigurationList, ...)
- func NewDataAwsMqBrokerConfigurationOutputReference_Override(d DataAwsMqBrokerConfigurationOutputReference, ...)
- func NewDataAwsMqBrokerEncryptionOptionsList_Override(d DataAwsMqBrokerEncryptionOptionsList, ...)
- func NewDataAwsMqBrokerEncryptionOptionsOutputReference_Override(d DataAwsMqBrokerEncryptionOptionsOutputReference, ...)
- func NewDataAwsMqBrokerInstancesList_Override(d DataAwsMqBrokerInstancesList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewDataAwsMqBrokerInstancesOutputReference_Override(d DataAwsMqBrokerInstancesOutputReference, ...)
- func NewDataAwsMqBrokerLdapServerMetadataList_Override(d DataAwsMqBrokerLdapServerMetadataList, ...)
- func NewDataAwsMqBrokerLdapServerMetadataOutputReference_Override(d DataAwsMqBrokerLdapServerMetadataOutputReference, ...)
- func NewDataAwsMqBrokerLogsList_Override(d DataAwsMqBrokerLogsList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewDataAwsMqBrokerLogsOutputReference_Override(d DataAwsMqBrokerLogsOutputReference, ...)
- func NewDataAwsMqBrokerMaintenanceWindowStartTimeList_Override(d DataAwsMqBrokerMaintenanceWindowStartTimeList, ...)
- func NewDataAwsMqBrokerMaintenanceWindowStartTimeOutputReference_Override(d DataAwsMqBrokerMaintenanceWindowStartTimeOutputReference, ...)
- func NewDataAwsMqBrokerUserList_Override(d DataAwsMqBrokerUserList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewDataAwsMqBrokerUserOutputReference_Override(d DataAwsMqBrokerUserOutputReference, ...)
- func NewDataAwsMqBroker_Override(d DataAwsMqBroker, scope constructs.Construct, id *string, ...)
- type DataAwsMqBroker
- type DataAwsMqBrokerConfig
- type DataAwsMqBrokerConfiguration
- type DataAwsMqBrokerConfigurationList
- type DataAwsMqBrokerConfigurationOutputReference
- type DataAwsMqBrokerEncryptionOptions
- type DataAwsMqBrokerEncryptionOptionsList
- type DataAwsMqBrokerEncryptionOptionsOutputReference
- type DataAwsMqBrokerInstances
- type DataAwsMqBrokerInstancesList
- type DataAwsMqBrokerInstancesOutputReference
- type DataAwsMqBrokerLdapServerMetadata
- type DataAwsMqBrokerLdapServerMetadataList
- type DataAwsMqBrokerLdapServerMetadataOutputReference
- type DataAwsMqBrokerLogs
- type DataAwsMqBrokerLogsList
- type DataAwsMqBrokerLogsOutputReference
- type DataAwsMqBrokerMaintenanceWindowStartTime
- type DataAwsMqBrokerMaintenanceWindowStartTimeList
- type DataAwsMqBrokerMaintenanceWindowStartTimeOutputReference
- type DataAwsMqBrokerUser
- type DataAwsMqBrokerUserList
- type DataAwsMqBrokerUserOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsMqBroker_IsConstruct ¶
func DataAwsMqBroker_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsMqBroker_IsTerraformDataSource ¶
func DataAwsMqBroker_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsMqBroker_IsTerraformElement ¶
func DataAwsMqBroker_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsMqBroker_TfResourceType ¶
func DataAwsMqBroker_TfResourceType() *string
func NewDataAwsMqBrokerConfigurationList_Override ¶
func NewDataAwsMqBrokerConfigurationList_Override(d DataAwsMqBrokerConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsMqBrokerConfigurationOutputReference_Override ¶
func NewDataAwsMqBrokerConfigurationOutputReference_Override(d DataAwsMqBrokerConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsMqBrokerEncryptionOptionsList_Override ¶
func NewDataAwsMqBrokerEncryptionOptionsList_Override(d DataAwsMqBrokerEncryptionOptionsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsMqBrokerEncryptionOptionsOutputReference_Override ¶
func NewDataAwsMqBrokerEncryptionOptionsOutputReference_Override(d DataAwsMqBrokerEncryptionOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsMqBrokerInstancesList_Override ¶
func NewDataAwsMqBrokerInstancesList_Override(d DataAwsMqBrokerInstancesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsMqBrokerInstancesOutputReference_Override ¶
func NewDataAwsMqBrokerInstancesOutputReference_Override(d DataAwsMqBrokerInstancesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsMqBrokerLdapServerMetadataList_Override ¶
func NewDataAwsMqBrokerLdapServerMetadataList_Override(d DataAwsMqBrokerLdapServerMetadataList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsMqBrokerLdapServerMetadataOutputReference_Override ¶
func NewDataAwsMqBrokerLdapServerMetadataOutputReference_Override(d DataAwsMqBrokerLdapServerMetadataOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsMqBrokerLogsList_Override ¶
func NewDataAwsMqBrokerLogsList_Override(d DataAwsMqBrokerLogsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsMqBrokerLogsOutputReference_Override ¶
func NewDataAwsMqBrokerLogsOutputReference_Override(d DataAwsMqBrokerLogsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsMqBrokerMaintenanceWindowStartTimeList_Override ¶
func NewDataAwsMqBrokerMaintenanceWindowStartTimeList_Override(d DataAwsMqBrokerMaintenanceWindowStartTimeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsMqBrokerMaintenanceWindowStartTimeOutputReference_Override ¶
func NewDataAwsMqBrokerMaintenanceWindowStartTimeOutputReference_Override(d DataAwsMqBrokerMaintenanceWindowStartTimeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsMqBrokerUserList_Override ¶
func NewDataAwsMqBrokerUserList_Override(d DataAwsMqBrokerUserList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsMqBrokerUserOutputReference_Override ¶
func NewDataAwsMqBrokerUserOutputReference_Override(d DataAwsMqBrokerUserOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsMqBroker_Override ¶
func NewDataAwsMqBroker_Override(d DataAwsMqBroker, scope constructs.Construct, id *string, config *DataAwsMqBrokerConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/mq_broker aws_mq_broker} Data Source.
Types ¶
type DataAwsMqBroker ¶
type DataAwsMqBroker interface {
cdktf.TerraformDataSource
Arn() *string
AuthenticationStrategy() *string
AutoMinorVersionUpgrade() cdktf.IResolvable
BrokerId() *string
SetBrokerId(val *string)
BrokerIdInput() *string
BrokerName() *string
SetBrokerName(val *string)
BrokerNameInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
Configuration() DataAwsMqBrokerConfigurationList
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeploymentMode() *string
EncryptionOptions() DataAwsMqBrokerEncryptionOptionsList
EngineType() *string
EngineVersion() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HostInstanceType() *string
Id() *string
SetId(val *string)
IdInput() *string
Instances() DataAwsMqBrokerInstancesList
LdapServerMetadata() DataAwsMqBrokerLdapServerMetadataList
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Logs() DataAwsMqBrokerLogsList
MaintenanceWindowStartTime() DataAwsMqBrokerMaintenanceWindowStartTimeList
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
PubliclyAccessible() cdktf.IResolvable
// Experimental.
RawOverrides() interface{}
SecurityGroups() *[]*string
StorageType() *string
SubnetIds() *[]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
User() DataAwsMqBrokerUserList
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetBrokerId()
ResetBrokerName()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/mq_broker aws_mq_broker}.
func NewDataAwsMqBroker ¶
func NewDataAwsMqBroker(scope constructs.Construct, id *string, config *DataAwsMqBrokerConfig) DataAwsMqBroker
Create a new {@link https://www.terraform.io/docs/providers/aws/d/mq_broker aws_mq_broker} Data Source.
type DataAwsMqBrokerConfig ¶
type DataAwsMqBrokerConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/mq_broker#broker_id DataAwsMqBroker#broker_id}.
BrokerId *string `field:"optional" json:"brokerId" yaml:"brokerId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/mq_broker#broker_name DataAwsMqBroker#broker_name}.
BrokerName *string `field:"optional" json:"brokerName" yaml:"brokerName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/mq_broker#id DataAwsMqBroker#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/mq_broker#tags DataAwsMqBroker#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsMqBrokerConfiguration ¶
type DataAwsMqBrokerConfiguration struct {
}
type DataAwsMqBrokerConfigurationList ¶
type DataAwsMqBrokerConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsMqBrokerConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMqBrokerConfigurationList ¶
func NewDataAwsMqBrokerConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsMqBrokerConfigurationList
type DataAwsMqBrokerConfigurationOutputReference ¶
type DataAwsMqBrokerConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *DataAwsMqBrokerConfiguration
SetInternalValue(val *DataAwsMqBrokerConfiguration)
Revision() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMqBrokerConfigurationOutputReference ¶
func NewDataAwsMqBrokerConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsMqBrokerConfigurationOutputReference
type DataAwsMqBrokerEncryptionOptions ¶
type DataAwsMqBrokerEncryptionOptions struct {
}
type DataAwsMqBrokerEncryptionOptionsList ¶
type DataAwsMqBrokerEncryptionOptionsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsMqBrokerEncryptionOptionsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMqBrokerEncryptionOptionsList ¶
func NewDataAwsMqBrokerEncryptionOptionsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsMqBrokerEncryptionOptionsList
type DataAwsMqBrokerEncryptionOptionsOutputReference ¶
type DataAwsMqBrokerEncryptionOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsMqBrokerEncryptionOptions
SetInternalValue(val *DataAwsMqBrokerEncryptionOptions)
KmsKeyId() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UseAwsOwnedKey() cdktf.IResolvable
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMqBrokerEncryptionOptionsOutputReference ¶
func NewDataAwsMqBrokerEncryptionOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsMqBrokerEncryptionOptionsOutputReference
type DataAwsMqBrokerInstances ¶
type DataAwsMqBrokerInstances struct {
}
type DataAwsMqBrokerInstancesList ¶
type DataAwsMqBrokerInstancesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsMqBrokerInstancesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMqBrokerInstancesList ¶
func NewDataAwsMqBrokerInstancesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsMqBrokerInstancesList
type DataAwsMqBrokerInstancesOutputReference ¶
type DataAwsMqBrokerInstancesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ConsoleUrl() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Endpoints() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsMqBrokerInstances
SetInternalValue(val *DataAwsMqBrokerInstances)
IpAddress() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMqBrokerInstancesOutputReference ¶
func NewDataAwsMqBrokerInstancesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsMqBrokerInstancesOutputReference
type DataAwsMqBrokerLdapServerMetadata ¶
type DataAwsMqBrokerLdapServerMetadata struct {
}
type DataAwsMqBrokerLdapServerMetadataList ¶
type DataAwsMqBrokerLdapServerMetadataList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsMqBrokerLdapServerMetadataOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMqBrokerLdapServerMetadataList ¶
func NewDataAwsMqBrokerLdapServerMetadataList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsMqBrokerLdapServerMetadataList
type DataAwsMqBrokerLdapServerMetadataOutputReference ¶
type DataAwsMqBrokerLdapServerMetadataOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Hosts() *[]*string
InternalValue() *DataAwsMqBrokerLdapServerMetadata
SetInternalValue(val *DataAwsMqBrokerLdapServerMetadata)
RoleBase() *string
RoleName() *string
RoleSearchMatching() *string
RoleSearchSubtree() cdktf.IResolvable
ServiceAccountPassword() *string
ServiceAccountUsername() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UserBase() *string
UserRoleName() *string
UserSearchMatching() *string
UserSearchSubtree() cdktf.IResolvable
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMqBrokerLdapServerMetadataOutputReference ¶
func NewDataAwsMqBrokerLdapServerMetadataOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsMqBrokerLdapServerMetadataOutputReference
type DataAwsMqBrokerLogs ¶
type DataAwsMqBrokerLogs struct {
}
type DataAwsMqBrokerLogsList ¶
type DataAwsMqBrokerLogsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsMqBrokerLogsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMqBrokerLogsList ¶
func NewDataAwsMqBrokerLogsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsMqBrokerLogsList
type DataAwsMqBrokerLogsOutputReference ¶
type DataAwsMqBrokerLogsOutputReference interface {
cdktf.ComplexObject
Audit() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
General() cdktf.IResolvable
InternalValue() *DataAwsMqBrokerLogs
SetInternalValue(val *DataAwsMqBrokerLogs)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMqBrokerLogsOutputReference ¶
func NewDataAwsMqBrokerLogsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsMqBrokerLogsOutputReference
type DataAwsMqBrokerMaintenanceWindowStartTime ¶
type DataAwsMqBrokerMaintenanceWindowStartTime struct {
}
type DataAwsMqBrokerMaintenanceWindowStartTimeList ¶
type DataAwsMqBrokerMaintenanceWindowStartTimeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsMqBrokerMaintenanceWindowStartTimeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMqBrokerMaintenanceWindowStartTimeList ¶
func NewDataAwsMqBrokerMaintenanceWindowStartTimeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsMqBrokerMaintenanceWindowStartTimeList
type DataAwsMqBrokerMaintenanceWindowStartTimeOutputReference ¶
type DataAwsMqBrokerMaintenanceWindowStartTimeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DayOfWeek() *string
// Experimental.
Fqn() *string
InternalValue() *DataAwsMqBrokerMaintenanceWindowStartTime
SetInternalValue(val *DataAwsMqBrokerMaintenanceWindowStartTime)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TimeOfDay() *string
TimeZone() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMqBrokerMaintenanceWindowStartTimeOutputReference ¶
func NewDataAwsMqBrokerMaintenanceWindowStartTimeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsMqBrokerMaintenanceWindowStartTimeOutputReference
type DataAwsMqBrokerUser ¶
type DataAwsMqBrokerUser struct {
}
type DataAwsMqBrokerUserList ¶
type DataAwsMqBrokerUserList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsMqBrokerUserOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMqBrokerUserList ¶
func NewDataAwsMqBrokerUserList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsMqBrokerUserList
type DataAwsMqBrokerUserOutputReference ¶
type DataAwsMqBrokerUserOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ConsoleAccess() cdktf.IResolvable
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Groups() *[]*string
InternalValue() *DataAwsMqBrokerUser
SetInternalValue(val *DataAwsMqBrokerUser)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Username() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMqBrokerUserOutputReference ¶
func NewDataAwsMqBrokerUserOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsMqBrokerUserOutputReference
Source Files
¶
- DataAwsMqBroker.go
- DataAwsMqBrokerConfig.go
- DataAwsMqBrokerConfiguration.go
- DataAwsMqBrokerConfigurationList.go
- DataAwsMqBrokerConfigurationList__checks.go
- DataAwsMqBrokerConfigurationOutputReference.go
- DataAwsMqBrokerConfigurationOutputReference__checks.go
- DataAwsMqBrokerEncryptionOptions.go
- DataAwsMqBrokerEncryptionOptionsList.go
- DataAwsMqBrokerEncryptionOptionsList__checks.go
- DataAwsMqBrokerEncryptionOptionsOutputReference.go
- DataAwsMqBrokerEncryptionOptionsOutputReference__checks.go
- DataAwsMqBrokerInstances.go
- DataAwsMqBrokerInstancesList.go
- DataAwsMqBrokerInstancesList__checks.go
- DataAwsMqBrokerInstancesOutputReference.go
- DataAwsMqBrokerInstancesOutputReference__checks.go
- DataAwsMqBrokerLdapServerMetadata.go
- DataAwsMqBrokerLdapServerMetadataList.go
- DataAwsMqBrokerLdapServerMetadataList__checks.go
- DataAwsMqBrokerLdapServerMetadataOutputReference.go
- DataAwsMqBrokerLdapServerMetadataOutputReference__checks.go
- DataAwsMqBrokerLogs.go
- DataAwsMqBrokerLogsList.go
- DataAwsMqBrokerLogsList__checks.go
- DataAwsMqBrokerLogsOutputReference.go
- DataAwsMqBrokerLogsOutputReference__checks.go
- DataAwsMqBrokerMaintenanceWindowStartTime.go
- DataAwsMqBrokerMaintenanceWindowStartTimeList.go
- DataAwsMqBrokerMaintenanceWindowStartTimeList__checks.go
- DataAwsMqBrokerMaintenanceWindowStartTimeOutputReference.go
- DataAwsMqBrokerMaintenanceWindowStartTimeOutputReference__checks.go
- DataAwsMqBrokerUser.go
- DataAwsMqBrokerUserList.go
- DataAwsMqBrokerUserList__checks.go
- DataAwsMqBrokerUserOutputReference.go
- DataAwsMqBrokerUserOutputReference__checks.go
- DataAwsMqBroker__checks.go
- main.go