Documentation
¶
Index ¶
- func DataAwsRdsCluster_IsConstruct(x interface{}) *bool
- func DataAwsRdsCluster_IsTerraformDataSource(x interface{}) *bool
- func DataAwsRdsCluster_IsTerraformElement(x interface{}) *bool
- func DataAwsRdsCluster_TfResourceType() *string
- func NewDataAwsRdsClusterMasterUserSecretList_Override(d DataAwsRdsClusterMasterUserSecretList, ...)
- func NewDataAwsRdsClusterMasterUserSecretOutputReference_Override(d DataAwsRdsClusterMasterUserSecretOutputReference, ...)
- func NewDataAwsRdsCluster_Override(d DataAwsRdsCluster, scope constructs.Construct, id *string, ...)
- type DataAwsRdsCluster
- type DataAwsRdsClusterConfig
- type DataAwsRdsClusterMasterUserSecret
- type DataAwsRdsClusterMasterUserSecretList
- type DataAwsRdsClusterMasterUserSecretOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsRdsCluster_IsConstruct ¶
func DataAwsRdsCluster_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsRdsCluster_IsTerraformDataSource ¶
func DataAwsRdsCluster_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsRdsCluster_IsTerraformElement ¶
func DataAwsRdsCluster_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsRdsCluster_TfResourceType ¶
func DataAwsRdsCluster_TfResourceType() *string
func NewDataAwsRdsClusterMasterUserSecretList_Override ¶ added in v12.0.12
func NewDataAwsRdsClusterMasterUserSecretList_Override(d DataAwsRdsClusterMasterUserSecretList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsRdsClusterMasterUserSecretOutputReference_Override ¶ added in v12.0.12
func NewDataAwsRdsClusterMasterUserSecretOutputReference_Override(d DataAwsRdsClusterMasterUserSecretOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsRdsCluster_Override ¶
func NewDataAwsRdsCluster_Override(d DataAwsRdsCluster, scope constructs.Construct, id *string, config *DataAwsRdsClusterConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/rds_cluster aws_rds_cluster} Data Source.
Types ¶
type DataAwsRdsCluster ¶
type DataAwsRdsCluster interface {
cdktf.TerraformDataSource
Arn() *string
AvailabilityZones() *[]*string
BacktrackWindow() *float64
BackupRetentionPeriod() *float64
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterIdentifier() *string
SetClusterIdentifier(val *string)
ClusterIdentifierInput() *string
ClusterMembers() *[]*string
ClusterResourceId() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DatabaseName() *string
DbClusterParameterGroupName() *string
DbSubnetGroupName() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EnabledCloudwatchLogsExports() *[]*string
Endpoint() *string
Engine() *string
EngineMode() *string
EngineVersion() *string
FinalSnapshotIdentifier() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HostedZoneId() *string
IamDatabaseAuthenticationEnabled() cdktf.IResolvable
IamRoles() *[]*string
Id() *string
SetId(val *string)
IdInput() *string
KmsKeyId() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MasterUsername() *string
MasterUserSecret() DataAwsRdsClusterMasterUserSecretList
NetworkType() *string
// The tree node.
Node() constructs.Node
Port() *float64
PreferredBackupWindow() *string
PreferredMaintenanceWindow() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
ReaderEndpoint() *string
ReplicationSourceIdentifier() *string
StorageEncrypted() cdktf.IResolvable
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
VpcSecurityGroupIds() *[]*string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/rds_cluster aws_rds_cluster}.
func NewDataAwsRdsCluster ¶
func NewDataAwsRdsCluster(scope constructs.Construct, id *string, config *DataAwsRdsClusterConfig) DataAwsRdsCluster
Create a new {@link https://www.terraform.io/docs/providers/aws/d/rds_cluster aws_rds_cluster} Data Source.
type DataAwsRdsClusterConfig ¶
type DataAwsRdsClusterConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_cluster#cluster_identifier DataAwsRdsCluster#cluster_identifier}.
ClusterIdentifier *string `field:"required" json:"clusterIdentifier" yaml:"clusterIdentifier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_cluster#id DataAwsRdsCluster#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_cluster#tags DataAwsRdsCluster#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsRdsClusterMasterUserSecret ¶ added in v12.0.12
type DataAwsRdsClusterMasterUserSecret struct {
}
type DataAwsRdsClusterMasterUserSecretList ¶ added in v12.0.12
type DataAwsRdsClusterMasterUserSecretList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsRdsClusterMasterUserSecretOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsRdsClusterMasterUserSecretList ¶ added in v12.0.12
func NewDataAwsRdsClusterMasterUserSecretList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsRdsClusterMasterUserSecretList
type DataAwsRdsClusterMasterUserSecretOutputReference ¶ added in v12.0.12
type DataAwsRdsClusterMasterUserSecretOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsRdsClusterMasterUserSecret
SetInternalValue(val *DataAwsRdsClusterMasterUserSecret)
KmsKeyId() *string
SecretArn() *string
SecretStatus() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsRdsClusterMasterUserSecretOutputReference ¶ added in v12.0.12
func NewDataAwsRdsClusterMasterUserSecretOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsRdsClusterMasterUserSecretOutputReference
Source Files
¶
- DataAwsRdsCluster.go
- DataAwsRdsClusterConfig.go
- DataAwsRdsClusterMasterUserSecret.go
- DataAwsRdsClusterMasterUserSecretList.go
- DataAwsRdsClusterMasterUserSecretList__checks.go
- DataAwsRdsClusterMasterUserSecretOutputReference.go
- DataAwsRdsClusterMasterUserSecretOutputReference__checks.go
- DataAwsRdsCluster__checks.go
- main.go