Documentation
¶
Index ¶
- func DataAwsRedshiftCluster_IsConstruct(x interface{}) *bool
- func DataAwsRedshiftCluster_IsTerraformDataSource(x interface{}) *bool
- func DataAwsRedshiftCluster_IsTerraformElement(x interface{}) *bool
- func DataAwsRedshiftCluster_TfResourceType() *string
- func NewDataAwsRedshiftClusterClusterNodesList_Override(d DataAwsRedshiftClusterClusterNodesList, ...)
- func NewDataAwsRedshiftClusterClusterNodesOutputReference_Override(d DataAwsRedshiftClusterClusterNodesOutputReference, ...)
- func NewDataAwsRedshiftCluster_Override(d DataAwsRedshiftCluster, scope constructs.Construct, id *string, ...)
- type DataAwsRedshiftCluster
- type DataAwsRedshiftClusterClusterNodes
- type DataAwsRedshiftClusterClusterNodesList
- type DataAwsRedshiftClusterClusterNodesOutputReference
- type DataAwsRedshiftClusterConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsRedshiftCluster_IsConstruct ¶
func DataAwsRedshiftCluster_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsRedshiftCluster_IsTerraformDataSource ¶
func DataAwsRedshiftCluster_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsRedshiftCluster_IsTerraformElement ¶
func DataAwsRedshiftCluster_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsRedshiftCluster_TfResourceType ¶
func DataAwsRedshiftCluster_TfResourceType() *string
func NewDataAwsRedshiftClusterClusterNodesList_Override ¶
func NewDataAwsRedshiftClusterClusterNodesList_Override(d DataAwsRedshiftClusterClusterNodesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsRedshiftClusterClusterNodesOutputReference_Override ¶
func NewDataAwsRedshiftClusterClusterNodesOutputReference_Override(d DataAwsRedshiftClusterClusterNodesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsRedshiftCluster_Override ¶
func NewDataAwsRedshiftCluster_Override(d DataAwsRedshiftCluster, scope constructs.Construct, id *string, config *DataAwsRedshiftClusterConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/redshift_cluster aws_redshift_cluster} Data Source.
Types ¶
type DataAwsRedshiftCluster ¶
type DataAwsRedshiftCluster interface {
cdktf.TerraformDataSource
AllowVersionUpgrade() cdktf.IResolvable
AquaConfigurationStatus() *string
Arn() *string
AutomatedSnapshotRetentionPeriod() *float64
AvailabilityZone() *string
AvailabilityZoneRelocationEnabled() cdktf.IResolvable
BucketName() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterIdentifier() *string
SetClusterIdentifier(val *string)
ClusterIdentifierInput() *string
ClusterNodes() DataAwsRedshiftClusterClusterNodesList
ClusterParameterGroupName() *string
ClusterPublicKey() *string
ClusterRevisionNumber() *string
ClusterSecurityGroups() *[]*string
ClusterSubnetGroupName() *string
ClusterType() *string
ClusterVersion() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DatabaseName() *string
DefaultIamRoleArn() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
ElasticIp() *string
EnableLogging() cdktf.IResolvable
Encrypted() cdktf.IResolvable
Endpoint() *string
EnhancedVpcRouting() cdktf.IResolvable
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
IamRoles() *[]*string
Id() *string
SetId(val *string)
IdInput() *string
KmsKeyId() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LogDestinationType() *string
LogExports() *[]*string
MaintenanceTrackName() *string
ManualSnapshotRetentionPeriod() *float64
MasterUsername() *string
// The tree node.
Node() constructs.Node
NodeType() *string
NumberOfNodes() *float64
Port() *float64
PreferredMaintenanceWindow() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
PubliclyAccessible() cdktf.IResolvable
// Experimental.
RawOverrides() interface{}
S3KeyPrefix() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
VpcId() *string
VpcSecurityGroupIds() *[]*string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/redshift_cluster aws_redshift_cluster}.
func NewDataAwsRedshiftCluster ¶
func NewDataAwsRedshiftCluster(scope constructs.Construct, id *string, config *DataAwsRedshiftClusterConfig) DataAwsRedshiftCluster
Create a new {@link https://www.terraform.io/docs/providers/aws/d/redshift_cluster aws_redshift_cluster} Data Source.
type DataAwsRedshiftClusterClusterNodes ¶
type DataAwsRedshiftClusterClusterNodes struct {
}
type DataAwsRedshiftClusterClusterNodesList ¶
type DataAwsRedshiftClusterClusterNodesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsRedshiftClusterClusterNodesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsRedshiftClusterClusterNodesList ¶
func NewDataAwsRedshiftClusterClusterNodesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsRedshiftClusterClusterNodesList
type DataAwsRedshiftClusterClusterNodesOutputReference ¶
type DataAwsRedshiftClusterClusterNodesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsRedshiftClusterClusterNodes
SetInternalValue(val *DataAwsRedshiftClusterClusterNodes)
NodeRole() *string
PrivateIpAddress() *string
PublicIpAddress() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsRedshiftClusterClusterNodesOutputReference ¶
func NewDataAwsRedshiftClusterClusterNodesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsRedshiftClusterClusterNodesOutputReference
type DataAwsRedshiftClusterConfig ¶
type DataAwsRedshiftClusterConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/redshift_cluster#cluster_identifier DataAwsRedshiftCluster#cluster_identifier}.
ClusterIdentifier *string `field:"required" json:"clusterIdentifier" yaml:"clusterIdentifier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/redshift_cluster#id DataAwsRedshiftCluster#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/redshift_cluster#tags DataAwsRedshiftCluster#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
Source Files
¶
- DataAwsRedshiftCluster.go
- DataAwsRedshiftClusterClusterNodes.go
- DataAwsRedshiftClusterClusterNodesList.go
- DataAwsRedshiftClusterClusterNodesList__checks.go
- DataAwsRedshiftClusterClusterNodesOutputReference.go
- DataAwsRedshiftClusterClusterNodesOutputReference__checks.go
- DataAwsRedshiftClusterConfig.go
- DataAwsRedshiftCluster__checks.go
- main.go