Documentation
¶
Index ¶
- func DataAwsWafv2RegexPatternSet_IsConstruct(x interface{}) *bool
- func DataAwsWafv2RegexPatternSet_IsTerraformDataSource(x interface{}) *bool
- func DataAwsWafv2RegexPatternSet_IsTerraformElement(x interface{}) *bool
- func DataAwsWafv2RegexPatternSet_TfResourceType() *string
- func NewDataAwsWafv2RegexPatternSetRegularExpressionList_Override(d DataAwsWafv2RegexPatternSetRegularExpressionList, ...)
- func NewDataAwsWafv2RegexPatternSetRegularExpressionOutputReference_Override(d DataAwsWafv2RegexPatternSetRegularExpressionOutputReference, ...)
- func NewDataAwsWafv2RegexPatternSet_Override(d DataAwsWafv2RegexPatternSet, scope constructs.Construct, id *string, ...)
- type DataAwsWafv2RegexPatternSet
- type DataAwsWafv2RegexPatternSetConfig
- type DataAwsWafv2RegexPatternSetRegularExpression
- type DataAwsWafv2RegexPatternSetRegularExpressionList
- type DataAwsWafv2RegexPatternSetRegularExpressionOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsWafv2RegexPatternSet_IsConstruct ¶
func DataAwsWafv2RegexPatternSet_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsWafv2RegexPatternSet_IsTerraformDataSource ¶
func DataAwsWafv2RegexPatternSet_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsWafv2RegexPatternSet_IsTerraformElement ¶
func DataAwsWafv2RegexPatternSet_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsWafv2RegexPatternSet_TfResourceType ¶
func DataAwsWafv2RegexPatternSet_TfResourceType() *string
func NewDataAwsWafv2RegexPatternSetRegularExpressionList_Override ¶
func NewDataAwsWafv2RegexPatternSetRegularExpressionList_Override(d DataAwsWafv2RegexPatternSetRegularExpressionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsWafv2RegexPatternSetRegularExpressionOutputReference_Override ¶
func NewDataAwsWafv2RegexPatternSetRegularExpressionOutputReference_Override(d DataAwsWafv2RegexPatternSetRegularExpressionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsWafv2RegexPatternSet_Override ¶
func NewDataAwsWafv2RegexPatternSet_Override(d DataAwsWafv2RegexPatternSet, scope constructs.Construct, id *string, config *DataAwsWafv2RegexPatternSetConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/wafv2_regex_pattern_set aws_wafv2_regex_pattern_set} Data Source.
Types ¶
type DataAwsWafv2RegexPatternSet ¶
type DataAwsWafv2RegexPatternSet interface {
cdktf.TerraformDataSource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
RegularExpression() DataAwsWafv2RegexPatternSetRegularExpressionList
Scope() *string
SetScope(val *string)
ScopeInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/wafv2_regex_pattern_set aws_wafv2_regex_pattern_set}.
func NewDataAwsWafv2RegexPatternSet ¶
func NewDataAwsWafv2RegexPatternSet(scope constructs.Construct, id *string, config *DataAwsWafv2RegexPatternSetConfig) DataAwsWafv2RegexPatternSet
Create a new {@link https://www.terraform.io/docs/providers/aws/d/wafv2_regex_pattern_set aws_wafv2_regex_pattern_set} Data Source.
type DataAwsWafv2RegexPatternSetConfig ¶
type DataAwsWafv2RegexPatternSetConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/wafv2_regex_pattern_set#name DataAwsWafv2RegexPatternSet#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/wafv2_regex_pattern_set#scope DataAwsWafv2RegexPatternSet#scope}.
Scope *string `field:"required" json:"scope" yaml:"scope"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/wafv2_regex_pattern_set#id DataAwsWafv2RegexPatternSet#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type DataAwsWafv2RegexPatternSetRegularExpression ¶
type DataAwsWafv2RegexPatternSetRegularExpression struct {
}
type DataAwsWafv2RegexPatternSetRegularExpressionList ¶
type DataAwsWafv2RegexPatternSetRegularExpressionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsWafv2RegexPatternSetRegularExpressionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsWafv2RegexPatternSetRegularExpressionList ¶
func NewDataAwsWafv2RegexPatternSetRegularExpressionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsWafv2RegexPatternSetRegularExpressionList
type DataAwsWafv2RegexPatternSetRegularExpressionOutputReference ¶
type DataAwsWafv2RegexPatternSetRegularExpressionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsWafv2RegexPatternSetRegularExpression
SetInternalValue(val *DataAwsWafv2RegexPatternSetRegularExpression)
RegexString() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsWafv2RegexPatternSetRegularExpressionOutputReference ¶
func NewDataAwsWafv2RegexPatternSetRegularExpressionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsWafv2RegexPatternSetRegularExpressionOutputReference
Source Files
¶
- DataAwsWafv2RegexPatternSet.go
- DataAwsWafv2RegexPatternSetConfig.go
- DataAwsWafv2RegexPatternSetRegularExpression.go
- DataAwsWafv2RegexPatternSetRegularExpressionList.go
- DataAwsWafv2RegexPatternSetRegularExpressionList__checks.go
- DataAwsWafv2RegexPatternSetRegularExpressionOutputReference.go
- DataAwsWafv2RegexPatternSetRegularExpressionOutputReference__checks.go
- DataAwsWafv2RegexPatternSet__checks.go
- main.go