Documentation
¶
Index ¶
- func DatasyncLocationHdfs_IsConstruct(x interface{}) *bool
- func DatasyncLocationHdfs_IsTerraformElement(x interface{}) *bool
- func DatasyncLocationHdfs_IsTerraformResource(x interface{}) *bool
- func DatasyncLocationHdfs_TfResourceType() *string
- func NewDatasyncLocationHdfsNameNodeList_Override(d DatasyncLocationHdfsNameNodeList, ...)
- func NewDatasyncLocationHdfsNameNodeOutputReference_Override(d DatasyncLocationHdfsNameNodeOutputReference, ...)
- func NewDatasyncLocationHdfsQopConfigurationOutputReference_Override(d DatasyncLocationHdfsQopConfigurationOutputReference, ...)
- func NewDatasyncLocationHdfs_Override(d DatasyncLocationHdfs, scope constructs.Construct, id *string, ...)
- type DatasyncLocationHdfs
- type DatasyncLocationHdfsConfig
- type DatasyncLocationHdfsNameNode
- type DatasyncLocationHdfsNameNodeList
- type DatasyncLocationHdfsNameNodeOutputReference
- type DatasyncLocationHdfsQopConfiguration
- type DatasyncLocationHdfsQopConfigurationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DatasyncLocationHdfs_IsConstruct ¶
func DatasyncLocationHdfs_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DatasyncLocationHdfs_IsTerraformElement ¶
func DatasyncLocationHdfs_IsTerraformElement(x interface{}) *bool
Experimental.
func DatasyncLocationHdfs_IsTerraformResource ¶
func DatasyncLocationHdfs_IsTerraformResource(x interface{}) *bool
Experimental.
func DatasyncLocationHdfs_TfResourceType ¶
func DatasyncLocationHdfs_TfResourceType() *string
func NewDatasyncLocationHdfsNameNodeList_Override ¶
func NewDatasyncLocationHdfsNameNodeList_Override(d DatasyncLocationHdfsNameNodeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDatasyncLocationHdfsNameNodeOutputReference_Override ¶
func NewDatasyncLocationHdfsNameNodeOutputReference_Override(d DatasyncLocationHdfsNameNodeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDatasyncLocationHdfsQopConfigurationOutputReference_Override ¶
func NewDatasyncLocationHdfsQopConfigurationOutputReference_Override(d DatasyncLocationHdfsQopConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDatasyncLocationHdfs_Override ¶
func NewDatasyncLocationHdfs_Override(d DatasyncLocationHdfs, scope constructs.Construct, id *string, config *DatasyncLocationHdfsConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs aws_datasync_location_hdfs} Resource.
Types ¶
type DatasyncLocationHdfs ¶
type DatasyncLocationHdfs interface {
cdktf.TerraformResource
AgentArns() *[]*string
SetAgentArns(val *[]*string)
AgentArnsInput() *[]*string
Arn() *string
AuthenticationType() *string
SetAuthenticationType(val *string)
AuthenticationTypeInput() *string
BlockSize() *float64
SetBlockSize(val *float64)
BlockSizeInput() *float64
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
KerberosKeytab() *string
SetKerberosKeytab(val *string)
KerberosKeytabInput() *string
KerberosKrb5Conf() *string
SetKerberosKrb5Conf(val *string)
KerberosKrb5ConfInput() *string
KerberosPrincipal() *string
SetKerberosPrincipal(val *string)
KerberosPrincipalInput() *string
KmsKeyProviderUri() *string
SetKmsKeyProviderUri(val *string)
KmsKeyProviderUriInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
NameNode() DatasyncLocationHdfsNameNodeList
NameNodeInput() interface{}
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
QopConfiguration() DatasyncLocationHdfsQopConfigurationOutputReference
QopConfigurationInput() *DatasyncLocationHdfsQopConfiguration
// Experimental.
RawOverrides() interface{}
ReplicationFactor() *float64
SetReplicationFactor(val *float64)
ReplicationFactorInput() *float64
SimpleUser() *string
SetSimpleUser(val *string)
SimpleUserInput() *string
Subdirectory() *string
SetSubdirectory(val *string)
SubdirectoryInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Uri() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutNameNode(value interface{})
PutQopConfiguration(value *DatasyncLocationHdfsQopConfiguration)
ResetAuthenticationType()
ResetBlockSize()
ResetId()
ResetKerberosKeytab()
ResetKerberosKrb5Conf()
ResetKerberosPrincipal()
ResetKmsKeyProviderUri()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetQopConfiguration()
ResetReplicationFactor()
ResetSimpleUser()
ResetSubdirectory()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs aws_datasync_location_hdfs}.
func NewDatasyncLocationHdfs ¶
func NewDatasyncLocationHdfs(scope constructs.Construct, id *string, config *DatasyncLocationHdfsConfig) DatasyncLocationHdfs
Create a new {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs aws_datasync_location_hdfs} Resource.
type DatasyncLocationHdfsConfig ¶
type DatasyncLocationHdfsConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#agent_arns DatasyncLocationHdfs#agent_arns}.
AgentArns *[]*string `field:"required" json:"agentArns" yaml:"agentArns"`
// name_node block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#name_node DatasyncLocationHdfs#name_node}
NameNode interface{} `field:"required" json:"nameNode" yaml:"nameNode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#authentication_type DatasyncLocationHdfs#authentication_type}.
AuthenticationType *string `field:"optional" json:"authenticationType" yaml:"authenticationType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#block_size DatasyncLocationHdfs#block_size}.
BlockSize *float64 `field:"optional" json:"blockSize" yaml:"blockSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#id DatasyncLocationHdfs#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#kerberos_keytab DatasyncLocationHdfs#kerberos_keytab}.
KerberosKeytab *string `field:"optional" json:"kerberosKeytab" yaml:"kerberosKeytab"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#kerberos_krb5_conf DatasyncLocationHdfs#kerberos_krb5_conf}.
KerberosKrb5Conf *string `field:"optional" json:"kerberosKrb5Conf" yaml:"kerberosKrb5Conf"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#kerberos_principal DatasyncLocationHdfs#kerberos_principal}.
KerberosPrincipal *string `field:"optional" json:"kerberosPrincipal" yaml:"kerberosPrincipal"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#kms_key_provider_uri DatasyncLocationHdfs#kms_key_provider_uri}.
KmsKeyProviderUri *string `field:"optional" json:"kmsKeyProviderUri" yaml:"kmsKeyProviderUri"`
// qop_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#qop_configuration DatasyncLocationHdfs#qop_configuration}
QopConfiguration *DatasyncLocationHdfsQopConfiguration `field:"optional" json:"qopConfiguration" yaml:"qopConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#replication_factor DatasyncLocationHdfs#replication_factor}.
ReplicationFactor *float64 `field:"optional" json:"replicationFactor" yaml:"replicationFactor"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#simple_user DatasyncLocationHdfs#simple_user}.
SimpleUser *string `field:"optional" json:"simpleUser" yaml:"simpleUser"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#subdirectory DatasyncLocationHdfs#subdirectory}.
Subdirectory *string `field:"optional" json:"subdirectory" yaml:"subdirectory"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#tags DatasyncLocationHdfs#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#tags_all DatasyncLocationHdfs#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type DatasyncLocationHdfsNameNode ¶
type DatasyncLocationHdfsNameNode struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#hostname DatasyncLocationHdfs#hostname}.
Hostname *string `field:"required" json:"hostname" yaml:"hostname"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#port DatasyncLocationHdfs#port}.
Port *float64 `field:"required" json:"port" yaml:"port"`
}
type DatasyncLocationHdfsNameNodeList ¶
type DatasyncLocationHdfsNameNodeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DatasyncLocationHdfsNameNodeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDatasyncLocationHdfsNameNodeList ¶
func NewDatasyncLocationHdfsNameNodeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DatasyncLocationHdfsNameNodeList
type DatasyncLocationHdfsNameNodeOutputReference ¶
type DatasyncLocationHdfsNameNodeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Hostname() *string
SetHostname(val *string)
HostnameInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Port() *float64
SetPort(val *float64)
PortInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDatasyncLocationHdfsNameNodeOutputReference ¶
func NewDatasyncLocationHdfsNameNodeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DatasyncLocationHdfsNameNodeOutputReference
type DatasyncLocationHdfsQopConfiguration ¶
type DatasyncLocationHdfsQopConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#data_transfer_protection DatasyncLocationHdfs#data_transfer_protection}.
DataTransferProtection *string `field:"optional" json:"dataTransferProtection" yaml:"dataTransferProtection"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_hdfs#rpc_protection DatasyncLocationHdfs#rpc_protection}.
RpcProtection *string `field:"optional" json:"rpcProtection" yaml:"rpcProtection"`
}
type DatasyncLocationHdfsQopConfigurationOutputReference ¶
type DatasyncLocationHdfsQopConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DataTransferProtection() *string
SetDataTransferProtection(val *string)
DataTransferProtectionInput() *string
// Experimental.
Fqn() *string
InternalValue() *DatasyncLocationHdfsQopConfiguration
SetInternalValue(val *DatasyncLocationHdfsQopConfiguration)
RpcProtection() *string
SetRpcProtection(val *string)
RpcProtectionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDataTransferProtection()
ResetRpcProtection()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDatasyncLocationHdfsQopConfigurationOutputReference ¶
func NewDatasyncLocationHdfsQopConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DatasyncLocationHdfsQopConfigurationOutputReference
Source Files
¶
- DatasyncLocationHdfs.go
- DatasyncLocationHdfsConfig.go
- DatasyncLocationHdfsNameNode.go
- DatasyncLocationHdfsNameNodeList.go
- DatasyncLocationHdfsNameNodeList__checks.go
- DatasyncLocationHdfsNameNodeOutputReference.go
- DatasyncLocationHdfsNameNodeOutputReference__checks.go
- DatasyncLocationHdfsQopConfiguration.go
- DatasyncLocationHdfsQopConfigurationOutputReference.go
- DatasyncLocationHdfsQopConfigurationOutputReference__checks.go
- DatasyncLocationHdfs__checks.go
- main.go