Documentation
¶
Index ¶
- func DatasyncLocationNfs_IsConstruct(x interface{}) *bool
- func DatasyncLocationNfs_IsTerraformElement(x interface{}) *bool
- func DatasyncLocationNfs_IsTerraformResource(x interface{}) *bool
- func DatasyncLocationNfs_TfResourceType() *string
- func NewDatasyncLocationNfsMountOptionsOutputReference_Override(d DatasyncLocationNfsMountOptionsOutputReference, ...)
- func NewDatasyncLocationNfsOnPremConfigOutputReference_Override(d DatasyncLocationNfsOnPremConfigOutputReference, ...)
- func NewDatasyncLocationNfs_Override(d DatasyncLocationNfs, scope constructs.Construct, id *string, ...)
- type DatasyncLocationNfs
- type DatasyncLocationNfsConfig
- type DatasyncLocationNfsMountOptions
- type DatasyncLocationNfsMountOptionsOutputReference
- type DatasyncLocationNfsOnPremConfig
- type DatasyncLocationNfsOnPremConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DatasyncLocationNfs_IsConstruct ¶
func DatasyncLocationNfs_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DatasyncLocationNfs_IsTerraformElement ¶
func DatasyncLocationNfs_IsTerraformElement(x interface{}) *bool
Experimental.
func DatasyncLocationNfs_IsTerraformResource ¶
func DatasyncLocationNfs_IsTerraformResource(x interface{}) *bool
Experimental.
func DatasyncLocationNfs_TfResourceType ¶
func DatasyncLocationNfs_TfResourceType() *string
func NewDatasyncLocationNfsMountOptionsOutputReference_Override ¶
func NewDatasyncLocationNfsMountOptionsOutputReference_Override(d DatasyncLocationNfsMountOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDatasyncLocationNfsOnPremConfigOutputReference_Override ¶
func NewDatasyncLocationNfsOnPremConfigOutputReference_Override(d DatasyncLocationNfsOnPremConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDatasyncLocationNfs_Override ¶
func NewDatasyncLocationNfs_Override(d DatasyncLocationNfs, scope constructs.Construct, id *string, config *DatasyncLocationNfsConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_nfs aws_datasync_location_nfs} Resource.
Types ¶
type DatasyncLocationNfs ¶
type DatasyncLocationNfs interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MountOptions() DatasyncLocationNfsMountOptionsOutputReference
MountOptionsInput() *DatasyncLocationNfsMountOptions
// The tree node.
Node() constructs.Node
OnPremConfig() DatasyncLocationNfsOnPremConfigOutputReference
OnPremConfigInput() *DatasyncLocationNfsOnPremConfig
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ServerHostname() *string
SetServerHostname(val *string)
ServerHostnameInput() *string
Subdirectory() *string
SetSubdirectory(val *string)
SubdirectoryInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Uri() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutMountOptions(value *DatasyncLocationNfsMountOptions)
PutOnPremConfig(value *DatasyncLocationNfsOnPremConfig)
ResetId()
ResetMountOptions()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_nfs aws_datasync_location_nfs}.
func NewDatasyncLocationNfs ¶
func NewDatasyncLocationNfs(scope constructs.Construct, id *string, config *DatasyncLocationNfsConfig) DatasyncLocationNfs
Create a new {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_nfs aws_datasync_location_nfs} Resource.
type DatasyncLocationNfsConfig ¶
type DatasyncLocationNfsConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// on_prem_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_nfs#on_prem_config DatasyncLocationNfs#on_prem_config}
OnPremConfig *DatasyncLocationNfsOnPremConfig `field:"required" json:"onPremConfig" yaml:"onPremConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_nfs#server_hostname DatasyncLocationNfs#server_hostname}.
ServerHostname *string `field:"required" json:"serverHostname" yaml:"serverHostname"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_nfs#subdirectory DatasyncLocationNfs#subdirectory}.
Subdirectory *string `field:"required" json:"subdirectory" yaml:"subdirectory"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_nfs#id DatasyncLocationNfs#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// mount_options block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_nfs#mount_options DatasyncLocationNfs#mount_options}
MountOptions *DatasyncLocationNfsMountOptions `field:"optional" json:"mountOptions" yaml:"mountOptions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_nfs#tags DatasyncLocationNfs#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_nfs#tags_all DatasyncLocationNfs#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type DatasyncLocationNfsMountOptions ¶
type DatasyncLocationNfsMountOptions struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_nfs#version DatasyncLocationNfs#version}.
Version *string `field:"optional" json:"version" yaml:"version"`
}
type DatasyncLocationNfsMountOptionsOutputReference ¶
type DatasyncLocationNfsMountOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DatasyncLocationNfsMountOptions
SetInternalValue(val *DatasyncLocationNfsMountOptions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Version() *string
SetVersion(val *string)
VersionInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetVersion()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDatasyncLocationNfsMountOptionsOutputReference ¶
func NewDatasyncLocationNfsMountOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DatasyncLocationNfsMountOptionsOutputReference
type DatasyncLocationNfsOnPremConfig ¶
type DatasyncLocationNfsOnPremConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_nfs#agent_arns DatasyncLocationNfs#agent_arns}.
AgentArns *[]*string `field:"required" json:"agentArns" yaml:"agentArns"`
}
type DatasyncLocationNfsOnPremConfigOutputReference ¶
type DatasyncLocationNfsOnPremConfigOutputReference interface {
cdktf.ComplexObject
AgentArns() *[]*string
SetAgentArns(val *[]*string)
AgentArnsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DatasyncLocationNfsOnPremConfig
SetInternalValue(val *DatasyncLocationNfsOnPremConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDatasyncLocationNfsOnPremConfigOutputReference ¶
func NewDatasyncLocationNfsOnPremConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DatasyncLocationNfsOnPremConfigOutputReference
Source Files
¶
- DatasyncLocationNfs.go
- DatasyncLocationNfsConfig.go
- DatasyncLocationNfsMountOptions.go
- DatasyncLocationNfsMountOptionsOutputReference.go
- DatasyncLocationNfsMountOptionsOutputReference__checks.go
- DatasyncLocationNfsOnPremConfig.go
- DatasyncLocationNfsOnPremConfigOutputReference.go
- DatasyncLocationNfsOnPremConfigOutputReference__checks.go
- DatasyncLocationNfs__checks.go
- main.go