Documentation
¶
Index ¶
- func DmsS3Endpoint_IsConstruct(x interface{}) *bool
- func DmsS3Endpoint_IsTerraformElement(x interface{}) *bool
- func DmsS3Endpoint_IsTerraformResource(x interface{}) *bool
- func DmsS3Endpoint_TfResourceType() *string
- func NewDmsS3EndpointTimeoutsOutputReference_Override(d DmsS3EndpointTimeoutsOutputReference, ...)
- func NewDmsS3Endpoint_Override(d DmsS3Endpoint, scope constructs.Construct, id *string, ...)
- type DmsS3Endpoint
- type DmsS3EndpointConfig
- type DmsS3EndpointTimeouts
- type DmsS3EndpointTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DmsS3Endpoint_IsConstruct ¶
func DmsS3Endpoint_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DmsS3Endpoint_IsTerraformElement ¶
func DmsS3Endpoint_IsTerraformElement(x interface{}) *bool
Experimental.
func DmsS3Endpoint_IsTerraformResource ¶
func DmsS3Endpoint_IsTerraformResource(x interface{}) *bool
Experimental.
func DmsS3Endpoint_TfResourceType ¶
func DmsS3Endpoint_TfResourceType() *string
func NewDmsS3EndpointTimeoutsOutputReference_Override ¶
func NewDmsS3EndpointTimeoutsOutputReference_Override(d DmsS3EndpointTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDmsS3Endpoint_Override ¶
func NewDmsS3Endpoint_Override(d DmsS3Endpoint, scope constructs.Construct, id *string, config *DmsS3EndpointConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint aws_dms_s3_endpoint} Resource.
Types ¶
type DmsS3Endpoint ¶
type DmsS3Endpoint interface {
cdktf.TerraformResource
AddColumnName() interface{}
SetAddColumnName(val interface{})
AddColumnNameInput() interface{}
AddTrailingPaddingCharacter() interface{}
SetAddTrailingPaddingCharacter(val interface{})
AddTrailingPaddingCharacterInput() interface{}
BucketFolder() *string
SetBucketFolder(val *string)
BucketFolderInput() *string
BucketName() *string
SetBucketName(val *string)
BucketNameInput() *string
CannedAclForObjects() *string
SetCannedAclForObjects(val *string)
CannedAclForObjectsInput() *string
CdcInsertsAndUpdates() interface{}
SetCdcInsertsAndUpdates(val interface{})
CdcInsertsAndUpdatesInput() interface{}
CdcInsertsOnly() interface{}
SetCdcInsertsOnly(val interface{})
CdcInsertsOnlyInput() interface{}
CdcMaxBatchInterval() *float64
SetCdcMaxBatchInterval(val *float64)
CdcMaxBatchIntervalInput() *float64
CdcMinFileSize() *float64
SetCdcMinFileSize(val *float64)
CdcMinFileSizeInput() *float64
CdcPath() *string
SetCdcPath(val *string)
CdcPathInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CertificateArn() *string
SetCertificateArn(val *string)
CertificateArnInput() *string
CompressionType() *string
SetCompressionType(val *string)
CompressionTypeInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CsvDelimiter() *string
SetCsvDelimiter(val *string)
CsvDelimiterInput() *string
CsvNoSupValue() *string
SetCsvNoSupValue(val *string)
CsvNoSupValueInput() *string
CsvNullValue() *string
SetCsvNullValue(val *string)
CsvNullValueInput() *string
CsvRowDelimiter() *string
SetCsvRowDelimiter(val *string)
CsvRowDelimiterInput() *string
DataFormat() *string
SetDataFormat(val *string)
DataFormatInput() *string
DataPageSize() *float64
SetDataPageSize(val *float64)
DataPageSizeInput() *float64
DatePartitionDelimiter() *string
SetDatePartitionDelimiter(val *string)
DatePartitionDelimiterInput() *string
DatePartitionEnabled() interface{}
SetDatePartitionEnabled(val interface{})
DatePartitionEnabledInput() interface{}
DatePartitionSequence() *string
SetDatePartitionSequence(val *string)
DatePartitionSequenceInput() *string
DatePartitionTimezone() *string
SetDatePartitionTimezone(val *string)
DatePartitionTimezoneInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DetachTargetOnLobLookupFailureParquet() interface{}
SetDetachTargetOnLobLookupFailureParquet(val interface{})
DetachTargetOnLobLookupFailureParquetInput() interface{}
DictPageSizeLimit() *float64
SetDictPageSizeLimit(val *float64)
DictPageSizeLimitInput() *float64
EnableStatistics() interface{}
SetEnableStatistics(val interface{})
EnableStatisticsInput() interface{}
EncodingType() *string
SetEncodingType(val *string)
EncodingTypeInput() *string
EncryptionMode() *string
SetEncryptionMode(val *string)
EncryptionModeInput() *string
EndpointArn() *string
EndpointId() *string
SetEndpointId(val *string)
EndpointIdInput() *string
EndpointType() *string
SetEndpointType(val *string)
EndpointTypeInput() *string
EngineDisplayName() *string
ExpectedBucketOwner() *string
SetExpectedBucketOwner(val *string)
ExpectedBucketOwnerInput() *string
ExternalId() *string
ExternalTableDefinition() *string
SetExternalTableDefinition(val *string)
ExternalTableDefinitionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IgnoreHeaderRows() *float64
SetIgnoreHeaderRows(val *float64)
IgnoreHeaderRowsInput() *float64
IncludeOpForFullLoad() interface{}
SetIncludeOpForFullLoad(val interface{})
IncludeOpForFullLoadInput() interface{}
KmsKeyArn() *string
SetKmsKeyArn(val *string)
KmsKeyArnInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaxFileSize() *float64
SetMaxFileSize(val *float64)
MaxFileSizeInput() *float64
// The tree node.
Node() constructs.Node
ParquetTimestampInMillisecond() interface{}
SetParquetTimestampInMillisecond(val interface{})
ParquetTimestampInMillisecondInput() interface{}
ParquetVersion() *string
SetParquetVersion(val *string)
ParquetVersionInput() *string
PreserveTransactions() interface{}
SetPreserveTransactions(val interface{})
PreserveTransactionsInput() interface{}
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Rfc4180() interface{}
SetRfc4180(val interface{})
Rfc4180Input() interface{}
RowGroupLength() *float64
SetRowGroupLength(val *float64)
RowGroupLengthInput() *float64
ServerSideEncryptionKmsKeyId() *string
SetServerSideEncryptionKmsKeyId(val *string)
ServerSideEncryptionKmsKeyIdInput() *string
ServiceAccessRoleArn() *string
SetServiceAccessRoleArn(val *string)
ServiceAccessRoleArnInput() *string
SslMode() *string
SetSslMode(val *string)
SslModeInput() *string
Status() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DmsS3EndpointTimeoutsOutputReference
TimeoutsInput() interface{}
TimestampColumnName() *string
SetTimestampColumnName(val *string)
TimestampColumnNameInput() *string
UseCsvNoSupValue() interface{}
SetUseCsvNoSupValue(val interface{})
UseCsvNoSupValueInput() interface{}
UseTaskStartTimeForFullLoadTimestamp() interface{}
SetUseTaskStartTimeForFullLoadTimestamp(val interface{})
UseTaskStartTimeForFullLoadTimestampInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *DmsS3EndpointTimeouts)
ResetAddColumnName()
ResetAddTrailingPaddingCharacter()
ResetBucketFolder()
ResetCannedAclForObjects()
ResetCdcInsertsAndUpdates()
ResetCdcInsertsOnly()
ResetCdcMaxBatchInterval()
ResetCdcMinFileSize()
ResetCdcPath()
ResetCertificateArn()
ResetCompressionType()
ResetCsvDelimiter()
ResetCsvNoSupValue()
ResetCsvNullValue()
ResetCsvRowDelimiter()
ResetDataFormat()
ResetDataPageSize()
ResetDatePartitionDelimiter()
ResetDatePartitionEnabled()
ResetDatePartitionSequence()
ResetDatePartitionTimezone()
ResetDetachTargetOnLobLookupFailureParquet()
ResetDictPageSizeLimit()
ResetEnableStatistics()
ResetEncodingType()
ResetEncryptionMode()
ResetExpectedBucketOwner()
ResetExternalTableDefinition()
ResetId()
ResetIgnoreHeaderRows()
ResetIncludeOpForFullLoad()
ResetKmsKeyArn()
ResetMaxFileSize()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetParquetTimestampInMillisecond()
ResetParquetVersion()
ResetPreserveTransactions()
ResetRfc4180()
ResetRowGroupLength()
ResetServerSideEncryptionKmsKeyId()
ResetSslMode()
ResetTags()
ResetTagsAll()
ResetTimeouts()
ResetTimestampColumnName()
ResetUseCsvNoSupValue()
ResetUseTaskStartTimeForFullLoadTimestamp()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint aws_dms_s3_endpoint}.
func NewDmsS3Endpoint ¶
func NewDmsS3Endpoint(scope constructs.Construct, id *string, config *DmsS3EndpointConfig) DmsS3Endpoint
Create a new {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint aws_dms_s3_endpoint} Resource.
type DmsS3EndpointConfig ¶
type DmsS3EndpointConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#bucket_name DmsS3Endpoint#bucket_name}.
BucketName *string `field:"required" json:"bucketName" yaml:"bucketName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#endpoint_id DmsS3Endpoint#endpoint_id}.
EndpointId *string `field:"required" json:"endpointId" yaml:"endpointId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#endpoint_type DmsS3Endpoint#endpoint_type}.
EndpointType *string `field:"required" json:"endpointType" yaml:"endpointType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#service_access_role_arn DmsS3Endpoint#service_access_role_arn}.
ServiceAccessRoleArn *string `field:"required" json:"serviceAccessRoleArn" yaml:"serviceAccessRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#add_column_name DmsS3Endpoint#add_column_name}.
AddColumnName interface{} `field:"optional" json:"addColumnName" yaml:"addColumnName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#add_trailing_padding_character DmsS3Endpoint#add_trailing_padding_character}.
AddTrailingPaddingCharacter interface{} `field:"optional" json:"addTrailingPaddingCharacter" yaml:"addTrailingPaddingCharacter"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#bucket_folder DmsS3Endpoint#bucket_folder}.
BucketFolder *string `field:"optional" json:"bucketFolder" yaml:"bucketFolder"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#canned_acl_for_objects DmsS3Endpoint#canned_acl_for_objects}.
CannedAclForObjects *string `field:"optional" json:"cannedAclForObjects" yaml:"cannedAclForObjects"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#cdc_inserts_and_updates DmsS3Endpoint#cdc_inserts_and_updates}.
CdcInsertsAndUpdates interface{} `field:"optional" json:"cdcInsertsAndUpdates" yaml:"cdcInsertsAndUpdates"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#cdc_inserts_only DmsS3Endpoint#cdc_inserts_only}.
CdcInsertsOnly interface{} `field:"optional" json:"cdcInsertsOnly" yaml:"cdcInsertsOnly"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#cdc_max_batch_interval DmsS3Endpoint#cdc_max_batch_interval}.
CdcMaxBatchInterval *float64 `field:"optional" json:"cdcMaxBatchInterval" yaml:"cdcMaxBatchInterval"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#cdc_min_file_size DmsS3Endpoint#cdc_min_file_size}.
CdcMinFileSize *float64 `field:"optional" json:"cdcMinFileSize" yaml:"cdcMinFileSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#cdc_path DmsS3Endpoint#cdc_path}.
CdcPath *string `field:"optional" json:"cdcPath" yaml:"cdcPath"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#certificate_arn DmsS3Endpoint#certificate_arn}.
CertificateArn *string `field:"optional" json:"certificateArn" yaml:"certificateArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#compression_type DmsS3Endpoint#compression_type}.
CompressionType *string `field:"optional" json:"compressionType" yaml:"compressionType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#csv_delimiter DmsS3Endpoint#csv_delimiter}.
CsvDelimiter *string `field:"optional" json:"csvDelimiter" yaml:"csvDelimiter"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#csv_no_sup_value DmsS3Endpoint#csv_no_sup_value}.
CsvNoSupValue *string `field:"optional" json:"csvNoSupValue" yaml:"csvNoSupValue"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#csv_null_value DmsS3Endpoint#csv_null_value}.
CsvNullValue *string `field:"optional" json:"csvNullValue" yaml:"csvNullValue"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#csv_row_delimiter DmsS3Endpoint#csv_row_delimiter}.
CsvRowDelimiter *string `field:"optional" json:"csvRowDelimiter" yaml:"csvRowDelimiter"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#data_format DmsS3Endpoint#data_format}.
DataFormat *string `field:"optional" json:"dataFormat" yaml:"dataFormat"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#data_page_size DmsS3Endpoint#data_page_size}.
DataPageSize *float64 `field:"optional" json:"dataPageSize" yaml:"dataPageSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#date_partition_delimiter DmsS3Endpoint#date_partition_delimiter}.
DatePartitionDelimiter *string `field:"optional" json:"datePartitionDelimiter" yaml:"datePartitionDelimiter"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#date_partition_enabled DmsS3Endpoint#date_partition_enabled}.
DatePartitionEnabled interface{} `field:"optional" json:"datePartitionEnabled" yaml:"datePartitionEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#date_partition_sequence DmsS3Endpoint#date_partition_sequence}.
DatePartitionSequence *string `field:"optional" json:"datePartitionSequence" yaml:"datePartitionSequence"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#date_partition_timezone DmsS3Endpoint#date_partition_timezone}.
DatePartitionTimezone *string `field:"optional" json:"datePartitionTimezone" yaml:"datePartitionTimezone"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#detach_target_on_lob_lookup_failure_parquet DmsS3Endpoint#detach_target_on_lob_lookup_failure_parquet}.
DetachTargetOnLobLookupFailureParquet interface{} `field:"optional" json:"detachTargetOnLobLookupFailureParquet" yaml:"detachTargetOnLobLookupFailureParquet"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#dict_page_size_limit DmsS3Endpoint#dict_page_size_limit}.
DictPageSizeLimit *float64 `field:"optional" json:"dictPageSizeLimit" yaml:"dictPageSizeLimit"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#enable_statistics DmsS3Endpoint#enable_statistics}.
EnableStatistics interface{} `field:"optional" json:"enableStatistics" yaml:"enableStatistics"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#encoding_type DmsS3Endpoint#encoding_type}.
EncodingType *string `field:"optional" json:"encodingType" yaml:"encodingType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#encryption_mode DmsS3Endpoint#encryption_mode}.
EncryptionMode *string `field:"optional" json:"encryptionMode" yaml:"encryptionMode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#expected_bucket_owner DmsS3Endpoint#expected_bucket_owner}.
ExpectedBucketOwner *string `field:"optional" json:"expectedBucketOwner" yaml:"expectedBucketOwner"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#external_table_definition DmsS3Endpoint#external_table_definition}.
ExternalTableDefinition *string `field:"optional" json:"externalTableDefinition" yaml:"externalTableDefinition"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#id DmsS3Endpoint#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#ignore_header_rows DmsS3Endpoint#ignore_header_rows}.
IgnoreHeaderRows *float64 `field:"optional" json:"ignoreHeaderRows" yaml:"ignoreHeaderRows"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#include_op_for_full_load DmsS3Endpoint#include_op_for_full_load}.
IncludeOpForFullLoad interface{} `field:"optional" json:"includeOpForFullLoad" yaml:"includeOpForFullLoad"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#kms_key_arn DmsS3Endpoint#kms_key_arn}.
KmsKeyArn *string `field:"optional" json:"kmsKeyArn" yaml:"kmsKeyArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#max_file_size DmsS3Endpoint#max_file_size}.
MaxFileSize *float64 `field:"optional" json:"maxFileSize" yaml:"maxFileSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#parquet_timestamp_in_millisecond DmsS3Endpoint#parquet_timestamp_in_millisecond}.
ParquetTimestampInMillisecond interface{} `field:"optional" json:"parquetTimestampInMillisecond" yaml:"parquetTimestampInMillisecond"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#parquet_version DmsS3Endpoint#parquet_version}.
ParquetVersion *string `field:"optional" json:"parquetVersion" yaml:"parquetVersion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#preserve_transactions DmsS3Endpoint#preserve_transactions}.
PreserveTransactions interface{} `field:"optional" json:"preserveTransactions" yaml:"preserveTransactions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#rfc_4180 DmsS3Endpoint#rfc_4180}.
Rfc4180 interface{} `field:"optional" json:"rfc4180" yaml:"rfc4180"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#row_group_length DmsS3Endpoint#row_group_length}.
RowGroupLength *float64 `field:"optional" json:"rowGroupLength" yaml:"rowGroupLength"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#server_side_encryption_kms_key_id DmsS3Endpoint#server_side_encryption_kms_key_id}.
ServerSideEncryptionKmsKeyId *string `field:"optional" json:"serverSideEncryptionKmsKeyId" yaml:"serverSideEncryptionKmsKeyId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#ssl_mode DmsS3Endpoint#ssl_mode}.
SslMode *string `field:"optional" json:"sslMode" yaml:"sslMode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#tags DmsS3Endpoint#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#tags_all DmsS3Endpoint#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#timeouts DmsS3Endpoint#timeouts}
Timeouts *DmsS3EndpointTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#timestamp_column_name DmsS3Endpoint#timestamp_column_name}.
TimestampColumnName *string `field:"optional" json:"timestampColumnName" yaml:"timestampColumnName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#use_csv_no_sup_value DmsS3Endpoint#use_csv_no_sup_value}.
UseCsvNoSupValue interface{} `field:"optional" json:"useCsvNoSupValue" yaml:"useCsvNoSupValue"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#use_task_start_time_for_full_load_timestamp DmsS3Endpoint#use_task_start_time_for_full_load_timestamp}.
UseTaskStartTimeForFullLoadTimestamp interface{} `field:"optional" json:"useTaskStartTimeForFullLoadTimestamp" yaml:"useTaskStartTimeForFullLoadTimestamp"`
}
type DmsS3EndpointTimeouts ¶
type DmsS3EndpointTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#create DmsS3Endpoint#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_s3_endpoint#delete DmsS3Endpoint#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type DmsS3EndpointTimeoutsOutputReference ¶
type DmsS3EndpointTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDmsS3EndpointTimeoutsOutputReference ¶
func NewDmsS3EndpointTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DmsS3EndpointTimeoutsOutputReference