Documentation
¶
Index ¶
- func EbsSnapshotImport_IsConstruct(x interface{}) *bool
- func EbsSnapshotImport_IsTerraformElement(x interface{}) *bool
- func EbsSnapshotImport_IsTerraformResource(x interface{}) *bool
- func EbsSnapshotImport_TfResourceType() *string
- func NewEbsSnapshotImportClientDataOutputReference_Override(e EbsSnapshotImportClientDataOutputReference, ...)
- func NewEbsSnapshotImportDiskContainerOutputReference_Override(e EbsSnapshotImportDiskContainerOutputReference, ...)
- func NewEbsSnapshotImportDiskContainerUserBucketOutputReference_Override(e EbsSnapshotImportDiskContainerUserBucketOutputReference, ...)
- func NewEbsSnapshotImportTimeoutsOutputReference_Override(e EbsSnapshotImportTimeoutsOutputReference, ...)
- func NewEbsSnapshotImport_Override(e EbsSnapshotImport, scope constructs.Construct, id *string, ...)
- type EbsSnapshotImport
- type EbsSnapshotImportClientData
- type EbsSnapshotImportClientDataOutputReference
- type EbsSnapshotImportConfig
- type EbsSnapshotImportDiskContainer
- type EbsSnapshotImportDiskContainerOutputReference
- type EbsSnapshotImportDiskContainerUserBucket
- type EbsSnapshotImportDiskContainerUserBucketOutputReference
- type EbsSnapshotImportTimeouts
- type EbsSnapshotImportTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EbsSnapshotImport_IsConstruct ¶
func EbsSnapshotImport_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func EbsSnapshotImport_IsTerraformElement ¶
func EbsSnapshotImport_IsTerraformElement(x interface{}) *bool
Experimental.
func EbsSnapshotImport_IsTerraformResource ¶
func EbsSnapshotImport_IsTerraformResource(x interface{}) *bool
Experimental.
func EbsSnapshotImport_TfResourceType ¶
func EbsSnapshotImport_TfResourceType() *string
func NewEbsSnapshotImportClientDataOutputReference_Override ¶
func NewEbsSnapshotImportClientDataOutputReference_Override(e EbsSnapshotImportClientDataOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEbsSnapshotImportDiskContainerOutputReference_Override ¶
func NewEbsSnapshotImportDiskContainerOutputReference_Override(e EbsSnapshotImportDiskContainerOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEbsSnapshotImportDiskContainerUserBucketOutputReference_Override ¶
func NewEbsSnapshotImportDiskContainerUserBucketOutputReference_Override(e EbsSnapshotImportDiskContainerUserBucketOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEbsSnapshotImportTimeoutsOutputReference_Override ¶
func NewEbsSnapshotImportTimeoutsOutputReference_Override(e EbsSnapshotImportTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEbsSnapshotImport_Override ¶
func NewEbsSnapshotImport_Override(e EbsSnapshotImport, scope constructs.Construct, id *string, config *EbsSnapshotImportConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import aws_ebs_snapshot_import} Resource.
Types ¶
type EbsSnapshotImport ¶
type EbsSnapshotImport interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ClientData() EbsSnapshotImportClientDataOutputReference
ClientDataInput() *EbsSnapshotImportClientData
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DataEncryptionKeyId() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DiskContainer() EbsSnapshotImportDiskContainerOutputReference
DiskContainerInput() *EbsSnapshotImportDiskContainer
Encrypted() interface{}
SetEncrypted(val interface{})
EncryptedInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
OutpostArn() *string
OwnerAlias() *string
OwnerId() *string
PermanentRestore() interface{}
SetPermanentRestore(val interface{})
PermanentRestoreInput() interface{}
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RoleName() *string
SetRoleName(val *string)
RoleNameInput() *string
StorageTier() *string
SetStorageTier(val *string)
StorageTierInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
TemporaryRestoreDays() *float64
SetTemporaryRestoreDays(val *float64)
TemporaryRestoreDaysInput() *float64
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() EbsSnapshotImportTimeoutsOutputReference
TimeoutsInput() interface{}
VolumeId() *string
VolumeSize() *float64
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutClientData(value *EbsSnapshotImportClientData)
PutDiskContainer(value *EbsSnapshotImportDiskContainer)
PutTimeouts(value *EbsSnapshotImportTimeouts)
ResetClientData()
ResetDescription()
ResetEncrypted()
ResetId()
ResetKmsKeyId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPermanentRestore()
ResetRoleName()
ResetStorageTier()
ResetTags()
ResetTagsAll()
ResetTemporaryRestoreDays()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import aws_ebs_snapshot_import}.
func NewEbsSnapshotImport ¶
func NewEbsSnapshotImport(scope constructs.Construct, id *string, config *EbsSnapshotImportConfig) EbsSnapshotImport
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import aws_ebs_snapshot_import} Resource.
type EbsSnapshotImportClientData ¶
type EbsSnapshotImportClientData struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#comment EbsSnapshotImport#comment}.
Comment *string `field:"optional" json:"comment" yaml:"comment"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#upload_end EbsSnapshotImport#upload_end}.
UploadEnd *string `field:"optional" json:"uploadEnd" yaml:"uploadEnd"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#upload_size EbsSnapshotImport#upload_size}.
UploadSize *float64 `field:"optional" json:"uploadSize" yaml:"uploadSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#upload_start EbsSnapshotImport#upload_start}.
UploadStart *string `field:"optional" json:"uploadStart" yaml:"uploadStart"`
}
type EbsSnapshotImportClientDataOutputReference ¶
type EbsSnapshotImportClientDataOutputReference interface {
cdktf.ComplexObject
Comment() *string
SetComment(val *string)
CommentInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EbsSnapshotImportClientData
SetInternalValue(val *EbsSnapshotImportClientData)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UploadEnd() *string
SetUploadEnd(val *string)
UploadEndInput() *string
UploadSize() *float64
SetUploadSize(val *float64)
UploadSizeInput() *float64
UploadStart() *string
SetUploadStart(val *string)
UploadStartInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetComment()
ResetUploadEnd()
ResetUploadSize()
ResetUploadStart()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEbsSnapshotImportClientDataOutputReference ¶
func NewEbsSnapshotImportClientDataOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EbsSnapshotImportClientDataOutputReference
type EbsSnapshotImportConfig ¶
type EbsSnapshotImportConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// disk_container block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#disk_container EbsSnapshotImport#disk_container}
DiskContainer *EbsSnapshotImportDiskContainer `field:"required" json:"diskContainer" yaml:"diskContainer"`
// client_data block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#client_data EbsSnapshotImport#client_data}
ClientData *EbsSnapshotImportClientData `field:"optional" json:"clientData" yaml:"clientData"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#description EbsSnapshotImport#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#encrypted EbsSnapshotImport#encrypted}.
Encrypted interface{} `field:"optional" json:"encrypted" yaml:"encrypted"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#id EbsSnapshotImport#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#kms_key_id EbsSnapshotImport#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#permanent_restore EbsSnapshotImport#permanent_restore}.
PermanentRestore interface{} `field:"optional" json:"permanentRestore" yaml:"permanentRestore"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#role_name EbsSnapshotImport#role_name}.
RoleName *string `field:"optional" json:"roleName" yaml:"roleName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#storage_tier EbsSnapshotImport#storage_tier}.
StorageTier *string `field:"optional" json:"storageTier" yaml:"storageTier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#tags EbsSnapshotImport#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#tags_all EbsSnapshotImport#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#temporary_restore_days EbsSnapshotImport#temporary_restore_days}.
TemporaryRestoreDays *float64 `field:"optional" json:"temporaryRestoreDays" yaml:"temporaryRestoreDays"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#timeouts EbsSnapshotImport#timeouts}
Timeouts *EbsSnapshotImportTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type EbsSnapshotImportDiskContainer ¶
type EbsSnapshotImportDiskContainer struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#format EbsSnapshotImport#format}.
Format *string `field:"required" json:"format" yaml:"format"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#description EbsSnapshotImport#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#url EbsSnapshotImport#url}.
Url *string `field:"optional" json:"url" yaml:"url"`
// user_bucket block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#user_bucket EbsSnapshotImport#user_bucket}
UserBucket *EbsSnapshotImportDiskContainerUserBucket `field:"optional" json:"userBucket" yaml:"userBucket"`
}
type EbsSnapshotImportDiskContainerOutputReference ¶
type EbsSnapshotImportDiskContainerOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Format() *string
SetFormat(val *string)
FormatInput() *string
// Experimental.
Fqn() *string
InternalValue() *EbsSnapshotImportDiskContainer
SetInternalValue(val *EbsSnapshotImportDiskContainer)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Url() *string
SetUrl(val *string)
UrlInput() *string
UserBucket() EbsSnapshotImportDiskContainerUserBucketOutputReference
UserBucketInput() *EbsSnapshotImportDiskContainerUserBucket
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutUserBucket(value *EbsSnapshotImportDiskContainerUserBucket)
ResetDescription()
ResetUrl()
ResetUserBucket()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEbsSnapshotImportDiskContainerOutputReference ¶
func NewEbsSnapshotImportDiskContainerOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EbsSnapshotImportDiskContainerOutputReference
type EbsSnapshotImportDiskContainerUserBucket ¶
type EbsSnapshotImportDiskContainerUserBucket struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#s3_bucket EbsSnapshotImport#s3_bucket}.
S3Bucket *string `field:"required" json:"s3Bucket" yaml:"s3Bucket"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#s3_key EbsSnapshotImport#s3_key}.
S3Key *string `field:"required" json:"s3Key" yaml:"s3Key"`
}
type EbsSnapshotImportDiskContainerUserBucketOutputReference ¶
type EbsSnapshotImportDiskContainerUserBucketOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EbsSnapshotImportDiskContainerUserBucket
SetInternalValue(val *EbsSnapshotImportDiskContainerUserBucket)
S3Bucket() *string
SetS3Bucket(val *string)
S3BucketInput() *string
S3Key() *string
SetS3Key(val *string)
S3KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEbsSnapshotImportDiskContainerUserBucketOutputReference ¶
func NewEbsSnapshotImportDiskContainerUserBucketOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EbsSnapshotImportDiskContainerUserBucketOutputReference
type EbsSnapshotImportTimeouts ¶
type EbsSnapshotImportTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#create EbsSnapshotImport#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ebs_snapshot_import#delete EbsSnapshotImport#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type EbsSnapshotImportTimeoutsOutputReference ¶
type EbsSnapshotImportTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEbsSnapshotImportTimeoutsOutputReference ¶
func NewEbsSnapshotImportTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EbsSnapshotImportTimeoutsOutputReference
Source Files
¶
- EbsSnapshotImport.go
- EbsSnapshotImportClientData.go
- EbsSnapshotImportClientDataOutputReference.go
- EbsSnapshotImportClientDataOutputReference__checks.go
- EbsSnapshotImportConfig.go
- EbsSnapshotImportDiskContainer.go
- EbsSnapshotImportDiskContainerOutputReference.go
- EbsSnapshotImportDiskContainerOutputReference__checks.go
- EbsSnapshotImportDiskContainerUserBucket.go
- EbsSnapshotImportDiskContainerUserBucketOutputReference.go
- EbsSnapshotImportDiskContainerUserBucketOutputReference__checks.go
- EbsSnapshotImportTimeouts.go
- EbsSnapshotImportTimeoutsOutputReference.go
- EbsSnapshotImportTimeoutsOutputReference__checks.go
- EbsSnapshotImport__checks.go
- main.go