Documentation
¶
Index ¶
- func Ec2ClientVpnEndpoint_IsConstruct(x interface{}) *bool
- func Ec2ClientVpnEndpoint_IsTerraformElement(x interface{}) *bool
- func Ec2ClientVpnEndpoint_IsTerraformResource(x interface{}) *bool
- func Ec2ClientVpnEndpoint_TfResourceType() *string
- func NewEc2ClientVpnEndpointAuthenticationOptionsList_Override(e Ec2ClientVpnEndpointAuthenticationOptionsList, ...)
- func NewEc2ClientVpnEndpointAuthenticationOptionsOutputReference_Override(e Ec2ClientVpnEndpointAuthenticationOptionsOutputReference, ...)
- func NewEc2ClientVpnEndpointClientConnectOptionsOutputReference_Override(e Ec2ClientVpnEndpointClientConnectOptionsOutputReference, ...)
- func NewEc2ClientVpnEndpointClientLoginBannerOptionsOutputReference_Override(e Ec2ClientVpnEndpointClientLoginBannerOptionsOutputReference, ...)
- func NewEc2ClientVpnEndpointConnectionLogOptionsOutputReference_Override(e Ec2ClientVpnEndpointConnectionLogOptionsOutputReference, ...)
- func NewEc2ClientVpnEndpoint_Override(e Ec2ClientVpnEndpoint, scope constructs.Construct, id *string, ...)
- type Ec2ClientVpnEndpoint
- type Ec2ClientVpnEndpointAuthenticationOptions
- type Ec2ClientVpnEndpointAuthenticationOptionsList
- type Ec2ClientVpnEndpointAuthenticationOptionsOutputReference
- type Ec2ClientVpnEndpointClientConnectOptions
- type Ec2ClientVpnEndpointClientConnectOptionsOutputReference
- type Ec2ClientVpnEndpointClientLoginBannerOptions
- type Ec2ClientVpnEndpointClientLoginBannerOptionsOutputReference
- type Ec2ClientVpnEndpointConfig
- type Ec2ClientVpnEndpointConnectionLogOptions
- type Ec2ClientVpnEndpointConnectionLogOptionsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Ec2ClientVpnEndpoint_IsConstruct ¶
func Ec2ClientVpnEndpoint_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func Ec2ClientVpnEndpoint_IsTerraformElement ¶
func Ec2ClientVpnEndpoint_IsTerraformElement(x interface{}) *bool
Experimental.
func Ec2ClientVpnEndpoint_IsTerraformResource ¶
func Ec2ClientVpnEndpoint_IsTerraformResource(x interface{}) *bool
Experimental.
func Ec2ClientVpnEndpoint_TfResourceType ¶
func Ec2ClientVpnEndpoint_TfResourceType() *string
func NewEc2ClientVpnEndpointAuthenticationOptionsList_Override ¶
func NewEc2ClientVpnEndpointAuthenticationOptionsList_Override(e Ec2ClientVpnEndpointAuthenticationOptionsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEc2ClientVpnEndpointAuthenticationOptionsOutputReference_Override ¶
func NewEc2ClientVpnEndpointAuthenticationOptionsOutputReference_Override(e Ec2ClientVpnEndpointAuthenticationOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEc2ClientVpnEndpointClientConnectOptionsOutputReference_Override ¶
func NewEc2ClientVpnEndpointClientConnectOptionsOutputReference_Override(e Ec2ClientVpnEndpointClientConnectOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEc2ClientVpnEndpointClientLoginBannerOptionsOutputReference_Override ¶
func NewEc2ClientVpnEndpointClientLoginBannerOptionsOutputReference_Override(e Ec2ClientVpnEndpointClientLoginBannerOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEc2ClientVpnEndpointConnectionLogOptionsOutputReference_Override ¶
func NewEc2ClientVpnEndpointConnectionLogOptionsOutputReference_Override(e Ec2ClientVpnEndpointConnectionLogOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEc2ClientVpnEndpoint_Override ¶
func NewEc2ClientVpnEndpoint_Override(e Ec2ClientVpnEndpoint, scope constructs.Construct, id *string, config *Ec2ClientVpnEndpointConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint aws_ec2_client_vpn_endpoint} Resource.
Types ¶
type Ec2ClientVpnEndpoint ¶
type Ec2ClientVpnEndpoint interface {
cdktf.TerraformResource
Arn() *string
AuthenticationOptions() Ec2ClientVpnEndpointAuthenticationOptionsList
AuthenticationOptionsInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
ClientCidrBlock() *string
SetClientCidrBlock(val *string)
ClientCidrBlockInput() *string
ClientConnectOptions() Ec2ClientVpnEndpointClientConnectOptionsOutputReference
ClientConnectOptionsInput() *Ec2ClientVpnEndpointClientConnectOptions
ClientLoginBannerOptions() Ec2ClientVpnEndpointClientLoginBannerOptionsOutputReference
ClientLoginBannerOptionsInput() *Ec2ClientVpnEndpointClientLoginBannerOptions
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
ConnectionLogOptions() Ec2ClientVpnEndpointConnectionLogOptionsOutputReference
ConnectionLogOptionsInput() *Ec2ClientVpnEndpointConnectionLogOptions
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DnsName() *string
DnsServers() *[]*string
SetDnsServers(val *[]*string)
DnsServersInput() *[]*string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
SelfServicePortal() *string
SetSelfServicePortal(val *string)
SelfServicePortalInput() *string
ServerCertificateArn() *string
SetServerCertificateArn(val *string)
ServerCertificateArnInput() *string
SessionTimeoutHours() *float64
SetSessionTimeoutHours(val *float64)
SessionTimeoutHoursInput() *float64
SplitTunnel() interface{}
SetSplitTunnel(val interface{})
SplitTunnelInput() interface{}
Status() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
TransportProtocol() *string
SetTransportProtocol(val *string)
TransportProtocolInput() *string
VpcId() *string
SetVpcId(val *string)
VpcIdInput() *string
VpnPort() *float64
SetVpnPort(val *float64)
VpnPortInput() *float64
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAuthenticationOptions(value interface{})
PutClientConnectOptions(value *Ec2ClientVpnEndpointClientConnectOptions)
PutClientLoginBannerOptions(value *Ec2ClientVpnEndpointClientLoginBannerOptions)
PutConnectionLogOptions(value *Ec2ClientVpnEndpointConnectionLogOptions)
ResetClientConnectOptions()
ResetClientLoginBannerOptions()
ResetDescription()
ResetDnsServers()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSecurityGroupIds()
ResetSelfServicePortal()
ResetSessionTimeoutHours()
ResetSplitTunnel()
ResetTags()
ResetTagsAll()
ResetTransportProtocol()
ResetVpcId()
ResetVpnPort()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint aws_ec2_client_vpn_endpoint}.
func NewEc2ClientVpnEndpoint ¶
func NewEc2ClientVpnEndpoint(scope constructs.Construct, id *string, config *Ec2ClientVpnEndpointConfig) Ec2ClientVpnEndpoint
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint aws_ec2_client_vpn_endpoint} Resource.
type Ec2ClientVpnEndpointAuthenticationOptions ¶
type Ec2ClientVpnEndpointAuthenticationOptions struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#type Ec2ClientVpnEndpoint#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#active_directory_id Ec2ClientVpnEndpoint#active_directory_id}.
ActiveDirectoryId *string `field:"optional" json:"activeDirectoryId" yaml:"activeDirectoryId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#root_certificate_chain_arn Ec2ClientVpnEndpoint#root_certificate_chain_arn}.
RootCertificateChainArn *string `field:"optional" json:"rootCertificateChainArn" yaml:"rootCertificateChainArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#saml_provider_arn Ec2ClientVpnEndpoint#saml_provider_arn}.
SamlProviderArn *string `field:"optional" json:"samlProviderArn" yaml:"samlProviderArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#self_service_saml_provider_arn Ec2ClientVpnEndpoint#self_service_saml_provider_arn}.
SelfServiceSamlProviderArn *string `field:"optional" json:"selfServiceSamlProviderArn" yaml:"selfServiceSamlProviderArn"`
}
type Ec2ClientVpnEndpointAuthenticationOptionsList ¶
type Ec2ClientVpnEndpointAuthenticationOptionsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) Ec2ClientVpnEndpointAuthenticationOptionsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEc2ClientVpnEndpointAuthenticationOptionsList ¶
func NewEc2ClientVpnEndpointAuthenticationOptionsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) Ec2ClientVpnEndpointAuthenticationOptionsList
type Ec2ClientVpnEndpointAuthenticationOptionsOutputReference ¶
type Ec2ClientVpnEndpointAuthenticationOptionsOutputReference interface {
cdktf.ComplexObject
ActiveDirectoryId() *string
SetActiveDirectoryId(val *string)
ActiveDirectoryIdInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
RootCertificateChainArn() *string
SetRootCertificateChainArn(val *string)
RootCertificateChainArnInput() *string
SamlProviderArn() *string
SetSamlProviderArn(val *string)
SamlProviderArnInput() *string
SelfServiceSamlProviderArn() *string
SetSelfServiceSamlProviderArn(val *string)
SelfServiceSamlProviderArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetActiveDirectoryId()
ResetRootCertificateChainArn()
ResetSamlProviderArn()
ResetSelfServiceSamlProviderArn()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEc2ClientVpnEndpointAuthenticationOptionsOutputReference ¶
func NewEc2ClientVpnEndpointAuthenticationOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) Ec2ClientVpnEndpointAuthenticationOptionsOutputReference
type Ec2ClientVpnEndpointClientConnectOptions ¶
type Ec2ClientVpnEndpointClientConnectOptions struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#enabled Ec2ClientVpnEndpoint#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#lambda_function_arn Ec2ClientVpnEndpoint#lambda_function_arn}.
LambdaFunctionArn *string `field:"optional" json:"lambdaFunctionArn" yaml:"lambdaFunctionArn"`
}
type Ec2ClientVpnEndpointClientConnectOptionsOutputReference ¶
type Ec2ClientVpnEndpointClientConnectOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *Ec2ClientVpnEndpointClientConnectOptions
SetInternalValue(val *Ec2ClientVpnEndpointClientConnectOptions)
LambdaFunctionArn() *string
SetLambdaFunctionArn(val *string)
LambdaFunctionArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnabled()
ResetLambdaFunctionArn()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEc2ClientVpnEndpointClientConnectOptionsOutputReference ¶
func NewEc2ClientVpnEndpointClientConnectOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Ec2ClientVpnEndpointClientConnectOptionsOutputReference
type Ec2ClientVpnEndpointClientLoginBannerOptions ¶
type Ec2ClientVpnEndpointClientLoginBannerOptions struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#banner_text Ec2ClientVpnEndpoint#banner_text}.
BannerText *string `field:"optional" json:"bannerText" yaml:"bannerText"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#enabled Ec2ClientVpnEndpoint#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
}
type Ec2ClientVpnEndpointClientLoginBannerOptionsOutputReference ¶
type Ec2ClientVpnEndpointClientLoginBannerOptionsOutputReference interface {
cdktf.ComplexObject
BannerText() *string
SetBannerText(val *string)
BannerTextInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *Ec2ClientVpnEndpointClientLoginBannerOptions
SetInternalValue(val *Ec2ClientVpnEndpointClientLoginBannerOptions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBannerText()
ResetEnabled()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEc2ClientVpnEndpointClientLoginBannerOptionsOutputReference ¶
func NewEc2ClientVpnEndpointClientLoginBannerOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Ec2ClientVpnEndpointClientLoginBannerOptionsOutputReference
type Ec2ClientVpnEndpointConfig ¶
type Ec2ClientVpnEndpointConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// authentication_options block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#authentication_options Ec2ClientVpnEndpoint#authentication_options}
AuthenticationOptions interface{} `field:"required" json:"authenticationOptions" yaml:"authenticationOptions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#client_cidr_block Ec2ClientVpnEndpoint#client_cidr_block}.
ClientCidrBlock *string `field:"required" json:"clientCidrBlock" yaml:"clientCidrBlock"`
// connection_log_options block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#connection_log_options Ec2ClientVpnEndpoint#connection_log_options}
ConnectionLogOptions *Ec2ClientVpnEndpointConnectionLogOptions `field:"required" json:"connectionLogOptions" yaml:"connectionLogOptions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#server_certificate_arn Ec2ClientVpnEndpoint#server_certificate_arn}.
ServerCertificateArn *string `field:"required" json:"serverCertificateArn" yaml:"serverCertificateArn"`
// client_connect_options block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#client_connect_options Ec2ClientVpnEndpoint#client_connect_options}
ClientConnectOptions *Ec2ClientVpnEndpointClientConnectOptions `field:"optional" json:"clientConnectOptions" yaml:"clientConnectOptions"`
// client_login_banner_options block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#client_login_banner_options Ec2ClientVpnEndpoint#client_login_banner_options}
ClientLoginBannerOptions *Ec2ClientVpnEndpointClientLoginBannerOptions `field:"optional" json:"clientLoginBannerOptions" yaml:"clientLoginBannerOptions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#description Ec2ClientVpnEndpoint#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#dns_servers Ec2ClientVpnEndpoint#dns_servers}.
DnsServers *[]*string `field:"optional" json:"dnsServers" yaml:"dnsServers"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#id Ec2ClientVpnEndpoint#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#security_group_ids Ec2ClientVpnEndpoint#security_group_ids}.
SecurityGroupIds *[]*string `field:"optional" json:"securityGroupIds" yaml:"securityGroupIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#self_service_portal Ec2ClientVpnEndpoint#self_service_portal}.
SelfServicePortal *string `field:"optional" json:"selfServicePortal" yaml:"selfServicePortal"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#session_timeout_hours Ec2ClientVpnEndpoint#session_timeout_hours}.
SessionTimeoutHours *float64 `field:"optional" json:"sessionTimeoutHours" yaml:"sessionTimeoutHours"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#split_tunnel Ec2ClientVpnEndpoint#split_tunnel}.
SplitTunnel interface{} `field:"optional" json:"splitTunnel" yaml:"splitTunnel"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#tags Ec2ClientVpnEndpoint#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#tags_all Ec2ClientVpnEndpoint#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#transport_protocol Ec2ClientVpnEndpoint#transport_protocol}.
TransportProtocol *string `field:"optional" json:"transportProtocol" yaml:"transportProtocol"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#vpc_id Ec2ClientVpnEndpoint#vpc_id}.
VpcId *string `field:"optional" json:"vpcId" yaml:"vpcId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#vpn_port Ec2ClientVpnEndpoint#vpn_port}.
VpnPort *float64 `field:"optional" json:"vpnPort" yaml:"vpnPort"`
}
type Ec2ClientVpnEndpointConnectionLogOptions ¶
type Ec2ClientVpnEndpointConnectionLogOptions struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#enabled Ec2ClientVpnEndpoint#enabled}.
Enabled interface{} `field:"required" json:"enabled" yaml:"enabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#cloudwatch_log_group Ec2ClientVpnEndpoint#cloudwatch_log_group}.
CloudwatchLogGroup *string `field:"optional" json:"cloudwatchLogGroup" yaml:"cloudwatchLogGroup"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_client_vpn_endpoint#cloudwatch_log_stream Ec2ClientVpnEndpoint#cloudwatch_log_stream}.
CloudwatchLogStream *string `field:"optional" json:"cloudwatchLogStream" yaml:"cloudwatchLogStream"`
}
type Ec2ClientVpnEndpointConnectionLogOptionsOutputReference ¶
type Ec2ClientVpnEndpointConnectionLogOptionsOutputReference interface {
cdktf.ComplexObject
CloudwatchLogGroup() *string
SetCloudwatchLogGroup(val *string)
CloudwatchLogGroupInput() *string
CloudwatchLogStream() *string
SetCloudwatchLogStream(val *string)
CloudwatchLogStreamInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *Ec2ClientVpnEndpointConnectionLogOptions
SetInternalValue(val *Ec2ClientVpnEndpointConnectionLogOptions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCloudwatchLogGroup()
ResetCloudwatchLogStream()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEc2ClientVpnEndpointConnectionLogOptionsOutputReference ¶
func NewEc2ClientVpnEndpointConnectionLogOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Ec2ClientVpnEndpointConnectionLogOptionsOutputReference
Source Files
¶
- Ec2ClientVpnEndpoint.go
- Ec2ClientVpnEndpointAuthenticationOptions.go
- Ec2ClientVpnEndpointAuthenticationOptionsList.go
- Ec2ClientVpnEndpointAuthenticationOptionsList__checks.go
- Ec2ClientVpnEndpointAuthenticationOptionsOutputReference.go
- Ec2ClientVpnEndpointAuthenticationOptionsOutputReference__checks.go
- Ec2ClientVpnEndpointClientConnectOptions.go
- Ec2ClientVpnEndpointClientConnectOptionsOutputReference.go
- Ec2ClientVpnEndpointClientConnectOptionsOutputReference__checks.go
- Ec2ClientVpnEndpointClientLoginBannerOptions.go
- Ec2ClientVpnEndpointClientLoginBannerOptionsOutputReference.go
- Ec2ClientVpnEndpointClientLoginBannerOptionsOutputReference__checks.go
- Ec2ClientVpnEndpointConfig.go
- Ec2ClientVpnEndpointConnectionLogOptions.go
- Ec2ClientVpnEndpointConnectionLogOptionsOutputReference.go
- Ec2ClientVpnEndpointConnectionLogOptionsOutputReference__checks.go
- Ec2ClientVpnEndpoint__checks.go
- main.go