Documentation
¶
Index ¶
- func EfsFileSystem_IsConstruct(x interface{}) *bool
- func EfsFileSystem_IsTerraformElement(x interface{}) *bool
- func EfsFileSystem_IsTerraformResource(x interface{}) *bool
- func EfsFileSystem_TfResourceType() *string
- func NewEfsFileSystemLifecyclePolicyList_Override(e EfsFileSystemLifecyclePolicyList, ...)
- func NewEfsFileSystemLifecyclePolicyOutputReference_Override(e EfsFileSystemLifecyclePolicyOutputReference, ...)
- func NewEfsFileSystemSizeInBytesList_Override(e EfsFileSystemSizeInBytesList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewEfsFileSystemSizeInBytesOutputReference_Override(e EfsFileSystemSizeInBytesOutputReference, ...)
- func NewEfsFileSystem_Override(e EfsFileSystem, scope constructs.Construct, id *string, ...)
- type EfsFileSystem
- type EfsFileSystemConfig
- type EfsFileSystemLifecyclePolicy
- type EfsFileSystemLifecyclePolicyList
- type EfsFileSystemLifecyclePolicyOutputReference
- type EfsFileSystemSizeInBytes
- type EfsFileSystemSizeInBytesList
- type EfsFileSystemSizeInBytesOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EfsFileSystem_IsConstruct ¶
func EfsFileSystem_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func EfsFileSystem_IsTerraformElement ¶
func EfsFileSystem_IsTerraformElement(x interface{}) *bool
Experimental.
func EfsFileSystem_IsTerraformResource ¶
func EfsFileSystem_IsTerraformResource(x interface{}) *bool
Experimental.
func EfsFileSystem_TfResourceType ¶
func EfsFileSystem_TfResourceType() *string
func NewEfsFileSystemLifecyclePolicyList_Override ¶
func NewEfsFileSystemLifecyclePolicyList_Override(e EfsFileSystemLifecyclePolicyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEfsFileSystemLifecyclePolicyOutputReference_Override ¶
func NewEfsFileSystemLifecyclePolicyOutputReference_Override(e EfsFileSystemLifecyclePolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEfsFileSystemSizeInBytesList_Override ¶
func NewEfsFileSystemSizeInBytesList_Override(e EfsFileSystemSizeInBytesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEfsFileSystemSizeInBytesOutputReference_Override ¶
func NewEfsFileSystemSizeInBytesOutputReference_Override(e EfsFileSystemSizeInBytesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEfsFileSystem_Override ¶
func NewEfsFileSystem_Override(e EfsFileSystem, scope constructs.Construct, id *string, config *EfsFileSystemConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system aws_efs_file_system} Resource.
Types ¶
type EfsFileSystem ¶
type EfsFileSystem interface {
cdktf.TerraformResource
Arn() *string
AvailabilityZoneId() *string
AvailabilityZoneName() *string
SetAvailabilityZoneName(val *string)
AvailabilityZoneNameInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreationToken() *string
SetCreationToken(val *string)
CreationTokenInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DnsName() *string
Encrypted() interface{}
SetEncrypted(val interface{})
EncryptedInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LifecyclePolicy() EfsFileSystemLifecyclePolicyList
LifecyclePolicyInput() interface{}
// The tree node.
Node() constructs.Node
NumberOfMountTargets() *float64
OwnerId() *string
PerformanceMode() *string
SetPerformanceMode(val *string)
PerformanceModeInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
ProvisionedThroughputInMibps() *float64
SetProvisionedThroughputInMibps(val *float64)
ProvisionedThroughputInMibpsInput() *float64
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SizeInBytes() EfsFileSystemSizeInBytesList
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
ThroughputMode() *string
SetThroughputMode(val *string)
ThroughputModeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutLifecyclePolicy(value interface{})
ResetAvailabilityZoneName()
ResetCreationToken()
ResetEncrypted()
ResetId()
ResetKmsKeyId()
ResetLifecyclePolicy()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPerformanceMode()
ResetProvisionedThroughputInMibps()
ResetTags()
ResetTagsAll()
ResetThroughputMode()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system aws_efs_file_system}.
func NewEfsFileSystem ¶
func NewEfsFileSystem(scope constructs.Construct, id *string, config *EfsFileSystemConfig) EfsFileSystem
Create a new {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system aws_efs_file_system} Resource.
type EfsFileSystemConfig ¶
type EfsFileSystemConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system#availability_zone_name EfsFileSystem#availability_zone_name}.
AvailabilityZoneName *string `field:"optional" json:"availabilityZoneName" yaml:"availabilityZoneName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system#creation_token EfsFileSystem#creation_token}.
CreationToken *string `field:"optional" json:"creationToken" yaml:"creationToken"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system#encrypted EfsFileSystem#encrypted}.
Encrypted interface{} `field:"optional" json:"encrypted" yaml:"encrypted"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system#id EfsFileSystem#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system#kms_key_id EfsFileSystem#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
// lifecycle_policy block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system#lifecycle_policy EfsFileSystem#lifecycle_policy}
LifecyclePolicy interface{} `field:"optional" json:"lifecyclePolicy" yaml:"lifecyclePolicy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system#performance_mode EfsFileSystem#performance_mode}.
PerformanceMode *string `field:"optional" json:"performanceMode" yaml:"performanceMode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system#provisioned_throughput_in_mibps EfsFileSystem#provisioned_throughput_in_mibps}.
ProvisionedThroughputInMibps *float64 `field:"optional" json:"provisionedThroughputInMibps" yaml:"provisionedThroughputInMibps"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system#tags EfsFileSystem#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system#tags_all EfsFileSystem#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system#throughput_mode EfsFileSystem#throughput_mode}.
ThroughputMode *string `field:"optional" json:"throughputMode" yaml:"throughputMode"`
}
type EfsFileSystemLifecyclePolicy ¶
type EfsFileSystemLifecyclePolicy struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system#transition_to_ia EfsFileSystem#transition_to_ia}.
TransitionToIa *string `field:"optional" json:"transitionToIa" yaml:"transitionToIa"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system#transition_to_primary_storage_class EfsFileSystem#transition_to_primary_storage_class}.
TransitionToPrimaryStorageClass *string `field:"optional" json:"transitionToPrimaryStorageClass" yaml:"transitionToPrimaryStorageClass"`
}
type EfsFileSystemLifecyclePolicyList ¶
type EfsFileSystemLifecyclePolicyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EfsFileSystemLifecyclePolicyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEfsFileSystemLifecyclePolicyList ¶
func NewEfsFileSystemLifecyclePolicyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EfsFileSystemLifecyclePolicyList
type EfsFileSystemLifecyclePolicyOutputReference ¶
type EfsFileSystemLifecyclePolicyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TransitionToIa() *string
SetTransitionToIa(val *string)
TransitionToIaInput() *string
TransitionToPrimaryStorageClass() *string
SetTransitionToPrimaryStorageClass(val *string)
TransitionToPrimaryStorageClassInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetTransitionToIa()
ResetTransitionToPrimaryStorageClass()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEfsFileSystemLifecyclePolicyOutputReference ¶
func NewEfsFileSystemLifecyclePolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EfsFileSystemLifecyclePolicyOutputReference
type EfsFileSystemSizeInBytes ¶
type EfsFileSystemSizeInBytes struct {
}
type EfsFileSystemSizeInBytesList ¶
type EfsFileSystemSizeInBytesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EfsFileSystemSizeInBytesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEfsFileSystemSizeInBytesList ¶
func NewEfsFileSystemSizeInBytesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EfsFileSystemSizeInBytesList
type EfsFileSystemSizeInBytesOutputReference ¶
type EfsFileSystemSizeInBytesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EfsFileSystemSizeInBytes
SetInternalValue(val *EfsFileSystemSizeInBytes)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *float64
ValueInIa() *float64
ValueInStandard() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEfsFileSystemSizeInBytesOutputReference ¶
func NewEfsFileSystemSizeInBytesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EfsFileSystemSizeInBytesOutputReference
Source Files
¶
- EfsFileSystem.go
- EfsFileSystemConfig.go
- EfsFileSystemLifecyclePolicy.go
- EfsFileSystemLifecyclePolicyList.go
- EfsFileSystemLifecyclePolicyList__checks.go
- EfsFileSystemLifecyclePolicyOutputReference.go
- EfsFileSystemLifecyclePolicyOutputReference__checks.go
- EfsFileSystemSizeInBytes.go
- EfsFileSystemSizeInBytesList.go
- EfsFileSystemSizeInBytesList__checks.go
- EfsFileSystemSizeInBytesOutputReference.go
- EfsFileSystemSizeInBytesOutputReference__checks.go
- EfsFileSystem__checks.go
- main.go