Documentation
¶
Index ¶
- func ElastictranscoderPipeline_IsConstruct(x interface{}) *bool
- func ElastictranscoderPipeline_IsTerraformElement(x interface{}) *bool
- func ElastictranscoderPipeline_IsTerraformResource(x interface{}) *bool
- func ElastictranscoderPipeline_TfResourceType() *string
- func NewElastictranscoderPipelineContentConfigOutputReference_Override(e ElastictranscoderPipelineContentConfigOutputReference, ...)
- func NewElastictranscoderPipelineContentConfigPermissionsList_Override(e ElastictranscoderPipelineContentConfigPermissionsList, ...)
- func NewElastictranscoderPipelineContentConfigPermissionsOutputReference_Override(e ElastictranscoderPipelineContentConfigPermissionsOutputReference, ...)
- func NewElastictranscoderPipelineNotificationsOutputReference_Override(e ElastictranscoderPipelineNotificationsOutputReference, ...)
- func NewElastictranscoderPipelineThumbnailConfigOutputReference_Override(e ElastictranscoderPipelineThumbnailConfigOutputReference, ...)
- func NewElastictranscoderPipelineThumbnailConfigPermissionsList_Override(e ElastictranscoderPipelineThumbnailConfigPermissionsList, ...)
- func NewElastictranscoderPipelineThumbnailConfigPermissionsOutputReference_Override(e ElastictranscoderPipelineThumbnailConfigPermissionsOutputReference, ...)
- func NewElastictranscoderPipeline_Override(e ElastictranscoderPipeline, scope constructs.Construct, id *string, ...)
- type ElastictranscoderPipeline
- type ElastictranscoderPipelineConfig
- type ElastictranscoderPipelineContentConfig
- type ElastictranscoderPipelineContentConfigOutputReference
- type ElastictranscoderPipelineContentConfigPermissions
- type ElastictranscoderPipelineContentConfigPermissionsList
- type ElastictranscoderPipelineContentConfigPermissionsOutputReference
- type ElastictranscoderPipelineNotifications
- type ElastictranscoderPipelineNotificationsOutputReference
- type ElastictranscoderPipelineThumbnailConfig
- type ElastictranscoderPipelineThumbnailConfigOutputReference
- type ElastictranscoderPipelineThumbnailConfigPermissions
- type ElastictranscoderPipelineThumbnailConfigPermissionsList
- type ElastictranscoderPipelineThumbnailConfigPermissionsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ElastictranscoderPipeline_IsConstruct ¶
func ElastictranscoderPipeline_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ElastictranscoderPipeline_IsTerraformElement ¶
func ElastictranscoderPipeline_IsTerraformElement(x interface{}) *bool
Experimental.
func ElastictranscoderPipeline_IsTerraformResource ¶
func ElastictranscoderPipeline_IsTerraformResource(x interface{}) *bool
Experimental.
func ElastictranscoderPipeline_TfResourceType ¶
func ElastictranscoderPipeline_TfResourceType() *string
func NewElastictranscoderPipelineContentConfigOutputReference_Override ¶
func NewElastictranscoderPipelineContentConfigOutputReference_Override(e ElastictranscoderPipelineContentConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewElastictranscoderPipelineContentConfigPermissionsList_Override ¶
func NewElastictranscoderPipelineContentConfigPermissionsList_Override(e ElastictranscoderPipelineContentConfigPermissionsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewElastictranscoderPipelineContentConfigPermissionsOutputReference_Override ¶
func NewElastictranscoderPipelineContentConfigPermissionsOutputReference_Override(e ElastictranscoderPipelineContentConfigPermissionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewElastictranscoderPipelineNotificationsOutputReference_Override ¶
func NewElastictranscoderPipelineNotificationsOutputReference_Override(e ElastictranscoderPipelineNotificationsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewElastictranscoderPipelineThumbnailConfigOutputReference_Override ¶
func NewElastictranscoderPipelineThumbnailConfigOutputReference_Override(e ElastictranscoderPipelineThumbnailConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewElastictranscoderPipelineThumbnailConfigPermissionsList_Override ¶
func NewElastictranscoderPipelineThumbnailConfigPermissionsList_Override(e ElastictranscoderPipelineThumbnailConfigPermissionsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewElastictranscoderPipelineThumbnailConfigPermissionsOutputReference_Override ¶
func NewElastictranscoderPipelineThumbnailConfigPermissionsOutputReference_Override(e ElastictranscoderPipelineThumbnailConfigPermissionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewElastictranscoderPipeline_Override ¶
func NewElastictranscoderPipeline_Override(e ElastictranscoderPipeline, scope constructs.Construct, id *string, config *ElastictranscoderPipelineConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline aws_elastictranscoder_pipeline} Resource.
Types ¶
type ElastictranscoderPipeline ¶
type ElastictranscoderPipeline interface {
cdktf.TerraformResource
Arn() *string
AwsKmsKeyArn() *string
SetAwsKmsKeyArn(val *string)
AwsKmsKeyArnInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ContentConfig() ElastictranscoderPipelineContentConfigOutputReference
ContentConfigInput() *ElastictranscoderPipelineContentConfig
ContentConfigPermissions() ElastictranscoderPipelineContentConfigPermissionsList
ContentConfigPermissionsInput() interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InputBucket() *string
SetInputBucket(val *string)
InputBucketInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Notifications() ElastictranscoderPipelineNotificationsOutputReference
NotificationsInput() *ElastictranscoderPipelineNotifications
OutputBucket() *string
SetOutputBucket(val *string)
OutputBucketInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Role() *string
SetRole(val *string)
RoleInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
ThumbnailConfig() ElastictranscoderPipelineThumbnailConfigOutputReference
ThumbnailConfigInput() *ElastictranscoderPipelineThumbnailConfig
ThumbnailConfigPermissions() ElastictranscoderPipelineThumbnailConfigPermissionsList
ThumbnailConfigPermissionsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutContentConfig(value *ElastictranscoderPipelineContentConfig)
PutContentConfigPermissions(value interface{})
PutNotifications(value *ElastictranscoderPipelineNotifications)
PutThumbnailConfig(value *ElastictranscoderPipelineThumbnailConfig)
PutThumbnailConfigPermissions(value interface{})
ResetAwsKmsKeyArn()
ResetContentConfig()
ResetContentConfigPermissions()
ResetId()
ResetName()
ResetNotifications()
ResetOutputBucket()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetThumbnailConfig()
ResetThumbnailConfigPermissions()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline aws_elastictranscoder_pipeline}.
func NewElastictranscoderPipeline ¶
func NewElastictranscoderPipeline(scope constructs.Construct, id *string, config *ElastictranscoderPipelineConfig) ElastictranscoderPipeline
Create a new {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline aws_elastictranscoder_pipeline} Resource.
type ElastictranscoderPipelineConfig ¶
type ElastictranscoderPipelineConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#input_bucket ElastictranscoderPipeline#input_bucket}.
InputBucket *string `field:"required" json:"inputBucket" yaml:"inputBucket"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#role ElastictranscoderPipeline#role}.
Role *string `field:"required" json:"role" yaml:"role"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#aws_kms_key_arn ElastictranscoderPipeline#aws_kms_key_arn}.
AwsKmsKeyArn *string `field:"optional" json:"awsKmsKeyArn" yaml:"awsKmsKeyArn"`
// content_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#content_config ElastictranscoderPipeline#content_config}
ContentConfig *ElastictranscoderPipelineContentConfig `field:"optional" json:"contentConfig" yaml:"contentConfig"`
// content_config_permissions block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#content_config_permissions ElastictranscoderPipeline#content_config_permissions}
ContentConfigPermissions interface{} `field:"optional" json:"contentConfigPermissions" yaml:"contentConfigPermissions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#id ElastictranscoderPipeline#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#name ElastictranscoderPipeline#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// notifications block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#notifications ElastictranscoderPipeline#notifications}
Notifications *ElastictranscoderPipelineNotifications `field:"optional" json:"notifications" yaml:"notifications"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#output_bucket ElastictranscoderPipeline#output_bucket}.
OutputBucket *string `field:"optional" json:"outputBucket" yaml:"outputBucket"`
// thumbnail_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#thumbnail_config ElastictranscoderPipeline#thumbnail_config}
ThumbnailConfig *ElastictranscoderPipelineThumbnailConfig `field:"optional" json:"thumbnailConfig" yaml:"thumbnailConfig"`
// thumbnail_config_permissions block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#thumbnail_config_permissions ElastictranscoderPipeline#thumbnail_config_permissions}
ThumbnailConfigPermissions interface{} `field:"optional" json:"thumbnailConfigPermissions" yaml:"thumbnailConfigPermissions"`
}
type ElastictranscoderPipelineContentConfig ¶
type ElastictranscoderPipelineContentConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#bucket ElastictranscoderPipeline#bucket}.
Bucket *string `field:"optional" json:"bucket" yaml:"bucket"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#storage_class ElastictranscoderPipeline#storage_class}.
StorageClass *string `field:"optional" json:"storageClass" yaml:"storageClass"`
}
type ElastictranscoderPipelineContentConfigOutputReference ¶
type ElastictranscoderPipelineContentConfigOutputReference interface {
cdktf.ComplexObject
Bucket() *string
SetBucket(val *string)
BucketInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ElastictranscoderPipelineContentConfig
SetInternalValue(val *ElastictranscoderPipelineContentConfig)
StorageClass() *string
SetStorageClass(val *string)
StorageClassInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBucket()
ResetStorageClass()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElastictranscoderPipelineContentConfigOutputReference ¶
func NewElastictranscoderPipelineContentConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ElastictranscoderPipelineContentConfigOutputReference
type ElastictranscoderPipelineContentConfigPermissions ¶
type ElastictranscoderPipelineContentConfigPermissions struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#access ElastictranscoderPipeline#access}.
Access *[]*string `field:"optional" json:"access" yaml:"access"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#grantee ElastictranscoderPipeline#grantee}.
Grantee *string `field:"optional" json:"grantee" yaml:"grantee"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#grantee_type ElastictranscoderPipeline#grantee_type}.
GranteeType *string `field:"optional" json:"granteeType" yaml:"granteeType"`
}
type ElastictranscoderPipelineContentConfigPermissionsList ¶
type ElastictranscoderPipelineContentConfigPermissionsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ElastictranscoderPipelineContentConfigPermissionsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElastictranscoderPipelineContentConfigPermissionsList ¶
func NewElastictranscoderPipelineContentConfigPermissionsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ElastictranscoderPipelineContentConfigPermissionsList
type ElastictranscoderPipelineContentConfigPermissionsOutputReference ¶
type ElastictranscoderPipelineContentConfigPermissionsOutputReference interface {
cdktf.ComplexObject
Access() *[]*string
SetAccess(val *[]*string)
AccessInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Grantee() *string
SetGrantee(val *string)
GranteeInput() *string
GranteeType() *string
SetGranteeType(val *string)
GranteeTypeInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAccess()
ResetGrantee()
ResetGranteeType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElastictranscoderPipelineContentConfigPermissionsOutputReference ¶
func NewElastictranscoderPipelineContentConfigPermissionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ElastictranscoderPipelineContentConfigPermissionsOutputReference
type ElastictranscoderPipelineNotifications ¶
type ElastictranscoderPipelineNotifications struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#completed ElastictranscoderPipeline#completed}.
Completed *string `field:"optional" json:"completed" yaml:"completed"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#error ElastictranscoderPipeline#error}.
Error *string `field:"optional" json:"error" yaml:"error"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#progressing ElastictranscoderPipeline#progressing}.
Progressing *string `field:"optional" json:"progressing" yaml:"progressing"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#warning ElastictranscoderPipeline#warning}.
Warning *string `field:"optional" json:"warning" yaml:"warning"`
}
type ElastictranscoderPipelineNotificationsOutputReference ¶
type ElastictranscoderPipelineNotificationsOutputReference interface {
cdktf.ComplexObject
Completed() *string
SetCompleted(val *string)
CompletedInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Error() *string
SetError(val *string)
ErrorInput() *string
// Experimental.
Fqn() *string
InternalValue() *ElastictranscoderPipelineNotifications
SetInternalValue(val *ElastictranscoderPipelineNotifications)
Progressing() *string
SetProgressing(val *string)
ProgressingInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Warning() *string
SetWarning(val *string)
WarningInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCompleted()
ResetError()
ResetProgressing()
ResetWarning()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElastictranscoderPipelineNotificationsOutputReference ¶
func NewElastictranscoderPipelineNotificationsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ElastictranscoderPipelineNotificationsOutputReference
type ElastictranscoderPipelineThumbnailConfig ¶
type ElastictranscoderPipelineThumbnailConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#bucket ElastictranscoderPipeline#bucket}.
Bucket *string `field:"optional" json:"bucket" yaml:"bucket"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#storage_class ElastictranscoderPipeline#storage_class}.
StorageClass *string `field:"optional" json:"storageClass" yaml:"storageClass"`
}
type ElastictranscoderPipelineThumbnailConfigOutputReference ¶
type ElastictranscoderPipelineThumbnailConfigOutputReference interface {
cdktf.ComplexObject
Bucket() *string
SetBucket(val *string)
BucketInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ElastictranscoderPipelineThumbnailConfig
SetInternalValue(val *ElastictranscoderPipelineThumbnailConfig)
StorageClass() *string
SetStorageClass(val *string)
StorageClassInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBucket()
ResetStorageClass()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElastictranscoderPipelineThumbnailConfigOutputReference ¶
func NewElastictranscoderPipelineThumbnailConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ElastictranscoderPipelineThumbnailConfigOutputReference
type ElastictranscoderPipelineThumbnailConfigPermissions ¶
type ElastictranscoderPipelineThumbnailConfigPermissions struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#access ElastictranscoderPipeline#access}.
Access *[]*string `field:"optional" json:"access" yaml:"access"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#grantee ElastictranscoderPipeline#grantee}.
Grantee *string `field:"optional" json:"grantee" yaml:"grantee"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#grantee_type ElastictranscoderPipeline#grantee_type}.
GranteeType *string `field:"optional" json:"granteeType" yaml:"granteeType"`
}
type ElastictranscoderPipelineThumbnailConfigPermissionsList ¶
type ElastictranscoderPipelineThumbnailConfigPermissionsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ElastictranscoderPipelineThumbnailConfigPermissionsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElastictranscoderPipelineThumbnailConfigPermissionsList ¶
func NewElastictranscoderPipelineThumbnailConfigPermissionsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ElastictranscoderPipelineThumbnailConfigPermissionsList
type ElastictranscoderPipelineThumbnailConfigPermissionsOutputReference ¶
type ElastictranscoderPipelineThumbnailConfigPermissionsOutputReference interface {
cdktf.ComplexObject
Access() *[]*string
SetAccess(val *[]*string)
AccessInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Grantee() *string
SetGrantee(val *string)
GranteeInput() *string
GranteeType() *string
SetGranteeType(val *string)
GranteeTypeInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAccess()
ResetGrantee()
ResetGranteeType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElastictranscoderPipelineThumbnailConfigPermissionsOutputReference ¶
func NewElastictranscoderPipelineThumbnailConfigPermissionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ElastictranscoderPipelineThumbnailConfigPermissionsOutputReference
Source Files
¶
- ElastictranscoderPipeline.go
- ElastictranscoderPipelineConfig.go
- ElastictranscoderPipelineContentConfig.go
- ElastictranscoderPipelineContentConfigOutputReference.go
- ElastictranscoderPipelineContentConfigOutputReference__checks.go
- ElastictranscoderPipelineContentConfigPermissions.go
- ElastictranscoderPipelineContentConfigPermissionsList.go
- ElastictranscoderPipelineContentConfigPermissionsList__checks.go
- ElastictranscoderPipelineContentConfigPermissionsOutputReference.go
- ElastictranscoderPipelineContentConfigPermissionsOutputReference__checks.go
- ElastictranscoderPipelineNotifications.go
- ElastictranscoderPipelineNotificationsOutputReference.go
- ElastictranscoderPipelineNotificationsOutputReference__checks.go
- ElastictranscoderPipelineThumbnailConfig.go
- ElastictranscoderPipelineThumbnailConfigOutputReference.go
- ElastictranscoderPipelineThumbnailConfigOutputReference__checks.go
- ElastictranscoderPipelineThumbnailConfigPermissions.go
- ElastictranscoderPipelineThumbnailConfigPermissionsList.go
- ElastictranscoderPipelineThumbnailConfigPermissionsList__checks.go
- ElastictranscoderPipelineThumbnailConfigPermissionsOutputReference.go
- ElastictranscoderPipelineThumbnailConfigPermissionsOutputReference__checks.go
- ElastictranscoderPipeline__checks.go
- main.go