Documentation
¶
Index ¶
- func Elb_IsConstruct(x interface{}) *bool
- func Elb_IsTerraformElement(x interface{}) *bool
- func Elb_IsTerraformResource(x interface{}) *bool
- func Elb_TfResourceType() *string
- func NewElbAccessLogsOutputReference_Override(e ElbAccessLogsOutputReference, terraformResource cdktf.IInterpolatingParent, ...)
- func NewElbHealthCheckOutputReference_Override(e ElbHealthCheckOutputReference, terraformResource cdktf.IInterpolatingParent, ...)
- func NewElbListenerList_Override(e ElbListenerList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewElbListenerOutputReference_Override(e ElbListenerOutputReference, terraformResource cdktf.IInterpolatingParent, ...)
- func NewElb_Override(e Elb, scope constructs.Construct, id *string, config *ElbConfig)
- type Elb
- type ElbAccessLogs
- type ElbAccessLogsOutputReference
- type ElbConfig
- type ElbHealthCheck
- type ElbHealthCheckOutputReference
- type ElbListener
- type ElbListenerList
- type ElbListenerOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Elb_IsConstruct ¶
func Elb_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func Elb_TfResourceType ¶
func Elb_TfResourceType() *string
func NewElbAccessLogsOutputReference_Override ¶
func NewElbAccessLogsOutputReference_Override(e ElbAccessLogsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewElbHealthCheckOutputReference_Override ¶
func NewElbHealthCheckOutputReference_Override(e ElbHealthCheckOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewElbListenerList_Override ¶
func NewElbListenerList_Override(e ElbListenerList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewElbListenerOutputReference_Override ¶
func NewElbListenerOutputReference_Override(e ElbListenerOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewElb_Override ¶
func NewElb_Override(e Elb, scope constructs.Construct, id *string, config *ElbConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/elb aws_elb} Resource.
Types ¶
type Elb ¶
type Elb interface {
cdktf.TerraformResource
AccessLogs() ElbAccessLogsOutputReference
AccessLogsInput() *ElbAccessLogs
Arn() *string
AvailabilityZones() *[]*string
SetAvailabilityZones(val *[]*string)
AvailabilityZonesInput() *[]*string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
ConnectionDraining() interface{}
SetConnectionDraining(val interface{})
ConnectionDrainingInput() interface{}
ConnectionDrainingTimeout() *float64
SetConnectionDrainingTimeout(val *float64)
ConnectionDrainingTimeoutInput() *float64
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CrossZoneLoadBalancing() interface{}
SetCrossZoneLoadBalancing(val interface{})
CrossZoneLoadBalancingInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DesyncMitigationMode() *string
SetDesyncMitigationMode(val *string)
DesyncMitigationModeInput() *string
DnsName() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HealthCheck() ElbHealthCheckOutputReference
HealthCheckInput() *ElbHealthCheck
Id() *string
SetId(val *string)
IdInput() *string
IdleTimeout() *float64
SetIdleTimeout(val *float64)
IdleTimeoutInput() *float64
Instances() *[]*string
SetInstances(val *[]*string)
InstancesInput() *[]*string
Internal() interface{}
SetInternal(val interface{})
InternalInput() interface{}
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Listener() ElbListenerList
ListenerInput() interface{}
Name() *string
SetName(val *string)
NameInput() *string
NamePrefix() *string
SetNamePrefix(val *string)
NamePrefixInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SecurityGroups() *[]*string
SetSecurityGroups(val *[]*string)
SecurityGroupsInput() *[]*string
SourceSecurityGroup() *string
SetSourceSecurityGroup(val *string)
SourceSecurityGroupId() *string
SourceSecurityGroupInput() *string
Subnets() *[]*string
SetSubnets(val *[]*string)
SubnetsInput() *[]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
ZoneId() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAccessLogs(value *ElbAccessLogs)
PutHealthCheck(value *ElbHealthCheck)
PutListener(value interface{})
ResetAccessLogs()
ResetAvailabilityZones()
ResetConnectionDraining()
ResetConnectionDrainingTimeout()
ResetCrossZoneLoadBalancing()
ResetDesyncMitigationMode()
ResetHealthCheck()
ResetId()
ResetIdleTimeout()
ResetInstances()
ResetInternal()
ResetName()
ResetNamePrefix()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSecurityGroups()
ResetSourceSecurityGroup()
ResetSubnets()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/elb aws_elb}.
func NewElb ¶
func NewElb(scope constructs.Construct, id *string, config *ElbConfig) Elb
Create a new {@link https://www.terraform.io/docs/providers/aws/r/elb aws_elb} Resource.
type ElbAccessLogs ¶
type ElbAccessLogs struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#bucket Elb#bucket}.
Bucket *string `field:"required" json:"bucket" yaml:"bucket"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#bucket_prefix Elb#bucket_prefix}.
BucketPrefix *string `field:"optional" json:"bucketPrefix" yaml:"bucketPrefix"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#enabled Elb#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#interval Elb#interval}.
Interval *float64 `field:"optional" json:"interval" yaml:"interval"`
}
type ElbAccessLogsOutputReference ¶
type ElbAccessLogsOutputReference interface {
cdktf.ComplexObject
Bucket() *string
SetBucket(val *string)
BucketInput() *string
BucketPrefix() *string
SetBucketPrefix(val *string)
BucketPrefixInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *ElbAccessLogs
SetInternalValue(val *ElbAccessLogs)
Interval() *float64
SetInterval(val *float64)
IntervalInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBucketPrefix()
ResetEnabled()
ResetInterval()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElbAccessLogsOutputReference ¶
func NewElbAccessLogsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ElbAccessLogsOutputReference
type ElbConfig ¶
type ElbConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// listener block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#listener Elb#listener}
Listener interface{} `field:"required" json:"listener" yaml:"listener"`
// access_logs block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#access_logs Elb#access_logs}
AccessLogs *ElbAccessLogs `field:"optional" json:"accessLogs" yaml:"accessLogs"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#availability_zones Elb#availability_zones}.
AvailabilityZones *[]*string `field:"optional" json:"availabilityZones" yaml:"availabilityZones"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#connection_draining Elb#connection_draining}.
ConnectionDraining interface{} `field:"optional" json:"connectionDraining" yaml:"connectionDraining"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#connection_draining_timeout Elb#connection_draining_timeout}.
ConnectionDrainingTimeout *float64 `field:"optional" json:"connectionDrainingTimeout" yaml:"connectionDrainingTimeout"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#cross_zone_load_balancing Elb#cross_zone_load_balancing}.
CrossZoneLoadBalancing interface{} `field:"optional" json:"crossZoneLoadBalancing" yaml:"crossZoneLoadBalancing"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#desync_mitigation_mode Elb#desync_mitigation_mode}.
DesyncMitigationMode *string `field:"optional" json:"desyncMitigationMode" yaml:"desyncMitigationMode"`
// health_check block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#health_check Elb#health_check}
HealthCheck *ElbHealthCheck `field:"optional" json:"healthCheck" yaml:"healthCheck"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#id Elb#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#idle_timeout Elb#idle_timeout}.
IdleTimeout *float64 `field:"optional" json:"idleTimeout" yaml:"idleTimeout"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#instances Elb#instances}.
Instances *[]*string `field:"optional" json:"instances" yaml:"instances"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#internal Elb#internal}.
Internal interface{} `field:"optional" json:"internal" yaml:"internal"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#name Elb#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#name_prefix Elb#name_prefix}.
NamePrefix *string `field:"optional" json:"namePrefix" yaml:"namePrefix"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#security_groups Elb#security_groups}.
SecurityGroups *[]*string `field:"optional" json:"securityGroups" yaml:"securityGroups"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#source_security_group Elb#source_security_group}.
SourceSecurityGroup *string `field:"optional" json:"sourceSecurityGroup" yaml:"sourceSecurityGroup"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#subnets Elb#subnets}.
Subnets *[]*string `field:"optional" json:"subnets" yaml:"subnets"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#tags Elb#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#tags_all Elb#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type ElbHealthCheck ¶
type ElbHealthCheck struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#healthy_threshold Elb#healthy_threshold}.
HealthyThreshold *float64 `field:"required" json:"healthyThreshold" yaml:"healthyThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#interval Elb#interval}.
Interval *float64 `field:"required" json:"interval" yaml:"interval"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#target Elb#target}.
Target *string `field:"required" json:"target" yaml:"target"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#timeout Elb#timeout}.
Timeout *float64 `field:"required" json:"timeout" yaml:"timeout"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#unhealthy_threshold Elb#unhealthy_threshold}.
UnhealthyThreshold *float64 `field:"required" json:"unhealthyThreshold" yaml:"unhealthyThreshold"`
}
type ElbHealthCheckOutputReference ¶
type ElbHealthCheckOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HealthyThreshold() *float64
SetHealthyThreshold(val *float64)
HealthyThresholdInput() *float64
InternalValue() *ElbHealthCheck
SetInternalValue(val *ElbHealthCheck)
Interval() *float64
SetInterval(val *float64)
IntervalInput() *float64
Target() *string
SetTarget(val *string)
TargetInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Timeout() *float64
SetTimeout(val *float64)
TimeoutInput() *float64
UnhealthyThreshold() *float64
SetUnhealthyThreshold(val *float64)
UnhealthyThresholdInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElbHealthCheckOutputReference ¶
func NewElbHealthCheckOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ElbHealthCheckOutputReference
type ElbListener ¶
type ElbListener struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#instance_port Elb#instance_port}.
InstancePort *float64 `field:"required" json:"instancePort" yaml:"instancePort"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#instance_protocol Elb#instance_protocol}.
InstanceProtocol *string `field:"required" json:"instanceProtocol" yaml:"instanceProtocol"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#lb_port Elb#lb_port}.
LbPort *float64 `field:"required" json:"lbPort" yaml:"lbPort"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#lb_protocol Elb#lb_protocol}.
LbProtocol *string `field:"required" json:"lbProtocol" yaml:"lbProtocol"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb#ssl_certificate_id Elb#ssl_certificate_id}.
SslCertificateId *string `field:"optional" json:"sslCertificateId" yaml:"sslCertificateId"`
}
type ElbListenerList ¶
type ElbListenerList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ElbListenerOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElbListenerList ¶
func NewElbListenerList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ElbListenerList
type ElbListenerOutputReference ¶
type ElbListenerOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InstancePort() *float64
SetInstancePort(val *float64)
InstancePortInput() *float64
InstanceProtocol() *string
SetInstanceProtocol(val *string)
InstanceProtocolInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
LbPort() *float64
SetLbPort(val *float64)
LbPortInput() *float64
LbProtocol() *string
SetLbProtocol(val *string)
LbProtocolInput() *string
SslCertificateId() *string
SetSslCertificateId(val *string)
SslCertificateIdInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetSslCertificateId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElbListenerOutputReference ¶
func NewElbListenerOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ElbListenerOutputReference
Source Files
¶
- Elb.go
- ElbAccessLogs.go
- ElbAccessLogsOutputReference.go
- ElbAccessLogsOutputReference__checks.go
- ElbConfig.go
- ElbHealthCheck.go
- ElbHealthCheckOutputReference.go
- ElbHealthCheckOutputReference__checks.go
- ElbListener.go
- ElbListenerList.go
- ElbListenerList__checks.go
- ElbListenerOutputReference.go
- ElbListenerOutputReference__checks.go
- Elb__checks.go
- main.go