Documentation
¶
Index ¶
- func EvidentlyProject_IsConstruct(x interface{}) *bool
- func EvidentlyProject_IsTerraformElement(x interface{}) *bool
- func EvidentlyProject_IsTerraformResource(x interface{}) *bool
- func EvidentlyProject_TfResourceType() *string
- func NewEvidentlyProjectDataDeliveryCloudwatchLogsOutputReference_Override(e EvidentlyProjectDataDeliveryCloudwatchLogsOutputReference, ...)
- func NewEvidentlyProjectDataDeliveryOutputReference_Override(e EvidentlyProjectDataDeliveryOutputReference, ...)
- func NewEvidentlyProjectDataDeliveryS3DestinationOutputReference_Override(e EvidentlyProjectDataDeliveryS3DestinationOutputReference, ...)
- func NewEvidentlyProjectTimeoutsOutputReference_Override(e EvidentlyProjectTimeoutsOutputReference, ...)
- func NewEvidentlyProject_Override(e EvidentlyProject, scope constructs.Construct, id *string, ...)
- type EvidentlyProject
- type EvidentlyProjectConfig
- type EvidentlyProjectDataDelivery
- type EvidentlyProjectDataDeliveryCloudwatchLogs
- type EvidentlyProjectDataDeliveryCloudwatchLogsOutputReference
- type EvidentlyProjectDataDeliveryOutputReference
- type EvidentlyProjectDataDeliveryS3Destination
- type EvidentlyProjectDataDeliveryS3DestinationOutputReference
- type EvidentlyProjectTimeouts
- type EvidentlyProjectTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EvidentlyProject_IsConstruct ¶
func EvidentlyProject_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func EvidentlyProject_IsTerraformElement ¶
func EvidentlyProject_IsTerraformElement(x interface{}) *bool
Experimental.
func EvidentlyProject_IsTerraformResource ¶
func EvidentlyProject_IsTerraformResource(x interface{}) *bool
Experimental.
func EvidentlyProject_TfResourceType ¶
func EvidentlyProject_TfResourceType() *string
func NewEvidentlyProjectDataDeliveryCloudwatchLogsOutputReference_Override ¶
func NewEvidentlyProjectDataDeliveryCloudwatchLogsOutputReference_Override(e EvidentlyProjectDataDeliveryCloudwatchLogsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEvidentlyProjectDataDeliveryOutputReference_Override ¶
func NewEvidentlyProjectDataDeliveryOutputReference_Override(e EvidentlyProjectDataDeliveryOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEvidentlyProjectDataDeliveryS3DestinationOutputReference_Override ¶
func NewEvidentlyProjectDataDeliveryS3DestinationOutputReference_Override(e EvidentlyProjectDataDeliveryS3DestinationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEvidentlyProjectTimeoutsOutputReference_Override ¶
func NewEvidentlyProjectTimeoutsOutputReference_Override(e EvidentlyProjectTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEvidentlyProject_Override ¶
func NewEvidentlyProject_Override(e EvidentlyProject, scope constructs.Construct, id *string, config *EvidentlyProjectConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/evidently_project aws_evidently_project} Resource.
Types ¶
type EvidentlyProject ¶
type EvidentlyProject interface {
cdktf.TerraformResource
ActiveExperimentCount() *float64
ActiveLaunchCount() *float64
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreatedTime() *string
DataDelivery() EvidentlyProjectDataDeliveryOutputReference
DataDeliveryInput() *EvidentlyProjectDataDelivery
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
ExperimentCount() *float64
FeatureCount() *float64
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
LastUpdatedTime() *string
LaunchCount() *float64
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Status() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() EvidentlyProjectTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDataDelivery(value *EvidentlyProjectDataDelivery)
PutTimeouts(value *EvidentlyProjectTimeouts)
ResetDataDelivery()
ResetDescription()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/evidently_project aws_evidently_project}.
func NewEvidentlyProject ¶
func NewEvidentlyProject(scope constructs.Construct, id *string, config *EvidentlyProjectConfig) EvidentlyProject
Create a new {@link https://www.terraform.io/docs/providers/aws/r/evidently_project aws_evidently_project} Resource.
type EvidentlyProjectConfig ¶
type EvidentlyProjectConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/evidently_project#name EvidentlyProject#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// data_delivery block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/evidently_project#data_delivery EvidentlyProject#data_delivery}
DataDelivery *EvidentlyProjectDataDelivery `field:"optional" json:"dataDelivery" yaml:"dataDelivery"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/evidently_project#description EvidentlyProject#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/evidently_project#id EvidentlyProject#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/evidently_project#tags EvidentlyProject#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/evidently_project#tags_all EvidentlyProject#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/evidently_project#timeouts EvidentlyProject#timeouts}
Timeouts *EvidentlyProjectTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type EvidentlyProjectDataDelivery ¶
type EvidentlyProjectDataDelivery struct {
// cloudwatch_logs block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/evidently_project#cloudwatch_logs EvidentlyProject#cloudwatch_logs}
CloudwatchLogs *EvidentlyProjectDataDeliveryCloudwatchLogs `field:"optional" json:"cloudwatchLogs" yaml:"cloudwatchLogs"`
// s3_destination block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/evidently_project#s3_destination EvidentlyProject#s3_destination}
S3Destination *EvidentlyProjectDataDeliveryS3Destination `field:"optional" json:"s3Destination" yaml:"s3Destination"`
}
type EvidentlyProjectDataDeliveryCloudwatchLogs ¶
type EvidentlyProjectDataDeliveryCloudwatchLogs struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/evidently_project#log_group EvidentlyProject#log_group}.
LogGroup *string `field:"optional" json:"logGroup" yaml:"logGroup"`
}
type EvidentlyProjectDataDeliveryCloudwatchLogsOutputReference ¶
type EvidentlyProjectDataDeliveryCloudwatchLogsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EvidentlyProjectDataDeliveryCloudwatchLogs
SetInternalValue(val *EvidentlyProjectDataDeliveryCloudwatchLogs)
LogGroup() *string
SetLogGroup(val *string)
LogGroupInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetLogGroup()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyProjectDataDeliveryCloudwatchLogsOutputReference ¶
func NewEvidentlyProjectDataDeliveryCloudwatchLogsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EvidentlyProjectDataDeliveryCloudwatchLogsOutputReference
type EvidentlyProjectDataDeliveryOutputReference ¶
type EvidentlyProjectDataDeliveryOutputReference interface {
cdktf.ComplexObject
CloudwatchLogs() EvidentlyProjectDataDeliveryCloudwatchLogsOutputReference
CloudwatchLogsInput() *EvidentlyProjectDataDeliveryCloudwatchLogs
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EvidentlyProjectDataDelivery
SetInternalValue(val *EvidentlyProjectDataDelivery)
S3Destination() EvidentlyProjectDataDeliveryS3DestinationOutputReference
S3DestinationInput() *EvidentlyProjectDataDeliveryS3Destination
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutCloudwatchLogs(value *EvidentlyProjectDataDeliveryCloudwatchLogs)
PutS3Destination(value *EvidentlyProjectDataDeliveryS3Destination)
ResetCloudwatchLogs()
ResetS3Destination()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyProjectDataDeliveryOutputReference ¶
func NewEvidentlyProjectDataDeliveryOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EvidentlyProjectDataDeliveryOutputReference
type EvidentlyProjectDataDeliveryS3Destination ¶
type EvidentlyProjectDataDeliveryS3Destination struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/evidently_project#bucket EvidentlyProject#bucket}.
Bucket *string `field:"optional" json:"bucket" yaml:"bucket"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/evidently_project#prefix EvidentlyProject#prefix}.
Prefix *string `field:"optional" json:"prefix" yaml:"prefix"`
}
type EvidentlyProjectDataDeliveryS3DestinationOutputReference ¶
type EvidentlyProjectDataDeliveryS3DestinationOutputReference interface {
cdktf.ComplexObject
Bucket() *string
SetBucket(val *string)
BucketInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EvidentlyProjectDataDeliveryS3Destination
SetInternalValue(val *EvidentlyProjectDataDeliveryS3Destination)
Prefix() *string
SetPrefix(val *string)
PrefixInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBucket()
ResetPrefix()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyProjectDataDeliveryS3DestinationOutputReference ¶
func NewEvidentlyProjectDataDeliveryS3DestinationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EvidentlyProjectDataDeliveryS3DestinationOutputReference
type EvidentlyProjectTimeouts ¶
type EvidentlyProjectTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/evidently_project#create EvidentlyProject#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/evidently_project#delete EvidentlyProject#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/evidently_project#update EvidentlyProject#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type EvidentlyProjectTimeoutsOutputReference ¶
type EvidentlyProjectTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyProjectTimeoutsOutputReference ¶
func NewEvidentlyProjectTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EvidentlyProjectTimeoutsOutputReference
Source Files
¶
- EvidentlyProject.go
- EvidentlyProjectConfig.go
- EvidentlyProjectDataDelivery.go
- EvidentlyProjectDataDeliveryCloudwatchLogs.go
- EvidentlyProjectDataDeliveryCloudwatchLogsOutputReference.go
- EvidentlyProjectDataDeliveryCloudwatchLogsOutputReference__checks.go
- EvidentlyProjectDataDeliveryOutputReference.go
- EvidentlyProjectDataDeliveryOutputReference__checks.go
- EvidentlyProjectDataDeliveryS3Destination.go
- EvidentlyProjectDataDeliveryS3DestinationOutputReference.go
- EvidentlyProjectDataDeliveryS3DestinationOutputReference__checks.go
- EvidentlyProjectTimeouts.go
- EvidentlyProjectTimeoutsOutputReference.go
- EvidentlyProjectTimeoutsOutputReference__checks.go
- EvidentlyProject__checks.go
- main.go