Documentation
¶
Index ¶
- func FsxDataRepositoryAssociation_IsConstruct(x interface{}) *bool
- func FsxDataRepositoryAssociation_IsTerraformElement(x interface{}) *bool
- func FsxDataRepositoryAssociation_IsTerraformResource(x interface{}) *bool
- func FsxDataRepositoryAssociation_TfResourceType() *string
- func NewFsxDataRepositoryAssociationS3AutoExportPolicyOutputReference_Override(f FsxDataRepositoryAssociationS3AutoExportPolicyOutputReference, ...)
- func NewFsxDataRepositoryAssociationS3AutoImportPolicyOutputReference_Override(f FsxDataRepositoryAssociationS3AutoImportPolicyOutputReference, ...)
- func NewFsxDataRepositoryAssociationS3OutputReference_Override(f FsxDataRepositoryAssociationS3OutputReference, ...)
- func NewFsxDataRepositoryAssociationTimeoutsOutputReference_Override(f FsxDataRepositoryAssociationTimeoutsOutputReference, ...)
- func NewFsxDataRepositoryAssociation_Override(f FsxDataRepositoryAssociation, scope constructs.Construct, id *string, ...)
- type FsxDataRepositoryAssociation
- type FsxDataRepositoryAssociationConfig
- type FsxDataRepositoryAssociationS3
- type FsxDataRepositoryAssociationS3AutoExportPolicy
- type FsxDataRepositoryAssociationS3AutoExportPolicyOutputReference
- type FsxDataRepositoryAssociationS3AutoImportPolicy
- type FsxDataRepositoryAssociationS3AutoImportPolicyOutputReference
- type FsxDataRepositoryAssociationS3OutputReference
- type FsxDataRepositoryAssociationTimeouts
- type FsxDataRepositoryAssociationTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FsxDataRepositoryAssociation_IsConstruct ¶
func FsxDataRepositoryAssociation_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func FsxDataRepositoryAssociation_IsTerraformElement ¶
func FsxDataRepositoryAssociation_IsTerraformElement(x interface{}) *bool
Experimental.
func FsxDataRepositoryAssociation_IsTerraformResource ¶
func FsxDataRepositoryAssociation_IsTerraformResource(x interface{}) *bool
Experimental.
func FsxDataRepositoryAssociation_TfResourceType ¶
func FsxDataRepositoryAssociation_TfResourceType() *string
func NewFsxDataRepositoryAssociationS3AutoExportPolicyOutputReference_Override ¶
func NewFsxDataRepositoryAssociationS3AutoExportPolicyOutputReference_Override(f FsxDataRepositoryAssociationS3AutoExportPolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFsxDataRepositoryAssociationS3AutoImportPolicyOutputReference_Override ¶
func NewFsxDataRepositoryAssociationS3AutoImportPolicyOutputReference_Override(f FsxDataRepositoryAssociationS3AutoImportPolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFsxDataRepositoryAssociationS3OutputReference_Override ¶
func NewFsxDataRepositoryAssociationS3OutputReference_Override(f FsxDataRepositoryAssociationS3OutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFsxDataRepositoryAssociationTimeoutsOutputReference_Override ¶
func NewFsxDataRepositoryAssociationTimeoutsOutputReference_Override(f FsxDataRepositoryAssociationTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFsxDataRepositoryAssociation_Override ¶
func NewFsxDataRepositoryAssociation_Override(f FsxDataRepositoryAssociation, scope constructs.Construct, id *string, config *FsxDataRepositoryAssociationConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association aws_fsx_data_repository_association} Resource.
Types ¶
type FsxDataRepositoryAssociation ¶
type FsxDataRepositoryAssociation interface {
cdktf.TerraformResource
Arn() *string
AssociationId() *string
BatchImportMetaDataOnCreate() interface{}
SetBatchImportMetaDataOnCreate(val interface{})
BatchImportMetaDataOnCreateInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DataRepositoryPath() *string
SetDataRepositoryPath(val *string)
DataRepositoryPathInput() *string
DeleteDataInFilesystem() interface{}
SetDeleteDataInFilesystem(val interface{})
DeleteDataInFilesystemInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
FileSystemId() *string
SetFileSystemId(val *string)
FileSystemIdInput() *string
FileSystemPath() *string
SetFileSystemPath(val *string)
FileSystemPathInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
ImportedFileChunkSize() *float64
SetImportedFileChunkSize(val *float64)
ImportedFileChunkSizeInput() *float64
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
S3() FsxDataRepositoryAssociationS3OutputReference
S3Input() *FsxDataRepositoryAssociationS3
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() FsxDataRepositoryAssociationTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutS3(value *FsxDataRepositoryAssociationS3)
PutTimeouts(value *FsxDataRepositoryAssociationTimeouts)
ResetBatchImportMetaDataOnCreate()
ResetDeleteDataInFilesystem()
ResetId()
ResetImportedFileChunkSize()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetS3()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association aws_fsx_data_repository_association}.
func NewFsxDataRepositoryAssociation ¶
func NewFsxDataRepositoryAssociation(scope constructs.Construct, id *string, config *FsxDataRepositoryAssociationConfig) FsxDataRepositoryAssociation
Create a new {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association aws_fsx_data_repository_association} Resource.
type FsxDataRepositoryAssociationConfig ¶
type FsxDataRepositoryAssociationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association#data_repository_path FsxDataRepositoryAssociation#data_repository_path}.
DataRepositoryPath *string `field:"required" json:"dataRepositoryPath" yaml:"dataRepositoryPath"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association#file_system_id FsxDataRepositoryAssociation#file_system_id}.
FileSystemId *string `field:"required" json:"fileSystemId" yaml:"fileSystemId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association#file_system_path FsxDataRepositoryAssociation#file_system_path}.
FileSystemPath *string `field:"required" json:"fileSystemPath" yaml:"fileSystemPath"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association#batch_import_meta_data_on_create FsxDataRepositoryAssociation#batch_import_meta_data_on_create}.
BatchImportMetaDataOnCreate interface{} `field:"optional" json:"batchImportMetaDataOnCreate" yaml:"batchImportMetaDataOnCreate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association#delete_data_in_filesystem FsxDataRepositoryAssociation#delete_data_in_filesystem}.
DeleteDataInFilesystem interface{} `field:"optional" json:"deleteDataInFilesystem" yaml:"deleteDataInFilesystem"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association#id FsxDataRepositoryAssociation#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association#imported_file_chunk_size FsxDataRepositoryAssociation#imported_file_chunk_size}.
ImportedFileChunkSize *float64 `field:"optional" json:"importedFileChunkSize" yaml:"importedFileChunkSize"`
// s3 block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association#s3 FsxDataRepositoryAssociation#s3}
S3 *FsxDataRepositoryAssociationS3 `field:"optional" json:"s3" yaml:"s3"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association#tags FsxDataRepositoryAssociation#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association#tags_all FsxDataRepositoryAssociation#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association#timeouts FsxDataRepositoryAssociation#timeouts}
Timeouts *FsxDataRepositoryAssociationTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type FsxDataRepositoryAssociationS3 ¶
type FsxDataRepositoryAssociationS3 struct {
// auto_export_policy block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association#auto_export_policy FsxDataRepositoryAssociation#auto_export_policy}
AutoExportPolicy *FsxDataRepositoryAssociationS3AutoExportPolicy `field:"optional" json:"autoExportPolicy" yaml:"autoExportPolicy"`
// auto_import_policy block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association#auto_import_policy FsxDataRepositoryAssociation#auto_import_policy}
AutoImportPolicy *FsxDataRepositoryAssociationS3AutoImportPolicy `field:"optional" json:"autoImportPolicy" yaml:"autoImportPolicy"`
}
type FsxDataRepositoryAssociationS3AutoExportPolicy ¶
type FsxDataRepositoryAssociationS3AutoExportPolicy struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association#events FsxDataRepositoryAssociation#events}.
Events *[]*string `field:"optional" json:"events" yaml:"events"`
}
type FsxDataRepositoryAssociationS3AutoExportPolicyOutputReference ¶
type FsxDataRepositoryAssociationS3AutoExportPolicyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Events() *[]*string
SetEvents(val *[]*string)
EventsInput() *[]*string
// Experimental.
Fqn() *string
InternalValue() *FsxDataRepositoryAssociationS3AutoExportPolicy
SetInternalValue(val *FsxDataRepositoryAssociationS3AutoExportPolicy)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEvents()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxDataRepositoryAssociationS3AutoExportPolicyOutputReference ¶
func NewFsxDataRepositoryAssociationS3AutoExportPolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FsxDataRepositoryAssociationS3AutoExportPolicyOutputReference
type FsxDataRepositoryAssociationS3AutoImportPolicy ¶
type FsxDataRepositoryAssociationS3AutoImportPolicy struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association#events FsxDataRepositoryAssociation#events}.
Events *[]*string `field:"optional" json:"events" yaml:"events"`
}
type FsxDataRepositoryAssociationS3AutoImportPolicyOutputReference ¶
type FsxDataRepositoryAssociationS3AutoImportPolicyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Events() *[]*string
SetEvents(val *[]*string)
EventsInput() *[]*string
// Experimental.
Fqn() *string
InternalValue() *FsxDataRepositoryAssociationS3AutoImportPolicy
SetInternalValue(val *FsxDataRepositoryAssociationS3AutoImportPolicy)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEvents()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxDataRepositoryAssociationS3AutoImportPolicyOutputReference ¶
func NewFsxDataRepositoryAssociationS3AutoImportPolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FsxDataRepositoryAssociationS3AutoImportPolicyOutputReference
type FsxDataRepositoryAssociationS3OutputReference ¶
type FsxDataRepositoryAssociationS3OutputReference interface {
cdktf.ComplexObject
AutoExportPolicy() FsxDataRepositoryAssociationS3AutoExportPolicyOutputReference
AutoExportPolicyInput() *FsxDataRepositoryAssociationS3AutoExportPolicy
AutoImportPolicy() FsxDataRepositoryAssociationS3AutoImportPolicyOutputReference
AutoImportPolicyInput() *FsxDataRepositoryAssociationS3AutoImportPolicy
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *FsxDataRepositoryAssociationS3
SetInternalValue(val *FsxDataRepositoryAssociationS3)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAutoExportPolicy(value *FsxDataRepositoryAssociationS3AutoExportPolicy)
PutAutoImportPolicy(value *FsxDataRepositoryAssociationS3AutoImportPolicy)
ResetAutoExportPolicy()
ResetAutoImportPolicy()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxDataRepositoryAssociationS3OutputReference ¶
func NewFsxDataRepositoryAssociationS3OutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FsxDataRepositoryAssociationS3OutputReference
type FsxDataRepositoryAssociationTimeouts ¶
type FsxDataRepositoryAssociationTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association#create FsxDataRepositoryAssociation#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association#delete FsxDataRepositoryAssociation#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_data_repository_association#update FsxDataRepositoryAssociation#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type FsxDataRepositoryAssociationTimeoutsOutputReference ¶
type FsxDataRepositoryAssociationTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxDataRepositoryAssociationTimeoutsOutputReference ¶
func NewFsxDataRepositoryAssociationTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FsxDataRepositoryAssociationTimeoutsOutputReference
Source Files
¶
- FsxDataRepositoryAssociation.go
- FsxDataRepositoryAssociationConfig.go
- FsxDataRepositoryAssociationS3.go
- FsxDataRepositoryAssociationS3AutoExportPolicy.go
- FsxDataRepositoryAssociationS3AutoExportPolicyOutputReference.go
- FsxDataRepositoryAssociationS3AutoExportPolicyOutputReference__checks.go
- FsxDataRepositoryAssociationS3AutoImportPolicy.go
- FsxDataRepositoryAssociationS3AutoImportPolicyOutputReference.go
- FsxDataRepositoryAssociationS3AutoImportPolicyOutputReference__checks.go
- FsxDataRepositoryAssociationS3OutputReference.go
- FsxDataRepositoryAssociationS3OutputReference__checks.go
- FsxDataRepositoryAssociationTimeouts.go
- FsxDataRepositoryAssociationTimeoutsOutputReference.go
- FsxDataRepositoryAssociationTimeoutsOutputReference__checks.go
- FsxDataRepositoryAssociation__checks.go
- main.go