Documentation
¶
Index ¶
- func GlueMlTransform_IsConstruct(x interface{}) *bool
- func GlueMlTransform_IsTerraformElement(x interface{}) *bool
- func GlueMlTransform_IsTerraformResource(x interface{}) *bool
- func GlueMlTransform_TfResourceType() *string
- func NewGlueMlTransformInputRecordTablesList_Override(g GlueMlTransformInputRecordTablesList, ...)
- func NewGlueMlTransformInputRecordTablesOutputReference_Override(g GlueMlTransformInputRecordTablesOutputReference, ...)
- func NewGlueMlTransformParametersFindMatchesParametersOutputReference_Override(g GlueMlTransformParametersFindMatchesParametersOutputReference, ...)
- func NewGlueMlTransformParametersOutputReference_Override(g GlueMlTransformParametersOutputReference, ...)
- func NewGlueMlTransformSchemaList_Override(g GlueMlTransformSchemaList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewGlueMlTransformSchemaOutputReference_Override(g GlueMlTransformSchemaOutputReference, ...)
- func NewGlueMlTransform_Override(g GlueMlTransform, scope constructs.Construct, id *string, ...)
- type GlueMlTransform
- type GlueMlTransformConfig
- type GlueMlTransformInputRecordTables
- type GlueMlTransformInputRecordTablesList
- type GlueMlTransformInputRecordTablesOutputReference
- type GlueMlTransformParameters
- type GlueMlTransformParametersFindMatchesParameters
- type GlueMlTransformParametersFindMatchesParametersOutputReference
- type GlueMlTransformParametersOutputReference
- type GlueMlTransformSchema
- type GlueMlTransformSchemaList
- type GlueMlTransformSchemaOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GlueMlTransform_IsConstruct ¶
func GlueMlTransform_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GlueMlTransform_IsTerraformElement ¶
func GlueMlTransform_IsTerraformElement(x interface{}) *bool
Experimental.
func GlueMlTransform_IsTerraformResource ¶
func GlueMlTransform_IsTerraformResource(x interface{}) *bool
Experimental.
func GlueMlTransform_TfResourceType ¶
func GlueMlTransform_TfResourceType() *string
func NewGlueMlTransformInputRecordTablesList_Override ¶
func NewGlueMlTransformInputRecordTablesList_Override(g GlueMlTransformInputRecordTablesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGlueMlTransformInputRecordTablesOutputReference_Override ¶
func NewGlueMlTransformInputRecordTablesOutputReference_Override(g GlueMlTransformInputRecordTablesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGlueMlTransformParametersFindMatchesParametersOutputReference_Override ¶
func NewGlueMlTransformParametersFindMatchesParametersOutputReference_Override(g GlueMlTransformParametersFindMatchesParametersOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGlueMlTransformParametersOutputReference_Override ¶
func NewGlueMlTransformParametersOutputReference_Override(g GlueMlTransformParametersOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGlueMlTransformSchemaList_Override ¶
func NewGlueMlTransformSchemaList_Override(g GlueMlTransformSchemaList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGlueMlTransformSchemaOutputReference_Override ¶
func NewGlueMlTransformSchemaOutputReference_Override(g GlueMlTransformSchemaOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGlueMlTransform_Override ¶
func NewGlueMlTransform_Override(g GlueMlTransform, scope constructs.Construct, id *string, config *GlueMlTransformConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform aws_glue_ml_transform} Resource.
Types ¶
type GlueMlTransform ¶
type GlueMlTransform interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GlueVersion() *string
SetGlueVersion(val *string)
GlueVersionInput() *string
Id() *string
SetId(val *string)
IdInput() *string
InputRecordTables() GlueMlTransformInputRecordTablesList
InputRecordTablesInput() interface{}
LabelCount() *float64
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaxCapacity() *float64
SetMaxCapacity(val *float64)
MaxCapacityInput() *float64
MaxRetries() *float64
SetMaxRetries(val *float64)
MaxRetriesInput() *float64
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
NumberOfWorkers() *float64
SetNumberOfWorkers(val *float64)
NumberOfWorkersInput() *float64
Parameters() GlueMlTransformParametersOutputReference
ParametersInput() *GlueMlTransformParameters
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
Schema() GlueMlTransformSchemaList
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeout() *float64
SetTimeout(val *float64)
TimeoutInput() *float64
WorkerType() *string
SetWorkerType(val *string)
WorkerTypeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutInputRecordTables(value interface{})
PutParameters(value *GlueMlTransformParameters)
ResetDescription()
ResetGlueVersion()
ResetId()
ResetMaxCapacity()
ResetMaxRetries()
ResetNumberOfWorkers()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
ResetTimeout()
ResetWorkerType()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform aws_glue_ml_transform}.
func NewGlueMlTransform ¶
func NewGlueMlTransform(scope constructs.Construct, id *string, config *GlueMlTransformConfig) GlueMlTransform
Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform aws_glue_ml_transform} Resource.
type GlueMlTransformConfig ¶
type GlueMlTransformConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// input_record_tables block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#input_record_tables GlueMlTransform#input_record_tables}
InputRecordTables interface{} `field:"required" json:"inputRecordTables" yaml:"inputRecordTables"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#name GlueMlTransform#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// parameters block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#parameters GlueMlTransform#parameters}
Parameters *GlueMlTransformParameters `field:"required" json:"parameters" yaml:"parameters"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#role_arn GlueMlTransform#role_arn}.
RoleArn *string `field:"required" json:"roleArn" yaml:"roleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#description GlueMlTransform#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#glue_version GlueMlTransform#glue_version}.
GlueVersion *string `field:"optional" json:"glueVersion" yaml:"glueVersion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#id GlueMlTransform#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#max_capacity GlueMlTransform#max_capacity}.
MaxCapacity *float64 `field:"optional" json:"maxCapacity" yaml:"maxCapacity"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#max_retries GlueMlTransform#max_retries}.
MaxRetries *float64 `field:"optional" json:"maxRetries" yaml:"maxRetries"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#number_of_workers GlueMlTransform#number_of_workers}.
NumberOfWorkers *float64 `field:"optional" json:"numberOfWorkers" yaml:"numberOfWorkers"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#tags GlueMlTransform#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#tags_all GlueMlTransform#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#timeout GlueMlTransform#timeout}.
Timeout *float64 `field:"optional" json:"timeout" yaml:"timeout"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#worker_type GlueMlTransform#worker_type}.
WorkerType *string `field:"optional" json:"workerType" yaml:"workerType"`
}
type GlueMlTransformInputRecordTables ¶
type GlueMlTransformInputRecordTables struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#database_name GlueMlTransform#database_name}.
DatabaseName *string `field:"required" json:"databaseName" yaml:"databaseName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#table_name GlueMlTransform#table_name}.
TableName *string `field:"required" json:"tableName" yaml:"tableName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#catalog_id GlueMlTransform#catalog_id}.
CatalogId *string `field:"optional" json:"catalogId" yaml:"catalogId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#connection_name GlueMlTransform#connection_name}.
ConnectionName *string `field:"optional" json:"connectionName" yaml:"connectionName"`
}
type GlueMlTransformInputRecordTablesList ¶
type GlueMlTransformInputRecordTablesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GlueMlTransformInputRecordTablesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueMlTransformInputRecordTablesList ¶
func NewGlueMlTransformInputRecordTablesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GlueMlTransformInputRecordTablesList
type GlueMlTransformInputRecordTablesOutputReference ¶
type GlueMlTransformInputRecordTablesOutputReference interface {
cdktf.ComplexObject
CatalogId() *string
SetCatalogId(val *string)
CatalogIdInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ConnectionName() *string
SetConnectionName(val *string)
ConnectionNameInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DatabaseName() *string
SetDatabaseName(val *string)
DatabaseNameInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
TableName() *string
SetTableName(val *string)
TableNameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCatalogId()
ResetConnectionName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueMlTransformInputRecordTablesOutputReference ¶
func NewGlueMlTransformInputRecordTablesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GlueMlTransformInputRecordTablesOutputReference
type GlueMlTransformParameters ¶
type GlueMlTransformParameters struct {
// find_matches_parameters block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#find_matches_parameters GlueMlTransform#find_matches_parameters}
FindMatchesParameters *GlueMlTransformParametersFindMatchesParameters `field:"required" json:"findMatchesParameters" yaml:"findMatchesParameters"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#transform_type GlueMlTransform#transform_type}.
TransformType *string `field:"required" json:"transformType" yaml:"transformType"`
}
type GlueMlTransformParametersFindMatchesParameters ¶
type GlueMlTransformParametersFindMatchesParameters struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#accuracy_cost_trade_off GlueMlTransform#accuracy_cost_trade_off}.
AccuracyCostTradeOff *float64 `field:"optional" json:"accuracyCostTradeOff" yaml:"accuracyCostTradeOff"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#enforce_provided_labels GlueMlTransform#enforce_provided_labels}.
EnforceProvidedLabels interface{} `field:"optional" json:"enforceProvidedLabels" yaml:"enforceProvidedLabels"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#precision_recall_trade_off GlueMlTransform#precision_recall_trade_off}.
PrecisionRecallTradeOff *float64 `field:"optional" json:"precisionRecallTradeOff" yaml:"precisionRecallTradeOff"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform#primary_key_column_name GlueMlTransform#primary_key_column_name}.
PrimaryKeyColumnName *string `field:"optional" json:"primaryKeyColumnName" yaml:"primaryKeyColumnName"`
}
type GlueMlTransformParametersFindMatchesParametersOutputReference ¶
type GlueMlTransformParametersFindMatchesParametersOutputReference interface {
cdktf.ComplexObject
AccuracyCostTradeOff() *float64
SetAccuracyCostTradeOff(val *float64)
AccuracyCostTradeOffInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EnforceProvidedLabels() interface{}
SetEnforceProvidedLabels(val interface{})
EnforceProvidedLabelsInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *GlueMlTransformParametersFindMatchesParameters
SetInternalValue(val *GlueMlTransformParametersFindMatchesParameters)
PrecisionRecallTradeOff() *float64
SetPrecisionRecallTradeOff(val *float64)
PrecisionRecallTradeOffInput() *float64
PrimaryKeyColumnName() *string
SetPrimaryKeyColumnName(val *string)
PrimaryKeyColumnNameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAccuracyCostTradeOff()
ResetEnforceProvidedLabels()
ResetPrecisionRecallTradeOff()
ResetPrimaryKeyColumnName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueMlTransformParametersFindMatchesParametersOutputReference ¶
func NewGlueMlTransformParametersFindMatchesParametersOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GlueMlTransformParametersFindMatchesParametersOutputReference
type GlueMlTransformParametersOutputReference ¶
type GlueMlTransformParametersOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FindMatchesParameters() GlueMlTransformParametersFindMatchesParametersOutputReference
FindMatchesParametersInput() *GlueMlTransformParametersFindMatchesParameters
// Experimental.
Fqn() *string
InternalValue() *GlueMlTransformParameters
SetInternalValue(val *GlueMlTransformParameters)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TransformType() *string
SetTransformType(val *string)
TransformTypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutFindMatchesParameters(value *GlueMlTransformParametersFindMatchesParameters)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueMlTransformParametersOutputReference ¶
func NewGlueMlTransformParametersOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GlueMlTransformParametersOutputReference
type GlueMlTransformSchema ¶
type GlueMlTransformSchema struct {
}
type GlueMlTransformSchemaList ¶
type GlueMlTransformSchemaList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GlueMlTransformSchemaOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueMlTransformSchemaList ¶
func NewGlueMlTransformSchemaList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GlueMlTransformSchemaList
type GlueMlTransformSchemaOutputReference ¶
type GlueMlTransformSchemaOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DataType() *string
// Experimental.
Fqn() *string
InternalValue() *GlueMlTransformSchema
SetInternalValue(val *GlueMlTransformSchema)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueMlTransformSchemaOutputReference ¶
func NewGlueMlTransformSchemaOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GlueMlTransformSchemaOutputReference
Source Files
¶
- GlueMlTransform.go
- GlueMlTransformConfig.go
- GlueMlTransformInputRecordTables.go
- GlueMlTransformInputRecordTablesList.go
- GlueMlTransformInputRecordTablesList__checks.go
- GlueMlTransformInputRecordTablesOutputReference.go
- GlueMlTransformInputRecordTablesOutputReference__checks.go
- GlueMlTransformParameters.go
- GlueMlTransformParametersFindMatchesParameters.go
- GlueMlTransformParametersFindMatchesParametersOutputReference.go
- GlueMlTransformParametersFindMatchesParametersOutputReference__checks.go
- GlueMlTransformParametersOutputReference.go
- GlueMlTransformParametersOutputReference__checks.go
- GlueMlTransformSchema.go
- GlueMlTransformSchemaList.go
- GlueMlTransformSchemaList__checks.go
- GlueMlTransformSchemaOutputReference.go
- GlueMlTransformSchemaOutputReference__checks.go
- GlueMlTransform__checks.go
- main.go