Documentation
¶
Index ¶
- func GluePartition_IsConstruct(x interface{}) *bool
- func GluePartition_IsTerraformElement(x interface{}) *bool
- func GluePartition_IsTerraformResource(x interface{}) *bool
- func GluePartition_TfResourceType() *string
- func NewGluePartitionStorageDescriptorColumnsList_Override(g GluePartitionStorageDescriptorColumnsList, ...)
- func NewGluePartitionStorageDescriptorColumnsOutputReference_Override(g GluePartitionStorageDescriptorColumnsOutputReference, ...)
- func NewGluePartitionStorageDescriptorOutputReference_Override(g GluePartitionStorageDescriptorOutputReference, ...)
- func NewGluePartitionStorageDescriptorSerDeInfoOutputReference_Override(g GluePartitionStorageDescriptorSerDeInfoOutputReference, ...)
- func NewGluePartitionStorageDescriptorSkewedInfoOutputReference_Override(g GluePartitionStorageDescriptorSkewedInfoOutputReference, ...)
- func NewGluePartitionStorageDescriptorSortColumnsList_Override(g GluePartitionStorageDescriptorSortColumnsList, ...)
- func NewGluePartitionStorageDescriptorSortColumnsOutputReference_Override(g GluePartitionStorageDescriptorSortColumnsOutputReference, ...)
- func NewGluePartition_Override(g GluePartition, scope constructs.Construct, id *string, ...)
- type GluePartition
- type GluePartitionConfig
- type GluePartitionStorageDescriptor
- type GluePartitionStorageDescriptorColumns
- type GluePartitionStorageDescriptorColumnsList
- type GluePartitionStorageDescriptorColumnsOutputReference
- type GluePartitionStorageDescriptorOutputReference
- type GluePartitionStorageDescriptorSerDeInfo
- type GluePartitionStorageDescriptorSerDeInfoOutputReference
- type GluePartitionStorageDescriptorSkewedInfo
- type GluePartitionStorageDescriptorSkewedInfoOutputReference
- type GluePartitionStorageDescriptorSortColumns
- type GluePartitionStorageDescriptorSortColumnsList
- type GluePartitionStorageDescriptorSortColumnsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GluePartition_IsConstruct ¶
func GluePartition_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GluePartition_IsTerraformElement ¶
func GluePartition_IsTerraformElement(x interface{}) *bool
Experimental.
func GluePartition_IsTerraformResource ¶
func GluePartition_IsTerraformResource(x interface{}) *bool
Experimental.
func GluePartition_TfResourceType ¶
func GluePartition_TfResourceType() *string
func NewGluePartitionStorageDescriptorColumnsList_Override ¶
func NewGluePartitionStorageDescriptorColumnsList_Override(g GluePartitionStorageDescriptorColumnsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGluePartitionStorageDescriptorColumnsOutputReference_Override ¶
func NewGluePartitionStorageDescriptorColumnsOutputReference_Override(g GluePartitionStorageDescriptorColumnsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGluePartitionStorageDescriptorOutputReference_Override ¶
func NewGluePartitionStorageDescriptorOutputReference_Override(g GluePartitionStorageDescriptorOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGluePartitionStorageDescriptorSerDeInfoOutputReference_Override ¶
func NewGluePartitionStorageDescriptorSerDeInfoOutputReference_Override(g GluePartitionStorageDescriptorSerDeInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGluePartitionStorageDescriptorSkewedInfoOutputReference_Override ¶
func NewGluePartitionStorageDescriptorSkewedInfoOutputReference_Override(g GluePartitionStorageDescriptorSkewedInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGluePartitionStorageDescriptorSortColumnsList_Override ¶
func NewGluePartitionStorageDescriptorSortColumnsList_Override(g GluePartitionStorageDescriptorSortColumnsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGluePartitionStorageDescriptorSortColumnsOutputReference_Override ¶
func NewGluePartitionStorageDescriptorSortColumnsOutputReference_Override(g GluePartitionStorageDescriptorSortColumnsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGluePartition_Override ¶
func NewGluePartition_Override(g GluePartition, scope constructs.Construct, id *string, config *GluePartitionConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_partition aws_glue_partition} Resource.
Types ¶
type GluePartition ¶
type GluePartition interface {
cdktf.TerraformResource
CatalogId() *string
SetCatalogId(val *string)
CatalogIdInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreationTime() *string
DatabaseName() *string
SetDatabaseName(val *string)
DatabaseNameInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
LastAccessedTime() *string
LastAnalyzedTime() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
Parameters() *map[string]*string
SetParameters(val *map[string]*string)
ParametersInput() *map[string]*string
PartitionValues() *[]*string
SetPartitionValues(val *[]*string)
PartitionValuesInput() *[]*string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
StorageDescriptor() GluePartitionStorageDescriptorOutputReference
StorageDescriptorInput() *GluePartitionStorageDescriptor
TableName() *string
SetTableName(val *string)
TableNameInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutStorageDescriptor(value *GluePartitionStorageDescriptor)
ResetCatalogId()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetParameters()
ResetStorageDescriptor()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_partition aws_glue_partition}.
func NewGluePartition ¶
func NewGluePartition(scope constructs.Construct, id *string, config *GluePartitionConfig) GluePartition
Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_partition aws_glue_partition} Resource.
type GluePartitionConfig ¶
type GluePartitionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#database_name GluePartition#database_name}.
DatabaseName *string `field:"required" json:"databaseName" yaml:"databaseName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#partition_values GluePartition#partition_values}.
PartitionValues *[]*string `field:"required" json:"partitionValues" yaml:"partitionValues"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#table_name GluePartition#table_name}.
TableName *string `field:"required" json:"tableName" yaml:"tableName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#catalog_id GluePartition#catalog_id}.
CatalogId *string `field:"optional" json:"catalogId" yaml:"catalogId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#id GluePartition#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#parameters GluePartition#parameters}.
Parameters *map[string]*string `field:"optional" json:"parameters" yaml:"parameters"`
// storage_descriptor block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#storage_descriptor GluePartition#storage_descriptor}
StorageDescriptor *GluePartitionStorageDescriptor `field:"optional" json:"storageDescriptor" yaml:"storageDescriptor"`
}
type GluePartitionStorageDescriptor ¶
type GluePartitionStorageDescriptor struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#bucket_columns GluePartition#bucket_columns}.
BucketColumns *[]*string `field:"optional" json:"bucketColumns" yaml:"bucketColumns"`
// columns block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#columns GluePartition#columns}
Columns interface{} `field:"optional" json:"columns" yaml:"columns"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#compressed GluePartition#compressed}.
Compressed interface{} `field:"optional" json:"compressed" yaml:"compressed"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#input_format GluePartition#input_format}.
InputFormat *string `field:"optional" json:"inputFormat" yaml:"inputFormat"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#location GluePartition#location}.
Location *string `field:"optional" json:"location" yaml:"location"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#number_of_buckets GluePartition#number_of_buckets}.
NumberOfBuckets *float64 `field:"optional" json:"numberOfBuckets" yaml:"numberOfBuckets"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#output_format GluePartition#output_format}.
OutputFormat *string `field:"optional" json:"outputFormat" yaml:"outputFormat"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#parameters GluePartition#parameters}.
Parameters *map[string]*string `field:"optional" json:"parameters" yaml:"parameters"`
// ser_de_info block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#ser_de_info GluePartition#ser_de_info}
SerDeInfo *GluePartitionStorageDescriptorSerDeInfo `field:"optional" json:"serDeInfo" yaml:"serDeInfo"`
// skewed_info block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#skewed_info GluePartition#skewed_info}
SkewedInfo *GluePartitionStorageDescriptorSkewedInfo `field:"optional" json:"skewedInfo" yaml:"skewedInfo"`
// sort_columns block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#sort_columns GluePartition#sort_columns}
SortColumns interface{} `field:"optional" json:"sortColumns" yaml:"sortColumns"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#stored_as_sub_directories GluePartition#stored_as_sub_directories}.
StoredAsSubDirectories interface{} `field:"optional" json:"storedAsSubDirectories" yaml:"storedAsSubDirectories"`
}
type GluePartitionStorageDescriptorColumns ¶
type GluePartitionStorageDescriptorColumns struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#name GluePartition#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#comment GluePartition#comment}.
Comment *string `field:"optional" json:"comment" yaml:"comment"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#type GluePartition#type}.
Type *string `field:"optional" json:"type" yaml:"type"`
}
type GluePartitionStorageDescriptorColumnsList ¶
type GluePartitionStorageDescriptorColumnsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GluePartitionStorageDescriptorColumnsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGluePartitionStorageDescriptorColumnsList ¶
func NewGluePartitionStorageDescriptorColumnsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GluePartitionStorageDescriptorColumnsList
type GluePartitionStorageDescriptorColumnsOutputReference ¶
type GluePartitionStorageDescriptorColumnsOutputReference interface {
cdktf.ComplexObject
Comment() *string
SetComment(val *string)
CommentInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetComment()
ResetType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGluePartitionStorageDescriptorColumnsOutputReference ¶
func NewGluePartitionStorageDescriptorColumnsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GluePartitionStorageDescriptorColumnsOutputReference
type GluePartitionStorageDescriptorOutputReference ¶
type GluePartitionStorageDescriptorOutputReference interface {
cdktf.ComplexObject
BucketColumns() *[]*string
SetBucketColumns(val *[]*string)
BucketColumnsInput() *[]*string
Columns() GluePartitionStorageDescriptorColumnsList
ColumnsInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Compressed() interface{}
SetCompressed(val interface{})
CompressedInput() interface{}
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InputFormat() *string
SetInputFormat(val *string)
InputFormatInput() *string
InternalValue() *GluePartitionStorageDescriptor
SetInternalValue(val *GluePartitionStorageDescriptor)
Location() *string
SetLocation(val *string)
LocationInput() *string
NumberOfBuckets() *float64
SetNumberOfBuckets(val *float64)
NumberOfBucketsInput() *float64
OutputFormat() *string
SetOutputFormat(val *string)
OutputFormatInput() *string
Parameters() *map[string]*string
SetParameters(val *map[string]*string)
ParametersInput() *map[string]*string
SerDeInfo() GluePartitionStorageDescriptorSerDeInfoOutputReference
SerDeInfoInput() *GluePartitionStorageDescriptorSerDeInfo
SkewedInfo() GluePartitionStorageDescriptorSkewedInfoOutputReference
SkewedInfoInput() *GluePartitionStorageDescriptorSkewedInfo
SortColumns() GluePartitionStorageDescriptorSortColumnsList
SortColumnsInput() interface{}
StoredAsSubDirectories() interface{}
SetStoredAsSubDirectories(val interface{})
StoredAsSubDirectoriesInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutColumns(value interface{})
PutSerDeInfo(value *GluePartitionStorageDescriptorSerDeInfo)
PutSkewedInfo(value *GluePartitionStorageDescriptorSkewedInfo)
PutSortColumns(value interface{})
ResetBucketColumns()
ResetColumns()
ResetCompressed()
ResetInputFormat()
ResetLocation()
ResetNumberOfBuckets()
ResetOutputFormat()
ResetParameters()
ResetSerDeInfo()
ResetSkewedInfo()
ResetSortColumns()
ResetStoredAsSubDirectories()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGluePartitionStorageDescriptorOutputReference ¶
func NewGluePartitionStorageDescriptorOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GluePartitionStorageDescriptorOutputReference
type GluePartitionStorageDescriptorSerDeInfo ¶
type GluePartitionStorageDescriptorSerDeInfo struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#name GluePartition#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#parameters GluePartition#parameters}.
Parameters *map[string]*string `field:"optional" json:"parameters" yaml:"parameters"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#serialization_library GluePartition#serialization_library}.
SerializationLibrary *string `field:"optional" json:"serializationLibrary" yaml:"serializationLibrary"`
}
type GluePartitionStorageDescriptorSerDeInfoOutputReference ¶
type GluePartitionStorageDescriptorSerDeInfoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GluePartitionStorageDescriptorSerDeInfo
SetInternalValue(val *GluePartitionStorageDescriptorSerDeInfo)
Name() *string
SetName(val *string)
NameInput() *string
Parameters() *map[string]*string
SetParameters(val *map[string]*string)
ParametersInput() *map[string]*string
SerializationLibrary() *string
SetSerializationLibrary(val *string)
SerializationLibraryInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetName()
ResetParameters()
ResetSerializationLibrary()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGluePartitionStorageDescriptorSerDeInfoOutputReference ¶
func NewGluePartitionStorageDescriptorSerDeInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GluePartitionStorageDescriptorSerDeInfoOutputReference
type GluePartitionStorageDescriptorSkewedInfo ¶
type GluePartitionStorageDescriptorSkewedInfo struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#skewed_column_names GluePartition#skewed_column_names}.
SkewedColumnNames *[]*string `field:"optional" json:"skewedColumnNames" yaml:"skewedColumnNames"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#skewed_column_value_location_maps GluePartition#skewed_column_value_location_maps}.
SkewedColumnValueLocationMaps *map[string]*string `field:"optional" json:"skewedColumnValueLocationMaps" yaml:"skewedColumnValueLocationMaps"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#skewed_column_values GluePartition#skewed_column_values}.
SkewedColumnValues *[]*string `field:"optional" json:"skewedColumnValues" yaml:"skewedColumnValues"`
}
type GluePartitionStorageDescriptorSkewedInfoOutputReference ¶
type GluePartitionStorageDescriptorSkewedInfoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GluePartitionStorageDescriptorSkewedInfo
SetInternalValue(val *GluePartitionStorageDescriptorSkewedInfo)
SkewedColumnNames() *[]*string
SetSkewedColumnNames(val *[]*string)
SkewedColumnNamesInput() *[]*string
SkewedColumnValueLocationMaps() *map[string]*string
SetSkewedColumnValueLocationMaps(val *map[string]*string)
SkewedColumnValueLocationMapsInput() *map[string]*string
SkewedColumnValues() *[]*string
SetSkewedColumnValues(val *[]*string)
SkewedColumnValuesInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetSkewedColumnNames()
ResetSkewedColumnValueLocationMaps()
ResetSkewedColumnValues()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGluePartitionStorageDescriptorSkewedInfoOutputReference ¶
func NewGluePartitionStorageDescriptorSkewedInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GluePartitionStorageDescriptorSkewedInfoOutputReference
type GluePartitionStorageDescriptorSortColumns ¶
type GluePartitionStorageDescriptorSortColumns struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#column GluePartition#column}.
Column *string `field:"required" json:"column" yaml:"column"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#sort_order GluePartition#sort_order}.
SortOrder *float64 `field:"required" json:"sortOrder" yaml:"sortOrder"`
}
type GluePartitionStorageDescriptorSortColumnsList ¶
type GluePartitionStorageDescriptorSortColumnsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GluePartitionStorageDescriptorSortColumnsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGluePartitionStorageDescriptorSortColumnsList ¶
func NewGluePartitionStorageDescriptorSortColumnsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GluePartitionStorageDescriptorSortColumnsList
type GluePartitionStorageDescriptorSortColumnsOutputReference ¶
type GluePartitionStorageDescriptorSortColumnsOutputReference interface {
cdktf.ComplexObject
Column() *string
SetColumn(val *string)
ColumnInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
SortOrder() *float64
SetSortOrder(val *float64)
SortOrderInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGluePartitionStorageDescriptorSortColumnsOutputReference ¶
func NewGluePartitionStorageDescriptorSortColumnsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GluePartitionStorageDescriptorSortColumnsOutputReference
Source Files
¶
- GluePartition.go
- GluePartitionConfig.go
- GluePartitionStorageDescriptor.go
- GluePartitionStorageDescriptorColumns.go
- GluePartitionStorageDescriptorColumnsList.go
- GluePartitionStorageDescriptorColumnsList__checks.go
- GluePartitionStorageDescriptorColumnsOutputReference.go
- GluePartitionStorageDescriptorColumnsOutputReference__checks.go
- GluePartitionStorageDescriptorOutputReference.go
- GluePartitionStorageDescriptorOutputReference__checks.go
- GluePartitionStorageDescriptorSerDeInfo.go
- GluePartitionStorageDescriptorSerDeInfoOutputReference.go
- GluePartitionStorageDescriptorSerDeInfoOutputReference__checks.go
- GluePartitionStorageDescriptorSkewedInfo.go
- GluePartitionStorageDescriptorSkewedInfoOutputReference.go
- GluePartitionStorageDescriptorSkewedInfoOutputReference__checks.go
- GluePartitionStorageDescriptorSortColumns.go
- GluePartitionStorageDescriptorSortColumnsList.go
- GluePartitionStorageDescriptorSortColumnsList__checks.go
- GluePartitionStorageDescriptorSortColumnsOutputReference.go
- GluePartitionStorageDescriptorSortColumnsOutputReference__checks.go
- GluePartition__checks.go
- main.go