Documentation
¶
Index ¶
- func GlueTrigger_IsConstruct(x interface{}) *bool
- func GlueTrigger_IsTerraformElement(x interface{}) *bool
- func GlueTrigger_IsTerraformResource(x interface{}) *bool
- func GlueTrigger_TfResourceType() *string
- func NewGlueTriggerActionsList_Override(g GlueTriggerActionsList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewGlueTriggerActionsNotificationPropertyOutputReference_Override(g GlueTriggerActionsNotificationPropertyOutputReference, ...)
- func NewGlueTriggerActionsOutputReference_Override(g GlueTriggerActionsOutputReference, ...)
- func NewGlueTriggerEventBatchingConditionList_Override(g GlueTriggerEventBatchingConditionList, ...)
- func NewGlueTriggerEventBatchingConditionOutputReference_Override(g GlueTriggerEventBatchingConditionOutputReference, ...)
- func NewGlueTriggerPredicateConditionsList_Override(g GlueTriggerPredicateConditionsList, ...)
- func NewGlueTriggerPredicateConditionsOutputReference_Override(g GlueTriggerPredicateConditionsOutputReference, ...)
- func NewGlueTriggerPredicateOutputReference_Override(g GlueTriggerPredicateOutputReference, ...)
- func NewGlueTriggerTimeoutsOutputReference_Override(g GlueTriggerTimeoutsOutputReference, ...)
- func NewGlueTrigger_Override(g GlueTrigger, scope constructs.Construct, id *string, ...)
- type GlueTrigger
- type GlueTriggerActions
- type GlueTriggerActionsList
- type GlueTriggerActionsNotificationProperty
- type GlueTriggerActionsNotificationPropertyOutputReference
- type GlueTriggerActionsOutputReference
- type GlueTriggerConfig
- type GlueTriggerEventBatchingCondition
- type GlueTriggerEventBatchingConditionList
- type GlueTriggerEventBatchingConditionOutputReference
- type GlueTriggerPredicate
- type GlueTriggerPredicateConditions
- type GlueTriggerPredicateConditionsList
- type GlueTriggerPredicateConditionsOutputReference
- type GlueTriggerPredicateOutputReference
- type GlueTriggerTimeouts
- type GlueTriggerTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GlueTrigger_IsConstruct ¶
func GlueTrigger_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GlueTrigger_IsTerraformElement ¶
func GlueTrigger_IsTerraformElement(x interface{}) *bool
Experimental.
func GlueTrigger_IsTerraformResource ¶
func GlueTrigger_IsTerraformResource(x interface{}) *bool
Experimental.
func GlueTrigger_TfResourceType ¶
func GlueTrigger_TfResourceType() *string
func NewGlueTriggerActionsList_Override ¶
func NewGlueTriggerActionsList_Override(g GlueTriggerActionsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGlueTriggerActionsNotificationPropertyOutputReference_Override ¶
func NewGlueTriggerActionsNotificationPropertyOutputReference_Override(g GlueTriggerActionsNotificationPropertyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGlueTriggerActionsOutputReference_Override ¶
func NewGlueTriggerActionsOutputReference_Override(g GlueTriggerActionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGlueTriggerEventBatchingConditionList_Override ¶
func NewGlueTriggerEventBatchingConditionList_Override(g GlueTriggerEventBatchingConditionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGlueTriggerEventBatchingConditionOutputReference_Override ¶
func NewGlueTriggerEventBatchingConditionOutputReference_Override(g GlueTriggerEventBatchingConditionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGlueTriggerPredicateConditionsList_Override ¶
func NewGlueTriggerPredicateConditionsList_Override(g GlueTriggerPredicateConditionsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGlueTriggerPredicateConditionsOutputReference_Override ¶
func NewGlueTriggerPredicateConditionsOutputReference_Override(g GlueTriggerPredicateConditionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGlueTriggerPredicateOutputReference_Override ¶
func NewGlueTriggerPredicateOutputReference_Override(g GlueTriggerPredicateOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGlueTriggerTimeoutsOutputReference_Override ¶
func NewGlueTriggerTimeoutsOutputReference_Override(g GlueTriggerTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGlueTrigger_Override ¶
func NewGlueTrigger_Override(g GlueTrigger, scope constructs.Construct, id *string, config *GlueTriggerConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger aws_glue_trigger} Resource.
Types ¶
type GlueTrigger ¶
type GlueTrigger interface {
cdktf.TerraformResource
Actions() GlueTriggerActionsList
ActionsInput() interface{}
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
EventBatchingCondition() GlueTriggerEventBatchingConditionList
EventBatchingConditionInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Predicate() GlueTriggerPredicateOutputReference
PredicateInput() *GlueTriggerPredicate
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Schedule() *string
SetSchedule(val *string)
ScheduleInput() *string
StartOnCreation() interface{}
SetStartOnCreation(val interface{})
StartOnCreationInput() interface{}
State() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GlueTriggerTimeoutsOutputReference
TimeoutsInput() interface{}
Type() *string
SetType(val *string)
TypeInput() *string
WorkflowName() *string
SetWorkflowName(val *string)
WorkflowNameInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutActions(value interface{})
PutEventBatchingCondition(value interface{})
PutPredicate(value *GlueTriggerPredicate)
PutTimeouts(value *GlueTriggerTimeouts)
ResetDescription()
ResetEnabled()
ResetEventBatchingCondition()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPredicate()
ResetSchedule()
ResetStartOnCreation()
ResetTags()
ResetTagsAll()
ResetTimeouts()
ResetWorkflowName()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger aws_glue_trigger}.
func NewGlueTrigger ¶
func NewGlueTrigger(scope constructs.Construct, id *string, config *GlueTriggerConfig) GlueTrigger
Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger aws_glue_trigger} Resource.
type GlueTriggerActions ¶
type GlueTriggerActions struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#arguments GlueTrigger#arguments}.
Arguments *map[string]*string `field:"optional" json:"arguments" yaml:"arguments"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#crawler_name GlueTrigger#crawler_name}.
CrawlerName *string `field:"optional" json:"crawlerName" yaml:"crawlerName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#job_name GlueTrigger#job_name}.
JobName *string `field:"optional" json:"jobName" yaml:"jobName"`
// notification_property block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#notification_property GlueTrigger#notification_property}
NotificationProperty *GlueTriggerActionsNotificationProperty `field:"optional" json:"notificationProperty" yaml:"notificationProperty"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#security_configuration GlueTrigger#security_configuration}.
SecurityConfiguration *string `field:"optional" json:"securityConfiguration" yaml:"securityConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#timeout GlueTrigger#timeout}.
Timeout *float64 `field:"optional" json:"timeout" yaml:"timeout"`
}
type GlueTriggerActionsList ¶
type GlueTriggerActionsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GlueTriggerActionsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueTriggerActionsList ¶
func NewGlueTriggerActionsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GlueTriggerActionsList
type GlueTriggerActionsNotificationProperty ¶
type GlueTriggerActionsNotificationProperty struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#notify_delay_after GlueTrigger#notify_delay_after}.
NotifyDelayAfter *float64 `field:"optional" json:"notifyDelayAfter" yaml:"notifyDelayAfter"`
}
type GlueTriggerActionsNotificationPropertyOutputReference ¶
type GlueTriggerActionsNotificationPropertyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GlueTriggerActionsNotificationProperty
SetInternalValue(val *GlueTriggerActionsNotificationProperty)
NotifyDelayAfter() *float64
SetNotifyDelayAfter(val *float64)
NotifyDelayAfterInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetNotifyDelayAfter()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueTriggerActionsNotificationPropertyOutputReference ¶
func NewGlueTriggerActionsNotificationPropertyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GlueTriggerActionsNotificationPropertyOutputReference
type GlueTriggerActionsOutputReference ¶
type GlueTriggerActionsOutputReference interface {
cdktf.ComplexObject
Arguments() *map[string]*string
SetArguments(val *map[string]*string)
ArgumentsInput() *map[string]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CrawlerName() *string
SetCrawlerName(val *string)
CrawlerNameInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
JobName() *string
SetJobName(val *string)
JobNameInput() *string
NotificationProperty() GlueTriggerActionsNotificationPropertyOutputReference
NotificationPropertyInput() *GlueTriggerActionsNotificationProperty
SecurityConfiguration() *string
SetSecurityConfiguration(val *string)
SecurityConfigurationInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Timeout() *float64
SetTimeout(val *float64)
TimeoutInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutNotificationProperty(value *GlueTriggerActionsNotificationProperty)
ResetArguments()
ResetCrawlerName()
ResetJobName()
ResetNotificationProperty()
ResetSecurityConfiguration()
ResetTimeout()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueTriggerActionsOutputReference ¶
func NewGlueTriggerActionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GlueTriggerActionsOutputReference
type GlueTriggerConfig ¶
type GlueTriggerConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// actions block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#actions GlueTrigger#actions}
Actions interface{} `field:"required" json:"actions" yaml:"actions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#name GlueTrigger#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#type GlueTrigger#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#description GlueTrigger#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#enabled GlueTrigger#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// event_batching_condition block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#event_batching_condition GlueTrigger#event_batching_condition}
EventBatchingCondition interface{} `field:"optional" json:"eventBatchingCondition" yaml:"eventBatchingCondition"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#id GlueTrigger#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// predicate block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#predicate GlueTrigger#predicate}
Predicate *GlueTriggerPredicate `field:"optional" json:"predicate" yaml:"predicate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#schedule GlueTrigger#schedule}.
Schedule *string `field:"optional" json:"schedule" yaml:"schedule"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#start_on_creation GlueTrigger#start_on_creation}.
StartOnCreation interface{} `field:"optional" json:"startOnCreation" yaml:"startOnCreation"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#tags GlueTrigger#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#tags_all GlueTrigger#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#timeouts GlueTrigger#timeouts}
Timeouts *GlueTriggerTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#workflow_name GlueTrigger#workflow_name}.
WorkflowName *string `field:"optional" json:"workflowName" yaml:"workflowName"`
}
type GlueTriggerEventBatchingCondition ¶
type GlueTriggerEventBatchingCondition struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#batch_size GlueTrigger#batch_size}.
BatchSize *float64 `field:"required" json:"batchSize" yaml:"batchSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#batch_window GlueTrigger#batch_window}.
BatchWindow *float64 `field:"optional" json:"batchWindow" yaml:"batchWindow"`
}
type GlueTriggerEventBatchingConditionList ¶
type GlueTriggerEventBatchingConditionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GlueTriggerEventBatchingConditionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueTriggerEventBatchingConditionList ¶
func NewGlueTriggerEventBatchingConditionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GlueTriggerEventBatchingConditionList
type GlueTriggerEventBatchingConditionOutputReference ¶
type GlueTriggerEventBatchingConditionOutputReference interface {
cdktf.ComplexObject
BatchSize() *float64
SetBatchSize(val *float64)
BatchSizeInput() *float64
BatchWindow() *float64
SetBatchWindow(val *float64)
BatchWindowInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBatchWindow()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueTriggerEventBatchingConditionOutputReference ¶
func NewGlueTriggerEventBatchingConditionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GlueTriggerEventBatchingConditionOutputReference
type GlueTriggerPredicate ¶
type GlueTriggerPredicate struct {
// conditions block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#conditions GlueTrigger#conditions}
Conditions interface{} `field:"required" json:"conditions" yaml:"conditions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#logical GlueTrigger#logical}.
Logical *string `field:"optional" json:"logical" yaml:"logical"`
}
type GlueTriggerPredicateConditions ¶
type GlueTriggerPredicateConditions struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#crawler_name GlueTrigger#crawler_name}.
CrawlerName *string `field:"optional" json:"crawlerName" yaml:"crawlerName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#crawl_state GlueTrigger#crawl_state}.
CrawlState *string `field:"optional" json:"crawlState" yaml:"crawlState"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#job_name GlueTrigger#job_name}.
JobName *string `field:"optional" json:"jobName" yaml:"jobName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#logical_operator GlueTrigger#logical_operator}.
LogicalOperator *string `field:"optional" json:"logicalOperator" yaml:"logicalOperator"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#state GlueTrigger#state}.
State *string `field:"optional" json:"state" yaml:"state"`
}
type GlueTriggerPredicateConditionsList ¶
type GlueTriggerPredicateConditionsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GlueTriggerPredicateConditionsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueTriggerPredicateConditionsList ¶
func NewGlueTriggerPredicateConditionsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GlueTriggerPredicateConditionsList
type GlueTriggerPredicateConditionsOutputReference ¶
type GlueTriggerPredicateConditionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CrawlerName() *string
SetCrawlerName(val *string)
CrawlerNameInput() *string
CrawlState() *string
SetCrawlState(val *string)
CrawlStateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
JobName() *string
SetJobName(val *string)
JobNameInput() *string
LogicalOperator() *string
SetLogicalOperator(val *string)
LogicalOperatorInput() *string
State() *string
SetState(val *string)
StateInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCrawlerName()
ResetCrawlState()
ResetJobName()
ResetLogicalOperator()
ResetState()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueTriggerPredicateConditionsOutputReference ¶
func NewGlueTriggerPredicateConditionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GlueTriggerPredicateConditionsOutputReference
type GlueTriggerPredicateOutputReference ¶
type GlueTriggerPredicateOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Conditions() GlueTriggerPredicateConditionsList
ConditionsInput() interface{}
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GlueTriggerPredicate
SetInternalValue(val *GlueTriggerPredicate)
Logical() *string
SetLogical(val *string)
LogicalInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutConditions(value interface{})
ResetLogical()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueTriggerPredicateOutputReference ¶
func NewGlueTriggerPredicateOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GlueTriggerPredicateOutputReference
type GlueTriggerTimeouts ¶
type GlueTriggerTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#create GlueTrigger#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger#delete GlueTrigger#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type GlueTriggerTimeoutsOutputReference ¶
type GlueTriggerTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueTriggerTimeoutsOutputReference ¶
func NewGlueTriggerTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GlueTriggerTimeoutsOutputReference
Source Files
¶
- GlueTrigger.go
- GlueTriggerActions.go
- GlueTriggerActionsList.go
- GlueTriggerActionsList__checks.go
- GlueTriggerActionsNotificationProperty.go
- GlueTriggerActionsNotificationPropertyOutputReference.go
- GlueTriggerActionsNotificationPropertyOutputReference__checks.go
- GlueTriggerActionsOutputReference.go
- GlueTriggerActionsOutputReference__checks.go
- GlueTriggerConfig.go
- GlueTriggerEventBatchingCondition.go
- GlueTriggerEventBatchingConditionList.go
- GlueTriggerEventBatchingConditionList__checks.go
- GlueTriggerEventBatchingConditionOutputReference.go
- GlueTriggerEventBatchingConditionOutputReference__checks.go
- GlueTriggerPredicate.go
- GlueTriggerPredicateConditions.go
- GlueTriggerPredicateConditionsList.go
- GlueTriggerPredicateConditionsList__checks.go
- GlueTriggerPredicateConditionsOutputReference.go
- GlueTriggerPredicateConditionsOutputReference__checks.go
- GlueTriggerPredicateOutputReference.go
- GlueTriggerPredicateOutputReference__checks.go
- GlueTriggerTimeouts.go
- GlueTriggerTimeoutsOutputReference.go
- GlueTriggerTimeoutsOutputReference__checks.go
- GlueTrigger__checks.go
- main.go