Documentation
¶
Index ¶
- func GrafanaWorkspaceApiKey_IsConstruct(x interface{}) *bool
- func GrafanaWorkspaceApiKey_IsTerraformElement(x interface{}) *bool
- func GrafanaWorkspaceApiKey_IsTerraformResource(x interface{}) *bool
- func GrafanaWorkspaceApiKey_TfResourceType() *string
- func NewGrafanaWorkspaceApiKey_Override(g GrafanaWorkspaceApiKey, scope constructs.Construct, id *string, ...)
- type GrafanaWorkspaceApiKey
- type GrafanaWorkspaceApiKeyConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GrafanaWorkspaceApiKey_IsConstruct ¶
func GrafanaWorkspaceApiKey_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GrafanaWorkspaceApiKey_IsTerraformElement ¶
func GrafanaWorkspaceApiKey_IsTerraformElement(x interface{}) *bool
Experimental.
func GrafanaWorkspaceApiKey_IsTerraformResource ¶
func GrafanaWorkspaceApiKey_IsTerraformResource(x interface{}) *bool
Experimental.
func GrafanaWorkspaceApiKey_TfResourceType ¶
func GrafanaWorkspaceApiKey_TfResourceType() *string
func NewGrafanaWorkspaceApiKey_Override ¶
func NewGrafanaWorkspaceApiKey_Override(g GrafanaWorkspaceApiKey, scope constructs.Construct, id *string, config *GrafanaWorkspaceApiKeyConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_api_key aws_grafana_workspace_api_key} Resource.
Types ¶
type GrafanaWorkspaceApiKey ¶
type GrafanaWorkspaceApiKey interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Key() *string
KeyName() *string
SetKeyName(val *string)
KeyNameInput() *string
KeyRole() *string
SetKeyRole(val *string)
KeyRoleInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SecondsToLive() *float64
SetSecondsToLive(val *float64)
SecondsToLiveInput() *float64
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
WorkspaceId() *string
SetWorkspaceId(val *string)
WorkspaceIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_api_key aws_grafana_workspace_api_key}.
func NewGrafanaWorkspaceApiKey ¶
func NewGrafanaWorkspaceApiKey(scope constructs.Construct, id *string, config *GrafanaWorkspaceApiKeyConfig) GrafanaWorkspaceApiKey
Create a new {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_api_key aws_grafana_workspace_api_key} Resource.
type GrafanaWorkspaceApiKeyConfig ¶
type GrafanaWorkspaceApiKeyConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_api_key#key_name GrafanaWorkspaceApiKey#key_name}.
KeyName *string `field:"required" json:"keyName" yaml:"keyName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_api_key#key_role GrafanaWorkspaceApiKey#key_role}.
KeyRole *string `field:"required" json:"keyRole" yaml:"keyRole"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_api_key#seconds_to_live GrafanaWorkspaceApiKey#seconds_to_live}.
SecondsToLive *float64 `field:"required" json:"secondsToLive" yaml:"secondsToLive"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_api_key#workspace_id GrafanaWorkspaceApiKey#workspace_id}.
WorkspaceId *string `field:"required" json:"workspaceId" yaml:"workspaceId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/grafana_workspace_api_key#id GrafanaWorkspaceApiKey#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}