Documentation
¶
Index ¶
- func GuarddutyDetector_IsConstruct(x interface{}) *bool
- func GuarddutyDetector_IsTerraformElement(x interface{}) *bool
- func GuarddutyDetector_IsTerraformResource(x interface{}) *bool
- func GuarddutyDetector_TfResourceType() *string
- func NewGuarddutyDetectorDatasourcesKubernetesAuditLogsOutputReference_Override(g GuarddutyDetectorDatasourcesKubernetesAuditLogsOutputReference, ...)
- func NewGuarddutyDetectorDatasourcesKubernetesOutputReference_Override(g GuarddutyDetectorDatasourcesKubernetesOutputReference, ...)
- func NewGuarddutyDetectorDatasourcesMalwareProtectionOutputReference_Override(g GuarddutyDetectorDatasourcesMalwareProtectionOutputReference, ...)
- func NewGuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference_Override(...)
- func NewGuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference_Override(...)
- func NewGuarddutyDetectorDatasourcesOutputReference_Override(g GuarddutyDetectorDatasourcesOutputReference, ...)
- func NewGuarddutyDetectorDatasourcesS3LogsOutputReference_Override(g GuarddutyDetectorDatasourcesS3LogsOutputReference, ...)
- func NewGuarddutyDetector_Override(g GuarddutyDetector, scope constructs.Construct, id *string, ...)
- type GuarddutyDetector
- type GuarddutyDetectorConfig
- type GuarddutyDetectorDatasources
- type GuarddutyDetectorDatasourcesKubernetes
- type GuarddutyDetectorDatasourcesKubernetesAuditLogs
- type GuarddutyDetectorDatasourcesKubernetesAuditLogsOutputReference
- type GuarddutyDetectorDatasourcesKubernetesOutputReference
- type GuarddutyDetectorDatasourcesMalwareProtection
- type GuarddutyDetectorDatasourcesMalwareProtectionOutputReference
- type GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings
- type GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes
- type GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference
- type GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference
- type GuarddutyDetectorDatasourcesOutputReference
- type GuarddutyDetectorDatasourcesS3Logs
- type GuarddutyDetectorDatasourcesS3LogsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GuarddutyDetector_IsConstruct ¶
func GuarddutyDetector_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GuarddutyDetector_IsTerraformElement ¶
func GuarddutyDetector_IsTerraformElement(x interface{}) *bool
Experimental.
func GuarddutyDetector_IsTerraformResource ¶
func GuarddutyDetector_IsTerraformResource(x interface{}) *bool
Experimental.
func GuarddutyDetector_TfResourceType ¶
func GuarddutyDetector_TfResourceType() *string
func NewGuarddutyDetectorDatasourcesKubernetesAuditLogsOutputReference_Override ¶
func NewGuarddutyDetectorDatasourcesKubernetesAuditLogsOutputReference_Override(g GuarddutyDetectorDatasourcesKubernetesAuditLogsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGuarddutyDetectorDatasourcesKubernetesOutputReference_Override ¶
func NewGuarddutyDetectorDatasourcesKubernetesOutputReference_Override(g GuarddutyDetectorDatasourcesKubernetesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGuarddutyDetectorDatasourcesMalwareProtectionOutputReference_Override ¶
func NewGuarddutyDetectorDatasourcesMalwareProtectionOutputReference_Override(g GuarddutyDetectorDatasourcesMalwareProtectionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference_Override ¶
func NewGuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference_Override(g GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference_Override ¶
func NewGuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference_Override(g GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGuarddutyDetectorDatasourcesOutputReference_Override ¶
func NewGuarddutyDetectorDatasourcesOutputReference_Override(g GuarddutyDetectorDatasourcesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGuarddutyDetectorDatasourcesS3LogsOutputReference_Override ¶
func NewGuarddutyDetectorDatasourcesS3LogsOutputReference_Override(g GuarddutyDetectorDatasourcesS3LogsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGuarddutyDetector_Override ¶
func NewGuarddutyDetector_Override(g GuarddutyDetector, scope constructs.Construct, id *string, config *GuarddutyDetectorConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector aws_guardduty_detector} Resource.
Types ¶
type GuarddutyDetector ¶
type GuarddutyDetector interface {
cdktf.TerraformResource
AccountId() *string
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
Datasources() GuarddutyDetectorDatasourcesOutputReference
DatasourcesInput() *GuarddutyDetectorDatasources
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Enable() interface{}
SetEnable(val interface{})
EnableInput() interface{}
FindingPublishingFrequency() *string
SetFindingPublishingFrequency(val *string)
FindingPublishingFrequencyInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDatasources(value *GuarddutyDetectorDatasources)
ResetDatasources()
ResetEnable()
ResetFindingPublishingFrequency()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector aws_guardduty_detector}.
func NewGuarddutyDetector ¶
func NewGuarddutyDetector(scope constructs.Construct, id *string, config *GuarddutyDetectorConfig) GuarddutyDetector
Create a new {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector aws_guardduty_detector} Resource.
type GuarddutyDetectorConfig ¶
type GuarddutyDetectorConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// datasources block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#datasources GuarddutyDetector#datasources}
Datasources *GuarddutyDetectorDatasources `field:"optional" json:"datasources" yaml:"datasources"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#enable GuarddutyDetector#enable}.
Enable interface{} `field:"optional" json:"enable" yaml:"enable"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#finding_publishing_frequency GuarddutyDetector#finding_publishing_frequency}.
FindingPublishingFrequency *string `field:"optional" json:"findingPublishingFrequency" yaml:"findingPublishingFrequency"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#id GuarddutyDetector#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#tags GuarddutyDetector#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#tags_all GuarddutyDetector#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type GuarddutyDetectorDatasources ¶
type GuarddutyDetectorDatasources struct {
// kubernetes block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#kubernetes GuarddutyDetector#kubernetes}
Kubernetes *GuarddutyDetectorDatasourcesKubernetes `field:"optional" json:"kubernetes" yaml:"kubernetes"`
// malware_protection block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#malware_protection GuarddutyDetector#malware_protection}
MalwareProtection *GuarddutyDetectorDatasourcesMalwareProtection `field:"optional" json:"malwareProtection" yaml:"malwareProtection"`
// s3_logs block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#s3_logs GuarddutyDetector#s3_logs}
S3Logs *GuarddutyDetectorDatasourcesS3Logs `field:"optional" json:"s3Logs" yaml:"s3Logs"`
}
type GuarddutyDetectorDatasourcesKubernetes ¶
type GuarddutyDetectorDatasourcesKubernetes struct {
// audit_logs block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#audit_logs GuarddutyDetector#audit_logs}
AuditLogs *GuarddutyDetectorDatasourcesKubernetesAuditLogs `field:"required" json:"auditLogs" yaml:"auditLogs"`
}
type GuarddutyDetectorDatasourcesKubernetesAuditLogs ¶
type GuarddutyDetectorDatasourcesKubernetesAuditLogs struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#enable GuarddutyDetector#enable}.
Enable interface{} `field:"required" json:"enable" yaml:"enable"`
}
type GuarddutyDetectorDatasourcesKubernetesAuditLogsOutputReference ¶
type GuarddutyDetectorDatasourcesKubernetesAuditLogsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enable() interface{}
SetEnable(val interface{})
EnableInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *GuarddutyDetectorDatasourcesKubernetesAuditLogs
SetInternalValue(val *GuarddutyDetectorDatasourcesKubernetesAuditLogs)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGuarddutyDetectorDatasourcesKubernetesAuditLogsOutputReference ¶
func NewGuarddutyDetectorDatasourcesKubernetesAuditLogsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GuarddutyDetectorDatasourcesKubernetesAuditLogsOutputReference
type GuarddutyDetectorDatasourcesKubernetesOutputReference ¶
type GuarddutyDetectorDatasourcesKubernetesOutputReference interface {
cdktf.ComplexObject
AuditLogs() GuarddutyDetectorDatasourcesKubernetesAuditLogsOutputReference
AuditLogsInput() *GuarddutyDetectorDatasourcesKubernetesAuditLogs
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GuarddutyDetectorDatasourcesKubernetes
SetInternalValue(val *GuarddutyDetectorDatasourcesKubernetes)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAuditLogs(value *GuarddutyDetectorDatasourcesKubernetesAuditLogs)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGuarddutyDetectorDatasourcesKubernetesOutputReference ¶
func NewGuarddutyDetectorDatasourcesKubernetesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GuarddutyDetectorDatasourcesKubernetesOutputReference
type GuarddutyDetectorDatasourcesMalwareProtection ¶
type GuarddutyDetectorDatasourcesMalwareProtection struct {
// scan_ec2_instance_with_findings block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#scan_ec2_instance_with_findings GuarddutyDetector#scan_ec2_instance_with_findings}
ScanEc2InstanceWithFindings *GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings `field:"required" json:"scanEc2InstanceWithFindings" yaml:"scanEc2InstanceWithFindings"`
}
type GuarddutyDetectorDatasourcesMalwareProtectionOutputReference ¶
type GuarddutyDetectorDatasourcesMalwareProtectionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GuarddutyDetectorDatasourcesMalwareProtection
SetInternalValue(val *GuarddutyDetectorDatasourcesMalwareProtection)
ScanEc2InstanceWithFindings() GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference
ScanEc2InstanceWithFindingsInput() *GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutScanEc2InstanceWithFindings(value *GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGuarddutyDetectorDatasourcesMalwareProtectionOutputReference ¶
func NewGuarddutyDetectorDatasourcesMalwareProtectionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GuarddutyDetectorDatasourcesMalwareProtectionOutputReference
type GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings ¶
type GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings struct {
// ebs_volumes block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#ebs_volumes GuarddutyDetector#ebs_volumes}
EbsVolumes *GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes `field:"required" json:"ebsVolumes" yaml:"ebsVolumes"`
}
type GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes ¶
type GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#enable GuarddutyDetector#enable}.
Enable interface{} `field:"required" json:"enable" yaml:"enable"`
}
type GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference ¶
type GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enable() interface{}
SetEnable(val interface{})
EnableInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes
SetInternalValue(val *GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference ¶
func NewGuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference
type GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference ¶
type GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EbsVolumes() GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference
EbsVolumesInput() *GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes
// Experimental.
Fqn() *string
InternalValue() *GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings
SetInternalValue(val *GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutEbsVolumes(value *GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference ¶
func NewGuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference
type GuarddutyDetectorDatasourcesOutputReference ¶
type GuarddutyDetectorDatasourcesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GuarddutyDetectorDatasources
SetInternalValue(val *GuarddutyDetectorDatasources)
Kubernetes() GuarddutyDetectorDatasourcesKubernetesOutputReference
KubernetesInput() *GuarddutyDetectorDatasourcesKubernetes
MalwareProtection() GuarddutyDetectorDatasourcesMalwareProtectionOutputReference
MalwareProtectionInput() *GuarddutyDetectorDatasourcesMalwareProtection
S3Logs() GuarddutyDetectorDatasourcesS3LogsOutputReference
S3LogsInput() *GuarddutyDetectorDatasourcesS3Logs
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutKubernetes(value *GuarddutyDetectorDatasourcesKubernetes)
PutMalwareProtection(value *GuarddutyDetectorDatasourcesMalwareProtection)
PutS3Logs(value *GuarddutyDetectorDatasourcesS3Logs)
ResetKubernetes()
ResetMalwareProtection()
ResetS3Logs()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGuarddutyDetectorDatasourcesOutputReference ¶
func NewGuarddutyDetectorDatasourcesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GuarddutyDetectorDatasourcesOutputReference
type GuarddutyDetectorDatasourcesS3Logs ¶
type GuarddutyDetectorDatasourcesS3Logs struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#enable GuarddutyDetector#enable}.
Enable interface{} `field:"required" json:"enable" yaml:"enable"`
}
type GuarddutyDetectorDatasourcesS3LogsOutputReference ¶
type GuarddutyDetectorDatasourcesS3LogsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enable() interface{}
SetEnable(val interface{})
EnableInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *GuarddutyDetectorDatasourcesS3Logs
SetInternalValue(val *GuarddutyDetectorDatasourcesS3Logs)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGuarddutyDetectorDatasourcesS3LogsOutputReference ¶
func NewGuarddutyDetectorDatasourcesS3LogsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GuarddutyDetectorDatasourcesS3LogsOutputReference
Source Files
¶
- GuarddutyDetector.go
- GuarddutyDetectorConfig.go
- GuarddutyDetectorDatasources.go
- GuarddutyDetectorDatasourcesKubernetes.go
- GuarddutyDetectorDatasourcesKubernetesAuditLogs.go
- GuarddutyDetectorDatasourcesKubernetesAuditLogsOutputReference.go
- GuarddutyDetectorDatasourcesKubernetesAuditLogsOutputReference__checks.go
- GuarddutyDetectorDatasourcesKubernetesOutputReference.go
- GuarddutyDetectorDatasourcesKubernetesOutputReference__checks.go
- GuarddutyDetectorDatasourcesMalwareProtection.go
- GuarddutyDetectorDatasourcesMalwareProtectionOutputReference.go
- GuarddutyDetectorDatasourcesMalwareProtectionOutputReference__checks.go
- GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindings.go
- GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumes.go
- GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference.go
- GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsEbsVolumesOutputReference__checks.go
- GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference.go
- GuarddutyDetectorDatasourcesMalwareProtectionScanEc2InstanceWithFindingsOutputReference__checks.go
- GuarddutyDetectorDatasourcesOutputReference.go
- GuarddutyDetectorDatasourcesOutputReference__checks.go
- GuarddutyDetectorDatasourcesS3Logs.go
- GuarddutyDetectorDatasourcesS3LogsOutputReference.go
- GuarddutyDetectorDatasourcesS3LogsOutputReference__checks.go
- GuarddutyDetector__checks.go
- main.go