Documentation
¶
Index ¶
- func LicensemanagerGrant_IsConstruct(x interface{}) *bool
- func LicensemanagerGrant_IsTerraformElement(x interface{}) *bool
- func LicensemanagerGrant_IsTerraformResource(x interface{}) *bool
- func LicensemanagerGrant_TfResourceType() *string
- func NewLicensemanagerGrant_Override(l LicensemanagerGrant, scope constructs.Construct, id *string, ...)
- type LicensemanagerGrant
- type LicensemanagerGrantConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LicensemanagerGrant_IsConstruct ¶
func LicensemanagerGrant_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func LicensemanagerGrant_IsTerraformElement ¶
func LicensemanagerGrant_IsTerraformElement(x interface{}) *bool
Experimental.
func LicensemanagerGrant_IsTerraformResource ¶
func LicensemanagerGrant_IsTerraformResource(x interface{}) *bool
Experimental.
func LicensemanagerGrant_TfResourceType ¶
func LicensemanagerGrant_TfResourceType() *string
func NewLicensemanagerGrant_Override ¶
func NewLicensemanagerGrant_Override(l LicensemanagerGrant, scope constructs.Construct, id *string, config *LicensemanagerGrantConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/licensemanager_grant aws_licensemanager_grant} Resource.
Types ¶
type LicensemanagerGrant ¶
type LicensemanagerGrant interface {
cdktf.TerraformResource
AllowedOperations() *[]*string
SetAllowedOperations(val *[]*string)
AllowedOperationsInput() *[]*string
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HomeRegion() *string
Id() *string
SetId(val *string)
IdInput() *string
LicenseArn() *string
SetLicenseArn(val *string)
LicenseArnInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
ParentArn() *string
Principal() *string
SetPrincipal(val *string)
PrincipalInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Status() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Version() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/licensemanager_grant aws_licensemanager_grant}.
func NewLicensemanagerGrant ¶
func NewLicensemanagerGrant(scope constructs.Construct, id *string, config *LicensemanagerGrantConfig) LicensemanagerGrant
Create a new {@link https://www.terraform.io/docs/providers/aws/r/licensemanager_grant aws_licensemanager_grant} Resource.
type LicensemanagerGrantConfig ¶
type LicensemanagerGrantConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Allowed operations for the grant. This is a subset of the allowed operations on the license.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/licensemanager_grant#allowed_operations LicensemanagerGrant#allowed_operations}
AllowedOperations *[]*string `field:"required" json:"allowedOperations" yaml:"allowedOperations"`
// License ARN.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/licensemanager_grant#license_arn LicensemanagerGrant#license_arn}
LicenseArn *string `field:"required" json:"licenseArn" yaml:"licenseArn"`
// Name of the grant.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/licensemanager_grant#name LicensemanagerGrant#name}
Name *string `field:"required" json:"name" yaml:"name"`
// The grantee principal ARN.
//
// The target account for the grant in the form of the ARN for an account principal of the root user.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/licensemanager_grant#principal LicensemanagerGrant#principal}
Principal *string `field:"required" json:"principal" yaml:"principal"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/licensemanager_grant#id LicensemanagerGrant#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}