Documentation
¶
Index ¶
- func NetworkmanagerConnectPeer_IsConstruct(x interface{}) *bool
- func NetworkmanagerConnectPeer_IsTerraformElement(x interface{}) *bool
- func NetworkmanagerConnectPeer_IsTerraformResource(x interface{}) *bool
- func NetworkmanagerConnectPeer_TfResourceType() *string
- func NewNetworkmanagerConnectPeerBgpOptionsOutputReference_Override(n NetworkmanagerConnectPeerBgpOptionsOutputReference, ...)
- func NewNetworkmanagerConnectPeerConfigurationBgpConfigurationsList_Override(n NetworkmanagerConnectPeerConfigurationBgpConfigurationsList, ...)
- func NewNetworkmanagerConnectPeerConfigurationBgpConfigurationsOutputReference_Override(n NetworkmanagerConnectPeerConfigurationBgpConfigurationsOutputReference, ...)
- func NewNetworkmanagerConnectPeerConfigurationList_Override(n NetworkmanagerConnectPeerConfigurationList, ...)
- func NewNetworkmanagerConnectPeerConfigurationOutputReference_Override(n NetworkmanagerConnectPeerConfigurationOutputReference, ...)
- func NewNetworkmanagerConnectPeerTimeoutsOutputReference_Override(n NetworkmanagerConnectPeerTimeoutsOutputReference, ...)
- func NewNetworkmanagerConnectPeer_Override(n NetworkmanagerConnectPeer, scope constructs.Construct, id *string, ...)
- type NetworkmanagerConnectPeer
- type NetworkmanagerConnectPeerBgpOptions
- type NetworkmanagerConnectPeerBgpOptionsOutputReference
- type NetworkmanagerConnectPeerConfig
- type NetworkmanagerConnectPeerConfiguration
- type NetworkmanagerConnectPeerConfigurationBgpConfigurations
- type NetworkmanagerConnectPeerConfigurationBgpConfigurationsList
- type NetworkmanagerConnectPeerConfigurationBgpConfigurationsOutputReference
- type NetworkmanagerConnectPeerConfigurationList
- type NetworkmanagerConnectPeerConfigurationOutputReference
- type NetworkmanagerConnectPeerTimeouts
- type NetworkmanagerConnectPeerTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NetworkmanagerConnectPeer_IsConstruct ¶
func NetworkmanagerConnectPeer_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func NetworkmanagerConnectPeer_IsTerraformElement ¶
func NetworkmanagerConnectPeer_IsTerraformElement(x interface{}) *bool
Experimental.
func NetworkmanagerConnectPeer_IsTerraformResource ¶
func NetworkmanagerConnectPeer_IsTerraformResource(x interface{}) *bool
Experimental.
func NetworkmanagerConnectPeer_TfResourceType ¶
func NetworkmanagerConnectPeer_TfResourceType() *string
func NewNetworkmanagerConnectPeerBgpOptionsOutputReference_Override ¶
func NewNetworkmanagerConnectPeerBgpOptionsOutputReference_Override(n NetworkmanagerConnectPeerBgpOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewNetworkmanagerConnectPeerConfigurationBgpConfigurationsList_Override ¶
func NewNetworkmanagerConnectPeerConfigurationBgpConfigurationsList_Override(n NetworkmanagerConnectPeerConfigurationBgpConfigurationsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewNetworkmanagerConnectPeerConfigurationBgpConfigurationsOutputReference_Override ¶
func NewNetworkmanagerConnectPeerConfigurationBgpConfigurationsOutputReference_Override(n NetworkmanagerConnectPeerConfigurationBgpConfigurationsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewNetworkmanagerConnectPeerConfigurationList_Override ¶
func NewNetworkmanagerConnectPeerConfigurationList_Override(n NetworkmanagerConnectPeerConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewNetworkmanagerConnectPeerConfigurationOutputReference_Override ¶
func NewNetworkmanagerConnectPeerConfigurationOutputReference_Override(n NetworkmanagerConnectPeerConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewNetworkmanagerConnectPeerTimeoutsOutputReference_Override ¶
func NewNetworkmanagerConnectPeerTimeoutsOutputReference_Override(n NetworkmanagerConnectPeerTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewNetworkmanagerConnectPeer_Override ¶
func NewNetworkmanagerConnectPeer_Override(n NetworkmanagerConnectPeer, scope constructs.Construct, id *string, config *NetworkmanagerConnectPeerConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/networkmanager_connect_peer aws_networkmanager_connect_peer} Resource.
Types ¶
type NetworkmanagerConnectPeer ¶
type NetworkmanagerConnectPeer interface {
cdktf.TerraformResource
Arn() *string
BgpOptions() NetworkmanagerConnectPeerBgpOptionsOutputReference
BgpOptionsInput() *NetworkmanagerConnectPeerBgpOptions
// Experimental.
CdktfStack() cdktf.TerraformStack
Configuration() NetworkmanagerConnectPeerConfigurationList
ConnectAttachmentId() *string
SetConnectAttachmentId(val *string)
ConnectAttachmentIdInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
ConnectPeerId() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
CoreNetworkAddress() *string
SetCoreNetworkAddress(val *string)
CoreNetworkAddressInput() *string
CoreNetworkId() *string
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreatedAt() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EdgeLocation() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InsideCidrBlocks() *[]*string
SetInsideCidrBlocks(val *[]*string)
InsideCidrBlocksInput() *[]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
PeerAddress() *string
SetPeerAddress(val *string)
PeerAddressInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
State() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() NetworkmanagerConnectPeerTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutBgpOptions(value *NetworkmanagerConnectPeerBgpOptions)
PutTimeouts(value *NetworkmanagerConnectPeerTimeouts)
ResetBgpOptions()
ResetCoreNetworkAddress()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/networkmanager_connect_peer aws_networkmanager_connect_peer}.
func NewNetworkmanagerConnectPeer ¶
func NewNetworkmanagerConnectPeer(scope constructs.Construct, id *string, config *NetworkmanagerConnectPeerConfig) NetworkmanagerConnectPeer
Create a new {@link https://www.terraform.io/docs/providers/aws/r/networkmanager_connect_peer aws_networkmanager_connect_peer} Resource.
type NetworkmanagerConnectPeerBgpOptions ¶
type NetworkmanagerConnectPeerBgpOptions struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkmanager_connect_peer#peer_asn NetworkmanagerConnectPeer#peer_asn}.
PeerAsn *float64 `field:"optional" json:"peerAsn" yaml:"peerAsn"`
}
type NetworkmanagerConnectPeerBgpOptionsOutputReference ¶
type NetworkmanagerConnectPeerBgpOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *NetworkmanagerConnectPeerBgpOptions
SetInternalValue(val *NetworkmanagerConnectPeerBgpOptions)
PeerAsn() *float64
SetPeerAsn(val *float64)
PeerAsnInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetPeerAsn()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkmanagerConnectPeerBgpOptionsOutputReference ¶
func NewNetworkmanagerConnectPeerBgpOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) NetworkmanagerConnectPeerBgpOptionsOutputReference
type NetworkmanagerConnectPeerConfig ¶
type NetworkmanagerConnectPeerConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkmanager_connect_peer#connect_attachment_id NetworkmanagerConnectPeer#connect_attachment_id}.
ConnectAttachmentId *string `field:"required" json:"connectAttachmentId" yaml:"connectAttachmentId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkmanager_connect_peer#inside_cidr_blocks NetworkmanagerConnectPeer#inside_cidr_blocks}.
InsideCidrBlocks *[]*string `field:"required" json:"insideCidrBlocks" yaml:"insideCidrBlocks"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkmanager_connect_peer#peer_address NetworkmanagerConnectPeer#peer_address}.
PeerAddress *string `field:"required" json:"peerAddress" yaml:"peerAddress"`
// bgp_options block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkmanager_connect_peer#bgp_options NetworkmanagerConnectPeer#bgp_options}
BgpOptions *NetworkmanagerConnectPeerBgpOptions `field:"optional" json:"bgpOptions" yaml:"bgpOptions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkmanager_connect_peer#core_network_address NetworkmanagerConnectPeer#core_network_address}.
CoreNetworkAddress *string `field:"optional" json:"coreNetworkAddress" yaml:"coreNetworkAddress"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkmanager_connect_peer#id NetworkmanagerConnectPeer#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkmanager_connect_peer#tags NetworkmanagerConnectPeer#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkmanager_connect_peer#tags_all NetworkmanagerConnectPeer#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkmanager_connect_peer#timeouts NetworkmanagerConnectPeer#timeouts}
Timeouts *NetworkmanagerConnectPeerTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type NetworkmanagerConnectPeerConfiguration ¶
type NetworkmanagerConnectPeerConfiguration struct {
}
type NetworkmanagerConnectPeerConfigurationBgpConfigurations ¶
type NetworkmanagerConnectPeerConfigurationBgpConfigurations struct {
}
type NetworkmanagerConnectPeerConfigurationBgpConfigurationsList ¶
type NetworkmanagerConnectPeerConfigurationBgpConfigurationsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) NetworkmanagerConnectPeerConfigurationBgpConfigurationsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkmanagerConnectPeerConfigurationBgpConfigurationsList ¶
func NewNetworkmanagerConnectPeerConfigurationBgpConfigurationsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) NetworkmanagerConnectPeerConfigurationBgpConfigurationsList
type NetworkmanagerConnectPeerConfigurationBgpConfigurationsOutputReference ¶
type NetworkmanagerConnectPeerConfigurationBgpConfigurationsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CoreNetworkAddress() *string
CoreNetworkAsn() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *NetworkmanagerConnectPeerConfigurationBgpConfigurations
SetInternalValue(val *NetworkmanagerConnectPeerConfigurationBgpConfigurations)
PeerAddress() *string
PeerAsn() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkmanagerConnectPeerConfigurationBgpConfigurationsOutputReference ¶
func NewNetworkmanagerConnectPeerConfigurationBgpConfigurationsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) NetworkmanagerConnectPeerConfigurationBgpConfigurationsOutputReference
type NetworkmanagerConnectPeerConfigurationList ¶
type NetworkmanagerConnectPeerConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) NetworkmanagerConnectPeerConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkmanagerConnectPeerConfigurationList ¶
func NewNetworkmanagerConnectPeerConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) NetworkmanagerConnectPeerConfigurationList
type NetworkmanagerConnectPeerConfigurationOutputReference ¶
type NetworkmanagerConnectPeerConfigurationOutputReference interface {
cdktf.ComplexObject
BgpConfigurations() NetworkmanagerConnectPeerConfigurationBgpConfigurationsList
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CoreNetworkAddress() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InsideCidrBlocks() *[]*string
InternalValue() *NetworkmanagerConnectPeerConfiguration
SetInternalValue(val *NetworkmanagerConnectPeerConfiguration)
PeerAddress() *string
Protocol() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkmanagerConnectPeerConfigurationOutputReference ¶
func NewNetworkmanagerConnectPeerConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) NetworkmanagerConnectPeerConfigurationOutputReference
type NetworkmanagerConnectPeerTimeouts ¶
type NetworkmanagerConnectPeerTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkmanager_connect_peer#create NetworkmanagerConnectPeer#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkmanager_connect_peer#delete NetworkmanagerConnectPeer#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type NetworkmanagerConnectPeerTimeoutsOutputReference ¶
type NetworkmanagerConnectPeerTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkmanagerConnectPeerTimeoutsOutputReference ¶
func NewNetworkmanagerConnectPeerTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) NetworkmanagerConnectPeerTimeoutsOutputReference
Source Files
¶
- NetworkmanagerConnectPeer.go
- NetworkmanagerConnectPeerBgpOptions.go
- NetworkmanagerConnectPeerBgpOptionsOutputReference.go
- NetworkmanagerConnectPeerBgpOptionsOutputReference__checks.go
- NetworkmanagerConnectPeerConfig.go
- NetworkmanagerConnectPeerConfiguration.go
- NetworkmanagerConnectPeerConfigurationBgpConfigurations.go
- NetworkmanagerConnectPeerConfigurationBgpConfigurationsList.go
- NetworkmanagerConnectPeerConfigurationBgpConfigurationsList__checks.go
- NetworkmanagerConnectPeerConfigurationBgpConfigurationsOutputReference.go
- NetworkmanagerConnectPeerConfigurationBgpConfigurationsOutputReference__checks.go
- NetworkmanagerConnectPeerConfigurationList.go
- NetworkmanagerConnectPeerConfigurationList__checks.go
- NetworkmanagerConnectPeerConfigurationOutputReference.go
- NetworkmanagerConnectPeerConfigurationOutputReference__checks.go
- NetworkmanagerConnectPeerTimeouts.go
- NetworkmanagerConnectPeerTimeoutsOutputReference.go
- NetworkmanagerConnectPeerTimeoutsOutputReference__checks.go
- NetworkmanagerConnectPeer__checks.go
- main.go