Documentation
¶
Index ¶
- func NewOpsworksApplicationAppSourceList_Override(o OpsworksApplicationAppSourceList, ...)
- func NewOpsworksApplicationAppSourceOutputReference_Override(o OpsworksApplicationAppSourceOutputReference, ...)
- func NewOpsworksApplicationEnvironmentList_Override(o OpsworksApplicationEnvironmentList, ...)
- func NewOpsworksApplicationEnvironmentOutputReference_Override(o OpsworksApplicationEnvironmentOutputReference, ...)
- func NewOpsworksApplicationSslConfigurationList_Override(o OpsworksApplicationSslConfigurationList, ...)
- func NewOpsworksApplicationSslConfigurationOutputReference_Override(o OpsworksApplicationSslConfigurationOutputReference, ...)
- func NewOpsworksApplication_Override(o OpsworksApplication, scope constructs.Construct, id *string, ...)
- func OpsworksApplication_IsConstruct(x interface{}) *bool
- func OpsworksApplication_IsTerraformElement(x interface{}) *bool
- func OpsworksApplication_IsTerraformResource(x interface{}) *bool
- func OpsworksApplication_TfResourceType() *string
- type OpsworksApplication
- type OpsworksApplicationAppSource
- type OpsworksApplicationAppSourceList
- type OpsworksApplicationAppSourceOutputReference
- type OpsworksApplicationConfig
- type OpsworksApplicationEnvironment
- type OpsworksApplicationEnvironmentList
- type OpsworksApplicationEnvironmentOutputReference
- type OpsworksApplicationSslConfiguration
- type OpsworksApplicationSslConfigurationList
- type OpsworksApplicationSslConfigurationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewOpsworksApplicationAppSourceList_Override ¶
func NewOpsworksApplicationAppSourceList_Override(o OpsworksApplicationAppSourceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewOpsworksApplicationAppSourceOutputReference_Override ¶
func NewOpsworksApplicationAppSourceOutputReference_Override(o OpsworksApplicationAppSourceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewOpsworksApplicationEnvironmentList_Override ¶
func NewOpsworksApplicationEnvironmentList_Override(o OpsworksApplicationEnvironmentList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewOpsworksApplicationEnvironmentOutputReference_Override ¶
func NewOpsworksApplicationEnvironmentOutputReference_Override(o OpsworksApplicationEnvironmentOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewOpsworksApplicationSslConfigurationList_Override ¶
func NewOpsworksApplicationSslConfigurationList_Override(o OpsworksApplicationSslConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewOpsworksApplicationSslConfigurationOutputReference_Override ¶
func NewOpsworksApplicationSslConfigurationOutputReference_Override(o OpsworksApplicationSslConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewOpsworksApplication_Override ¶
func NewOpsworksApplication_Override(o OpsworksApplication, scope constructs.Construct, id *string, config *OpsworksApplicationConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application aws_opsworks_application} Resource.
func OpsworksApplication_IsConstruct ¶
func OpsworksApplication_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func OpsworksApplication_IsTerraformElement ¶
func OpsworksApplication_IsTerraformElement(x interface{}) *bool
Experimental.
func OpsworksApplication_IsTerraformResource ¶
func OpsworksApplication_IsTerraformResource(x interface{}) *bool
Experimental.
func OpsworksApplication_TfResourceType ¶
func OpsworksApplication_TfResourceType() *string
Types ¶
type OpsworksApplication ¶
type OpsworksApplication interface {
cdktf.TerraformResource
AppSource() OpsworksApplicationAppSourceList
AppSourceInput() interface{}
AutoBundleOnDeploy() *string
SetAutoBundleOnDeploy(val *string)
AutoBundleOnDeployInput() *string
AwsFlowRubySettings() *string
SetAwsFlowRubySettings(val *string)
AwsFlowRubySettingsInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DataSourceArn() *string
SetDataSourceArn(val *string)
DataSourceArnInput() *string
DataSourceDatabaseName() *string
SetDataSourceDatabaseName(val *string)
DataSourceDatabaseNameInput() *string
DataSourceType() *string
SetDataSourceType(val *string)
DataSourceTypeInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DocumentRoot() *string
SetDocumentRoot(val *string)
DocumentRootInput() *string
Domains() *[]*string
SetDomains(val *[]*string)
DomainsInput() *[]*string
EnableSsl() interface{}
SetEnableSsl(val interface{})
EnableSslInput() interface{}
Environment() OpsworksApplicationEnvironmentList
EnvironmentInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
RailsEnv() *string
SetRailsEnv(val *string)
RailsEnvInput() *string
// Experimental.
RawOverrides() interface{}
ShortName() *string
SetShortName(val *string)
ShortNameInput() *string
SslConfiguration() OpsworksApplicationSslConfigurationList
SslConfigurationInput() interface{}
StackId() *string
SetStackId(val *string)
StackIdInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAppSource(value interface{})
PutEnvironment(value interface{})
PutSslConfiguration(value interface{})
ResetAppSource()
ResetAutoBundleOnDeploy()
ResetAwsFlowRubySettings()
ResetDataSourceArn()
ResetDataSourceDatabaseName()
ResetDataSourceType()
ResetDescription()
ResetDocumentRoot()
ResetDomains()
ResetEnableSsl()
ResetEnvironment()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRailsEnv()
ResetShortName()
ResetSslConfiguration()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application aws_opsworks_application}.
func NewOpsworksApplication ¶
func NewOpsworksApplication(scope constructs.Construct, id *string, config *OpsworksApplicationConfig) OpsworksApplication
Create a new {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application aws_opsworks_application} Resource.
type OpsworksApplicationAppSource ¶
type OpsworksApplicationAppSource struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#type OpsworksApplication#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#password OpsworksApplication#password}.
Password *string `field:"optional" json:"password" yaml:"password"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#revision OpsworksApplication#revision}.
Revision *string `field:"optional" json:"revision" yaml:"revision"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#ssh_key OpsworksApplication#ssh_key}.
SshKey *string `field:"optional" json:"sshKey" yaml:"sshKey"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#url OpsworksApplication#url}.
Url *string `field:"optional" json:"url" yaml:"url"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#username OpsworksApplication#username}.
Username *string `field:"optional" json:"username" yaml:"username"`
}
type OpsworksApplicationAppSourceList ¶
type OpsworksApplicationAppSourceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) OpsworksApplicationAppSourceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksApplicationAppSourceList ¶
func NewOpsworksApplicationAppSourceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) OpsworksApplicationAppSourceList
type OpsworksApplicationAppSourceOutputReference ¶
type OpsworksApplicationAppSourceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Password() *string
SetPassword(val *string)
PasswordInput() *string
Revision() *string
SetRevision(val *string)
RevisionInput() *string
SshKey() *string
SetSshKey(val *string)
SshKeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
Url() *string
SetUrl(val *string)
UrlInput() *string
Username() *string
SetUsername(val *string)
UsernameInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetPassword()
ResetRevision()
ResetSshKey()
ResetUrl()
ResetUsername()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksApplicationAppSourceOutputReference ¶
func NewOpsworksApplicationAppSourceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) OpsworksApplicationAppSourceOutputReference
type OpsworksApplicationConfig ¶
type OpsworksApplicationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#name OpsworksApplication#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#stack_id OpsworksApplication#stack_id}.
StackId *string `field:"required" json:"stackId" yaml:"stackId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#type OpsworksApplication#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// app_source block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#app_source OpsworksApplication#app_source}
AppSource interface{} `field:"optional" json:"appSource" yaml:"appSource"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#auto_bundle_on_deploy OpsworksApplication#auto_bundle_on_deploy}.
AutoBundleOnDeploy *string `field:"optional" json:"autoBundleOnDeploy" yaml:"autoBundleOnDeploy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#aws_flow_ruby_settings OpsworksApplication#aws_flow_ruby_settings}.
AwsFlowRubySettings *string `field:"optional" json:"awsFlowRubySettings" yaml:"awsFlowRubySettings"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#data_source_arn OpsworksApplication#data_source_arn}.
DataSourceArn *string `field:"optional" json:"dataSourceArn" yaml:"dataSourceArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#data_source_database_name OpsworksApplication#data_source_database_name}.
DataSourceDatabaseName *string `field:"optional" json:"dataSourceDatabaseName" yaml:"dataSourceDatabaseName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#data_source_type OpsworksApplication#data_source_type}.
DataSourceType *string `field:"optional" json:"dataSourceType" yaml:"dataSourceType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#description OpsworksApplication#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#document_root OpsworksApplication#document_root}.
DocumentRoot *string `field:"optional" json:"documentRoot" yaml:"documentRoot"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#domains OpsworksApplication#domains}.
Domains *[]*string `field:"optional" json:"domains" yaml:"domains"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#enable_ssl OpsworksApplication#enable_ssl}.
EnableSsl interface{} `field:"optional" json:"enableSsl" yaml:"enableSsl"`
// environment block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#environment OpsworksApplication#environment}
Environment interface{} `field:"optional" json:"environment" yaml:"environment"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#id OpsworksApplication#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#rails_env OpsworksApplication#rails_env}.
RailsEnv *string `field:"optional" json:"railsEnv" yaml:"railsEnv"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#short_name OpsworksApplication#short_name}.
ShortName *string `field:"optional" json:"shortName" yaml:"shortName"`
// ssl_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#ssl_configuration OpsworksApplication#ssl_configuration}
SslConfiguration interface{} `field:"optional" json:"sslConfiguration" yaml:"sslConfiguration"`
}
type OpsworksApplicationEnvironment ¶
type OpsworksApplicationEnvironment struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#key OpsworksApplication#key}.
Key *string `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#value OpsworksApplication#value}.
Value *string `field:"required" json:"value" yaml:"value"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#secure OpsworksApplication#secure}.
Secure interface{} `field:"optional" json:"secure" yaml:"secure"`
}
type OpsworksApplicationEnvironmentList ¶
type OpsworksApplicationEnvironmentList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) OpsworksApplicationEnvironmentOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksApplicationEnvironmentList ¶
func NewOpsworksApplicationEnvironmentList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) OpsworksApplicationEnvironmentList
type OpsworksApplicationEnvironmentOutputReference ¶
type OpsworksApplicationEnvironmentOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Key() *string
SetKey(val *string)
KeyInput() *string
Secure() interface{}
SetSecure(val interface{})
SecureInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetSecure()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksApplicationEnvironmentOutputReference ¶
func NewOpsworksApplicationEnvironmentOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) OpsworksApplicationEnvironmentOutputReference
type OpsworksApplicationSslConfiguration ¶
type OpsworksApplicationSslConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#certificate OpsworksApplication#certificate}.
Certificate *string `field:"required" json:"certificate" yaml:"certificate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#private_key OpsworksApplication#private_key}.
PrivateKey *string `field:"required" json:"privateKey" yaml:"privateKey"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_application#chain OpsworksApplication#chain}.
Chain *string `field:"optional" json:"chain" yaml:"chain"`
}
type OpsworksApplicationSslConfigurationList ¶
type OpsworksApplicationSslConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) OpsworksApplicationSslConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksApplicationSslConfigurationList ¶
func NewOpsworksApplicationSslConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) OpsworksApplicationSslConfigurationList
type OpsworksApplicationSslConfigurationOutputReference ¶
type OpsworksApplicationSslConfigurationOutputReference interface {
cdktf.ComplexObject
Certificate() *string
SetCertificate(val *string)
CertificateInput() *string
Chain() *string
SetChain(val *string)
ChainInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
PrivateKey() *string
SetPrivateKey(val *string)
PrivateKeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetChain()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksApplicationSslConfigurationOutputReference ¶
func NewOpsworksApplicationSslConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) OpsworksApplicationSslConfigurationOutputReference
Source Files
¶
- OpsworksApplication.go
- OpsworksApplicationAppSource.go
- OpsworksApplicationAppSourceList.go
- OpsworksApplicationAppSourceList__checks.go
- OpsworksApplicationAppSourceOutputReference.go
- OpsworksApplicationAppSourceOutputReference__checks.go
- OpsworksApplicationConfig.go
- OpsworksApplicationEnvironment.go
- OpsworksApplicationEnvironmentList.go
- OpsworksApplicationEnvironmentList__checks.go
- OpsworksApplicationEnvironmentOutputReference.go
- OpsworksApplicationEnvironmentOutputReference__checks.go
- OpsworksApplicationSslConfiguration.go
- OpsworksApplicationSslConfigurationList.go
- OpsworksApplicationSslConfigurationList__checks.go
- OpsworksApplicationSslConfigurationOutputReference.go
- OpsworksApplicationSslConfigurationOutputReference__checks.go
- OpsworksApplication__checks.go
- main.go