Documentation
¶
Index ¶
- func NewOpsworksInstanceEbsBlockDeviceList_Override(o OpsworksInstanceEbsBlockDeviceList, ...)
- func NewOpsworksInstanceEbsBlockDeviceOutputReference_Override(o OpsworksInstanceEbsBlockDeviceOutputReference, ...)
- func NewOpsworksInstanceEphemeralBlockDeviceList_Override(o OpsworksInstanceEphemeralBlockDeviceList, ...)
- func NewOpsworksInstanceEphemeralBlockDeviceOutputReference_Override(o OpsworksInstanceEphemeralBlockDeviceOutputReference, ...)
- func NewOpsworksInstanceRootBlockDeviceList_Override(o OpsworksInstanceRootBlockDeviceList, ...)
- func NewOpsworksInstanceRootBlockDeviceOutputReference_Override(o OpsworksInstanceRootBlockDeviceOutputReference, ...)
- func NewOpsworksInstanceTimeoutsOutputReference_Override(o OpsworksInstanceTimeoutsOutputReference, ...)
- func NewOpsworksInstance_Override(o OpsworksInstance, scope constructs.Construct, id *string, ...)
- func OpsworksInstance_IsConstruct(x interface{}) *bool
- func OpsworksInstance_IsTerraformElement(x interface{}) *bool
- func OpsworksInstance_IsTerraformResource(x interface{}) *bool
- func OpsworksInstance_TfResourceType() *string
- type OpsworksInstance
- type OpsworksInstanceConfig
- type OpsworksInstanceEbsBlockDevice
- type OpsworksInstanceEbsBlockDeviceList
- type OpsworksInstanceEbsBlockDeviceOutputReference
- type OpsworksInstanceEphemeralBlockDevice
- type OpsworksInstanceEphemeralBlockDeviceList
- type OpsworksInstanceEphemeralBlockDeviceOutputReference
- type OpsworksInstanceRootBlockDevice
- type OpsworksInstanceRootBlockDeviceList
- type OpsworksInstanceRootBlockDeviceOutputReference
- type OpsworksInstanceTimeouts
- type OpsworksInstanceTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewOpsworksInstanceEbsBlockDeviceList_Override ¶
func NewOpsworksInstanceEbsBlockDeviceList_Override(o OpsworksInstanceEbsBlockDeviceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewOpsworksInstanceEbsBlockDeviceOutputReference_Override ¶
func NewOpsworksInstanceEbsBlockDeviceOutputReference_Override(o OpsworksInstanceEbsBlockDeviceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewOpsworksInstanceEphemeralBlockDeviceList_Override ¶
func NewOpsworksInstanceEphemeralBlockDeviceList_Override(o OpsworksInstanceEphemeralBlockDeviceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewOpsworksInstanceEphemeralBlockDeviceOutputReference_Override ¶
func NewOpsworksInstanceEphemeralBlockDeviceOutputReference_Override(o OpsworksInstanceEphemeralBlockDeviceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewOpsworksInstanceRootBlockDeviceList_Override ¶
func NewOpsworksInstanceRootBlockDeviceList_Override(o OpsworksInstanceRootBlockDeviceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewOpsworksInstanceRootBlockDeviceOutputReference_Override ¶
func NewOpsworksInstanceRootBlockDeviceOutputReference_Override(o OpsworksInstanceRootBlockDeviceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewOpsworksInstanceTimeoutsOutputReference_Override ¶
func NewOpsworksInstanceTimeoutsOutputReference_Override(o OpsworksInstanceTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpsworksInstance_Override ¶
func NewOpsworksInstance_Override(o OpsworksInstance, scope constructs.Construct, id *string, config *OpsworksInstanceConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance aws_opsworks_instance} Resource.
func OpsworksInstance_IsConstruct ¶
func OpsworksInstance_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func OpsworksInstance_IsTerraformElement ¶
func OpsworksInstance_IsTerraformElement(x interface{}) *bool
Experimental.
func OpsworksInstance_IsTerraformResource ¶
func OpsworksInstance_IsTerraformResource(x interface{}) *bool
Experimental.
func OpsworksInstance_TfResourceType ¶
func OpsworksInstance_TfResourceType() *string
Types ¶
type OpsworksInstance ¶
type OpsworksInstance interface {
cdktf.TerraformResource
AgentVersion() *string
SetAgentVersion(val *string)
AgentVersionInput() *string
AmiId() *string
SetAmiId(val *string)
AmiIdInput() *string
Architecture() *string
SetArchitecture(val *string)
ArchitectureInput() *string
AutoScalingType() *string
SetAutoScalingType(val *string)
AutoScalingTypeInput() *string
AvailabilityZone() *string
SetAvailabilityZone(val *string)
AvailabilityZoneInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreatedAt() *string
SetCreatedAt(val *string)
CreatedAtInput() *string
DeleteEbs() interface{}
SetDeleteEbs(val interface{})
DeleteEbsInput() interface{}
DeleteEip() interface{}
SetDeleteEip(val interface{})
DeleteEipInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EbsBlockDevice() OpsworksInstanceEbsBlockDeviceList
EbsBlockDeviceInput() interface{}
EbsOptimized() interface{}
SetEbsOptimized(val interface{})
EbsOptimizedInput() interface{}
Ec2InstanceId() *string
EcsClusterArn() *string
SetEcsClusterArn(val *string)
EcsClusterArnInput() *string
ElasticIp() *string
SetElasticIp(val *string)
ElasticIpInput() *string
EphemeralBlockDevice() OpsworksInstanceEphemeralBlockDeviceList
EphemeralBlockDeviceInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Hostname() *string
SetHostname(val *string)
HostnameInput() *string
Id() *string
SetId(val *string)
IdInput() *string
InfrastructureClass() *string
SetInfrastructureClass(val *string)
InfrastructureClassInput() *string
InstallUpdatesOnBoot() interface{}
SetInstallUpdatesOnBoot(val interface{})
InstallUpdatesOnBootInput() interface{}
InstanceProfileArn() *string
SetInstanceProfileArn(val *string)
InstanceProfileArnInput() *string
InstanceType() *string
SetInstanceType(val *string)
InstanceTypeInput() *string
LastServiceErrorId() *string
LayerIds() *[]*string
SetLayerIds(val *[]*string)
LayerIdsInput() *[]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
Os() *string
SetOs(val *string)
OsInput() *string
Platform() *string
PrivateDns() *string
PrivateIp() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
PublicDns() *string
PublicIp() *string
// Experimental.
RawOverrides() interface{}
RegisteredBy() *string
ReportedAgentVersion() *string
ReportedOsFamily() *string
ReportedOsName() *string
ReportedOsVersion() *string
RootBlockDevice() OpsworksInstanceRootBlockDeviceList
RootBlockDeviceInput() interface{}
RootDeviceType() *string
SetRootDeviceType(val *string)
RootDeviceTypeInput() *string
RootDeviceVolumeId() *string
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
SshHostDsaKeyFingerprint() *string
SshHostRsaKeyFingerprint() *string
SshKeyName() *string
SetSshKeyName(val *string)
SshKeyNameInput() *string
StackId() *string
SetStackId(val *string)
StackIdInput() *string
State() *string
SetState(val *string)
StateInput() *string
Status() *string
SetStatus(val *string)
StatusInput() *string
SubnetId() *string
SetSubnetId(val *string)
SubnetIdInput() *string
Tenancy() *string
SetTenancy(val *string)
TenancyInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() OpsworksInstanceTimeoutsOutputReference
TimeoutsInput() interface{}
VirtualizationType() *string
SetVirtualizationType(val *string)
VirtualizationTypeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutEbsBlockDevice(value interface{})
PutEphemeralBlockDevice(value interface{})
PutRootBlockDevice(value interface{})
PutTimeouts(value *OpsworksInstanceTimeouts)
ResetAgentVersion()
ResetAmiId()
ResetArchitecture()
ResetAutoScalingType()
ResetAvailabilityZone()
ResetCreatedAt()
ResetDeleteEbs()
ResetDeleteEip()
ResetEbsBlockDevice()
ResetEbsOptimized()
ResetEcsClusterArn()
ResetElasticIp()
ResetEphemeralBlockDevice()
ResetHostname()
ResetId()
ResetInfrastructureClass()
ResetInstallUpdatesOnBoot()
ResetInstanceProfileArn()
ResetInstanceType()
ResetOs()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRootBlockDevice()
ResetRootDeviceType()
ResetSecurityGroupIds()
ResetSshKeyName()
ResetState()
ResetStatus()
ResetSubnetId()
ResetTenancy()
ResetTimeouts()
ResetVirtualizationType()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance aws_opsworks_instance}.
func NewOpsworksInstance ¶
func NewOpsworksInstance(scope constructs.Construct, id *string, config *OpsworksInstanceConfig) OpsworksInstance
Create a new {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance aws_opsworks_instance} Resource.
type OpsworksInstanceConfig ¶
type OpsworksInstanceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#layer_ids OpsworksInstance#layer_ids}.
LayerIds *[]*string `field:"required" json:"layerIds" yaml:"layerIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#stack_id OpsworksInstance#stack_id}.
StackId *string `field:"required" json:"stackId" yaml:"stackId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#agent_version OpsworksInstance#agent_version}.
AgentVersion *string `field:"optional" json:"agentVersion" yaml:"agentVersion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#ami_id OpsworksInstance#ami_id}.
AmiId *string `field:"optional" json:"amiId" yaml:"amiId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#architecture OpsworksInstance#architecture}.
Architecture *string `field:"optional" json:"architecture" yaml:"architecture"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#auto_scaling_type OpsworksInstance#auto_scaling_type}.
AutoScalingType *string `field:"optional" json:"autoScalingType" yaml:"autoScalingType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#availability_zone OpsworksInstance#availability_zone}.
AvailabilityZone *string `field:"optional" json:"availabilityZone" yaml:"availabilityZone"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#created_at OpsworksInstance#created_at}.
CreatedAt *string `field:"optional" json:"createdAt" yaml:"createdAt"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#delete_ebs OpsworksInstance#delete_ebs}.
DeleteEbs interface{} `field:"optional" json:"deleteEbs" yaml:"deleteEbs"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#delete_eip OpsworksInstance#delete_eip}.
DeleteEip interface{} `field:"optional" json:"deleteEip" yaml:"deleteEip"`
// ebs_block_device block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#ebs_block_device OpsworksInstance#ebs_block_device}
EbsBlockDevice interface{} `field:"optional" json:"ebsBlockDevice" yaml:"ebsBlockDevice"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#ebs_optimized OpsworksInstance#ebs_optimized}.
EbsOptimized interface{} `field:"optional" json:"ebsOptimized" yaml:"ebsOptimized"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#ecs_cluster_arn OpsworksInstance#ecs_cluster_arn}.
EcsClusterArn *string `field:"optional" json:"ecsClusterArn" yaml:"ecsClusterArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#elastic_ip OpsworksInstance#elastic_ip}.
ElasticIp *string `field:"optional" json:"elasticIp" yaml:"elasticIp"`
// ephemeral_block_device block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#ephemeral_block_device OpsworksInstance#ephemeral_block_device}
EphemeralBlockDevice interface{} `field:"optional" json:"ephemeralBlockDevice" yaml:"ephemeralBlockDevice"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#hostname OpsworksInstance#hostname}.
Hostname *string `field:"optional" json:"hostname" yaml:"hostname"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#id OpsworksInstance#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#infrastructure_class OpsworksInstance#infrastructure_class}.
InfrastructureClass *string `field:"optional" json:"infrastructureClass" yaml:"infrastructureClass"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#install_updates_on_boot OpsworksInstance#install_updates_on_boot}.
InstallUpdatesOnBoot interface{} `field:"optional" json:"installUpdatesOnBoot" yaml:"installUpdatesOnBoot"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#instance_profile_arn OpsworksInstance#instance_profile_arn}.
InstanceProfileArn *string `field:"optional" json:"instanceProfileArn" yaml:"instanceProfileArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#instance_type OpsworksInstance#instance_type}.
InstanceType *string `field:"optional" json:"instanceType" yaml:"instanceType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#os OpsworksInstance#os}.
Os *string `field:"optional" json:"os" yaml:"os"`
// root_block_device block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#root_block_device OpsworksInstance#root_block_device}
RootBlockDevice interface{} `field:"optional" json:"rootBlockDevice" yaml:"rootBlockDevice"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#root_device_type OpsworksInstance#root_device_type}.
RootDeviceType *string `field:"optional" json:"rootDeviceType" yaml:"rootDeviceType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#security_group_ids OpsworksInstance#security_group_ids}.
SecurityGroupIds *[]*string `field:"optional" json:"securityGroupIds" yaml:"securityGroupIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#ssh_key_name OpsworksInstance#ssh_key_name}.
SshKeyName *string `field:"optional" json:"sshKeyName" yaml:"sshKeyName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#state OpsworksInstance#state}.
State *string `field:"optional" json:"state" yaml:"state"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#status OpsworksInstance#status}.
Status *string `field:"optional" json:"status" yaml:"status"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#subnet_id OpsworksInstance#subnet_id}.
SubnetId *string `field:"optional" json:"subnetId" yaml:"subnetId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#tenancy OpsworksInstance#tenancy}.
Tenancy *string `field:"optional" json:"tenancy" yaml:"tenancy"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#timeouts OpsworksInstance#timeouts}
Timeouts *OpsworksInstanceTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#virtualization_type OpsworksInstance#virtualization_type}.
VirtualizationType *string `field:"optional" json:"virtualizationType" yaml:"virtualizationType"`
}
type OpsworksInstanceEbsBlockDevice ¶
type OpsworksInstanceEbsBlockDevice struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#device_name OpsworksInstance#device_name}.
DeviceName *string `field:"required" json:"deviceName" yaml:"deviceName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#delete_on_termination OpsworksInstance#delete_on_termination}.
DeleteOnTermination interface{} `field:"optional" json:"deleteOnTermination" yaml:"deleteOnTermination"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#iops OpsworksInstance#iops}.
Iops *float64 `field:"optional" json:"iops" yaml:"iops"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#snapshot_id OpsworksInstance#snapshot_id}.
SnapshotId *string `field:"optional" json:"snapshotId" yaml:"snapshotId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#volume_size OpsworksInstance#volume_size}.
VolumeSize *float64 `field:"optional" json:"volumeSize" yaml:"volumeSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#volume_type OpsworksInstance#volume_type}.
VolumeType *string `field:"optional" json:"volumeType" yaml:"volumeType"`
}
type OpsworksInstanceEbsBlockDeviceList ¶
type OpsworksInstanceEbsBlockDeviceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) OpsworksInstanceEbsBlockDeviceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksInstanceEbsBlockDeviceList ¶
func NewOpsworksInstanceEbsBlockDeviceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) OpsworksInstanceEbsBlockDeviceList
type OpsworksInstanceEbsBlockDeviceOutputReference ¶
type OpsworksInstanceEbsBlockDeviceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeleteOnTermination() interface{}
SetDeleteOnTermination(val interface{})
DeleteOnTerminationInput() interface{}
DeviceName() *string
SetDeviceName(val *string)
DeviceNameInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Iops() *float64
SetIops(val *float64)
IopsInput() *float64
SnapshotId() *string
SetSnapshotId(val *string)
SnapshotIdInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VolumeSize() *float64
SetVolumeSize(val *float64)
VolumeSizeInput() *float64
VolumeType() *string
SetVolumeType(val *string)
VolumeTypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDeleteOnTermination()
ResetIops()
ResetSnapshotId()
ResetVolumeSize()
ResetVolumeType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksInstanceEbsBlockDeviceOutputReference ¶
func NewOpsworksInstanceEbsBlockDeviceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) OpsworksInstanceEbsBlockDeviceOutputReference
type OpsworksInstanceEphemeralBlockDevice ¶
type OpsworksInstanceEphemeralBlockDevice struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#device_name OpsworksInstance#device_name}.
DeviceName *string `field:"required" json:"deviceName" yaml:"deviceName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#virtual_name OpsworksInstance#virtual_name}.
VirtualName *string `field:"required" json:"virtualName" yaml:"virtualName"`
}
type OpsworksInstanceEphemeralBlockDeviceList ¶
type OpsworksInstanceEphemeralBlockDeviceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) OpsworksInstanceEphemeralBlockDeviceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksInstanceEphemeralBlockDeviceList ¶
func NewOpsworksInstanceEphemeralBlockDeviceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) OpsworksInstanceEphemeralBlockDeviceList
type OpsworksInstanceEphemeralBlockDeviceOutputReference ¶
type OpsworksInstanceEphemeralBlockDeviceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeviceName() *string
SetDeviceName(val *string)
DeviceNameInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VirtualName() *string
SetVirtualName(val *string)
VirtualNameInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksInstanceEphemeralBlockDeviceOutputReference ¶
func NewOpsworksInstanceEphemeralBlockDeviceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) OpsworksInstanceEphemeralBlockDeviceOutputReference
type OpsworksInstanceRootBlockDevice ¶
type OpsworksInstanceRootBlockDevice struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#delete_on_termination OpsworksInstance#delete_on_termination}.
DeleteOnTermination interface{} `field:"optional" json:"deleteOnTermination" yaml:"deleteOnTermination"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#iops OpsworksInstance#iops}.
Iops *float64 `field:"optional" json:"iops" yaml:"iops"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#volume_size OpsworksInstance#volume_size}.
VolumeSize *float64 `field:"optional" json:"volumeSize" yaml:"volumeSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#volume_type OpsworksInstance#volume_type}.
VolumeType *string `field:"optional" json:"volumeType" yaml:"volumeType"`
}
type OpsworksInstanceRootBlockDeviceList ¶
type OpsworksInstanceRootBlockDeviceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) OpsworksInstanceRootBlockDeviceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksInstanceRootBlockDeviceList ¶
func NewOpsworksInstanceRootBlockDeviceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) OpsworksInstanceRootBlockDeviceList
type OpsworksInstanceRootBlockDeviceOutputReference ¶
type OpsworksInstanceRootBlockDeviceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeleteOnTermination() interface{}
SetDeleteOnTermination(val interface{})
DeleteOnTerminationInput() interface{}
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Iops() *float64
SetIops(val *float64)
IopsInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VolumeSize() *float64
SetVolumeSize(val *float64)
VolumeSizeInput() *float64
VolumeType() *string
SetVolumeType(val *string)
VolumeTypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDeleteOnTermination()
ResetIops()
ResetVolumeSize()
ResetVolumeType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksInstanceRootBlockDeviceOutputReference ¶
func NewOpsworksInstanceRootBlockDeviceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) OpsworksInstanceRootBlockDeviceOutputReference
type OpsworksInstanceTimeouts ¶
type OpsworksInstanceTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#create OpsworksInstance#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#delete OpsworksInstance#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_instance#update OpsworksInstance#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type OpsworksInstanceTimeoutsOutputReference ¶
type OpsworksInstanceTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksInstanceTimeoutsOutputReference ¶
func NewOpsworksInstanceTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpsworksInstanceTimeoutsOutputReference
Source Files
¶
- OpsworksInstance.go
- OpsworksInstanceConfig.go
- OpsworksInstanceEbsBlockDevice.go
- OpsworksInstanceEbsBlockDeviceList.go
- OpsworksInstanceEbsBlockDeviceList__checks.go
- OpsworksInstanceEbsBlockDeviceOutputReference.go
- OpsworksInstanceEbsBlockDeviceOutputReference__checks.go
- OpsworksInstanceEphemeralBlockDevice.go
- OpsworksInstanceEphemeralBlockDeviceList.go
- OpsworksInstanceEphemeralBlockDeviceList__checks.go
- OpsworksInstanceEphemeralBlockDeviceOutputReference.go
- OpsworksInstanceEphemeralBlockDeviceOutputReference__checks.go
- OpsworksInstanceRootBlockDevice.go
- OpsworksInstanceRootBlockDeviceList.go
- OpsworksInstanceRootBlockDeviceList__checks.go
- OpsworksInstanceRootBlockDeviceOutputReference.go
- OpsworksInstanceRootBlockDeviceOutputReference__checks.go
- OpsworksInstanceTimeouts.go
- OpsworksInstanceTimeoutsOutputReference.go
- OpsworksInstanceTimeoutsOutputReference__checks.go
- OpsworksInstance__checks.go
- main.go