Documentation
¶
Index ¶
- func NewOpsworksMysqlLayerCloudwatchConfigurationLogStreamsList_Override(o OpsworksMysqlLayerCloudwatchConfigurationLogStreamsList, ...)
- func NewOpsworksMysqlLayerCloudwatchConfigurationLogStreamsOutputReference_Override(o OpsworksMysqlLayerCloudwatchConfigurationLogStreamsOutputReference, ...)
- func NewOpsworksMysqlLayerCloudwatchConfigurationOutputReference_Override(o OpsworksMysqlLayerCloudwatchConfigurationOutputReference, ...)
- func NewOpsworksMysqlLayerEbsVolumeList_Override(o OpsworksMysqlLayerEbsVolumeList, ...)
- func NewOpsworksMysqlLayerEbsVolumeOutputReference_Override(o OpsworksMysqlLayerEbsVolumeOutputReference, ...)
- func NewOpsworksMysqlLayerLoadBasedAutoScalingDownscalingOutputReference_Override(o OpsworksMysqlLayerLoadBasedAutoScalingDownscalingOutputReference, ...)
- func NewOpsworksMysqlLayerLoadBasedAutoScalingOutputReference_Override(o OpsworksMysqlLayerLoadBasedAutoScalingOutputReference, ...)
- func NewOpsworksMysqlLayerLoadBasedAutoScalingUpscalingOutputReference_Override(o OpsworksMysqlLayerLoadBasedAutoScalingUpscalingOutputReference, ...)
- func NewOpsworksMysqlLayer_Override(o OpsworksMysqlLayer, scope constructs.Construct, id *string, ...)
- func OpsworksMysqlLayer_IsConstruct(x interface{}) *bool
- func OpsworksMysqlLayer_IsTerraformElement(x interface{}) *bool
- func OpsworksMysqlLayer_IsTerraformResource(x interface{}) *bool
- func OpsworksMysqlLayer_TfResourceType() *string
- type OpsworksMysqlLayer
- type OpsworksMysqlLayerCloudwatchConfiguration
- type OpsworksMysqlLayerCloudwatchConfigurationLogStreams
- type OpsworksMysqlLayerCloudwatchConfigurationLogStreamsList
- type OpsworksMysqlLayerCloudwatchConfigurationLogStreamsOutputReference
- type OpsworksMysqlLayerCloudwatchConfigurationOutputReference
- type OpsworksMysqlLayerConfig
- type OpsworksMysqlLayerEbsVolume
- type OpsworksMysqlLayerEbsVolumeList
- type OpsworksMysqlLayerEbsVolumeOutputReference
- type OpsworksMysqlLayerLoadBasedAutoScaling
- type OpsworksMysqlLayerLoadBasedAutoScalingDownscaling
- type OpsworksMysqlLayerLoadBasedAutoScalingDownscalingOutputReference
- type OpsworksMysqlLayerLoadBasedAutoScalingOutputReference
- type OpsworksMysqlLayerLoadBasedAutoScalingUpscaling
- type OpsworksMysqlLayerLoadBasedAutoScalingUpscalingOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewOpsworksMysqlLayerCloudwatchConfigurationLogStreamsList_Override ¶
func NewOpsworksMysqlLayerCloudwatchConfigurationLogStreamsList_Override(o OpsworksMysqlLayerCloudwatchConfigurationLogStreamsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewOpsworksMysqlLayerCloudwatchConfigurationLogStreamsOutputReference_Override ¶
func NewOpsworksMysqlLayerCloudwatchConfigurationLogStreamsOutputReference_Override(o OpsworksMysqlLayerCloudwatchConfigurationLogStreamsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewOpsworksMysqlLayerCloudwatchConfigurationOutputReference_Override ¶
func NewOpsworksMysqlLayerCloudwatchConfigurationOutputReference_Override(o OpsworksMysqlLayerCloudwatchConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpsworksMysqlLayerEbsVolumeList_Override ¶
func NewOpsworksMysqlLayerEbsVolumeList_Override(o OpsworksMysqlLayerEbsVolumeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewOpsworksMysqlLayerEbsVolumeOutputReference_Override ¶
func NewOpsworksMysqlLayerEbsVolumeOutputReference_Override(o OpsworksMysqlLayerEbsVolumeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewOpsworksMysqlLayerLoadBasedAutoScalingDownscalingOutputReference_Override ¶
func NewOpsworksMysqlLayerLoadBasedAutoScalingDownscalingOutputReference_Override(o OpsworksMysqlLayerLoadBasedAutoScalingDownscalingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpsworksMysqlLayerLoadBasedAutoScalingOutputReference_Override ¶
func NewOpsworksMysqlLayerLoadBasedAutoScalingOutputReference_Override(o OpsworksMysqlLayerLoadBasedAutoScalingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpsworksMysqlLayerLoadBasedAutoScalingUpscalingOutputReference_Override ¶
func NewOpsworksMysqlLayerLoadBasedAutoScalingUpscalingOutputReference_Override(o OpsworksMysqlLayerLoadBasedAutoScalingUpscalingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpsworksMysqlLayer_Override ¶
func NewOpsworksMysqlLayer_Override(o OpsworksMysqlLayer, scope constructs.Construct, id *string, config *OpsworksMysqlLayerConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer aws_opsworks_mysql_layer} Resource.
func OpsworksMysqlLayer_IsConstruct ¶
func OpsworksMysqlLayer_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func OpsworksMysqlLayer_IsTerraformElement ¶
func OpsworksMysqlLayer_IsTerraformElement(x interface{}) *bool
Experimental.
func OpsworksMysqlLayer_IsTerraformResource ¶
func OpsworksMysqlLayer_IsTerraformResource(x interface{}) *bool
Experimental.
func OpsworksMysqlLayer_TfResourceType ¶
func OpsworksMysqlLayer_TfResourceType() *string
Types ¶
type OpsworksMysqlLayer ¶
type OpsworksMysqlLayer interface {
cdktf.TerraformResource
Arn() *string
AutoAssignElasticIps() interface{}
SetAutoAssignElasticIps(val interface{})
AutoAssignElasticIpsInput() interface{}
AutoAssignPublicIps() interface{}
SetAutoAssignPublicIps(val interface{})
AutoAssignPublicIpsInput() interface{}
AutoHealing() interface{}
SetAutoHealing(val interface{})
AutoHealingInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
CloudwatchConfiguration() OpsworksMysqlLayerCloudwatchConfigurationOutputReference
CloudwatchConfigurationInput() *OpsworksMysqlLayerCloudwatchConfiguration
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CustomConfigureRecipes() *[]*string
SetCustomConfigureRecipes(val *[]*string)
CustomConfigureRecipesInput() *[]*string
CustomDeployRecipes() *[]*string
SetCustomDeployRecipes(val *[]*string)
CustomDeployRecipesInput() *[]*string
CustomInstanceProfileArn() *string
SetCustomInstanceProfileArn(val *string)
CustomInstanceProfileArnInput() *string
CustomJson() *string
SetCustomJson(val *string)
CustomJsonInput() *string
CustomSecurityGroupIds() *[]*string
SetCustomSecurityGroupIds(val *[]*string)
CustomSecurityGroupIdsInput() *[]*string
CustomSetupRecipes() *[]*string
SetCustomSetupRecipes(val *[]*string)
CustomSetupRecipesInput() *[]*string
CustomShutdownRecipes() *[]*string
SetCustomShutdownRecipes(val *[]*string)
CustomShutdownRecipesInput() *[]*string
CustomUndeployRecipes() *[]*string
SetCustomUndeployRecipes(val *[]*string)
CustomUndeployRecipesInput() *[]*string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DrainElbOnShutdown() interface{}
SetDrainElbOnShutdown(val interface{})
DrainElbOnShutdownInput() interface{}
EbsVolume() OpsworksMysqlLayerEbsVolumeList
EbsVolumeInput() interface{}
ElasticLoadBalancer() *string
SetElasticLoadBalancer(val *string)
ElasticLoadBalancerInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InstallUpdatesOnBoot() interface{}
SetInstallUpdatesOnBoot(val interface{})
InstallUpdatesOnBootInput() interface{}
InstanceShutdownTimeout() *float64
SetInstanceShutdownTimeout(val *float64)
InstanceShutdownTimeoutInput() *float64
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LoadBasedAutoScaling() OpsworksMysqlLayerLoadBasedAutoScalingOutputReference
LoadBasedAutoScalingInput() *OpsworksMysqlLayerLoadBasedAutoScaling
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RootPassword() *string
SetRootPassword(val *string)
RootPasswordInput() *string
RootPasswordOnAllInstances() interface{}
SetRootPasswordOnAllInstances(val interface{})
RootPasswordOnAllInstancesInput() interface{}
StackId() *string
SetStackId(val *string)
StackIdInput() *string
SystemPackages() *[]*string
SetSystemPackages(val *[]*string)
SystemPackagesInput() *[]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
UseEbsOptimizedInstances() interface{}
SetUseEbsOptimizedInstances(val interface{})
UseEbsOptimizedInstancesInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCloudwatchConfiguration(value *OpsworksMysqlLayerCloudwatchConfiguration)
PutEbsVolume(value interface{})
PutLoadBasedAutoScaling(value *OpsworksMysqlLayerLoadBasedAutoScaling)
ResetAutoAssignElasticIps()
ResetAutoAssignPublicIps()
ResetAutoHealing()
ResetCloudwatchConfiguration()
ResetCustomConfigureRecipes()
ResetCustomDeployRecipes()
ResetCustomInstanceProfileArn()
ResetCustomJson()
ResetCustomSecurityGroupIds()
ResetCustomSetupRecipes()
ResetCustomShutdownRecipes()
ResetCustomUndeployRecipes()
ResetDrainElbOnShutdown()
ResetEbsVolume()
ResetElasticLoadBalancer()
ResetId()
ResetInstallUpdatesOnBoot()
ResetInstanceShutdownTimeout()
ResetLoadBasedAutoScaling()
ResetName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRootPassword()
ResetRootPasswordOnAllInstances()
ResetSystemPackages()
ResetTags()
ResetTagsAll()
ResetUseEbsOptimizedInstances()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer aws_opsworks_mysql_layer}.
func NewOpsworksMysqlLayer ¶
func NewOpsworksMysqlLayer(scope constructs.Construct, id *string, config *OpsworksMysqlLayerConfig) OpsworksMysqlLayer
Create a new {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer aws_opsworks_mysql_layer} Resource.
type OpsworksMysqlLayerCloudwatchConfiguration ¶
type OpsworksMysqlLayerCloudwatchConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#enabled OpsworksMysqlLayer#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// log_streams block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#log_streams OpsworksMysqlLayer#log_streams}
LogStreams interface{} `field:"optional" json:"logStreams" yaml:"logStreams"`
}
type OpsworksMysqlLayerCloudwatchConfigurationLogStreams ¶
type OpsworksMysqlLayerCloudwatchConfigurationLogStreams struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#file OpsworksMysqlLayer#file}.
File *string `field:"required" json:"file" yaml:"file"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#log_group_name OpsworksMysqlLayer#log_group_name}.
LogGroupName *string `field:"required" json:"logGroupName" yaml:"logGroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#batch_count OpsworksMysqlLayer#batch_count}.
BatchCount *float64 `field:"optional" json:"batchCount" yaml:"batchCount"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#batch_size OpsworksMysqlLayer#batch_size}.
BatchSize *float64 `field:"optional" json:"batchSize" yaml:"batchSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#buffer_duration OpsworksMysqlLayer#buffer_duration}.
BufferDuration *float64 `field:"optional" json:"bufferDuration" yaml:"bufferDuration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#datetime_format OpsworksMysqlLayer#datetime_format}.
DatetimeFormat *string `field:"optional" json:"datetimeFormat" yaml:"datetimeFormat"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#encoding OpsworksMysqlLayer#encoding}.
Encoding *string `field:"optional" json:"encoding" yaml:"encoding"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#file_fingerprint_lines OpsworksMysqlLayer#file_fingerprint_lines}.
FileFingerprintLines *string `field:"optional" json:"fileFingerprintLines" yaml:"fileFingerprintLines"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#initial_position OpsworksMysqlLayer#initial_position}.
InitialPosition *string `field:"optional" json:"initialPosition" yaml:"initialPosition"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#multiline_start_pattern OpsworksMysqlLayer#multiline_start_pattern}.
MultilineStartPattern *string `field:"optional" json:"multilineStartPattern" yaml:"multilineStartPattern"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#time_zone OpsworksMysqlLayer#time_zone}.
TimeZone *string `field:"optional" json:"timeZone" yaml:"timeZone"`
}
type OpsworksMysqlLayerCloudwatchConfigurationLogStreamsList ¶
type OpsworksMysqlLayerCloudwatchConfigurationLogStreamsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) OpsworksMysqlLayerCloudwatchConfigurationLogStreamsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksMysqlLayerCloudwatchConfigurationLogStreamsList ¶
func NewOpsworksMysqlLayerCloudwatchConfigurationLogStreamsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) OpsworksMysqlLayerCloudwatchConfigurationLogStreamsList
type OpsworksMysqlLayerCloudwatchConfigurationLogStreamsOutputReference ¶
type OpsworksMysqlLayerCloudwatchConfigurationLogStreamsOutputReference interface {
cdktf.ComplexObject
BatchCount() *float64
SetBatchCount(val *float64)
BatchCountInput() *float64
BatchSize() *float64
SetBatchSize(val *float64)
BatchSizeInput() *float64
BufferDuration() *float64
SetBufferDuration(val *float64)
BufferDurationInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DatetimeFormat() *string
SetDatetimeFormat(val *string)
DatetimeFormatInput() *string
Encoding() *string
SetEncoding(val *string)
EncodingInput() *string
File() *string
SetFile(val *string)
FileFingerprintLines() *string
SetFileFingerprintLines(val *string)
FileFingerprintLinesInput() *string
FileInput() *string
// Experimental.
Fqn() *string
InitialPosition() *string
SetInitialPosition(val *string)
InitialPositionInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
LogGroupName() *string
SetLogGroupName(val *string)
LogGroupNameInput() *string
MultilineStartPattern() *string
SetMultilineStartPattern(val *string)
MultilineStartPatternInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TimeZone() *string
SetTimeZone(val *string)
TimeZoneInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBatchCount()
ResetBatchSize()
ResetBufferDuration()
ResetDatetimeFormat()
ResetEncoding()
ResetFileFingerprintLines()
ResetInitialPosition()
ResetMultilineStartPattern()
ResetTimeZone()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksMysqlLayerCloudwatchConfigurationLogStreamsOutputReference ¶
func NewOpsworksMysqlLayerCloudwatchConfigurationLogStreamsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) OpsworksMysqlLayerCloudwatchConfigurationLogStreamsOutputReference
type OpsworksMysqlLayerCloudwatchConfigurationOutputReference ¶
type OpsworksMysqlLayerCloudwatchConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *OpsworksMysqlLayerCloudwatchConfiguration
SetInternalValue(val *OpsworksMysqlLayerCloudwatchConfiguration)
LogStreams() OpsworksMysqlLayerCloudwatchConfigurationLogStreamsList
LogStreamsInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutLogStreams(value interface{})
ResetEnabled()
ResetLogStreams()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksMysqlLayerCloudwatchConfigurationOutputReference ¶
func NewOpsworksMysqlLayerCloudwatchConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpsworksMysqlLayerCloudwatchConfigurationOutputReference
type OpsworksMysqlLayerConfig ¶
type OpsworksMysqlLayerConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#stack_id OpsworksMysqlLayer#stack_id}.
StackId *string `field:"required" json:"stackId" yaml:"stackId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#auto_assign_elastic_ips OpsworksMysqlLayer#auto_assign_elastic_ips}.
AutoAssignElasticIps interface{} `field:"optional" json:"autoAssignElasticIps" yaml:"autoAssignElasticIps"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#auto_assign_public_ips OpsworksMysqlLayer#auto_assign_public_ips}.
AutoAssignPublicIps interface{} `field:"optional" json:"autoAssignPublicIps" yaml:"autoAssignPublicIps"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#auto_healing OpsworksMysqlLayer#auto_healing}.
AutoHealing interface{} `field:"optional" json:"autoHealing" yaml:"autoHealing"`
// cloudwatch_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#cloudwatch_configuration OpsworksMysqlLayer#cloudwatch_configuration}
CloudwatchConfiguration *OpsworksMysqlLayerCloudwatchConfiguration `field:"optional" json:"cloudwatchConfiguration" yaml:"cloudwatchConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#custom_configure_recipes OpsworksMysqlLayer#custom_configure_recipes}.
CustomConfigureRecipes *[]*string `field:"optional" json:"customConfigureRecipes" yaml:"customConfigureRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#custom_deploy_recipes OpsworksMysqlLayer#custom_deploy_recipes}.
CustomDeployRecipes *[]*string `field:"optional" json:"customDeployRecipes" yaml:"customDeployRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#custom_instance_profile_arn OpsworksMysqlLayer#custom_instance_profile_arn}.
CustomInstanceProfileArn *string `field:"optional" json:"customInstanceProfileArn" yaml:"customInstanceProfileArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#custom_json OpsworksMysqlLayer#custom_json}.
CustomJson *string `field:"optional" json:"customJson" yaml:"customJson"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#custom_security_group_ids OpsworksMysqlLayer#custom_security_group_ids}.
CustomSecurityGroupIds *[]*string `field:"optional" json:"customSecurityGroupIds" yaml:"customSecurityGroupIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#custom_setup_recipes OpsworksMysqlLayer#custom_setup_recipes}.
CustomSetupRecipes *[]*string `field:"optional" json:"customSetupRecipes" yaml:"customSetupRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#custom_shutdown_recipes OpsworksMysqlLayer#custom_shutdown_recipes}.
CustomShutdownRecipes *[]*string `field:"optional" json:"customShutdownRecipes" yaml:"customShutdownRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#custom_undeploy_recipes OpsworksMysqlLayer#custom_undeploy_recipes}.
CustomUndeployRecipes *[]*string `field:"optional" json:"customUndeployRecipes" yaml:"customUndeployRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#drain_elb_on_shutdown OpsworksMysqlLayer#drain_elb_on_shutdown}.
DrainElbOnShutdown interface{} `field:"optional" json:"drainElbOnShutdown" yaml:"drainElbOnShutdown"`
// ebs_volume block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#ebs_volume OpsworksMysqlLayer#ebs_volume}
EbsVolume interface{} `field:"optional" json:"ebsVolume" yaml:"ebsVolume"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#elastic_load_balancer OpsworksMysqlLayer#elastic_load_balancer}.
ElasticLoadBalancer *string `field:"optional" json:"elasticLoadBalancer" yaml:"elasticLoadBalancer"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#id OpsworksMysqlLayer#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#install_updates_on_boot OpsworksMysqlLayer#install_updates_on_boot}.
InstallUpdatesOnBoot interface{} `field:"optional" json:"installUpdatesOnBoot" yaml:"installUpdatesOnBoot"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#instance_shutdown_timeout OpsworksMysqlLayer#instance_shutdown_timeout}.
InstanceShutdownTimeout *float64 `field:"optional" json:"instanceShutdownTimeout" yaml:"instanceShutdownTimeout"`
// load_based_auto_scaling block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#load_based_auto_scaling OpsworksMysqlLayer#load_based_auto_scaling}
LoadBasedAutoScaling *OpsworksMysqlLayerLoadBasedAutoScaling `field:"optional" json:"loadBasedAutoScaling" yaml:"loadBasedAutoScaling"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#name OpsworksMysqlLayer#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#root_password OpsworksMysqlLayer#root_password}.
RootPassword *string `field:"optional" json:"rootPassword" yaml:"rootPassword"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#root_password_on_all_instances OpsworksMysqlLayer#root_password_on_all_instances}.
RootPasswordOnAllInstances interface{} `field:"optional" json:"rootPasswordOnAllInstances" yaml:"rootPasswordOnAllInstances"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#system_packages OpsworksMysqlLayer#system_packages}.
SystemPackages *[]*string `field:"optional" json:"systemPackages" yaml:"systemPackages"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#tags OpsworksMysqlLayer#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#tags_all OpsworksMysqlLayer#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#use_ebs_optimized_instances OpsworksMysqlLayer#use_ebs_optimized_instances}.
UseEbsOptimizedInstances interface{} `field:"optional" json:"useEbsOptimizedInstances" yaml:"useEbsOptimizedInstances"`
}
type OpsworksMysqlLayerEbsVolume ¶
type OpsworksMysqlLayerEbsVolume struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#mount_point OpsworksMysqlLayer#mount_point}.
MountPoint *string `field:"required" json:"mountPoint" yaml:"mountPoint"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#number_of_disks OpsworksMysqlLayer#number_of_disks}.
NumberOfDisks *float64 `field:"required" json:"numberOfDisks" yaml:"numberOfDisks"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#size OpsworksMysqlLayer#size}.
Size *float64 `field:"required" json:"size" yaml:"size"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#encrypted OpsworksMysqlLayer#encrypted}.
Encrypted interface{} `field:"optional" json:"encrypted" yaml:"encrypted"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#iops OpsworksMysqlLayer#iops}.
Iops *float64 `field:"optional" json:"iops" yaml:"iops"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#raid_level OpsworksMysqlLayer#raid_level}.
RaidLevel *string `field:"optional" json:"raidLevel" yaml:"raidLevel"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#type OpsworksMysqlLayer#type}.
Type *string `field:"optional" json:"type" yaml:"type"`
}
type OpsworksMysqlLayerEbsVolumeList ¶
type OpsworksMysqlLayerEbsVolumeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) OpsworksMysqlLayerEbsVolumeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksMysqlLayerEbsVolumeList ¶
func NewOpsworksMysqlLayerEbsVolumeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) OpsworksMysqlLayerEbsVolumeList
type OpsworksMysqlLayerEbsVolumeOutputReference ¶
type OpsworksMysqlLayerEbsVolumeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Encrypted() interface{}
SetEncrypted(val interface{})
EncryptedInput() interface{}
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Iops() *float64
SetIops(val *float64)
IopsInput() *float64
MountPoint() *string
SetMountPoint(val *string)
MountPointInput() *string
NumberOfDisks() *float64
SetNumberOfDisks(val *float64)
NumberOfDisksInput() *float64
RaidLevel() *string
SetRaidLevel(val *string)
RaidLevelInput() *string
Size() *float64
SetSize(val *float64)
SizeInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEncrypted()
ResetIops()
ResetRaidLevel()
ResetType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksMysqlLayerEbsVolumeOutputReference ¶
func NewOpsworksMysqlLayerEbsVolumeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) OpsworksMysqlLayerEbsVolumeOutputReference
type OpsworksMysqlLayerLoadBasedAutoScaling ¶
type OpsworksMysqlLayerLoadBasedAutoScaling struct {
// downscaling block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#downscaling OpsworksMysqlLayer#downscaling}
Downscaling *OpsworksMysqlLayerLoadBasedAutoScalingDownscaling `field:"optional" json:"downscaling" yaml:"downscaling"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#enable OpsworksMysqlLayer#enable}.
Enable interface{} `field:"optional" json:"enable" yaml:"enable"`
// upscaling block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#upscaling OpsworksMysqlLayer#upscaling}
Upscaling *OpsworksMysqlLayerLoadBasedAutoScalingUpscaling `field:"optional" json:"upscaling" yaml:"upscaling"`
}
type OpsworksMysqlLayerLoadBasedAutoScalingDownscaling ¶
type OpsworksMysqlLayerLoadBasedAutoScalingDownscaling struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#alarms OpsworksMysqlLayer#alarms}.
Alarms *[]*string `field:"optional" json:"alarms" yaml:"alarms"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#cpu_threshold OpsworksMysqlLayer#cpu_threshold}.
CpuThreshold *float64 `field:"optional" json:"cpuThreshold" yaml:"cpuThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#ignore_metrics_time OpsworksMysqlLayer#ignore_metrics_time}.
IgnoreMetricsTime *float64 `field:"optional" json:"ignoreMetricsTime" yaml:"ignoreMetricsTime"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#instance_count OpsworksMysqlLayer#instance_count}.
InstanceCount *float64 `field:"optional" json:"instanceCount" yaml:"instanceCount"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#load_threshold OpsworksMysqlLayer#load_threshold}.
LoadThreshold *float64 `field:"optional" json:"loadThreshold" yaml:"loadThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#memory_threshold OpsworksMysqlLayer#memory_threshold}.
MemoryThreshold *float64 `field:"optional" json:"memoryThreshold" yaml:"memoryThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#thresholds_wait_time OpsworksMysqlLayer#thresholds_wait_time}.
ThresholdsWaitTime *float64 `field:"optional" json:"thresholdsWaitTime" yaml:"thresholdsWaitTime"`
}
type OpsworksMysqlLayerLoadBasedAutoScalingDownscalingOutputReference ¶
type OpsworksMysqlLayerLoadBasedAutoScalingDownscalingOutputReference interface {
cdktf.ComplexObject
Alarms() *[]*string
SetAlarms(val *[]*string)
AlarmsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CpuThreshold() *float64
SetCpuThreshold(val *float64)
CpuThresholdInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IgnoreMetricsTime() *float64
SetIgnoreMetricsTime(val *float64)
IgnoreMetricsTimeInput() *float64
InstanceCount() *float64
SetInstanceCount(val *float64)
InstanceCountInput() *float64
InternalValue() *OpsworksMysqlLayerLoadBasedAutoScalingDownscaling
SetInternalValue(val *OpsworksMysqlLayerLoadBasedAutoScalingDownscaling)
LoadThreshold() *float64
SetLoadThreshold(val *float64)
LoadThresholdInput() *float64
MemoryThreshold() *float64
SetMemoryThreshold(val *float64)
MemoryThresholdInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ThresholdsWaitTime() *float64
SetThresholdsWaitTime(val *float64)
ThresholdsWaitTimeInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAlarms()
ResetCpuThreshold()
ResetIgnoreMetricsTime()
ResetInstanceCount()
ResetLoadThreshold()
ResetMemoryThreshold()
ResetThresholdsWaitTime()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksMysqlLayerLoadBasedAutoScalingDownscalingOutputReference ¶
func NewOpsworksMysqlLayerLoadBasedAutoScalingDownscalingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpsworksMysqlLayerLoadBasedAutoScalingDownscalingOutputReference
type OpsworksMysqlLayerLoadBasedAutoScalingOutputReference ¶
type OpsworksMysqlLayerLoadBasedAutoScalingOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Downscaling() OpsworksMysqlLayerLoadBasedAutoScalingDownscalingOutputReference
DownscalingInput() *OpsworksMysqlLayerLoadBasedAutoScalingDownscaling
Enable() interface{}
SetEnable(val interface{})
EnableInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *OpsworksMysqlLayerLoadBasedAutoScaling
SetInternalValue(val *OpsworksMysqlLayerLoadBasedAutoScaling)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Upscaling() OpsworksMysqlLayerLoadBasedAutoScalingUpscalingOutputReference
UpscalingInput() *OpsworksMysqlLayerLoadBasedAutoScalingUpscaling
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutDownscaling(value *OpsworksMysqlLayerLoadBasedAutoScalingDownscaling)
PutUpscaling(value *OpsworksMysqlLayerLoadBasedAutoScalingUpscaling)
ResetDownscaling()
ResetEnable()
ResetUpscaling()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksMysqlLayerLoadBasedAutoScalingOutputReference ¶
func NewOpsworksMysqlLayerLoadBasedAutoScalingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpsworksMysqlLayerLoadBasedAutoScalingOutputReference
type OpsworksMysqlLayerLoadBasedAutoScalingUpscaling ¶
type OpsworksMysqlLayerLoadBasedAutoScalingUpscaling struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#alarms OpsworksMysqlLayer#alarms}.
Alarms *[]*string `field:"optional" json:"alarms" yaml:"alarms"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#cpu_threshold OpsworksMysqlLayer#cpu_threshold}.
CpuThreshold *float64 `field:"optional" json:"cpuThreshold" yaml:"cpuThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#ignore_metrics_time OpsworksMysqlLayer#ignore_metrics_time}.
IgnoreMetricsTime *float64 `field:"optional" json:"ignoreMetricsTime" yaml:"ignoreMetricsTime"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#instance_count OpsworksMysqlLayer#instance_count}.
InstanceCount *float64 `field:"optional" json:"instanceCount" yaml:"instanceCount"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#load_threshold OpsworksMysqlLayer#load_threshold}.
LoadThreshold *float64 `field:"optional" json:"loadThreshold" yaml:"loadThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#memory_threshold OpsworksMysqlLayer#memory_threshold}.
MemoryThreshold *float64 `field:"optional" json:"memoryThreshold" yaml:"memoryThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_mysql_layer#thresholds_wait_time OpsworksMysqlLayer#thresholds_wait_time}.
ThresholdsWaitTime *float64 `field:"optional" json:"thresholdsWaitTime" yaml:"thresholdsWaitTime"`
}
type OpsworksMysqlLayerLoadBasedAutoScalingUpscalingOutputReference ¶
type OpsworksMysqlLayerLoadBasedAutoScalingUpscalingOutputReference interface {
cdktf.ComplexObject
Alarms() *[]*string
SetAlarms(val *[]*string)
AlarmsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CpuThreshold() *float64
SetCpuThreshold(val *float64)
CpuThresholdInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IgnoreMetricsTime() *float64
SetIgnoreMetricsTime(val *float64)
IgnoreMetricsTimeInput() *float64
InstanceCount() *float64
SetInstanceCount(val *float64)
InstanceCountInput() *float64
InternalValue() *OpsworksMysqlLayerLoadBasedAutoScalingUpscaling
SetInternalValue(val *OpsworksMysqlLayerLoadBasedAutoScalingUpscaling)
LoadThreshold() *float64
SetLoadThreshold(val *float64)
LoadThresholdInput() *float64
MemoryThreshold() *float64
SetMemoryThreshold(val *float64)
MemoryThresholdInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ThresholdsWaitTime() *float64
SetThresholdsWaitTime(val *float64)
ThresholdsWaitTimeInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAlarms()
ResetCpuThreshold()
ResetIgnoreMetricsTime()
ResetInstanceCount()
ResetLoadThreshold()
ResetMemoryThreshold()
ResetThresholdsWaitTime()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksMysqlLayerLoadBasedAutoScalingUpscalingOutputReference ¶
func NewOpsworksMysqlLayerLoadBasedAutoScalingUpscalingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpsworksMysqlLayerLoadBasedAutoScalingUpscalingOutputReference
Source Files
¶
- OpsworksMysqlLayer.go
- OpsworksMysqlLayerCloudwatchConfiguration.go
- OpsworksMysqlLayerCloudwatchConfigurationLogStreams.go
- OpsworksMysqlLayerCloudwatchConfigurationLogStreamsList.go
- OpsworksMysqlLayerCloudwatchConfigurationLogStreamsList__checks.go
- OpsworksMysqlLayerCloudwatchConfigurationLogStreamsOutputReference.go
- OpsworksMysqlLayerCloudwatchConfigurationLogStreamsOutputReference__checks.go
- OpsworksMysqlLayerCloudwatchConfigurationOutputReference.go
- OpsworksMysqlLayerCloudwatchConfigurationOutputReference__checks.go
- OpsworksMysqlLayerConfig.go
- OpsworksMysqlLayerEbsVolume.go
- OpsworksMysqlLayerEbsVolumeList.go
- OpsworksMysqlLayerEbsVolumeList__checks.go
- OpsworksMysqlLayerEbsVolumeOutputReference.go
- OpsworksMysqlLayerEbsVolumeOutputReference__checks.go
- OpsworksMysqlLayerLoadBasedAutoScaling.go
- OpsworksMysqlLayerLoadBasedAutoScalingDownscaling.go
- OpsworksMysqlLayerLoadBasedAutoScalingDownscalingOutputReference.go
- OpsworksMysqlLayerLoadBasedAutoScalingDownscalingOutputReference__checks.go
- OpsworksMysqlLayerLoadBasedAutoScalingOutputReference.go
- OpsworksMysqlLayerLoadBasedAutoScalingOutputReference__checks.go
- OpsworksMysqlLayerLoadBasedAutoScalingUpscaling.go
- OpsworksMysqlLayerLoadBasedAutoScalingUpscalingOutputReference.go
- OpsworksMysqlLayerLoadBasedAutoScalingUpscalingOutputReference__checks.go
- OpsworksMysqlLayer__checks.go
- main.go