Documentation
¶
Index ¶
- func NewPinpointAppCampaignHookOutputReference_Override(p PinpointAppCampaignHookOutputReference, ...)
- func NewPinpointAppLimitsOutputReference_Override(p PinpointAppLimitsOutputReference, ...)
- func NewPinpointAppQuietTimeOutputReference_Override(p PinpointAppQuietTimeOutputReference, ...)
- func NewPinpointApp_Override(p PinpointApp, scope constructs.Construct, id *string, ...)
- func PinpointApp_IsConstruct(x interface{}) *bool
- func PinpointApp_IsTerraformElement(x interface{}) *bool
- func PinpointApp_IsTerraformResource(x interface{}) *bool
- func PinpointApp_TfResourceType() *string
- type PinpointApp
- type PinpointAppCampaignHook
- type PinpointAppCampaignHookOutputReference
- type PinpointAppConfig
- type PinpointAppLimits
- type PinpointAppLimitsOutputReference
- type PinpointAppQuietTime
- type PinpointAppQuietTimeOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewPinpointAppCampaignHookOutputReference_Override ¶
func NewPinpointAppCampaignHookOutputReference_Override(p PinpointAppCampaignHookOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewPinpointAppLimitsOutputReference_Override ¶
func NewPinpointAppLimitsOutputReference_Override(p PinpointAppLimitsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewPinpointAppQuietTimeOutputReference_Override ¶
func NewPinpointAppQuietTimeOutputReference_Override(p PinpointAppQuietTimeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewPinpointApp_Override ¶
func NewPinpointApp_Override(p PinpointApp, scope constructs.Construct, id *string, config *PinpointAppConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app aws_pinpoint_app} Resource.
func PinpointApp_IsConstruct ¶
func PinpointApp_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func PinpointApp_IsTerraformElement ¶
func PinpointApp_IsTerraformElement(x interface{}) *bool
Experimental.
func PinpointApp_IsTerraformResource ¶
func PinpointApp_IsTerraformResource(x interface{}) *bool
Experimental.
func PinpointApp_TfResourceType ¶
func PinpointApp_TfResourceType() *string
Types ¶
type PinpointApp ¶
type PinpointApp interface {
cdktf.TerraformResource
ApplicationId() *string
Arn() *string
CampaignHook() PinpointAppCampaignHookOutputReference
CampaignHookInput() *PinpointAppCampaignHook
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Limits() PinpointAppLimitsOutputReference
LimitsInput() *PinpointAppLimits
Name() *string
SetName(val *string)
NameInput() *string
NamePrefix() *string
SetNamePrefix(val *string)
NamePrefixInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
QuietTime() PinpointAppQuietTimeOutputReference
QuietTimeInput() *PinpointAppQuietTime
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCampaignHook(value *PinpointAppCampaignHook)
PutLimits(value *PinpointAppLimits)
PutQuietTime(value *PinpointAppQuietTime)
ResetCampaignHook()
ResetId()
ResetLimits()
ResetName()
ResetNamePrefix()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetQuietTime()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app aws_pinpoint_app}.
func NewPinpointApp ¶
func NewPinpointApp(scope constructs.Construct, id *string, config *PinpointAppConfig) PinpointApp
Create a new {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app aws_pinpoint_app} Resource.
type PinpointAppCampaignHook ¶
type PinpointAppCampaignHook struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app#lambda_function_name PinpointApp#lambda_function_name}.
LambdaFunctionName *string `field:"optional" json:"lambdaFunctionName" yaml:"lambdaFunctionName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app#mode PinpointApp#mode}.
Mode *string `field:"optional" json:"mode" yaml:"mode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app#web_url PinpointApp#web_url}.
WebUrl *string `field:"optional" json:"webUrl" yaml:"webUrl"`
}
type PinpointAppCampaignHookOutputReference ¶
type PinpointAppCampaignHookOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *PinpointAppCampaignHook
SetInternalValue(val *PinpointAppCampaignHook)
LambdaFunctionName() *string
SetLambdaFunctionName(val *string)
LambdaFunctionNameInput() *string
Mode() *string
SetMode(val *string)
ModeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
WebUrl() *string
SetWebUrl(val *string)
WebUrlInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetLambdaFunctionName()
ResetMode()
ResetWebUrl()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewPinpointAppCampaignHookOutputReference ¶
func NewPinpointAppCampaignHookOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) PinpointAppCampaignHookOutputReference
type PinpointAppConfig ¶
type PinpointAppConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// campaign_hook block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app#campaign_hook PinpointApp#campaign_hook}
CampaignHook *PinpointAppCampaignHook `field:"optional" json:"campaignHook" yaml:"campaignHook"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app#id PinpointApp#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// limits block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app#limits PinpointApp#limits}
Limits *PinpointAppLimits `field:"optional" json:"limits" yaml:"limits"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app#name PinpointApp#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app#name_prefix PinpointApp#name_prefix}.
NamePrefix *string `field:"optional" json:"namePrefix" yaml:"namePrefix"`
// quiet_time block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app#quiet_time PinpointApp#quiet_time}
QuietTime *PinpointAppQuietTime `field:"optional" json:"quietTime" yaml:"quietTime"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app#tags PinpointApp#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app#tags_all PinpointApp#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type PinpointAppLimits ¶
type PinpointAppLimits struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app#daily PinpointApp#daily}.
Daily *float64 `field:"optional" json:"daily" yaml:"daily"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app#maximum_duration PinpointApp#maximum_duration}.
MaximumDuration *float64 `field:"optional" json:"maximumDuration" yaml:"maximumDuration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app#messages_per_second PinpointApp#messages_per_second}.
MessagesPerSecond *float64 `field:"optional" json:"messagesPerSecond" yaml:"messagesPerSecond"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app#total PinpointApp#total}.
Total *float64 `field:"optional" json:"total" yaml:"total"`
}
type PinpointAppLimitsOutputReference ¶
type PinpointAppLimitsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Daily() *float64
SetDaily(val *float64)
DailyInput() *float64
// Experimental.
Fqn() *string
InternalValue() *PinpointAppLimits
SetInternalValue(val *PinpointAppLimits)
MaximumDuration() *float64
SetMaximumDuration(val *float64)
MaximumDurationInput() *float64
MessagesPerSecond() *float64
SetMessagesPerSecond(val *float64)
MessagesPerSecondInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Total() *float64
SetTotal(val *float64)
TotalInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDaily()
ResetMaximumDuration()
ResetMessagesPerSecond()
ResetTotal()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewPinpointAppLimitsOutputReference ¶
func NewPinpointAppLimitsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) PinpointAppLimitsOutputReference
type PinpointAppQuietTime ¶
type PinpointAppQuietTime struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app#end PinpointApp#end}.
End *string `field:"optional" json:"end" yaml:"end"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pinpoint_app#start PinpointApp#start}.
Start *string `field:"optional" json:"start" yaml:"start"`
}
type PinpointAppQuietTimeOutputReference ¶
type PinpointAppQuietTimeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
End() *string
SetEnd(val *string)
EndInput() *string
// Experimental.
Fqn() *string
InternalValue() *PinpointAppQuietTime
SetInternalValue(val *PinpointAppQuietTime)
Start() *string
SetStart(val *string)
StartInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnd()
ResetStart()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewPinpointAppQuietTimeOutputReference ¶
func NewPinpointAppQuietTimeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) PinpointAppQuietTimeOutputReference
Source Files
¶
- PinpointApp.go
- PinpointAppCampaignHook.go
- PinpointAppCampaignHookOutputReference.go
- PinpointAppCampaignHookOutputReference__checks.go
- PinpointAppConfig.go
- PinpointAppLimits.go
- PinpointAppLimitsOutputReference.go
- PinpointAppLimitsOutputReference__checks.go
- PinpointAppQuietTime.go
- PinpointAppQuietTimeOutputReference.go
- PinpointAppQuietTimeOutputReference__checks.go
- PinpointApp__checks.go
- main.go