Documentation
¶
Index ¶
- func NewRbinRuleLockConfigurationOutputReference_Override(r RbinRuleLockConfigurationOutputReference, ...)
- func NewRbinRuleLockConfigurationUnlockDelayOutputReference_Override(r RbinRuleLockConfigurationUnlockDelayOutputReference, ...)
- func NewRbinRuleResourceTagsList_Override(r RbinRuleResourceTagsList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewRbinRuleResourceTagsOutputReference_Override(r RbinRuleResourceTagsOutputReference, ...)
- func NewRbinRuleRetentionPeriodOutputReference_Override(r RbinRuleRetentionPeriodOutputReference, ...)
- func NewRbinRuleTimeoutsOutputReference_Override(r RbinRuleTimeoutsOutputReference, ...)
- func NewRbinRule_Override(r RbinRule, scope constructs.Construct, id *string, config *RbinRuleConfig)
- func RbinRule_IsConstruct(x interface{}) *bool
- func RbinRule_IsTerraformElement(x interface{}) *bool
- func RbinRule_IsTerraformResource(x interface{}) *bool
- func RbinRule_TfResourceType() *string
- type RbinRule
- type RbinRuleConfig
- type RbinRuleLockConfiguration
- type RbinRuleLockConfigurationOutputReference
- type RbinRuleLockConfigurationUnlockDelay
- type RbinRuleLockConfigurationUnlockDelayOutputReference
- type RbinRuleResourceTags
- type RbinRuleResourceTagsList
- type RbinRuleResourceTagsOutputReference
- type RbinRuleRetentionPeriod
- type RbinRuleRetentionPeriodOutputReference
- type RbinRuleTimeouts
- type RbinRuleTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRbinRuleLockConfigurationOutputReference_Override ¶
func NewRbinRuleLockConfigurationOutputReference_Override(r RbinRuleLockConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewRbinRuleLockConfigurationUnlockDelayOutputReference_Override ¶
func NewRbinRuleLockConfigurationUnlockDelayOutputReference_Override(r RbinRuleLockConfigurationUnlockDelayOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewRbinRuleResourceTagsList_Override ¶
func NewRbinRuleResourceTagsList_Override(r RbinRuleResourceTagsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewRbinRuleResourceTagsOutputReference_Override ¶
func NewRbinRuleResourceTagsOutputReference_Override(r RbinRuleResourceTagsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewRbinRuleRetentionPeriodOutputReference_Override ¶
func NewRbinRuleRetentionPeriodOutputReference_Override(r RbinRuleRetentionPeriodOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewRbinRuleTimeoutsOutputReference_Override ¶
func NewRbinRuleTimeoutsOutputReference_Override(r RbinRuleTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewRbinRule_Override ¶
func NewRbinRule_Override(r RbinRule, scope constructs.Construct, id *string, config *RbinRuleConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule aws_rbin_rule} Resource.
func RbinRule_IsConstruct ¶
func RbinRule_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func RbinRule_IsTerraformElement ¶
func RbinRule_IsTerraformElement(x interface{}) *bool
Experimental.
func RbinRule_IsTerraformResource ¶
func RbinRule_IsTerraformResource(x interface{}) *bool
Experimental.
func RbinRule_TfResourceType ¶
func RbinRule_TfResourceType() *string
Types ¶
type RbinRule ¶
type RbinRule interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LockConfiguration() RbinRuleLockConfigurationOutputReference
LockConfigurationInput() *RbinRuleLockConfiguration
LockEndTime() *string
LockState() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ResourceTags() RbinRuleResourceTagsList
ResourceTagsInput() interface{}
ResourceType() *string
SetResourceType(val *string)
ResourceTypeInput() *string
RetentionPeriod() RbinRuleRetentionPeriodOutputReference
RetentionPeriodInput() *RbinRuleRetentionPeriod
Status() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() RbinRuleTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutLockConfiguration(value *RbinRuleLockConfiguration)
PutResourceTags(value interface{})
PutRetentionPeriod(value *RbinRuleRetentionPeriod)
PutTimeouts(value *RbinRuleTimeouts)
ResetDescription()
ResetLockConfiguration()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetResourceTags()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule aws_rbin_rule}.
func NewRbinRule ¶
func NewRbinRule(scope constructs.Construct, id *string, config *RbinRuleConfig) RbinRule
Create a new {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule aws_rbin_rule} Resource.
type RbinRuleConfig ¶
type RbinRuleConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule#resource_type RbinRule#resource_type}.
ResourceType *string `field:"required" json:"resourceType" yaml:"resourceType"`
// retention_period block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule#retention_period RbinRule#retention_period}
RetentionPeriod *RbinRuleRetentionPeriod `field:"required" json:"retentionPeriod" yaml:"retentionPeriod"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule#description RbinRule#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// lock_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule#lock_configuration RbinRule#lock_configuration}
LockConfiguration *RbinRuleLockConfiguration `field:"optional" json:"lockConfiguration" yaml:"lockConfiguration"`
// resource_tags block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule#resource_tags RbinRule#resource_tags}
ResourceTags interface{} `field:"optional" json:"resourceTags" yaml:"resourceTags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule#tags RbinRule#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule#tags_all RbinRule#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule#timeouts RbinRule#timeouts}
Timeouts *RbinRuleTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type RbinRuleLockConfiguration ¶
type RbinRuleLockConfiguration struct {
// unlock_delay block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule#unlock_delay RbinRule#unlock_delay}
UnlockDelay *RbinRuleLockConfigurationUnlockDelay `field:"required" json:"unlockDelay" yaml:"unlockDelay"`
}
type RbinRuleLockConfigurationOutputReference ¶
type RbinRuleLockConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *RbinRuleLockConfiguration
SetInternalValue(val *RbinRuleLockConfiguration)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UnlockDelay() RbinRuleLockConfigurationUnlockDelayOutputReference
UnlockDelayInput() *RbinRuleLockConfigurationUnlockDelay
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutUnlockDelay(value *RbinRuleLockConfigurationUnlockDelay)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRbinRuleLockConfigurationOutputReference ¶
func NewRbinRuleLockConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) RbinRuleLockConfigurationOutputReference
type RbinRuleLockConfigurationUnlockDelay ¶
type RbinRuleLockConfigurationUnlockDelay struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule#unlock_delay_unit RbinRule#unlock_delay_unit}.
UnlockDelayUnit *string `field:"required" json:"unlockDelayUnit" yaml:"unlockDelayUnit"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule#unlock_delay_value RbinRule#unlock_delay_value}.
UnlockDelayValue *float64 `field:"required" json:"unlockDelayValue" yaml:"unlockDelayValue"`
}
type RbinRuleLockConfigurationUnlockDelayOutputReference ¶
type RbinRuleLockConfigurationUnlockDelayOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *RbinRuleLockConfigurationUnlockDelay
SetInternalValue(val *RbinRuleLockConfigurationUnlockDelay)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UnlockDelayUnit() *string
SetUnlockDelayUnit(val *string)
UnlockDelayUnitInput() *string
UnlockDelayValue() *float64
SetUnlockDelayValue(val *float64)
UnlockDelayValueInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRbinRuleLockConfigurationUnlockDelayOutputReference ¶
func NewRbinRuleLockConfigurationUnlockDelayOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) RbinRuleLockConfigurationUnlockDelayOutputReference
type RbinRuleResourceTags ¶
type RbinRuleResourceTags struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule#resource_tag_key RbinRule#resource_tag_key}.
ResourceTagKey *string `field:"required" json:"resourceTagKey" yaml:"resourceTagKey"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule#resource_tag_value RbinRule#resource_tag_value}.
ResourceTagValue *string `field:"optional" json:"resourceTagValue" yaml:"resourceTagValue"`
}
type RbinRuleResourceTagsList ¶
type RbinRuleResourceTagsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) RbinRuleResourceTagsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRbinRuleResourceTagsList ¶
func NewRbinRuleResourceTagsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) RbinRuleResourceTagsList
type RbinRuleResourceTagsOutputReference ¶
type RbinRuleResourceTagsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
ResourceTagKey() *string
SetResourceTagKey(val *string)
ResourceTagKeyInput() *string
ResourceTagValue() *string
SetResourceTagValue(val *string)
ResourceTagValueInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetResourceTagValue()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRbinRuleResourceTagsOutputReference ¶
func NewRbinRuleResourceTagsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) RbinRuleResourceTagsOutputReference
type RbinRuleRetentionPeriod ¶
type RbinRuleRetentionPeriod struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule#retention_period_unit RbinRule#retention_period_unit}.
RetentionPeriodUnit *string `field:"required" json:"retentionPeriodUnit" yaml:"retentionPeriodUnit"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule#retention_period_value RbinRule#retention_period_value}.
RetentionPeriodValue *float64 `field:"required" json:"retentionPeriodValue" yaml:"retentionPeriodValue"`
}
type RbinRuleRetentionPeriodOutputReference ¶
type RbinRuleRetentionPeriodOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *RbinRuleRetentionPeriod
SetInternalValue(val *RbinRuleRetentionPeriod)
RetentionPeriodUnit() *string
SetRetentionPeriodUnit(val *string)
RetentionPeriodUnitInput() *string
RetentionPeriodValue() *float64
SetRetentionPeriodValue(val *float64)
RetentionPeriodValueInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRbinRuleRetentionPeriodOutputReference ¶
func NewRbinRuleRetentionPeriodOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) RbinRuleRetentionPeriodOutputReference
type RbinRuleTimeouts ¶
type RbinRuleTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule#create RbinRule#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule#delete RbinRule#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rbin_rule#update RbinRule#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type RbinRuleTimeoutsOutputReference ¶
type RbinRuleTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRbinRuleTimeoutsOutputReference ¶
func NewRbinRuleTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) RbinRuleTimeoutsOutputReference
Source Files
¶
- RbinRule.go
- RbinRuleConfig.go
- RbinRuleLockConfiguration.go
- RbinRuleLockConfigurationOutputReference.go
- RbinRuleLockConfigurationOutputReference__checks.go
- RbinRuleLockConfigurationUnlockDelay.go
- RbinRuleLockConfigurationUnlockDelayOutputReference.go
- RbinRuleLockConfigurationUnlockDelayOutputReference__checks.go
- RbinRuleResourceTags.go
- RbinRuleResourceTagsList.go
- RbinRuleResourceTagsList__checks.go
- RbinRuleResourceTagsOutputReference.go
- RbinRuleResourceTagsOutputReference__checks.go
- RbinRuleRetentionPeriod.go
- RbinRuleRetentionPeriodOutputReference.go
- RbinRuleRetentionPeriodOutputReference__checks.go
- RbinRuleTimeouts.go
- RbinRuleTimeoutsOutputReference.go
- RbinRuleTimeoutsOutputReference__checks.go
- RbinRule__checks.go
- main.go