Documentation
¶
Index ¶
- func NewRoute53CidrLocation_Override(r Route53CidrLocation, scope constructs.Construct, id *string, ...)
- func Route53CidrLocation_IsConstruct(x interface{}) *bool
- func Route53CidrLocation_IsTerraformElement(x interface{}) *bool
- func Route53CidrLocation_IsTerraformResource(x interface{}) *bool
- func Route53CidrLocation_TfResourceType() *string
- type Route53CidrLocation
- type Route53CidrLocationConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRoute53CidrLocation_Override ¶
func NewRoute53CidrLocation_Override(r Route53CidrLocation, scope constructs.Construct, id *string, config *Route53CidrLocationConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/route53_cidr_location aws_route53_cidr_location} Resource.
func Route53CidrLocation_IsConstruct ¶
func Route53CidrLocation_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func Route53CidrLocation_IsTerraformElement ¶
func Route53CidrLocation_IsTerraformElement(x interface{}) *bool
Experimental.
func Route53CidrLocation_IsTerraformResource ¶
func Route53CidrLocation_IsTerraformResource(x interface{}) *bool
Experimental.
func Route53CidrLocation_TfResourceType ¶
func Route53CidrLocation_TfResourceType() *string
Types ¶
type Route53CidrLocation ¶
type Route53CidrLocation interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
CidrBlocks() *[]*string
SetCidrBlocks(val *[]*string)
CidrBlocksInput() *[]*string
CidrCollectionId() *string
SetCidrCollectionId(val *string)
CidrCollectionIdInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/route53_cidr_location aws_route53_cidr_location}.
func NewRoute53CidrLocation ¶
func NewRoute53CidrLocation(scope constructs.Construct, id *string, config *Route53CidrLocationConfig) Route53CidrLocation
Create a new {@link https://www.terraform.io/docs/providers/aws/r/route53_cidr_location aws_route53_cidr_location} Resource.
type Route53CidrLocationConfig ¶
type Route53CidrLocationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_cidr_location#cidr_blocks Route53CidrLocation#cidr_blocks}.
CidrBlocks *[]*string `field:"required" json:"cidrBlocks" yaml:"cidrBlocks"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_cidr_location#cidr_collection_id Route53CidrLocation#cidr_collection_id}.
CidrCollectionId *string `field:"required" json:"cidrCollectionId" yaml:"cidrCollectionId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_cidr_location#name Route53CidrLocation#name}.
Name *string `field:"required" json:"name" yaml:"name"`
}