Documentation
¶
Index ¶
- func NewRumAppMonitorAppMonitorConfigurationOutputReference_Override(r RumAppMonitorAppMonitorConfigurationOutputReference, ...)
- func NewRumAppMonitorCustomEventsOutputReference_Override(r RumAppMonitorCustomEventsOutputReference, ...)
- func NewRumAppMonitor_Override(r RumAppMonitor, scope constructs.Construct, id *string, ...)
- func RumAppMonitor_IsConstruct(x interface{}) *bool
- func RumAppMonitor_IsTerraformElement(x interface{}) *bool
- func RumAppMonitor_IsTerraformResource(x interface{}) *bool
- func RumAppMonitor_TfResourceType() *string
- type RumAppMonitor
- type RumAppMonitorAppMonitorConfiguration
- type RumAppMonitorAppMonitorConfigurationOutputReference
- type RumAppMonitorConfig
- type RumAppMonitorCustomEvents
- type RumAppMonitorCustomEventsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRumAppMonitorAppMonitorConfigurationOutputReference_Override ¶
func NewRumAppMonitorAppMonitorConfigurationOutputReference_Override(r RumAppMonitorAppMonitorConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewRumAppMonitorCustomEventsOutputReference_Override ¶ added in v12.0.1
func NewRumAppMonitorCustomEventsOutputReference_Override(r RumAppMonitorCustomEventsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewRumAppMonitor_Override ¶
func NewRumAppMonitor_Override(r RumAppMonitor, scope constructs.Construct, id *string, config *RumAppMonitorConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor aws_rum_app_monitor} Resource.
func RumAppMonitor_IsConstruct ¶
func RumAppMonitor_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func RumAppMonitor_IsTerraformElement ¶
func RumAppMonitor_IsTerraformElement(x interface{}) *bool
Experimental.
func RumAppMonitor_IsTerraformResource ¶
func RumAppMonitor_IsTerraformResource(x interface{}) *bool
Experimental.
func RumAppMonitor_TfResourceType ¶
func RumAppMonitor_TfResourceType() *string
Types ¶
type RumAppMonitor ¶
type RumAppMonitor interface {
cdktf.TerraformResource
AppMonitorConfiguration() RumAppMonitorAppMonitorConfigurationOutputReference
AppMonitorConfigurationInput() *RumAppMonitorAppMonitorConfiguration
AppMonitorId() *string
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CustomEvents() RumAppMonitorCustomEventsOutputReference
CustomEventsInput() *RumAppMonitorCustomEvents
CwLogEnabled() interface{}
SetCwLogEnabled(val interface{})
CwLogEnabledInput() interface{}
CwLogGroup() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Domain() *string
SetDomain(val *string)
DomainInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAppMonitorConfiguration(value *RumAppMonitorAppMonitorConfiguration)
PutCustomEvents(value *RumAppMonitorCustomEvents)
ResetAppMonitorConfiguration()
ResetCustomEvents()
ResetCwLogEnabled()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor aws_rum_app_monitor}.
func NewRumAppMonitor ¶
func NewRumAppMonitor(scope constructs.Construct, id *string, config *RumAppMonitorConfig) RumAppMonitor
Create a new {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor aws_rum_app_monitor} Resource.
type RumAppMonitorAppMonitorConfiguration ¶
type RumAppMonitorAppMonitorConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor#allow_cookies RumAppMonitor#allow_cookies}.
AllowCookies interface{} `field:"optional" json:"allowCookies" yaml:"allowCookies"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor#enable_xray RumAppMonitor#enable_xray}.
EnableXray interface{} `field:"optional" json:"enableXray" yaml:"enableXray"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor#excluded_pages RumAppMonitor#excluded_pages}.
ExcludedPages *[]*string `field:"optional" json:"excludedPages" yaml:"excludedPages"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor#favorite_pages RumAppMonitor#favorite_pages}.
FavoritePages *[]*string `field:"optional" json:"favoritePages" yaml:"favoritePages"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor#guest_role_arn RumAppMonitor#guest_role_arn}.
GuestRoleArn *string `field:"optional" json:"guestRoleArn" yaml:"guestRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor#identity_pool_id RumAppMonitor#identity_pool_id}.
IdentityPoolId *string `field:"optional" json:"identityPoolId" yaml:"identityPoolId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor#included_pages RumAppMonitor#included_pages}.
IncludedPages *[]*string `field:"optional" json:"includedPages" yaml:"includedPages"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor#session_sample_rate RumAppMonitor#session_sample_rate}.
SessionSampleRate *float64 `field:"optional" json:"sessionSampleRate" yaml:"sessionSampleRate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor#telemetries RumAppMonitor#telemetries}.
Telemetries *[]*string `field:"optional" json:"telemetries" yaml:"telemetries"`
}
type RumAppMonitorAppMonitorConfigurationOutputReference ¶
type RumAppMonitorAppMonitorConfigurationOutputReference interface {
cdktf.ComplexObject
AllowCookies() interface{}
SetAllowCookies(val interface{})
AllowCookiesInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EnableXray() interface{}
SetEnableXray(val interface{})
EnableXrayInput() interface{}
ExcludedPages() *[]*string
SetExcludedPages(val *[]*string)
ExcludedPagesInput() *[]*string
FavoritePages() *[]*string
SetFavoritePages(val *[]*string)
FavoritePagesInput() *[]*string
// Experimental.
Fqn() *string
GuestRoleArn() *string
SetGuestRoleArn(val *string)
GuestRoleArnInput() *string
IdentityPoolId() *string
SetIdentityPoolId(val *string)
IdentityPoolIdInput() *string
IncludedPages() *[]*string
SetIncludedPages(val *[]*string)
IncludedPagesInput() *[]*string
InternalValue() *RumAppMonitorAppMonitorConfiguration
SetInternalValue(val *RumAppMonitorAppMonitorConfiguration)
SessionSampleRate() *float64
SetSessionSampleRate(val *float64)
SessionSampleRateInput() *float64
Telemetries() *[]*string
SetTelemetries(val *[]*string)
TelemetriesInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAllowCookies()
ResetEnableXray()
ResetExcludedPages()
ResetFavoritePages()
ResetGuestRoleArn()
ResetIdentityPoolId()
ResetIncludedPages()
ResetSessionSampleRate()
ResetTelemetries()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRumAppMonitorAppMonitorConfigurationOutputReference ¶
func NewRumAppMonitorAppMonitorConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) RumAppMonitorAppMonitorConfigurationOutputReference
type RumAppMonitorConfig ¶
type RumAppMonitorConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor#domain RumAppMonitor#domain}.
Domain *string `field:"required" json:"domain" yaml:"domain"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor#name RumAppMonitor#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// app_monitor_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor#app_monitor_configuration RumAppMonitor#app_monitor_configuration}
AppMonitorConfiguration *RumAppMonitorAppMonitorConfiguration `field:"optional" json:"appMonitorConfiguration" yaml:"appMonitorConfiguration"`
// custom_events block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor#custom_events RumAppMonitor#custom_events}
CustomEvents *RumAppMonitorCustomEvents `field:"optional" json:"customEvents" yaml:"customEvents"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor#cw_log_enabled RumAppMonitor#cw_log_enabled}.
CwLogEnabled interface{} `field:"optional" json:"cwLogEnabled" yaml:"cwLogEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor#id RumAppMonitor#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor#tags RumAppMonitor#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor#tags_all RumAppMonitor#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type RumAppMonitorCustomEvents ¶ added in v12.0.1
type RumAppMonitorCustomEvents struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rum_app_monitor#status RumAppMonitor#status}.
Status *string `field:"optional" json:"status" yaml:"status"`
}
type RumAppMonitorCustomEventsOutputReference ¶ added in v12.0.1
type RumAppMonitorCustomEventsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *RumAppMonitorCustomEvents
SetInternalValue(val *RumAppMonitorCustomEvents)
Status() *string
SetStatus(val *string)
StatusInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetStatus()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRumAppMonitorCustomEventsOutputReference ¶ added in v12.0.1
func NewRumAppMonitorCustomEventsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) RumAppMonitorCustomEventsOutputReference
Source Files
¶
- RumAppMonitor.go
- RumAppMonitorAppMonitorConfiguration.go
- RumAppMonitorAppMonitorConfigurationOutputReference.go
- RumAppMonitorAppMonitorConfigurationOutputReference__checks.go
- RumAppMonitorConfig.go
- RumAppMonitorCustomEvents.go
- RumAppMonitorCustomEventsOutputReference.go
- RumAppMonitorCustomEventsOutputReference__checks.go
- RumAppMonitor__checks.go
- main.go