Documentation
¶
Index ¶
- func NewS3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUploadOutputReference_Override(...)
- func NewS3BucketLifecycleConfigurationRuleExpirationOutputReference_Override(s S3BucketLifecycleConfigurationRuleExpirationOutputReference, ...)
- func NewS3BucketLifecycleConfigurationRuleFilterAndOutputReference_Override(s S3BucketLifecycleConfigurationRuleFilterAndOutputReference, ...)
- func NewS3BucketLifecycleConfigurationRuleFilterOutputReference_Override(s S3BucketLifecycleConfigurationRuleFilterOutputReference, ...)
- func NewS3BucketLifecycleConfigurationRuleFilterTagOutputReference_Override(s S3BucketLifecycleConfigurationRuleFilterTagOutputReference, ...)
- func NewS3BucketLifecycleConfigurationRuleList_Override(s S3BucketLifecycleConfigurationRuleList, ...)
- func NewS3BucketLifecycleConfigurationRuleNoncurrentVersionExpirationOutputReference_Override(s S3BucketLifecycleConfigurationRuleNoncurrentVersionExpirationOutputReference, ...)
- func NewS3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionList_Override(s S3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionList, ...)
- func NewS3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionOutputReference_Override(s S3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionOutputReference, ...)
- func NewS3BucketLifecycleConfigurationRuleOutputReference_Override(s S3BucketLifecycleConfigurationRuleOutputReference, ...)
- func NewS3BucketLifecycleConfigurationRuleTransitionList_Override(s S3BucketLifecycleConfigurationRuleTransitionList, ...)
- func NewS3BucketLifecycleConfigurationRuleTransitionOutputReference_Override(s S3BucketLifecycleConfigurationRuleTransitionOutputReference, ...)
- func NewS3BucketLifecycleConfiguration_Override(s S3BucketLifecycleConfiguration, scope constructs.Construct, id *string, ...)
- func S3BucketLifecycleConfiguration_IsConstruct(x interface{}) *bool
- func S3BucketLifecycleConfiguration_IsTerraformElement(x interface{}) *bool
- func S3BucketLifecycleConfiguration_IsTerraformResource(x interface{}) *bool
- func S3BucketLifecycleConfiguration_TfResourceType() *string
- type S3BucketLifecycleConfiguration
- type S3BucketLifecycleConfigurationConfig
- type S3BucketLifecycleConfigurationRule
- type S3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUpload
- type S3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUploadOutputReference
- type S3BucketLifecycleConfigurationRuleExpiration
- type S3BucketLifecycleConfigurationRuleExpirationOutputReference
- type S3BucketLifecycleConfigurationRuleFilter
- type S3BucketLifecycleConfigurationRuleFilterAnd
- type S3BucketLifecycleConfigurationRuleFilterAndOutputReference
- type S3BucketLifecycleConfigurationRuleFilterOutputReference
- type S3BucketLifecycleConfigurationRuleFilterTag
- type S3BucketLifecycleConfigurationRuleFilterTagOutputReference
- type S3BucketLifecycleConfigurationRuleList
- type S3BucketLifecycleConfigurationRuleNoncurrentVersionExpiration
- type S3BucketLifecycleConfigurationRuleNoncurrentVersionExpirationOutputReference
- type S3BucketLifecycleConfigurationRuleNoncurrentVersionTransition
- type S3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionList
- type S3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionOutputReference
- type S3BucketLifecycleConfigurationRuleOutputReference
- type S3BucketLifecycleConfigurationRuleTransition
- type S3BucketLifecycleConfigurationRuleTransitionList
- type S3BucketLifecycleConfigurationRuleTransitionOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewS3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUploadOutputReference_Override ¶
func NewS3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUploadOutputReference_Override(s S3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUploadOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketLifecycleConfigurationRuleExpirationOutputReference_Override ¶
func NewS3BucketLifecycleConfigurationRuleExpirationOutputReference_Override(s S3BucketLifecycleConfigurationRuleExpirationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketLifecycleConfigurationRuleFilterAndOutputReference_Override ¶
func NewS3BucketLifecycleConfigurationRuleFilterAndOutputReference_Override(s S3BucketLifecycleConfigurationRuleFilterAndOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketLifecycleConfigurationRuleFilterOutputReference_Override ¶
func NewS3BucketLifecycleConfigurationRuleFilterOutputReference_Override(s S3BucketLifecycleConfigurationRuleFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketLifecycleConfigurationRuleFilterTagOutputReference_Override ¶
func NewS3BucketLifecycleConfigurationRuleFilterTagOutputReference_Override(s S3BucketLifecycleConfigurationRuleFilterTagOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketLifecycleConfigurationRuleList_Override ¶
func NewS3BucketLifecycleConfigurationRuleList_Override(s S3BucketLifecycleConfigurationRuleList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewS3BucketLifecycleConfigurationRuleNoncurrentVersionExpirationOutputReference_Override ¶
func NewS3BucketLifecycleConfigurationRuleNoncurrentVersionExpirationOutputReference_Override(s S3BucketLifecycleConfigurationRuleNoncurrentVersionExpirationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionList_Override ¶
func NewS3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionList_Override(s S3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewS3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionOutputReference_Override ¶
func NewS3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionOutputReference_Override(s S3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewS3BucketLifecycleConfigurationRuleOutputReference_Override ¶
func NewS3BucketLifecycleConfigurationRuleOutputReference_Override(s S3BucketLifecycleConfigurationRuleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewS3BucketLifecycleConfigurationRuleTransitionList_Override ¶
func NewS3BucketLifecycleConfigurationRuleTransitionList_Override(s S3BucketLifecycleConfigurationRuleTransitionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewS3BucketLifecycleConfigurationRuleTransitionOutputReference_Override ¶
func NewS3BucketLifecycleConfigurationRuleTransitionOutputReference_Override(s S3BucketLifecycleConfigurationRuleTransitionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewS3BucketLifecycleConfiguration_Override ¶
func NewS3BucketLifecycleConfiguration_Override(s S3BucketLifecycleConfiguration, scope constructs.Construct, id *string, config *S3BucketLifecycleConfigurationConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration aws_s3_bucket_lifecycle_configuration} Resource.
func S3BucketLifecycleConfiguration_IsConstruct ¶
func S3BucketLifecycleConfiguration_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func S3BucketLifecycleConfiguration_IsTerraformElement ¶
func S3BucketLifecycleConfiguration_IsTerraformElement(x interface{}) *bool
Experimental.
func S3BucketLifecycleConfiguration_IsTerraformResource ¶
func S3BucketLifecycleConfiguration_IsTerraformResource(x interface{}) *bool
Experimental.
func S3BucketLifecycleConfiguration_TfResourceType ¶
func S3BucketLifecycleConfiguration_TfResourceType() *string
Types ¶
type S3BucketLifecycleConfiguration ¶
type S3BucketLifecycleConfiguration interface {
cdktf.TerraformResource
Bucket() *string
SetBucket(val *string)
BucketInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
ExpectedBucketOwner() *string
SetExpectedBucketOwner(val *string)
ExpectedBucketOwnerInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Rule() S3BucketLifecycleConfigurationRuleList
RuleInput() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutRule(value interface{})
ResetExpectedBucketOwner()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration aws_s3_bucket_lifecycle_configuration}.
func NewS3BucketLifecycleConfiguration ¶
func NewS3BucketLifecycleConfiguration(scope constructs.Construct, id *string, config *S3BucketLifecycleConfigurationConfig) S3BucketLifecycleConfiguration
Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration aws_s3_bucket_lifecycle_configuration} Resource.
type S3BucketLifecycleConfigurationConfig ¶
type S3BucketLifecycleConfigurationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#bucket S3BucketLifecycleConfiguration#bucket}.
Bucket *string `field:"required" json:"bucket" yaml:"bucket"`
// rule block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#rule S3BucketLifecycleConfiguration#rule}
Rule interface{} `field:"required" json:"rule" yaml:"rule"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#expected_bucket_owner S3BucketLifecycleConfiguration#expected_bucket_owner}.
ExpectedBucketOwner *string `field:"optional" json:"expectedBucketOwner" yaml:"expectedBucketOwner"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#id S3BucketLifecycleConfiguration#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type S3BucketLifecycleConfigurationRule ¶
type S3BucketLifecycleConfigurationRule struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#id S3BucketLifecycleConfiguration#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"required" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#status S3BucketLifecycleConfiguration#status}.
Status *string `field:"required" json:"status" yaml:"status"`
// abort_incomplete_multipart_upload block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#abort_incomplete_multipart_upload S3BucketLifecycleConfiguration#abort_incomplete_multipart_upload}
AbortIncompleteMultipartUpload *S3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUpload `field:"optional" json:"abortIncompleteMultipartUpload" yaml:"abortIncompleteMultipartUpload"`
// expiration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#expiration S3BucketLifecycleConfiguration#expiration}
Expiration *S3BucketLifecycleConfigurationRuleExpiration `field:"optional" json:"expiration" yaml:"expiration"`
// filter block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#filter S3BucketLifecycleConfiguration#filter}
Filter *S3BucketLifecycleConfigurationRuleFilter `field:"optional" json:"filter" yaml:"filter"`
// noncurrent_version_expiration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#noncurrent_version_expiration S3BucketLifecycleConfiguration#noncurrent_version_expiration}
NoncurrentVersionExpiration *S3BucketLifecycleConfigurationRuleNoncurrentVersionExpiration `field:"optional" json:"noncurrentVersionExpiration" yaml:"noncurrentVersionExpiration"`
// noncurrent_version_transition block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#noncurrent_version_transition S3BucketLifecycleConfiguration#noncurrent_version_transition}
NoncurrentVersionTransition interface{} `field:"optional" json:"noncurrentVersionTransition" yaml:"noncurrentVersionTransition"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#prefix S3BucketLifecycleConfiguration#prefix}.
Prefix *string `field:"optional" json:"prefix" yaml:"prefix"`
// transition block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#transition S3BucketLifecycleConfiguration#transition}
Transition interface{} `field:"optional" json:"transition" yaml:"transition"`
}
type S3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUpload ¶
type S3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUpload struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#days_after_initiation S3BucketLifecycleConfiguration#days_after_initiation}.
DaysAfterInitiation *float64 `field:"optional" json:"daysAfterInitiation" yaml:"daysAfterInitiation"`
}
type S3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUploadOutputReference ¶
type S3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUploadOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DaysAfterInitiation() *float64
SetDaysAfterInitiation(val *float64)
DaysAfterInitiationInput() *float64
// Experimental.
Fqn() *string
InternalValue() *S3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUpload
SetInternalValue(val *S3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUpload)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDaysAfterInitiation()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUploadOutputReference ¶
func NewS3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUploadOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUploadOutputReference
type S3BucketLifecycleConfigurationRuleExpiration ¶
type S3BucketLifecycleConfigurationRuleExpiration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#date S3BucketLifecycleConfiguration#date}.
Date *string `field:"optional" json:"date" yaml:"date"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#days S3BucketLifecycleConfiguration#days}.
Days *float64 `field:"optional" json:"days" yaml:"days"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#expired_object_delete_marker S3BucketLifecycleConfiguration#expired_object_delete_marker}.
ExpiredObjectDeleteMarker interface{} `field:"optional" json:"expiredObjectDeleteMarker" yaml:"expiredObjectDeleteMarker"`
}
type S3BucketLifecycleConfigurationRuleExpirationOutputReference ¶
type S3BucketLifecycleConfigurationRuleExpirationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Date() *string
SetDate(val *string)
DateInput() *string
Days() *float64
SetDays(val *float64)
DaysInput() *float64
ExpiredObjectDeleteMarker() interface{}
SetExpiredObjectDeleteMarker(val interface{})
ExpiredObjectDeleteMarkerInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *S3BucketLifecycleConfigurationRuleExpiration
SetInternalValue(val *S3BucketLifecycleConfigurationRuleExpiration)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDate()
ResetDays()
ResetExpiredObjectDeleteMarker()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketLifecycleConfigurationRuleExpirationOutputReference ¶
func NewS3BucketLifecycleConfigurationRuleExpirationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketLifecycleConfigurationRuleExpirationOutputReference
type S3BucketLifecycleConfigurationRuleFilter ¶
type S3BucketLifecycleConfigurationRuleFilter struct {
// and block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#and S3BucketLifecycleConfiguration#and}
And *S3BucketLifecycleConfigurationRuleFilterAnd `field:"optional" json:"and" yaml:"and"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#object_size_greater_than S3BucketLifecycleConfiguration#object_size_greater_than}.
ObjectSizeGreaterThan *string `field:"optional" json:"objectSizeGreaterThan" yaml:"objectSizeGreaterThan"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#object_size_less_than S3BucketLifecycleConfiguration#object_size_less_than}.
ObjectSizeLessThan *string `field:"optional" json:"objectSizeLessThan" yaml:"objectSizeLessThan"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#prefix S3BucketLifecycleConfiguration#prefix}.
Prefix *string `field:"optional" json:"prefix" yaml:"prefix"`
// tag block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#tag S3BucketLifecycleConfiguration#tag}
Tag *S3BucketLifecycleConfigurationRuleFilterTag `field:"optional" json:"tag" yaml:"tag"`
}
type S3BucketLifecycleConfigurationRuleFilterAnd ¶
type S3BucketLifecycleConfigurationRuleFilterAnd struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#object_size_greater_than S3BucketLifecycleConfiguration#object_size_greater_than}.
ObjectSizeGreaterThan *float64 `field:"optional" json:"objectSizeGreaterThan" yaml:"objectSizeGreaterThan"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#object_size_less_than S3BucketLifecycleConfiguration#object_size_less_than}.
ObjectSizeLessThan *float64 `field:"optional" json:"objectSizeLessThan" yaml:"objectSizeLessThan"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#prefix S3BucketLifecycleConfiguration#prefix}.
Prefix *string `field:"optional" json:"prefix" yaml:"prefix"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#tags S3BucketLifecycleConfiguration#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type S3BucketLifecycleConfigurationRuleFilterAndOutputReference ¶
type S3BucketLifecycleConfigurationRuleFilterAndOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *S3BucketLifecycleConfigurationRuleFilterAnd
SetInternalValue(val *S3BucketLifecycleConfigurationRuleFilterAnd)
ObjectSizeGreaterThan() *float64
SetObjectSizeGreaterThan(val *float64)
ObjectSizeGreaterThanInput() *float64
ObjectSizeLessThan() *float64
SetObjectSizeLessThan(val *float64)
ObjectSizeLessThanInput() *float64
Prefix() *string
SetPrefix(val *string)
PrefixInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetObjectSizeGreaterThan()
ResetObjectSizeLessThan()
ResetPrefix()
ResetTags()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketLifecycleConfigurationRuleFilterAndOutputReference ¶
func NewS3BucketLifecycleConfigurationRuleFilterAndOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketLifecycleConfigurationRuleFilterAndOutputReference
type S3BucketLifecycleConfigurationRuleFilterOutputReference ¶
type S3BucketLifecycleConfigurationRuleFilterOutputReference interface {
cdktf.ComplexObject
And() S3BucketLifecycleConfigurationRuleFilterAndOutputReference
AndInput() *S3BucketLifecycleConfigurationRuleFilterAnd
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *S3BucketLifecycleConfigurationRuleFilter
SetInternalValue(val *S3BucketLifecycleConfigurationRuleFilter)
ObjectSizeGreaterThan() *string
SetObjectSizeGreaterThan(val *string)
ObjectSizeGreaterThanInput() *string
ObjectSizeLessThan() *string
SetObjectSizeLessThan(val *string)
ObjectSizeLessThanInput() *string
Prefix() *string
SetPrefix(val *string)
PrefixInput() *string
Tag() S3BucketLifecycleConfigurationRuleFilterTagOutputReference
TagInput() *S3BucketLifecycleConfigurationRuleFilterTag
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAnd(value *S3BucketLifecycleConfigurationRuleFilterAnd)
PutTag(value *S3BucketLifecycleConfigurationRuleFilterTag)
ResetAnd()
ResetObjectSizeGreaterThan()
ResetObjectSizeLessThan()
ResetPrefix()
ResetTag()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketLifecycleConfigurationRuleFilterOutputReference ¶
func NewS3BucketLifecycleConfigurationRuleFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketLifecycleConfigurationRuleFilterOutputReference
type S3BucketLifecycleConfigurationRuleFilterTag ¶
type S3BucketLifecycleConfigurationRuleFilterTag struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#key S3BucketLifecycleConfiguration#key}.
Key *string `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#value S3BucketLifecycleConfiguration#value}.
Value *string `field:"required" json:"value" yaml:"value"`
}
type S3BucketLifecycleConfigurationRuleFilterTagOutputReference ¶
type S3BucketLifecycleConfigurationRuleFilterTagOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *S3BucketLifecycleConfigurationRuleFilterTag
SetInternalValue(val *S3BucketLifecycleConfigurationRuleFilterTag)
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketLifecycleConfigurationRuleFilterTagOutputReference ¶
func NewS3BucketLifecycleConfigurationRuleFilterTagOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketLifecycleConfigurationRuleFilterTagOutputReference
type S3BucketLifecycleConfigurationRuleList ¶
type S3BucketLifecycleConfigurationRuleList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) S3BucketLifecycleConfigurationRuleOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketLifecycleConfigurationRuleList ¶
func NewS3BucketLifecycleConfigurationRuleList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) S3BucketLifecycleConfigurationRuleList
type S3BucketLifecycleConfigurationRuleNoncurrentVersionExpiration ¶
type S3BucketLifecycleConfigurationRuleNoncurrentVersionExpiration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#newer_noncurrent_versions S3BucketLifecycleConfiguration#newer_noncurrent_versions}.
NewerNoncurrentVersions *string `field:"optional" json:"newerNoncurrentVersions" yaml:"newerNoncurrentVersions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#noncurrent_days S3BucketLifecycleConfiguration#noncurrent_days}.
NoncurrentDays *float64 `field:"optional" json:"noncurrentDays" yaml:"noncurrentDays"`
}
type S3BucketLifecycleConfigurationRuleNoncurrentVersionExpirationOutputReference ¶
type S3BucketLifecycleConfigurationRuleNoncurrentVersionExpirationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *S3BucketLifecycleConfigurationRuleNoncurrentVersionExpiration
SetInternalValue(val *S3BucketLifecycleConfigurationRuleNoncurrentVersionExpiration)
NewerNoncurrentVersions() *string
SetNewerNoncurrentVersions(val *string)
NewerNoncurrentVersionsInput() *string
NoncurrentDays() *float64
SetNoncurrentDays(val *float64)
NoncurrentDaysInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetNewerNoncurrentVersions()
ResetNoncurrentDays()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketLifecycleConfigurationRuleNoncurrentVersionExpirationOutputReference ¶
func NewS3BucketLifecycleConfigurationRuleNoncurrentVersionExpirationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketLifecycleConfigurationRuleNoncurrentVersionExpirationOutputReference
type S3BucketLifecycleConfigurationRuleNoncurrentVersionTransition ¶
type S3BucketLifecycleConfigurationRuleNoncurrentVersionTransition struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#storage_class S3BucketLifecycleConfiguration#storage_class}.
StorageClass *string `field:"required" json:"storageClass" yaml:"storageClass"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#newer_noncurrent_versions S3BucketLifecycleConfiguration#newer_noncurrent_versions}.
NewerNoncurrentVersions *string `field:"optional" json:"newerNoncurrentVersions" yaml:"newerNoncurrentVersions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#noncurrent_days S3BucketLifecycleConfiguration#noncurrent_days}.
NoncurrentDays *float64 `field:"optional" json:"noncurrentDays" yaml:"noncurrentDays"`
}
type S3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionList ¶
type S3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) S3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionList ¶
func NewS3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) S3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionList
type S3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionOutputReference ¶
type S3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
NewerNoncurrentVersions() *string
SetNewerNoncurrentVersions(val *string)
NewerNoncurrentVersionsInput() *string
NoncurrentDays() *float64
SetNoncurrentDays(val *float64)
NoncurrentDaysInput() *float64
StorageClass() *string
SetStorageClass(val *string)
StorageClassInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetNewerNoncurrentVersions()
ResetNoncurrentDays()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionOutputReference ¶
func NewS3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) S3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionOutputReference
type S3BucketLifecycleConfigurationRuleOutputReference ¶
type S3BucketLifecycleConfigurationRuleOutputReference interface {
cdktf.ComplexObject
AbortIncompleteMultipartUpload() S3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUploadOutputReference
AbortIncompleteMultipartUploadInput() *S3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUpload
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Expiration() S3BucketLifecycleConfigurationRuleExpirationOutputReference
ExpirationInput() *S3BucketLifecycleConfigurationRuleExpiration
Filter() S3BucketLifecycleConfigurationRuleFilterOutputReference
FilterInput() *S3BucketLifecycleConfigurationRuleFilter
// Experimental.
Fqn() *string
Id() *string
SetId(val *string)
IdInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
NoncurrentVersionExpiration() S3BucketLifecycleConfigurationRuleNoncurrentVersionExpirationOutputReference
NoncurrentVersionExpirationInput() *S3BucketLifecycleConfigurationRuleNoncurrentVersionExpiration
NoncurrentVersionTransition() S3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionList
NoncurrentVersionTransitionInput() interface{}
Prefix() *string
SetPrefix(val *string)
PrefixInput() *string
Status() *string
SetStatus(val *string)
StatusInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Transition() S3BucketLifecycleConfigurationRuleTransitionList
TransitionInput() interface{}
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAbortIncompleteMultipartUpload(value *S3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUpload)
PutExpiration(value *S3BucketLifecycleConfigurationRuleExpiration)
PutFilter(value *S3BucketLifecycleConfigurationRuleFilter)
PutNoncurrentVersionExpiration(value *S3BucketLifecycleConfigurationRuleNoncurrentVersionExpiration)
PutNoncurrentVersionTransition(value interface{})
PutTransition(value interface{})
ResetAbortIncompleteMultipartUpload()
ResetExpiration()
ResetFilter()
ResetNoncurrentVersionExpiration()
ResetNoncurrentVersionTransition()
ResetPrefix()
ResetTransition()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketLifecycleConfigurationRuleOutputReference ¶
func NewS3BucketLifecycleConfigurationRuleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) S3BucketLifecycleConfigurationRuleOutputReference
type S3BucketLifecycleConfigurationRuleTransition ¶
type S3BucketLifecycleConfigurationRuleTransition struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#storage_class S3BucketLifecycleConfiguration#storage_class}.
StorageClass *string `field:"required" json:"storageClass" yaml:"storageClass"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#date S3BucketLifecycleConfiguration#date}.
Date *string `field:"optional" json:"date" yaml:"date"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_lifecycle_configuration#days S3BucketLifecycleConfiguration#days}.
Days *float64 `field:"optional" json:"days" yaml:"days"`
}
type S3BucketLifecycleConfigurationRuleTransitionList ¶
type S3BucketLifecycleConfigurationRuleTransitionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) S3BucketLifecycleConfigurationRuleTransitionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketLifecycleConfigurationRuleTransitionList ¶
func NewS3BucketLifecycleConfigurationRuleTransitionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) S3BucketLifecycleConfigurationRuleTransitionList
type S3BucketLifecycleConfigurationRuleTransitionOutputReference ¶
type S3BucketLifecycleConfigurationRuleTransitionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Date() *string
SetDate(val *string)
DateInput() *string
Days() *float64
SetDays(val *float64)
DaysInput() *float64
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
StorageClass() *string
SetStorageClass(val *string)
StorageClassInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDate()
ResetDays()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketLifecycleConfigurationRuleTransitionOutputReference ¶
func NewS3BucketLifecycleConfigurationRuleTransitionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) S3BucketLifecycleConfigurationRuleTransitionOutputReference
Source Files
¶
- S3BucketLifecycleConfiguration.go
- S3BucketLifecycleConfigurationConfig.go
- S3BucketLifecycleConfigurationRule.go
- S3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUpload.go
- S3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUploadOutputReference.go
- S3BucketLifecycleConfigurationRuleAbortIncompleteMultipartUploadOutputReference__checks.go
- S3BucketLifecycleConfigurationRuleExpiration.go
- S3BucketLifecycleConfigurationRuleExpirationOutputReference.go
- S3BucketLifecycleConfigurationRuleExpirationOutputReference__checks.go
- S3BucketLifecycleConfigurationRuleFilter.go
- S3BucketLifecycleConfigurationRuleFilterAnd.go
- S3BucketLifecycleConfigurationRuleFilterAndOutputReference.go
- S3BucketLifecycleConfigurationRuleFilterAndOutputReference__checks.go
- S3BucketLifecycleConfigurationRuleFilterOutputReference.go
- S3BucketLifecycleConfigurationRuleFilterOutputReference__checks.go
- S3BucketLifecycleConfigurationRuleFilterTag.go
- S3BucketLifecycleConfigurationRuleFilterTagOutputReference.go
- S3BucketLifecycleConfigurationRuleFilterTagOutputReference__checks.go
- S3BucketLifecycleConfigurationRuleList.go
- S3BucketLifecycleConfigurationRuleList__checks.go
- S3BucketLifecycleConfigurationRuleNoncurrentVersionExpiration.go
- S3BucketLifecycleConfigurationRuleNoncurrentVersionExpirationOutputReference.go
- S3BucketLifecycleConfigurationRuleNoncurrentVersionExpirationOutputReference__checks.go
- S3BucketLifecycleConfigurationRuleNoncurrentVersionTransition.go
- S3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionList.go
- S3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionList__checks.go
- S3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionOutputReference.go
- S3BucketLifecycleConfigurationRuleNoncurrentVersionTransitionOutputReference__checks.go
- S3BucketLifecycleConfigurationRuleOutputReference.go
- S3BucketLifecycleConfigurationRuleOutputReference__checks.go
- S3BucketLifecycleConfigurationRuleTransition.go
- S3BucketLifecycleConfigurationRuleTransitionList.go
- S3BucketLifecycleConfigurationRuleTransitionList__checks.go
- S3BucketLifecycleConfigurationRuleTransitionOutputReference.go
- S3BucketLifecycleConfigurationRuleTransitionOutputReference__checks.go
- S3BucketLifecycleConfiguration__checks.go
- main.go