Documentation
¶
Index ¶
- func NewSagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfigOutputReference_Override(...)
- func NewSagemakerFlowDefinitionHumanLoopActivationConfigOutputReference_Override(s SagemakerFlowDefinitionHumanLoopActivationConfigOutputReference, ...)
- func NewSagemakerFlowDefinitionHumanLoopConfigOutputReference_Override(s SagemakerFlowDefinitionHumanLoopConfigOutputReference, ...)
- func NewSagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsdOutputReference_Override(...)
- func NewSagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceOutputReference_Override(...)
- func NewSagemakerFlowDefinitionHumanLoopRequestSourceOutputReference_Override(s SagemakerFlowDefinitionHumanLoopRequestSourceOutputReference, ...)
- func NewSagemakerFlowDefinitionOutputConfigOutputReference_Override(s SagemakerFlowDefinitionOutputConfigOutputReference, ...)
- func NewSagemakerFlowDefinition_Override(s SagemakerFlowDefinition, scope constructs.Construct, id *string, ...)
- func SagemakerFlowDefinition_IsConstruct(x interface{}) *bool
- func SagemakerFlowDefinition_IsTerraformElement(x interface{}) *bool
- func SagemakerFlowDefinition_IsTerraformResource(x interface{}) *bool
- func SagemakerFlowDefinition_TfResourceType() *string
- type SagemakerFlowDefinition
- type SagemakerFlowDefinitionConfig
- type SagemakerFlowDefinitionHumanLoopActivationConfig
- type SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfig
- type SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfigOutputReference
- type SagemakerFlowDefinitionHumanLoopActivationConfigOutputReference
- type SagemakerFlowDefinitionHumanLoopConfig
- type SagemakerFlowDefinitionHumanLoopConfigOutputReference
- type SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPrice
- type SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsd
- type SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsdOutputReference
- type SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceOutputReference
- type SagemakerFlowDefinitionHumanLoopRequestSource
- type SagemakerFlowDefinitionHumanLoopRequestSourceOutputReference
- type SagemakerFlowDefinitionOutputConfig
- type SagemakerFlowDefinitionOutputConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfigOutputReference_Override ¶
func NewSagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfigOutputReference_Override(s SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerFlowDefinitionHumanLoopActivationConfigOutputReference_Override ¶
func NewSagemakerFlowDefinitionHumanLoopActivationConfigOutputReference_Override(s SagemakerFlowDefinitionHumanLoopActivationConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerFlowDefinitionHumanLoopConfigOutputReference_Override ¶
func NewSagemakerFlowDefinitionHumanLoopConfigOutputReference_Override(s SagemakerFlowDefinitionHumanLoopConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsdOutputReference_Override ¶
func NewSagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsdOutputReference_Override(s SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsdOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceOutputReference_Override ¶
func NewSagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceOutputReference_Override(s SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerFlowDefinitionHumanLoopRequestSourceOutputReference_Override ¶
func NewSagemakerFlowDefinitionHumanLoopRequestSourceOutputReference_Override(s SagemakerFlowDefinitionHumanLoopRequestSourceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerFlowDefinitionOutputConfigOutputReference_Override ¶
func NewSagemakerFlowDefinitionOutputConfigOutputReference_Override(s SagemakerFlowDefinitionOutputConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerFlowDefinition_Override ¶
func NewSagemakerFlowDefinition_Override(s SagemakerFlowDefinition, scope constructs.Construct, id *string, config *SagemakerFlowDefinitionConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition aws_sagemaker_flow_definition} Resource.
func SagemakerFlowDefinition_IsConstruct ¶
func SagemakerFlowDefinition_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SagemakerFlowDefinition_IsTerraformElement ¶
func SagemakerFlowDefinition_IsTerraformElement(x interface{}) *bool
Experimental.
func SagemakerFlowDefinition_IsTerraformResource ¶
func SagemakerFlowDefinition_IsTerraformResource(x interface{}) *bool
Experimental.
func SagemakerFlowDefinition_TfResourceType ¶
func SagemakerFlowDefinition_TfResourceType() *string
Types ¶
type SagemakerFlowDefinition ¶
type SagemakerFlowDefinition interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
FlowDefinitionName() *string
SetFlowDefinitionName(val *string)
FlowDefinitionNameInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HumanLoopActivationConfig() SagemakerFlowDefinitionHumanLoopActivationConfigOutputReference
HumanLoopActivationConfigInput() *SagemakerFlowDefinitionHumanLoopActivationConfig
HumanLoopConfig() SagemakerFlowDefinitionHumanLoopConfigOutputReference
HumanLoopConfigInput() *SagemakerFlowDefinitionHumanLoopConfig
HumanLoopRequestSource() SagemakerFlowDefinitionHumanLoopRequestSourceOutputReference
HumanLoopRequestSourceInput() *SagemakerFlowDefinitionHumanLoopRequestSource
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
OutputConfig() SagemakerFlowDefinitionOutputConfigOutputReference
OutputConfigInput() *SagemakerFlowDefinitionOutputConfig
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutHumanLoopActivationConfig(value *SagemakerFlowDefinitionHumanLoopActivationConfig)
PutHumanLoopConfig(value *SagemakerFlowDefinitionHumanLoopConfig)
PutHumanLoopRequestSource(value *SagemakerFlowDefinitionHumanLoopRequestSource)
PutOutputConfig(value *SagemakerFlowDefinitionOutputConfig)
ResetHumanLoopActivationConfig()
ResetHumanLoopRequestSource()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition aws_sagemaker_flow_definition}.
func NewSagemakerFlowDefinition ¶
func NewSagemakerFlowDefinition(scope constructs.Construct, id *string, config *SagemakerFlowDefinitionConfig) SagemakerFlowDefinition
Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition aws_sagemaker_flow_definition} Resource.
type SagemakerFlowDefinitionConfig ¶
type SagemakerFlowDefinitionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#flow_definition_name SagemakerFlowDefinition#flow_definition_name}.
FlowDefinitionName *string `field:"required" json:"flowDefinitionName" yaml:"flowDefinitionName"`
// human_loop_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#human_loop_config SagemakerFlowDefinition#human_loop_config}
HumanLoopConfig *SagemakerFlowDefinitionHumanLoopConfig `field:"required" json:"humanLoopConfig" yaml:"humanLoopConfig"`
// output_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#output_config SagemakerFlowDefinition#output_config}
OutputConfig *SagemakerFlowDefinitionOutputConfig `field:"required" json:"outputConfig" yaml:"outputConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#role_arn SagemakerFlowDefinition#role_arn}.
RoleArn *string `field:"required" json:"roleArn" yaml:"roleArn"`
// human_loop_activation_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#human_loop_activation_config SagemakerFlowDefinition#human_loop_activation_config}
HumanLoopActivationConfig *SagemakerFlowDefinitionHumanLoopActivationConfig `field:"optional" json:"humanLoopActivationConfig" yaml:"humanLoopActivationConfig"`
// human_loop_request_source block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#human_loop_request_source SagemakerFlowDefinition#human_loop_request_source}
HumanLoopRequestSource *SagemakerFlowDefinitionHumanLoopRequestSource `field:"optional" json:"humanLoopRequestSource" yaml:"humanLoopRequestSource"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#id SagemakerFlowDefinition#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#tags SagemakerFlowDefinition#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#tags_all SagemakerFlowDefinition#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type SagemakerFlowDefinitionHumanLoopActivationConfig ¶
type SagemakerFlowDefinitionHumanLoopActivationConfig struct {
// human_loop_activation_conditions_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#human_loop_activation_conditions_config SagemakerFlowDefinition#human_loop_activation_conditions_config}
HumanLoopActivationConditionsConfig *SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfig `field:"optional" json:"humanLoopActivationConditionsConfig" yaml:"humanLoopActivationConditionsConfig"`
}
type SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfig ¶
type SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#human_loop_activation_conditions SagemakerFlowDefinition#human_loop_activation_conditions}.
HumanLoopActivationConditions *string `field:"required" json:"humanLoopActivationConditions" yaml:"humanLoopActivationConditions"`
}
type SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfigOutputReference ¶
type SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HumanLoopActivationConditions() *string
SetHumanLoopActivationConditions(val *string)
HumanLoopActivationConditionsInput() *string
InternalValue() *SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfig
SetInternalValue(val *SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfigOutputReference ¶
func NewSagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfigOutputReference
type SagemakerFlowDefinitionHumanLoopActivationConfigOutputReference ¶
type SagemakerFlowDefinitionHumanLoopActivationConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HumanLoopActivationConditionsConfig() SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfigOutputReference
HumanLoopActivationConditionsConfigInput() *SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfig
InternalValue() *SagemakerFlowDefinitionHumanLoopActivationConfig
SetInternalValue(val *SagemakerFlowDefinitionHumanLoopActivationConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutHumanLoopActivationConditionsConfig(value *SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfig)
ResetHumanLoopActivationConditionsConfig()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerFlowDefinitionHumanLoopActivationConfigOutputReference ¶
func NewSagemakerFlowDefinitionHumanLoopActivationConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerFlowDefinitionHumanLoopActivationConfigOutputReference
type SagemakerFlowDefinitionHumanLoopConfig ¶
type SagemakerFlowDefinitionHumanLoopConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#human_task_ui_arn SagemakerFlowDefinition#human_task_ui_arn}.
HumanTaskUiArn *string `field:"required" json:"humanTaskUiArn" yaml:"humanTaskUiArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#task_count SagemakerFlowDefinition#task_count}.
TaskCount *float64 `field:"required" json:"taskCount" yaml:"taskCount"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#task_description SagemakerFlowDefinition#task_description}.
TaskDescription *string `field:"required" json:"taskDescription" yaml:"taskDescription"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#task_title SagemakerFlowDefinition#task_title}.
TaskTitle *string `field:"required" json:"taskTitle" yaml:"taskTitle"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#workteam_arn SagemakerFlowDefinition#workteam_arn}.
WorkteamArn *string `field:"required" json:"workteamArn" yaml:"workteamArn"`
// public_workforce_task_price block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#public_workforce_task_price SagemakerFlowDefinition#public_workforce_task_price}
PublicWorkforceTaskPrice *SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPrice `field:"optional" json:"publicWorkforceTaskPrice" yaml:"publicWorkforceTaskPrice"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#task_availability_lifetime_in_seconds SagemakerFlowDefinition#task_availability_lifetime_in_seconds}.
TaskAvailabilityLifetimeInSeconds *float64 `field:"optional" json:"taskAvailabilityLifetimeInSeconds" yaml:"taskAvailabilityLifetimeInSeconds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#task_keywords SagemakerFlowDefinition#task_keywords}.
TaskKeywords *[]*string `field:"optional" json:"taskKeywords" yaml:"taskKeywords"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#task_time_limit_in_seconds SagemakerFlowDefinition#task_time_limit_in_seconds}.
TaskTimeLimitInSeconds *float64 `field:"optional" json:"taskTimeLimitInSeconds" yaml:"taskTimeLimitInSeconds"`
}
type SagemakerFlowDefinitionHumanLoopConfigOutputReference ¶
type SagemakerFlowDefinitionHumanLoopConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HumanTaskUiArn() *string
SetHumanTaskUiArn(val *string)
HumanTaskUiArnInput() *string
InternalValue() *SagemakerFlowDefinitionHumanLoopConfig
SetInternalValue(val *SagemakerFlowDefinitionHumanLoopConfig)
PublicWorkforceTaskPrice() SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceOutputReference
PublicWorkforceTaskPriceInput() *SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPrice
TaskAvailabilityLifetimeInSeconds() *float64
SetTaskAvailabilityLifetimeInSeconds(val *float64)
TaskAvailabilityLifetimeInSecondsInput() *float64
TaskCount() *float64
SetTaskCount(val *float64)
TaskCountInput() *float64
TaskDescription() *string
SetTaskDescription(val *string)
TaskDescriptionInput() *string
TaskKeywords() *[]*string
SetTaskKeywords(val *[]*string)
TaskKeywordsInput() *[]*string
TaskTimeLimitInSeconds() *float64
SetTaskTimeLimitInSeconds(val *float64)
TaskTimeLimitInSecondsInput() *float64
TaskTitle() *string
SetTaskTitle(val *string)
TaskTitleInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
WorkteamArn() *string
SetWorkteamArn(val *string)
WorkteamArnInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutPublicWorkforceTaskPrice(value *SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPrice)
ResetPublicWorkforceTaskPrice()
ResetTaskAvailabilityLifetimeInSeconds()
ResetTaskKeywords()
ResetTaskTimeLimitInSeconds()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerFlowDefinitionHumanLoopConfigOutputReference ¶
func NewSagemakerFlowDefinitionHumanLoopConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerFlowDefinitionHumanLoopConfigOutputReference
type SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPrice ¶
type SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPrice struct {
// amount_in_usd block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#amount_in_usd SagemakerFlowDefinition#amount_in_usd}
AmountInUsd *SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsd `field:"optional" json:"amountInUsd" yaml:"amountInUsd"`
}
type SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsd ¶
type SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsd struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#cents SagemakerFlowDefinition#cents}.
Cents *float64 `field:"optional" json:"cents" yaml:"cents"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#dollars SagemakerFlowDefinition#dollars}.
Dollars *float64 `field:"optional" json:"dollars" yaml:"dollars"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#tenth_fractions_of_a_cent SagemakerFlowDefinition#tenth_fractions_of_a_cent}.
TenthFractionsOfACent *float64 `field:"optional" json:"tenthFractionsOfACent" yaml:"tenthFractionsOfACent"`
}
type SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsdOutputReference ¶
type SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsdOutputReference interface {
cdktf.ComplexObject
Cents() *float64
SetCents(val *float64)
CentsInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Dollars() *float64
SetDollars(val *float64)
DollarsInput() *float64
// Experimental.
Fqn() *string
InternalValue() *SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsd
SetInternalValue(val *SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsd)
TenthFractionsOfACent() *float64
SetTenthFractionsOfACent(val *float64)
TenthFractionsOfACentInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCents()
ResetDollars()
ResetTenthFractionsOfACent()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsdOutputReference ¶
func NewSagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsdOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsdOutputReference
type SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceOutputReference ¶
type SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceOutputReference interface {
cdktf.ComplexObject
AmountInUsd() SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsdOutputReference
AmountInUsdInput() *SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsd
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPrice
SetInternalValue(val *SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPrice)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAmountInUsd(value *SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsd)
ResetAmountInUsd()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceOutputReference ¶
func NewSagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceOutputReference
type SagemakerFlowDefinitionHumanLoopRequestSource ¶
type SagemakerFlowDefinitionHumanLoopRequestSource struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#aws_managed_human_loop_request_source SagemakerFlowDefinition#aws_managed_human_loop_request_source}.
AwsManagedHumanLoopRequestSource *string `field:"required" json:"awsManagedHumanLoopRequestSource" yaml:"awsManagedHumanLoopRequestSource"`
}
type SagemakerFlowDefinitionHumanLoopRequestSourceOutputReference ¶
type SagemakerFlowDefinitionHumanLoopRequestSourceOutputReference interface {
cdktf.ComplexObject
AwsManagedHumanLoopRequestSource() *string
SetAwsManagedHumanLoopRequestSource(val *string)
AwsManagedHumanLoopRequestSourceInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SagemakerFlowDefinitionHumanLoopRequestSource
SetInternalValue(val *SagemakerFlowDefinitionHumanLoopRequestSource)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerFlowDefinitionHumanLoopRequestSourceOutputReference ¶
func NewSagemakerFlowDefinitionHumanLoopRequestSourceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerFlowDefinitionHumanLoopRequestSourceOutputReference
type SagemakerFlowDefinitionOutputConfig ¶
type SagemakerFlowDefinitionOutputConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#s3_output_path SagemakerFlowDefinition#s3_output_path}.
S3OutputPath *string `field:"required" json:"s3OutputPath" yaml:"s3OutputPath"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition#kms_key_id SagemakerFlowDefinition#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
}
type SagemakerFlowDefinitionOutputConfigOutputReference ¶
type SagemakerFlowDefinitionOutputConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SagemakerFlowDefinitionOutputConfig
SetInternalValue(val *SagemakerFlowDefinitionOutputConfig)
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
S3OutputPath() *string
SetS3OutputPath(val *string)
S3OutputPathInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetKmsKeyId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerFlowDefinitionOutputConfigOutputReference ¶
func NewSagemakerFlowDefinitionOutputConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerFlowDefinitionOutputConfigOutputReference
Source Files
¶
- SagemakerFlowDefinition.go
- SagemakerFlowDefinitionConfig.go
- SagemakerFlowDefinitionHumanLoopActivationConfig.go
- SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfig.go
- SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfigOutputReference.go
- SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfigOutputReference__checks.go
- SagemakerFlowDefinitionHumanLoopActivationConfigOutputReference.go
- SagemakerFlowDefinitionHumanLoopActivationConfigOutputReference__checks.go
- SagemakerFlowDefinitionHumanLoopConfig.go
- SagemakerFlowDefinitionHumanLoopConfigOutputReference.go
- SagemakerFlowDefinitionHumanLoopConfigOutputReference__checks.go
- SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPrice.go
- SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsd.go
- SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsdOutputReference.go
- SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsdOutputReference__checks.go
- SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceOutputReference.go
- SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceOutputReference__checks.go
- SagemakerFlowDefinitionHumanLoopRequestSource.go
- SagemakerFlowDefinitionHumanLoopRequestSourceOutputReference.go
- SagemakerFlowDefinitionHumanLoopRequestSourceOutputReference__checks.go
- SagemakerFlowDefinitionOutputConfig.go
- SagemakerFlowDefinitionOutputConfigOutputReference.go
- SagemakerFlowDefinitionOutputConfigOutputReference__checks.go
- SagemakerFlowDefinition__checks.go
- main.go