Documentation
¶
Index ¶
- func NewSagemakerNotebookInstanceInstanceMetadataServiceConfigurationOutputReference_Override(s SagemakerNotebookInstanceInstanceMetadataServiceConfigurationOutputReference, ...)
- func NewSagemakerNotebookInstance_Override(s SagemakerNotebookInstance, scope constructs.Construct, id *string, ...)
- func SagemakerNotebookInstance_IsConstruct(x interface{}) *bool
- func SagemakerNotebookInstance_IsTerraformElement(x interface{}) *bool
- func SagemakerNotebookInstance_IsTerraformResource(x interface{}) *bool
- func SagemakerNotebookInstance_TfResourceType() *string
- type SagemakerNotebookInstance
- type SagemakerNotebookInstanceConfig
- type SagemakerNotebookInstanceInstanceMetadataServiceConfiguration
- type SagemakerNotebookInstanceInstanceMetadataServiceConfigurationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSagemakerNotebookInstanceInstanceMetadataServiceConfigurationOutputReference_Override ¶
func NewSagemakerNotebookInstanceInstanceMetadataServiceConfigurationOutputReference_Override(s SagemakerNotebookInstanceInstanceMetadataServiceConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerNotebookInstance_Override ¶
func NewSagemakerNotebookInstance_Override(s SagemakerNotebookInstance, scope constructs.Construct, id *string, config *SagemakerNotebookInstanceConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance aws_sagemaker_notebook_instance} Resource.
func SagemakerNotebookInstance_IsConstruct ¶
func SagemakerNotebookInstance_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SagemakerNotebookInstance_IsTerraformElement ¶
func SagemakerNotebookInstance_IsTerraformElement(x interface{}) *bool
Experimental.
func SagemakerNotebookInstance_IsTerraformResource ¶
func SagemakerNotebookInstance_IsTerraformResource(x interface{}) *bool
Experimental.
func SagemakerNotebookInstance_TfResourceType ¶
func SagemakerNotebookInstance_TfResourceType() *string
Types ¶
type SagemakerNotebookInstance ¶
type SagemakerNotebookInstance interface {
cdktf.TerraformResource
AcceleratorTypes() *[]*string
SetAcceleratorTypes(val *[]*string)
AcceleratorTypesInput() *[]*string
AdditionalCodeRepositories() *[]*string
SetAdditionalCodeRepositories(val *[]*string)
AdditionalCodeRepositoriesInput() *[]*string
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DefaultCodeRepository() *string
SetDefaultCodeRepository(val *string)
DefaultCodeRepositoryInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DirectInternetAccess() *string
SetDirectInternetAccess(val *string)
DirectInternetAccessInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InstanceMetadataServiceConfiguration() SagemakerNotebookInstanceInstanceMetadataServiceConfigurationOutputReference
InstanceMetadataServiceConfigurationInput() *SagemakerNotebookInstanceInstanceMetadataServiceConfiguration
InstanceType() *string
SetInstanceType(val *string)
InstanceTypeInput() *string
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LifecycleConfigName() *string
SetLifecycleConfigName(val *string)
LifecycleConfigNameInput() *string
Name() *string
SetName(val *string)
NameInput() *string
NetworkInterfaceId() *string
// The tree node.
Node() constructs.Node
PlatformIdentifier() *string
SetPlatformIdentifier(val *string)
PlatformIdentifierInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
RootAccess() *string
SetRootAccess(val *string)
RootAccessInput() *string
SecurityGroups() *[]*string
SetSecurityGroups(val *[]*string)
SecurityGroupsInput() *[]*string
SubnetId() *string
SetSubnetId(val *string)
SubnetIdInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Url() *string
VolumeSize() *float64
SetVolumeSize(val *float64)
VolumeSizeInput() *float64
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutInstanceMetadataServiceConfiguration(value *SagemakerNotebookInstanceInstanceMetadataServiceConfiguration)
ResetAcceleratorTypes()
ResetAdditionalCodeRepositories()
ResetDefaultCodeRepository()
ResetDirectInternetAccess()
ResetId()
ResetInstanceMetadataServiceConfiguration()
ResetKmsKeyId()
ResetLifecycleConfigName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPlatformIdentifier()
ResetRootAccess()
ResetSecurityGroups()
ResetSubnetId()
ResetTags()
ResetTagsAll()
ResetVolumeSize()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance aws_sagemaker_notebook_instance}.
func NewSagemakerNotebookInstance ¶
func NewSagemakerNotebookInstance(scope constructs.Construct, id *string, config *SagemakerNotebookInstanceConfig) SagemakerNotebookInstance
Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance aws_sagemaker_notebook_instance} Resource.
type SagemakerNotebookInstanceConfig ¶
type SagemakerNotebookInstanceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance#instance_type SagemakerNotebookInstance#instance_type}.
InstanceType *string `field:"required" json:"instanceType" yaml:"instanceType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance#name SagemakerNotebookInstance#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance#role_arn SagemakerNotebookInstance#role_arn}.
RoleArn *string `field:"required" json:"roleArn" yaml:"roleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance#accelerator_types SagemakerNotebookInstance#accelerator_types}.
AcceleratorTypes *[]*string `field:"optional" json:"acceleratorTypes" yaml:"acceleratorTypes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance#additional_code_repositories SagemakerNotebookInstance#additional_code_repositories}.
AdditionalCodeRepositories *[]*string `field:"optional" json:"additionalCodeRepositories" yaml:"additionalCodeRepositories"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance#default_code_repository SagemakerNotebookInstance#default_code_repository}.
DefaultCodeRepository *string `field:"optional" json:"defaultCodeRepository" yaml:"defaultCodeRepository"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance#direct_internet_access SagemakerNotebookInstance#direct_internet_access}.
DirectInternetAccess *string `field:"optional" json:"directInternetAccess" yaml:"directInternetAccess"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance#id SagemakerNotebookInstance#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// instance_metadata_service_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance#instance_metadata_service_configuration SagemakerNotebookInstance#instance_metadata_service_configuration}
InstanceMetadataServiceConfiguration *SagemakerNotebookInstanceInstanceMetadataServiceConfiguration `field:"optional" json:"instanceMetadataServiceConfiguration" yaml:"instanceMetadataServiceConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance#kms_key_id SagemakerNotebookInstance#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance#lifecycle_config_name SagemakerNotebookInstance#lifecycle_config_name}.
LifecycleConfigName *string `field:"optional" json:"lifecycleConfigName" yaml:"lifecycleConfigName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance#platform_identifier SagemakerNotebookInstance#platform_identifier}.
PlatformIdentifier *string `field:"optional" json:"platformIdentifier" yaml:"platformIdentifier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance#root_access SagemakerNotebookInstance#root_access}.
RootAccess *string `field:"optional" json:"rootAccess" yaml:"rootAccess"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance#security_groups SagemakerNotebookInstance#security_groups}.
SecurityGroups *[]*string `field:"optional" json:"securityGroups" yaml:"securityGroups"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance#subnet_id SagemakerNotebookInstance#subnet_id}.
SubnetId *string `field:"optional" json:"subnetId" yaml:"subnetId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance#tags SagemakerNotebookInstance#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance#tags_all SagemakerNotebookInstance#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance#volume_size SagemakerNotebookInstance#volume_size}.
VolumeSize *float64 `field:"optional" json:"volumeSize" yaml:"volumeSize"`
}
type SagemakerNotebookInstanceInstanceMetadataServiceConfiguration ¶
type SagemakerNotebookInstanceInstanceMetadataServiceConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance#minimum_instance_metadata_service_version SagemakerNotebookInstance#minimum_instance_metadata_service_version}.
MinimumInstanceMetadataServiceVersion *string `field:"optional" json:"minimumInstanceMetadataServiceVersion" yaml:"minimumInstanceMetadataServiceVersion"`
}
type SagemakerNotebookInstanceInstanceMetadataServiceConfigurationOutputReference ¶
type SagemakerNotebookInstanceInstanceMetadataServiceConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SagemakerNotebookInstanceInstanceMetadataServiceConfiguration
SetInternalValue(val *SagemakerNotebookInstanceInstanceMetadataServiceConfiguration)
MinimumInstanceMetadataServiceVersion() *string
SetMinimumInstanceMetadataServiceVersion(val *string)
MinimumInstanceMetadataServiceVersionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetMinimumInstanceMetadataServiceVersion()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerNotebookInstanceInstanceMetadataServiceConfigurationOutputReference ¶
func NewSagemakerNotebookInstanceInstanceMetadataServiceConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerNotebookInstanceInstanceMetadataServiceConfigurationOutputReference
Source Files
¶
- SagemakerNotebookInstance.go
- SagemakerNotebookInstanceConfig.go
- SagemakerNotebookInstanceInstanceMetadataServiceConfiguration.go
- SagemakerNotebookInstanceInstanceMetadataServiceConfigurationOutputReference.go
- SagemakerNotebookInstanceInstanceMetadataServiceConfigurationOutputReference__checks.go
- SagemakerNotebookInstance__checks.go
- main.go