Documentation
¶
Index ¶
- func NewSagemakerWorkforceCognitoConfigOutputReference_Override(s SagemakerWorkforceCognitoConfigOutputReference, ...)
- func NewSagemakerWorkforceOidcConfigOutputReference_Override(s SagemakerWorkforceOidcConfigOutputReference, ...)
- func NewSagemakerWorkforceSourceIpConfigOutputReference_Override(s SagemakerWorkforceSourceIpConfigOutputReference, ...)
- func NewSagemakerWorkforceWorkforceVpcConfigOutputReference_Override(s SagemakerWorkforceWorkforceVpcConfigOutputReference, ...)
- func NewSagemakerWorkforce_Override(s SagemakerWorkforce, scope constructs.Construct, id *string, ...)
- func SagemakerWorkforce_IsConstruct(x interface{}) *bool
- func SagemakerWorkforce_IsTerraformElement(x interface{}) *bool
- func SagemakerWorkforce_IsTerraformResource(x interface{}) *bool
- func SagemakerWorkforce_TfResourceType() *string
- type SagemakerWorkforce
- type SagemakerWorkforceCognitoConfig
- type SagemakerWorkforceCognitoConfigOutputReference
- type SagemakerWorkforceConfig
- type SagemakerWorkforceOidcConfig
- type SagemakerWorkforceOidcConfigOutputReference
- type SagemakerWorkforceSourceIpConfig
- type SagemakerWorkforceSourceIpConfigOutputReference
- type SagemakerWorkforceWorkforceVpcConfig
- type SagemakerWorkforceWorkforceVpcConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSagemakerWorkforceCognitoConfigOutputReference_Override ¶
func NewSagemakerWorkforceCognitoConfigOutputReference_Override(s SagemakerWorkforceCognitoConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerWorkforceOidcConfigOutputReference_Override ¶
func NewSagemakerWorkforceOidcConfigOutputReference_Override(s SagemakerWorkforceOidcConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerWorkforceSourceIpConfigOutputReference_Override ¶
func NewSagemakerWorkforceSourceIpConfigOutputReference_Override(s SagemakerWorkforceSourceIpConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerWorkforceWorkforceVpcConfigOutputReference_Override ¶
func NewSagemakerWorkforceWorkforceVpcConfigOutputReference_Override(s SagemakerWorkforceWorkforceVpcConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerWorkforce_Override ¶
func NewSagemakerWorkforce_Override(s SagemakerWorkforce, scope constructs.Construct, id *string, config *SagemakerWorkforceConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce aws_sagemaker_workforce} Resource.
func SagemakerWorkforce_IsConstruct ¶
func SagemakerWorkforce_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SagemakerWorkforce_IsTerraformElement ¶
func SagemakerWorkforce_IsTerraformElement(x interface{}) *bool
Experimental.
func SagemakerWorkforce_IsTerraformResource ¶
func SagemakerWorkforce_IsTerraformResource(x interface{}) *bool
Experimental.
func SagemakerWorkforce_TfResourceType ¶
func SagemakerWorkforce_TfResourceType() *string
Types ¶
type SagemakerWorkforce ¶
type SagemakerWorkforce interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CognitoConfig() SagemakerWorkforceCognitoConfigOutputReference
CognitoConfigInput() *SagemakerWorkforceCognitoConfig
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
OidcConfig() SagemakerWorkforceOidcConfigOutputReference
OidcConfigInput() *SagemakerWorkforceOidcConfig
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SourceIpConfig() SagemakerWorkforceSourceIpConfigOutputReference
SourceIpConfigInput() *SagemakerWorkforceSourceIpConfig
Subdomain() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
WorkforceName() *string
SetWorkforceName(val *string)
WorkforceNameInput() *string
WorkforceVpcConfig() SagemakerWorkforceWorkforceVpcConfigOutputReference
WorkforceVpcConfigInput() *SagemakerWorkforceWorkforceVpcConfig
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCognitoConfig(value *SagemakerWorkforceCognitoConfig)
PutOidcConfig(value *SagemakerWorkforceOidcConfig)
PutSourceIpConfig(value *SagemakerWorkforceSourceIpConfig)
PutWorkforceVpcConfig(value *SagemakerWorkforceWorkforceVpcConfig)
ResetCognitoConfig()
ResetId()
ResetOidcConfig()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSourceIpConfig()
ResetWorkforceVpcConfig()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce aws_sagemaker_workforce}.
func NewSagemakerWorkforce ¶
func NewSagemakerWorkforce(scope constructs.Construct, id *string, config *SagemakerWorkforceConfig) SagemakerWorkforce
Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce aws_sagemaker_workforce} Resource.
type SagemakerWorkforceCognitoConfig ¶
type SagemakerWorkforceCognitoConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#client_id SagemakerWorkforce#client_id}.
ClientId *string `field:"required" json:"clientId" yaml:"clientId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#user_pool SagemakerWorkforce#user_pool}.
UserPool *string `field:"required" json:"userPool" yaml:"userPool"`
}
type SagemakerWorkforceCognitoConfigOutputReference ¶
type SagemakerWorkforceCognitoConfigOutputReference interface {
cdktf.ComplexObject
ClientId() *string
SetClientId(val *string)
ClientIdInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SagemakerWorkforceCognitoConfig
SetInternalValue(val *SagemakerWorkforceCognitoConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UserPool() *string
SetUserPool(val *string)
UserPoolInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerWorkforceCognitoConfigOutputReference ¶
func NewSagemakerWorkforceCognitoConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerWorkforceCognitoConfigOutputReference
type SagemakerWorkforceConfig ¶
type SagemakerWorkforceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#workforce_name SagemakerWorkforce#workforce_name}.
WorkforceName *string `field:"required" json:"workforceName" yaml:"workforceName"`
// cognito_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#cognito_config SagemakerWorkforce#cognito_config}
CognitoConfig *SagemakerWorkforceCognitoConfig `field:"optional" json:"cognitoConfig" yaml:"cognitoConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#id SagemakerWorkforce#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// oidc_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#oidc_config SagemakerWorkforce#oidc_config}
OidcConfig *SagemakerWorkforceOidcConfig `field:"optional" json:"oidcConfig" yaml:"oidcConfig"`
// source_ip_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#source_ip_config SagemakerWorkforce#source_ip_config}
SourceIpConfig *SagemakerWorkforceSourceIpConfig `field:"optional" json:"sourceIpConfig" yaml:"sourceIpConfig"`
// workforce_vpc_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#workforce_vpc_config SagemakerWorkforce#workforce_vpc_config}
WorkforceVpcConfig *SagemakerWorkforceWorkforceVpcConfig `field:"optional" json:"workforceVpcConfig" yaml:"workforceVpcConfig"`
}
type SagemakerWorkforceOidcConfig ¶
type SagemakerWorkforceOidcConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#authorization_endpoint SagemakerWorkforce#authorization_endpoint}.
AuthorizationEndpoint *string `field:"required" json:"authorizationEndpoint" yaml:"authorizationEndpoint"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#client_id SagemakerWorkforce#client_id}.
ClientId *string `field:"required" json:"clientId" yaml:"clientId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#client_secret SagemakerWorkforce#client_secret}.
ClientSecret *string `field:"required" json:"clientSecret" yaml:"clientSecret"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#issuer SagemakerWorkforce#issuer}.
Issuer *string `field:"required" json:"issuer" yaml:"issuer"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#jwks_uri SagemakerWorkforce#jwks_uri}.
JwksUri *string `field:"required" json:"jwksUri" yaml:"jwksUri"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#logout_endpoint SagemakerWorkforce#logout_endpoint}.
LogoutEndpoint *string `field:"required" json:"logoutEndpoint" yaml:"logoutEndpoint"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#token_endpoint SagemakerWorkforce#token_endpoint}.
TokenEndpoint *string `field:"required" json:"tokenEndpoint" yaml:"tokenEndpoint"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#user_info_endpoint SagemakerWorkforce#user_info_endpoint}.
UserInfoEndpoint *string `field:"required" json:"userInfoEndpoint" yaml:"userInfoEndpoint"`
}
type SagemakerWorkforceOidcConfigOutputReference ¶
type SagemakerWorkforceOidcConfigOutputReference interface {
cdktf.ComplexObject
AuthorizationEndpoint() *string
SetAuthorizationEndpoint(val *string)
AuthorizationEndpointInput() *string
ClientId() *string
SetClientId(val *string)
ClientIdInput() *string
ClientSecret() *string
SetClientSecret(val *string)
ClientSecretInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SagemakerWorkforceOidcConfig
SetInternalValue(val *SagemakerWorkforceOidcConfig)
Issuer() *string
SetIssuer(val *string)
IssuerInput() *string
JwksUri() *string
SetJwksUri(val *string)
JwksUriInput() *string
LogoutEndpoint() *string
SetLogoutEndpoint(val *string)
LogoutEndpointInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TokenEndpoint() *string
SetTokenEndpoint(val *string)
TokenEndpointInput() *string
UserInfoEndpoint() *string
SetUserInfoEndpoint(val *string)
UserInfoEndpointInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerWorkforceOidcConfigOutputReference ¶
func NewSagemakerWorkforceOidcConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerWorkforceOidcConfigOutputReference
type SagemakerWorkforceSourceIpConfig ¶
type SagemakerWorkforceSourceIpConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#cidrs SagemakerWorkforce#cidrs}.
Cidrs *[]*string `field:"required" json:"cidrs" yaml:"cidrs"`
}
type SagemakerWorkforceSourceIpConfigOutputReference ¶
type SagemakerWorkforceSourceIpConfigOutputReference interface {
cdktf.ComplexObject
Cidrs() *[]*string
SetCidrs(val *[]*string)
CidrsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SagemakerWorkforceSourceIpConfig
SetInternalValue(val *SagemakerWorkforceSourceIpConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerWorkforceSourceIpConfigOutputReference ¶
func NewSagemakerWorkforceSourceIpConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerWorkforceSourceIpConfigOutputReference
type SagemakerWorkforceWorkforceVpcConfig ¶
type SagemakerWorkforceWorkforceVpcConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#security_group_ids SagemakerWorkforce#security_group_ids}.
SecurityGroupIds *[]*string `field:"optional" json:"securityGroupIds" yaml:"securityGroupIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#subnets SagemakerWorkforce#subnets}.
Subnets *[]*string `field:"optional" json:"subnets" yaml:"subnets"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce#vpc_id SagemakerWorkforce#vpc_id}.
VpcId *string `field:"optional" json:"vpcId" yaml:"vpcId"`
}
type SagemakerWorkforceWorkforceVpcConfigOutputReference ¶
type SagemakerWorkforceWorkforceVpcConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SagemakerWorkforceWorkforceVpcConfig
SetInternalValue(val *SagemakerWorkforceWorkforceVpcConfig)
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
Subnets() *[]*string
SetSubnets(val *[]*string)
SubnetsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VpcEndpointId() *string
VpcId() *string
SetVpcId(val *string)
VpcIdInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetSecurityGroupIds()
ResetSubnets()
ResetVpcId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerWorkforceWorkforceVpcConfigOutputReference ¶
func NewSagemakerWorkforceWorkforceVpcConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerWorkforceWorkforceVpcConfigOutputReference
Source Files
¶
- SagemakerWorkforce.go
- SagemakerWorkforceCognitoConfig.go
- SagemakerWorkforceCognitoConfigOutputReference.go
- SagemakerWorkforceCognitoConfigOutputReference__checks.go
- SagemakerWorkforceConfig.go
- SagemakerWorkforceOidcConfig.go
- SagemakerWorkforceOidcConfigOutputReference.go
- SagemakerWorkforceOidcConfigOutputReference__checks.go
- SagemakerWorkforceSourceIpConfig.go
- SagemakerWorkforceSourceIpConfigOutputReference.go
- SagemakerWorkforceSourceIpConfigOutputReference__checks.go
- SagemakerWorkforceWorkforceVpcConfig.go
- SagemakerWorkforceWorkforceVpcConfigOutputReference.go
- SagemakerWorkforceWorkforceVpcConfigOutputReference__checks.go
- SagemakerWorkforce__checks.go
- main.go