Documentation
¶
Index ¶
- func NewServicecatalogPortfolioShareTimeoutsOutputReference_Override(s ServicecatalogPortfolioShareTimeoutsOutputReference, ...)
- func NewServicecatalogPortfolioShare_Override(s ServicecatalogPortfolioShare, scope constructs.Construct, id *string, ...)
- func ServicecatalogPortfolioShare_IsConstruct(x interface{}) *bool
- func ServicecatalogPortfolioShare_IsTerraformElement(x interface{}) *bool
- func ServicecatalogPortfolioShare_IsTerraformResource(x interface{}) *bool
- func ServicecatalogPortfolioShare_TfResourceType() *string
- type ServicecatalogPortfolioShare
- type ServicecatalogPortfolioShareConfig
- type ServicecatalogPortfolioShareTimeouts
- type ServicecatalogPortfolioShareTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewServicecatalogPortfolioShareTimeoutsOutputReference_Override ¶
func NewServicecatalogPortfolioShareTimeoutsOutputReference_Override(s ServicecatalogPortfolioShareTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewServicecatalogPortfolioShare_Override ¶
func NewServicecatalogPortfolioShare_Override(s ServicecatalogPortfolioShare, scope constructs.Construct, id *string, config *ServicecatalogPortfolioShareConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/servicecatalog_portfolio_share aws_servicecatalog_portfolio_share} Resource.
func ServicecatalogPortfolioShare_IsConstruct ¶
func ServicecatalogPortfolioShare_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ServicecatalogPortfolioShare_IsTerraformElement ¶
func ServicecatalogPortfolioShare_IsTerraformElement(x interface{}) *bool
Experimental.
func ServicecatalogPortfolioShare_IsTerraformResource ¶
func ServicecatalogPortfolioShare_IsTerraformResource(x interface{}) *bool
Experimental.
func ServicecatalogPortfolioShare_TfResourceType ¶
func ServicecatalogPortfolioShare_TfResourceType() *string
Types ¶
type ServicecatalogPortfolioShare ¶
type ServicecatalogPortfolioShare interface {
cdktf.TerraformResource
CdktfStack() cdktf.TerraformStack
Connection() interface{}
SetConnection(val interface{})
ConstructNodeMetadata() *map[string]interface{}
Count() *float64
SetCount(val *float64)
DependsOn() *[]*string
SetDependsOn(val *[]*string)
ForEach() cdktf.ITerraformIterator
SetForEach(val cdktf.ITerraformIterator)
Fqn() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Provider() cdktf.TerraformProvider
SetProvider(val cdktf.TerraformProvider)
Provisioners() *[]interface{}
SetProvisioners(val *[]interface{})
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformMetaArguments() *map[string]interface{}
// Experimental.
AddOverride(path *string, value interface{})
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ToMetadata() interface{}
ToString() *string
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/servicecatalog_portfolio_share aws_servicecatalog_portfolio_share}.
func NewServicecatalogPortfolioShare ¶
func NewServicecatalogPortfolioShare(scope constructs.Construct, id *string, config *ServicecatalogPortfolioShareConfig) ServicecatalogPortfolioShare
Create a new {@link https://www.terraform.io/docs/providers/aws/r/servicecatalog_portfolio_share aws_servicecatalog_portfolio_share} Resource.
type ServicecatalogPortfolioShareConfig ¶
type ServicecatalogPortfolioShareConfig struct {
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
Count *float64 `field:"optional" json:"count" yaml:"count"`
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
PortfolioId *string `field:"required" json:"portfolioId" yaml:"portfolioId"`
PrincipalId *string `field:"required" json:"principalId" yaml:"principalId"`
Type *string `field:"required" json:"type" yaml:"type"`
AcceptLanguage *string `field:"optional" json:"acceptLanguage" yaml:"acceptLanguage"`
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
SharePrincipals interface{} `field:"optional" json:"sharePrincipals" yaml:"sharePrincipals"`
ShareTagOptions interface{} `field:"optional" json:"shareTagOptions" yaml:"shareTagOptions"`
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/servicecatalog_portfolio_share#timeouts ServicecatalogPortfolioShare#timeouts}
Timeouts *ServicecatalogPortfolioShareTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
WaitForAcceptance interface{} `field:"optional" json:"waitForAcceptance" yaml:"waitForAcceptance"`
}
type ServicecatalogPortfolioShareTimeoutsOutputReference ¶
type ServicecatalogPortfolioShareTimeoutsOutputReference interface {
cdktf.ComplexObject
// Experimental.
ComplexObjectIndex() interface{}
SetComplexObjectIndex(val interface{})
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
// Experimental.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
ComputeFqn() *string
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationAsList() cdktf.IResolvable
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewServicecatalogPortfolioShareTimeoutsOutputReference ¶
func NewServicecatalogPortfolioShareTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ServicecatalogPortfolioShareTimeoutsOutputReference