Documentation
¶
Index ¶
- func NewSesConfigurationSetDeliveryOptionsOutputReference_Override(s SesConfigurationSetDeliveryOptionsOutputReference, ...)
- func NewSesConfigurationSetTrackingOptionsOutputReference_Override(s SesConfigurationSetTrackingOptionsOutputReference, ...)
- func NewSesConfigurationSet_Override(s SesConfigurationSet, scope constructs.Construct, id *string, ...)
- func SesConfigurationSet_IsConstruct(x interface{}) *bool
- func SesConfigurationSet_IsTerraformElement(x interface{}) *bool
- func SesConfigurationSet_IsTerraformResource(x interface{}) *bool
- func SesConfigurationSet_TfResourceType() *string
- type SesConfigurationSet
- type SesConfigurationSetConfig
- type SesConfigurationSetDeliveryOptions
- type SesConfigurationSetDeliveryOptionsOutputReference
- type SesConfigurationSetTrackingOptions
- type SesConfigurationSetTrackingOptionsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSesConfigurationSetDeliveryOptionsOutputReference_Override ¶
func NewSesConfigurationSetDeliveryOptionsOutputReference_Override(s SesConfigurationSetDeliveryOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSesConfigurationSetTrackingOptionsOutputReference_Override ¶
func NewSesConfigurationSetTrackingOptionsOutputReference_Override(s SesConfigurationSetTrackingOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSesConfigurationSet_Override ¶
func NewSesConfigurationSet_Override(s SesConfigurationSet, scope constructs.Construct, id *string, config *SesConfigurationSetConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set aws_ses_configuration_set} Resource.
func SesConfigurationSet_IsConstruct ¶
func SesConfigurationSet_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SesConfigurationSet_IsTerraformElement ¶
func SesConfigurationSet_IsTerraformElement(x interface{}) *bool
Experimental.
func SesConfigurationSet_IsTerraformResource ¶
func SesConfigurationSet_IsTerraformResource(x interface{}) *bool
Experimental.
func SesConfigurationSet_TfResourceType ¶
func SesConfigurationSet_TfResourceType() *string
Types ¶
type SesConfigurationSet ¶
type SesConfigurationSet interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DeliveryOptions() SesConfigurationSetDeliveryOptionsOutputReference
DeliveryOptionsInput() *SesConfigurationSetDeliveryOptions
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
LastFreshStart() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ReputationMetricsEnabled() interface{}
SetReputationMetricsEnabled(val interface{})
ReputationMetricsEnabledInput() interface{}
SendingEnabled() interface{}
SetSendingEnabled(val interface{})
SendingEnabledInput() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
TrackingOptions() SesConfigurationSetTrackingOptionsOutputReference
TrackingOptionsInput() *SesConfigurationSetTrackingOptions
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDeliveryOptions(value *SesConfigurationSetDeliveryOptions)
PutTrackingOptions(value *SesConfigurationSetTrackingOptions)
ResetDeliveryOptions()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetReputationMetricsEnabled()
ResetSendingEnabled()
ResetTrackingOptions()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set aws_ses_configuration_set}.
func NewSesConfigurationSet ¶
func NewSesConfigurationSet(scope constructs.Construct, id *string, config *SesConfigurationSetConfig) SesConfigurationSet
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set aws_ses_configuration_set} Resource.
type SesConfigurationSetConfig ¶
type SesConfigurationSetConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set#name SesConfigurationSet#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// delivery_options block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set#delivery_options SesConfigurationSet#delivery_options}
DeliveryOptions *SesConfigurationSetDeliveryOptions `field:"optional" json:"deliveryOptions" yaml:"deliveryOptions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set#id SesConfigurationSet#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set#reputation_metrics_enabled SesConfigurationSet#reputation_metrics_enabled}.
ReputationMetricsEnabled interface{} `field:"optional" json:"reputationMetricsEnabled" yaml:"reputationMetricsEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set#sending_enabled SesConfigurationSet#sending_enabled}.
SendingEnabled interface{} `field:"optional" json:"sendingEnabled" yaml:"sendingEnabled"`
// tracking_options block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set#tracking_options SesConfigurationSet#tracking_options}
TrackingOptions *SesConfigurationSetTrackingOptions `field:"optional" json:"trackingOptions" yaml:"trackingOptions"`
}
type SesConfigurationSetDeliveryOptions ¶
type SesConfigurationSetDeliveryOptions struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set#tls_policy SesConfigurationSet#tls_policy}.
TlsPolicy *string `field:"optional" json:"tlsPolicy" yaml:"tlsPolicy"`
}
type SesConfigurationSetDeliveryOptionsOutputReference ¶
type SesConfigurationSetDeliveryOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SesConfigurationSetDeliveryOptions
SetInternalValue(val *SesConfigurationSetDeliveryOptions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TlsPolicy() *string
SetTlsPolicy(val *string)
TlsPolicyInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetTlsPolicy()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesConfigurationSetDeliveryOptionsOutputReference ¶
func NewSesConfigurationSetDeliveryOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SesConfigurationSetDeliveryOptionsOutputReference
type SesConfigurationSetTrackingOptions ¶
type SesConfigurationSetTrackingOptions struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set#custom_redirect_domain SesConfigurationSet#custom_redirect_domain}.
CustomRedirectDomain *string `field:"optional" json:"customRedirectDomain" yaml:"customRedirectDomain"`
}
type SesConfigurationSetTrackingOptionsOutputReference ¶
type SesConfigurationSetTrackingOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
CustomRedirectDomain() *string
SetCustomRedirectDomain(val *string)
CustomRedirectDomainInput() *string
// Experimental.
Fqn() *string
InternalValue() *SesConfigurationSetTrackingOptions
SetInternalValue(val *SesConfigurationSetTrackingOptions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCustomRedirectDomain()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesConfigurationSetTrackingOptionsOutputReference ¶
func NewSesConfigurationSetTrackingOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SesConfigurationSetTrackingOptionsOutputReference
Source Files
¶
- SesConfigurationSet.go
- SesConfigurationSetConfig.go
- SesConfigurationSetDeliveryOptions.go
- SesConfigurationSetDeliveryOptionsOutputReference.go
- SesConfigurationSetDeliveryOptionsOutputReference__checks.go
- SesConfigurationSetTrackingOptions.go
- SesConfigurationSetTrackingOptionsOutputReference.go
- SesConfigurationSetTrackingOptionsOutputReference__checks.go
- SesConfigurationSet__checks.go
- main.go