Documentation
¶
Index ¶
- func NewSesEventDestinationCloudwatchDestinationList_Override(s SesEventDestinationCloudwatchDestinationList, ...)
- func NewSesEventDestinationCloudwatchDestinationOutputReference_Override(s SesEventDestinationCloudwatchDestinationOutputReference, ...)
- func NewSesEventDestinationKinesisDestinationOutputReference_Override(s SesEventDestinationKinesisDestinationOutputReference, ...)
- func NewSesEventDestinationSnsDestinationOutputReference_Override(s SesEventDestinationSnsDestinationOutputReference, ...)
- func NewSesEventDestination_Override(s SesEventDestination, scope constructs.Construct, id *string, ...)
- func SesEventDestination_IsConstruct(x interface{}) *bool
- func SesEventDestination_IsTerraformElement(x interface{}) *bool
- func SesEventDestination_IsTerraformResource(x interface{}) *bool
- func SesEventDestination_TfResourceType() *string
- type SesEventDestination
- type SesEventDestinationCloudwatchDestination
- type SesEventDestinationCloudwatchDestinationList
- type SesEventDestinationCloudwatchDestinationOutputReference
- type SesEventDestinationConfig
- type SesEventDestinationKinesisDestination
- type SesEventDestinationKinesisDestinationOutputReference
- type SesEventDestinationSnsDestination
- type SesEventDestinationSnsDestinationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSesEventDestinationCloudwatchDestinationList_Override ¶
func NewSesEventDestinationCloudwatchDestinationList_Override(s SesEventDestinationCloudwatchDestinationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSesEventDestinationCloudwatchDestinationOutputReference_Override ¶
func NewSesEventDestinationCloudwatchDestinationOutputReference_Override(s SesEventDestinationCloudwatchDestinationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSesEventDestinationKinesisDestinationOutputReference_Override ¶
func NewSesEventDestinationKinesisDestinationOutputReference_Override(s SesEventDestinationKinesisDestinationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSesEventDestinationSnsDestinationOutputReference_Override ¶
func NewSesEventDestinationSnsDestinationOutputReference_Override(s SesEventDestinationSnsDestinationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSesEventDestination_Override ¶
func NewSesEventDestination_Override(s SesEventDestination, scope constructs.Construct, id *string, config *SesEventDestinationConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination aws_ses_event_destination} Resource.
func SesEventDestination_IsConstruct ¶
func SesEventDestination_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SesEventDestination_IsTerraformElement ¶
func SesEventDestination_IsTerraformElement(x interface{}) *bool
Experimental.
func SesEventDestination_IsTerraformResource ¶
func SesEventDestination_IsTerraformResource(x interface{}) *bool
Experimental.
func SesEventDestination_TfResourceType ¶
func SesEventDestination_TfResourceType() *string
Types ¶
type SesEventDestination ¶
type SesEventDestination interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CloudwatchDestination() SesEventDestinationCloudwatchDestinationList
CloudwatchDestinationInput() interface{}
ConfigurationSetName() *string
SetConfigurationSetName(val *string)
ConfigurationSetNameInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
KinesisDestination() SesEventDestinationKinesisDestinationOutputReference
KinesisDestinationInput() *SesEventDestinationKinesisDestination
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MatchingTypes() *[]*string
SetMatchingTypes(val *[]*string)
MatchingTypesInput() *[]*string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SnsDestination() SesEventDestinationSnsDestinationOutputReference
SnsDestinationInput() *SesEventDestinationSnsDestination
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCloudwatchDestination(value interface{})
PutKinesisDestination(value *SesEventDestinationKinesisDestination)
PutSnsDestination(value *SesEventDestinationSnsDestination)
ResetCloudwatchDestination()
ResetEnabled()
ResetId()
ResetKinesisDestination()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSnsDestination()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination aws_ses_event_destination}.
func NewSesEventDestination ¶
func NewSesEventDestination(scope constructs.Construct, id *string, config *SesEventDestinationConfig) SesEventDestination
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination aws_ses_event_destination} Resource.
type SesEventDestinationCloudwatchDestination ¶
type SesEventDestinationCloudwatchDestination struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#default_value SesEventDestination#default_value}.
DefaultValue *string `field:"required" json:"defaultValue" yaml:"defaultValue"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#dimension_name SesEventDestination#dimension_name}.
DimensionName *string `field:"required" json:"dimensionName" yaml:"dimensionName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#value_source SesEventDestination#value_source}.
ValueSource *string `field:"required" json:"valueSource" yaml:"valueSource"`
}
type SesEventDestinationCloudwatchDestinationList ¶
type SesEventDestinationCloudwatchDestinationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SesEventDestinationCloudwatchDestinationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesEventDestinationCloudwatchDestinationList ¶
func NewSesEventDestinationCloudwatchDestinationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SesEventDestinationCloudwatchDestinationList
type SesEventDestinationCloudwatchDestinationOutputReference ¶
type SesEventDestinationCloudwatchDestinationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DefaultValue() *string
SetDefaultValue(val *string)
DefaultValueInput() *string
DimensionName() *string
SetDimensionName(val *string)
DimensionNameInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ValueSource() *string
SetValueSource(val *string)
ValueSourceInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesEventDestinationCloudwatchDestinationOutputReference ¶
func NewSesEventDestinationCloudwatchDestinationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SesEventDestinationCloudwatchDestinationOutputReference
type SesEventDestinationConfig ¶
type SesEventDestinationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#configuration_set_name SesEventDestination#configuration_set_name}.
ConfigurationSetName *string `field:"required" json:"configurationSetName" yaml:"configurationSetName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#matching_types SesEventDestination#matching_types}.
MatchingTypes *[]*string `field:"required" json:"matchingTypes" yaml:"matchingTypes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#name SesEventDestination#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// cloudwatch_destination block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#cloudwatch_destination SesEventDestination#cloudwatch_destination}
CloudwatchDestination interface{} `field:"optional" json:"cloudwatchDestination" yaml:"cloudwatchDestination"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#enabled SesEventDestination#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#id SesEventDestination#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// kinesis_destination block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#kinesis_destination SesEventDestination#kinesis_destination}
KinesisDestination *SesEventDestinationKinesisDestination `field:"optional" json:"kinesisDestination" yaml:"kinesisDestination"`
// sns_destination block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#sns_destination SesEventDestination#sns_destination}
SnsDestination *SesEventDestinationSnsDestination `field:"optional" json:"snsDestination" yaml:"snsDestination"`
}
type SesEventDestinationKinesisDestination ¶
type SesEventDestinationKinesisDestination struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#role_arn SesEventDestination#role_arn}.
RoleArn *string `field:"required" json:"roleArn" yaml:"roleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#stream_arn SesEventDestination#stream_arn}.
StreamArn *string `field:"required" json:"streamArn" yaml:"streamArn"`
}
type SesEventDestinationKinesisDestinationOutputReference ¶
type SesEventDestinationKinesisDestinationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SesEventDestinationKinesisDestination
SetInternalValue(val *SesEventDestinationKinesisDestination)
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
StreamArn() *string
SetStreamArn(val *string)
StreamArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesEventDestinationKinesisDestinationOutputReference ¶
func NewSesEventDestinationKinesisDestinationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SesEventDestinationKinesisDestinationOutputReference
type SesEventDestinationSnsDestination ¶
type SesEventDestinationSnsDestination struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#topic_arn SesEventDestination#topic_arn}.
TopicArn *string `field:"required" json:"topicArn" yaml:"topicArn"`
}
type SesEventDestinationSnsDestinationOutputReference ¶
type SesEventDestinationSnsDestinationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SesEventDestinationSnsDestination
SetInternalValue(val *SesEventDestinationSnsDestination)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TopicArn() *string
SetTopicArn(val *string)
TopicArnInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesEventDestinationSnsDestinationOutputReference ¶
func NewSesEventDestinationSnsDestinationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SesEventDestinationSnsDestinationOutputReference
Source Files
¶
- SesEventDestination.go
- SesEventDestinationCloudwatchDestination.go
- SesEventDestinationCloudwatchDestinationList.go
- SesEventDestinationCloudwatchDestinationList__checks.go
- SesEventDestinationCloudwatchDestinationOutputReference.go
- SesEventDestinationCloudwatchDestinationOutputReference__checks.go
- SesEventDestinationConfig.go
- SesEventDestinationKinesisDestination.go
- SesEventDestinationKinesisDestinationOutputReference.go
- SesEventDestinationKinesisDestinationOutputReference__checks.go
- SesEventDestinationSnsDestination.go
- SesEventDestinationSnsDestinationOutputReference.go
- SesEventDestinationSnsDestinationOutputReference__checks.go
- SesEventDestination__checks.go
- main.go