Documentation
¶
Index ¶
- func NewSnsPlatformApplication_Override(s SnsPlatformApplication, scope constructs.Construct, id *string, ...)
- func SnsPlatformApplication_IsConstruct(x interface{}) *bool
- func SnsPlatformApplication_IsTerraformElement(x interface{}) *bool
- func SnsPlatformApplication_IsTerraformResource(x interface{}) *bool
- func SnsPlatformApplication_TfResourceType() *string
- type SnsPlatformApplication
- type SnsPlatformApplicationConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSnsPlatformApplication_Override ¶
func NewSnsPlatformApplication_Override(s SnsPlatformApplication, scope constructs.Construct, id *string, config *SnsPlatformApplicationConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/sns_platform_application aws_sns_platform_application} Resource.
func SnsPlatformApplication_IsConstruct ¶
func SnsPlatformApplication_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SnsPlatformApplication_IsTerraformElement ¶
func SnsPlatformApplication_IsTerraformElement(x interface{}) *bool
Experimental.
func SnsPlatformApplication_IsTerraformResource ¶
func SnsPlatformApplication_IsTerraformResource(x interface{}) *bool
Experimental.
func SnsPlatformApplication_TfResourceType ¶
func SnsPlatformApplication_TfResourceType() *string
Types ¶
type SnsPlatformApplication ¶
type SnsPlatformApplication interface {
cdktf.TerraformResource
ApplePlatformBundleId() *string
SetApplePlatformBundleId(val *string)
ApplePlatformBundleIdInput() *string
ApplePlatformTeamId() *string
SetApplePlatformTeamId(val *string)
ApplePlatformTeamIdInput() *string
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EventDeliveryFailureTopicArn() *string
SetEventDeliveryFailureTopicArn(val *string)
EventDeliveryFailureTopicArnInput() *string
EventEndpointCreatedTopicArn() *string
SetEventEndpointCreatedTopicArn(val *string)
EventEndpointCreatedTopicArnInput() *string
EventEndpointDeletedTopicArn() *string
SetEventEndpointDeletedTopicArn(val *string)
EventEndpointDeletedTopicArnInput() *string
EventEndpointUpdatedTopicArn() *string
SetEventEndpointUpdatedTopicArn(val *string)
EventEndpointUpdatedTopicArnInput() *string
FailureFeedbackRoleArn() *string
SetFailureFeedbackRoleArn(val *string)
FailureFeedbackRoleArnInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Platform() *string
SetPlatform(val *string)
PlatformCredential() *string
SetPlatformCredential(val *string)
PlatformCredentialInput() *string
PlatformInput() *string
PlatformPrincipal() *string
SetPlatformPrincipal(val *string)
PlatformPrincipalInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SuccessFeedbackRoleArn() *string
SetSuccessFeedbackRoleArn(val *string)
SuccessFeedbackRoleArnInput() *string
SuccessFeedbackSampleRate() *string
SetSuccessFeedbackSampleRate(val *string)
SuccessFeedbackSampleRateInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetApplePlatformBundleId()
ResetApplePlatformTeamId()
ResetEventDeliveryFailureTopicArn()
ResetEventEndpointCreatedTopicArn()
ResetEventEndpointDeletedTopicArn()
ResetEventEndpointUpdatedTopicArn()
ResetFailureFeedbackRoleArn()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPlatformPrincipal()
ResetSuccessFeedbackRoleArn()
ResetSuccessFeedbackSampleRate()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/sns_platform_application aws_sns_platform_application}.
func NewSnsPlatformApplication ¶
func NewSnsPlatformApplication(scope constructs.Construct, id *string, config *SnsPlatformApplicationConfig) SnsPlatformApplication
Create a new {@link https://www.terraform.io/docs/providers/aws/r/sns_platform_application aws_sns_platform_application} Resource.
type SnsPlatformApplicationConfig ¶
type SnsPlatformApplicationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_platform_application#name SnsPlatformApplication#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_platform_application#platform SnsPlatformApplication#platform}.
Platform *string `field:"required" json:"platform" yaml:"platform"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_platform_application#platform_credential SnsPlatformApplication#platform_credential}.
PlatformCredential *string `field:"required" json:"platformCredential" yaml:"platformCredential"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_platform_application#apple_platform_bundle_id SnsPlatformApplication#apple_platform_bundle_id}.
ApplePlatformBundleId *string `field:"optional" json:"applePlatformBundleId" yaml:"applePlatformBundleId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_platform_application#apple_platform_team_id SnsPlatformApplication#apple_platform_team_id}.
ApplePlatformTeamId *string `field:"optional" json:"applePlatformTeamId" yaml:"applePlatformTeamId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_platform_application#event_delivery_failure_topic_arn SnsPlatformApplication#event_delivery_failure_topic_arn}.
EventDeliveryFailureTopicArn *string `field:"optional" json:"eventDeliveryFailureTopicArn" yaml:"eventDeliveryFailureTopicArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_platform_application#event_endpoint_created_topic_arn SnsPlatformApplication#event_endpoint_created_topic_arn}.
EventEndpointCreatedTopicArn *string `field:"optional" json:"eventEndpointCreatedTopicArn" yaml:"eventEndpointCreatedTopicArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_platform_application#event_endpoint_deleted_topic_arn SnsPlatformApplication#event_endpoint_deleted_topic_arn}.
EventEndpointDeletedTopicArn *string `field:"optional" json:"eventEndpointDeletedTopicArn" yaml:"eventEndpointDeletedTopicArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_platform_application#event_endpoint_updated_topic_arn SnsPlatformApplication#event_endpoint_updated_topic_arn}.
EventEndpointUpdatedTopicArn *string `field:"optional" json:"eventEndpointUpdatedTopicArn" yaml:"eventEndpointUpdatedTopicArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_platform_application#failure_feedback_role_arn SnsPlatformApplication#failure_feedback_role_arn}.
FailureFeedbackRoleArn *string `field:"optional" json:"failureFeedbackRoleArn" yaml:"failureFeedbackRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_platform_application#id SnsPlatformApplication#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_platform_application#platform_principal SnsPlatformApplication#platform_principal}.
PlatformPrincipal *string `field:"optional" json:"platformPrincipal" yaml:"platformPrincipal"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_platform_application#success_feedback_role_arn SnsPlatformApplication#success_feedback_role_arn}.
SuccessFeedbackRoleArn *string `field:"optional" json:"successFeedbackRoleArn" yaml:"successFeedbackRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_platform_application#success_feedback_sample_rate SnsPlatformApplication#success_feedback_sample_rate}.
SuccessFeedbackSampleRate *string `field:"optional" json:"successFeedbackSampleRate" yaml:"successFeedbackSampleRate"`
}