Documentation
¶
Index ¶
- func NewSnsTopic_Override(s SnsTopic, scope constructs.Construct, id *string, config *SnsTopicConfig)
- func SnsTopic_IsConstruct(x interface{}) *bool
- func SnsTopic_IsTerraformElement(x interface{}) *bool
- func SnsTopic_IsTerraformResource(x interface{}) *bool
- func SnsTopic_TfResourceType() *string
- type SnsTopic
- type SnsTopicConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSnsTopic_Override ¶
func NewSnsTopic_Override(s SnsTopic, scope constructs.Construct, id *string, config *SnsTopicConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/sns_topic aws_sns_topic} Resource.
func SnsTopic_IsConstruct ¶
func SnsTopic_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SnsTopic_IsTerraformElement ¶
func SnsTopic_IsTerraformElement(x interface{}) *bool
Experimental.
func SnsTopic_IsTerraformResource ¶
func SnsTopic_IsTerraformResource(x interface{}) *bool
Experimental.
func SnsTopic_TfResourceType ¶
func SnsTopic_TfResourceType() *string
Types ¶
type SnsTopic ¶
type SnsTopic interface {
cdktf.TerraformResource
ApplicationFailureFeedbackRoleArn() *string
SetApplicationFailureFeedbackRoleArn(val *string)
ApplicationFailureFeedbackRoleArnInput() *string
ApplicationSuccessFeedbackRoleArn() *string
SetApplicationSuccessFeedbackRoleArn(val *string)
ApplicationSuccessFeedbackRoleArnInput() *string
ApplicationSuccessFeedbackSampleRate() *float64
SetApplicationSuccessFeedbackSampleRate(val *float64)
ApplicationSuccessFeedbackSampleRateInput() *float64
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ContentBasedDeduplication() interface{}
SetContentBasedDeduplication(val interface{})
ContentBasedDeduplicationInput() interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DeliveryPolicy() *string
SetDeliveryPolicy(val *string)
DeliveryPolicyInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
FifoTopic() interface{}
SetFifoTopic(val interface{})
FifoTopicInput() interface{}
FirehoseFailureFeedbackRoleArn() *string
SetFirehoseFailureFeedbackRoleArn(val *string)
FirehoseFailureFeedbackRoleArnInput() *string
FirehoseSuccessFeedbackRoleArn() *string
SetFirehoseSuccessFeedbackRoleArn(val *string)
FirehoseSuccessFeedbackRoleArnInput() *string
FirehoseSuccessFeedbackSampleRate() *float64
SetFirehoseSuccessFeedbackSampleRate(val *float64)
FirehoseSuccessFeedbackSampleRateInput() *float64
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HttpFailureFeedbackRoleArn() *string
SetHttpFailureFeedbackRoleArn(val *string)
HttpFailureFeedbackRoleArnInput() *string
HttpSuccessFeedbackRoleArn() *string
SetHttpSuccessFeedbackRoleArn(val *string)
HttpSuccessFeedbackRoleArnInput() *string
HttpSuccessFeedbackSampleRate() *float64
SetHttpSuccessFeedbackSampleRate(val *float64)
HttpSuccessFeedbackSampleRateInput() *float64
Id() *string
SetId(val *string)
IdInput() *string
KmsMasterKeyId() *string
SetKmsMasterKeyId(val *string)
KmsMasterKeyIdInput() *string
LambdaFailureFeedbackRoleArn() *string
SetLambdaFailureFeedbackRoleArn(val *string)
LambdaFailureFeedbackRoleArnInput() *string
LambdaSuccessFeedbackRoleArn() *string
SetLambdaSuccessFeedbackRoleArn(val *string)
LambdaSuccessFeedbackRoleArnInput() *string
LambdaSuccessFeedbackSampleRate() *float64
SetLambdaSuccessFeedbackSampleRate(val *float64)
LambdaSuccessFeedbackSampleRateInput() *float64
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
NamePrefix() *string
SetNamePrefix(val *string)
NamePrefixInput() *string
// The tree node.
Node() constructs.Node
Owner() *string
Policy() *string
SetPolicy(val *string)
PolicyInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SignatureVersion() *float64
SetSignatureVersion(val *float64)
SignatureVersionInput() *float64
SqsFailureFeedbackRoleArn() *string
SetSqsFailureFeedbackRoleArn(val *string)
SqsFailureFeedbackRoleArnInput() *string
SqsSuccessFeedbackRoleArn() *string
SetSqsSuccessFeedbackRoleArn(val *string)
SqsSuccessFeedbackRoleArnInput() *string
SqsSuccessFeedbackSampleRate() *float64
SetSqsSuccessFeedbackSampleRate(val *float64)
SqsSuccessFeedbackSampleRateInput() *float64
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
TracingConfig() *string
SetTracingConfig(val *string)
TracingConfigInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetApplicationFailureFeedbackRoleArn()
ResetApplicationSuccessFeedbackRoleArn()
ResetApplicationSuccessFeedbackSampleRate()
ResetContentBasedDeduplication()
ResetDeliveryPolicy()
ResetDisplayName()
ResetFifoTopic()
ResetFirehoseFailureFeedbackRoleArn()
ResetFirehoseSuccessFeedbackRoleArn()
ResetFirehoseSuccessFeedbackSampleRate()
ResetHttpFailureFeedbackRoleArn()
ResetHttpSuccessFeedbackRoleArn()
ResetHttpSuccessFeedbackSampleRate()
ResetId()
ResetKmsMasterKeyId()
ResetLambdaFailureFeedbackRoleArn()
ResetLambdaSuccessFeedbackRoleArn()
ResetLambdaSuccessFeedbackSampleRate()
ResetName()
ResetNamePrefix()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPolicy()
ResetSignatureVersion()
ResetSqsFailureFeedbackRoleArn()
ResetSqsSuccessFeedbackRoleArn()
ResetSqsSuccessFeedbackSampleRate()
ResetTags()
ResetTagsAll()
ResetTracingConfig()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/sns_topic aws_sns_topic}.
func NewSnsTopic ¶
func NewSnsTopic(scope constructs.Construct, id *string, config *SnsTopicConfig) SnsTopic
Create a new {@link https://www.terraform.io/docs/providers/aws/r/sns_topic aws_sns_topic} Resource.
type SnsTopicConfig ¶
type SnsTopicConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#application_failure_feedback_role_arn SnsTopic#application_failure_feedback_role_arn}.
ApplicationFailureFeedbackRoleArn *string `field:"optional" json:"applicationFailureFeedbackRoleArn" yaml:"applicationFailureFeedbackRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#application_success_feedback_role_arn SnsTopic#application_success_feedback_role_arn}.
ApplicationSuccessFeedbackRoleArn *string `field:"optional" json:"applicationSuccessFeedbackRoleArn" yaml:"applicationSuccessFeedbackRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#application_success_feedback_sample_rate SnsTopic#application_success_feedback_sample_rate}.
ApplicationSuccessFeedbackSampleRate *float64 `field:"optional" json:"applicationSuccessFeedbackSampleRate" yaml:"applicationSuccessFeedbackSampleRate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#content_based_deduplication SnsTopic#content_based_deduplication}.
ContentBasedDeduplication interface{} `field:"optional" json:"contentBasedDeduplication" yaml:"contentBasedDeduplication"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#delivery_policy SnsTopic#delivery_policy}.
DeliveryPolicy *string `field:"optional" json:"deliveryPolicy" yaml:"deliveryPolicy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#display_name SnsTopic#display_name}.
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#fifo_topic SnsTopic#fifo_topic}.
FifoTopic interface{} `field:"optional" json:"fifoTopic" yaml:"fifoTopic"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#firehose_failure_feedback_role_arn SnsTopic#firehose_failure_feedback_role_arn}.
FirehoseFailureFeedbackRoleArn *string `field:"optional" json:"firehoseFailureFeedbackRoleArn" yaml:"firehoseFailureFeedbackRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#firehose_success_feedback_role_arn SnsTopic#firehose_success_feedback_role_arn}.
FirehoseSuccessFeedbackRoleArn *string `field:"optional" json:"firehoseSuccessFeedbackRoleArn" yaml:"firehoseSuccessFeedbackRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#firehose_success_feedback_sample_rate SnsTopic#firehose_success_feedback_sample_rate}.
FirehoseSuccessFeedbackSampleRate *float64 `field:"optional" json:"firehoseSuccessFeedbackSampleRate" yaml:"firehoseSuccessFeedbackSampleRate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#http_failure_feedback_role_arn SnsTopic#http_failure_feedback_role_arn}.
HttpFailureFeedbackRoleArn *string `field:"optional" json:"httpFailureFeedbackRoleArn" yaml:"httpFailureFeedbackRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#http_success_feedback_role_arn SnsTopic#http_success_feedback_role_arn}.
HttpSuccessFeedbackRoleArn *string `field:"optional" json:"httpSuccessFeedbackRoleArn" yaml:"httpSuccessFeedbackRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#http_success_feedback_sample_rate SnsTopic#http_success_feedback_sample_rate}.
HttpSuccessFeedbackSampleRate *float64 `field:"optional" json:"httpSuccessFeedbackSampleRate" yaml:"httpSuccessFeedbackSampleRate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#id SnsTopic#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#kms_master_key_id SnsTopic#kms_master_key_id}.
KmsMasterKeyId *string `field:"optional" json:"kmsMasterKeyId" yaml:"kmsMasterKeyId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#lambda_failure_feedback_role_arn SnsTopic#lambda_failure_feedback_role_arn}.
LambdaFailureFeedbackRoleArn *string `field:"optional" json:"lambdaFailureFeedbackRoleArn" yaml:"lambdaFailureFeedbackRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#lambda_success_feedback_role_arn SnsTopic#lambda_success_feedback_role_arn}.
LambdaSuccessFeedbackRoleArn *string `field:"optional" json:"lambdaSuccessFeedbackRoleArn" yaml:"lambdaSuccessFeedbackRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#lambda_success_feedback_sample_rate SnsTopic#lambda_success_feedback_sample_rate}.
LambdaSuccessFeedbackSampleRate *float64 `field:"optional" json:"lambdaSuccessFeedbackSampleRate" yaml:"lambdaSuccessFeedbackSampleRate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#name SnsTopic#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#name_prefix SnsTopic#name_prefix}.
NamePrefix *string `field:"optional" json:"namePrefix" yaml:"namePrefix"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#policy SnsTopic#policy}.
Policy *string `field:"optional" json:"policy" yaml:"policy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#signature_version SnsTopic#signature_version}.
SignatureVersion *float64 `field:"optional" json:"signatureVersion" yaml:"signatureVersion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#sqs_failure_feedback_role_arn SnsTopic#sqs_failure_feedback_role_arn}.
SqsFailureFeedbackRoleArn *string `field:"optional" json:"sqsFailureFeedbackRoleArn" yaml:"sqsFailureFeedbackRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#sqs_success_feedback_role_arn SnsTopic#sqs_success_feedback_role_arn}.
SqsSuccessFeedbackRoleArn *string `field:"optional" json:"sqsSuccessFeedbackRoleArn" yaml:"sqsSuccessFeedbackRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#sqs_success_feedback_sample_rate SnsTopic#sqs_success_feedback_sample_rate}.
SqsSuccessFeedbackSampleRate *float64 `field:"optional" json:"sqsSuccessFeedbackSampleRate" yaml:"sqsSuccessFeedbackSampleRate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#tags SnsTopic#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#tags_all SnsTopic#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sns_topic#tracing_config SnsTopic#tracing_config}.
TracingConfig *string `field:"optional" json:"tracingConfig" yaml:"tracingConfig"`
}