Documentation
¶
Index ¶
- func NewSyntheticsCanaryArtifactConfigOutputReference_Override(s SyntheticsCanaryArtifactConfigOutputReference, ...)
- func NewSyntheticsCanaryArtifactConfigS3EncryptionOutputReference_Override(s SyntheticsCanaryArtifactConfigS3EncryptionOutputReference, ...)
- func NewSyntheticsCanaryRunConfigOutputReference_Override(s SyntheticsCanaryRunConfigOutputReference, ...)
- func NewSyntheticsCanaryScheduleOutputReference_Override(s SyntheticsCanaryScheduleOutputReference, ...)
- func NewSyntheticsCanaryTimelineList_Override(s SyntheticsCanaryTimelineList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewSyntheticsCanaryTimelineOutputReference_Override(s SyntheticsCanaryTimelineOutputReference, ...)
- func NewSyntheticsCanaryVpcConfigOutputReference_Override(s SyntheticsCanaryVpcConfigOutputReference, ...)
- func NewSyntheticsCanary_Override(s SyntheticsCanary, scope constructs.Construct, id *string, ...)
- func SyntheticsCanary_IsConstruct(x interface{}) *bool
- func SyntheticsCanary_IsTerraformElement(x interface{}) *bool
- func SyntheticsCanary_IsTerraformResource(x interface{}) *bool
- func SyntheticsCanary_TfResourceType() *string
- type SyntheticsCanary
- type SyntheticsCanaryArtifactConfig
- type SyntheticsCanaryArtifactConfigOutputReference
- type SyntheticsCanaryArtifactConfigS3Encryption
- type SyntheticsCanaryArtifactConfigS3EncryptionOutputReference
- type SyntheticsCanaryConfig
- type SyntheticsCanaryRunConfig
- type SyntheticsCanaryRunConfigOutputReference
- type SyntheticsCanarySchedule
- type SyntheticsCanaryScheduleOutputReference
- type SyntheticsCanaryTimeline
- type SyntheticsCanaryTimelineList
- type SyntheticsCanaryTimelineOutputReference
- type SyntheticsCanaryVpcConfig
- type SyntheticsCanaryVpcConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSyntheticsCanaryArtifactConfigOutputReference_Override ¶
func NewSyntheticsCanaryArtifactConfigOutputReference_Override(s SyntheticsCanaryArtifactConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSyntheticsCanaryArtifactConfigS3EncryptionOutputReference_Override ¶
func NewSyntheticsCanaryArtifactConfigS3EncryptionOutputReference_Override(s SyntheticsCanaryArtifactConfigS3EncryptionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSyntheticsCanaryRunConfigOutputReference_Override ¶
func NewSyntheticsCanaryRunConfigOutputReference_Override(s SyntheticsCanaryRunConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSyntheticsCanaryScheduleOutputReference_Override ¶
func NewSyntheticsCanaryScheduleOutputReference_Override(s SyntheticsCanaryScheduleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSyntheticsCanaryTimelineList_Override ¶
func NewSyntheticsCanaryTimelineList_Override(s SyntheticsCanaryTimelineList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSyntheticsCanaryTimelineOutputReference_Override ¶
func NewSyntheticsCanaryTimelineOutputReference_Override(s SyntheticsCanaryTimelineOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSyntheticsCanaryVpcConfigOutputReference_Override ¶
func NewSyntheticsCanaryVpcConfigOutputReference_Override(s SyntheticsCanaryVpcConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSyntheticsCanary_Override ¶
func NewSyntheticsCanary_Override(s SyntheticsCanary, scope constructs.Construct, id *string, config *SyntheticsCanaryConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary aws_synthetics_canary} Resource.
func SyntheticsCanary_IsConstruct ¶
func SyntheticsCanary_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SyntheticsCanary_IsTerraformElement ¶
func SyntheticsCanary_IsTerraformElement(x interface{}) *bool
Experimental.
func SyntheticsCanary_IsTerraformResource ¶
func SyntheticsCanary_IsTerraformResource(x interface{}) *bool
Experimental.
func SyntheticsCanary_TfResourceType ¶
func SyntheticsCanary_TfResourceType() *string
Types ¶
type SyntheticsCanary ¶
type SyntheticsCanary interface {
cdktf.TerraformResource
Arn() *string
ArtifactConfig() SyntheticsCanaryArtifactConfigOutputReference
ArtifactConfigInput() *SyntheticsCanaryArtifactConfig
ArtifactS3Location() *string
SetArtifactS3Location(val *string)
ArtifactS3LocationInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DeleteLambda() interface{}
SetDeleteLambda(val interface{})
DeleteLambdaInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EngineArn() *string
ExecutionRoleArn() *string
SetExecutionRoleArn(val *string)
ExecutionRoleArnInput() *string
FailureRetentionPeriod() *float64
SetFailureRetentionPeriod(val *float64)
FailureRetentionPeriodInput() *float64
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Handler() *string
SetHandler(val *string)
HandlerInput() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RunConfig() SyntheticsCanaryRunConfigOutputReference
RunConfigInput() *SyntheticsCanaryRunConfig
RuntimeVersion() *string
SetRuntimeVersion(val *string)
RuntimeVersionInput() *string
S3Bucket() *string
SetS3Bucket(val *string)
S3BucketInput() *string
S3Key() *string
SetS3Key(val *string)
S3KeyInput() *string
S3Version() *string
SetS3Version(val *string)
S3VersionInput() *string
Schedule() SyntheticsCanaryScheduleOutputReference
ScheduleInput() *SyntheticsCanarySchedule
SourceLocationArn() *string
StartCanary() interface{}
SetStartCanary(val interface{})
StartCanaryInput() interface{}
Status() *string
SuccessRetentionPeriod() *float64
SetSuccessRetentionPeriod(val *float64)
SuccessRetentionPeriodInput() *float64
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeline() SyntheticsCanaryTimelineList
VpcConfig() SyntheticsCanaryVpcConfigOutputReference
VpcConfigInput() *SyntheticsCanaryVpcConfig
ZipFile() *string
SetZipFile(val *string)
ZipFileInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutArtifactConfig(value *SyntheticsCanaryArtifactConfig)
PutRunConfig(value *SyntheticsCanaryRunConfig)
PutSchedule(value *SyntheticsCanarySchedule)
PutVpcConfig(value *SyntheticsCanaryVpcConfig)
ResetArtifactConfig()
ResetDeleteLambda()
ResetFailureRetentionPeriod()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRunConfig()
ResetS3Bucket()
ResetS3Key()
ResetS3Version()
ResetStartCanary()
ResetSuccessRetentionPeriod()
ResetTags()
ResetTagsAll()
ResetVpcConfig()
ResetZipFile()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary aws_synthetics_canary}.
func NewSyntheticsCanary ¶
func NewSyntheticsCanary(scope constructs.Construct, id *string, config *SyntheticsCanaryConfig) SyntheticsCanary
Create a new {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary aws_synthetics_canary} Resource.
type SyntheticsCanaryArtifactConfig ¶
type SyntheticsCanaryArtifactConfig struct {
// s3_encryption block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#s3_encryption SyntheticsCanary#s3_encryption}
S3Encryption *SyntheticsCanaryArtifactConfigS3Encryption `field:"optional" json:"s3Encryption" yaml:"s3Encryption"`
}
type SyntheticsCanaryArtifactConfigOutputReference ¶
type SyntheticsCanaryArtifactConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SyntheticsCanaryArtifactConfig
SetInternalValue(val *SyntheticsCanaryArtifactConfig)
S3Encryption() SyntheticsCanaryArtifactConfigS3EncryptionOutputReference
S3EncryptionInput() *SyntheticsCanaryArtifactConfigS3Encryption
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutS3Encryption(value *SyntheticsCanaryArtifactConfigS3Encryption)
ResetS3Encryption()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSyntheticsCanaryArtifactConfigOutputReference ¶
func NewSyntheticsCanaryArtifactConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SyntheticsCanaryArtifactConfigOutputReference
type SyntheticsCanaryArtifactConfigS3Encryption ¶
type SyntheticsCanaryArtifactConfigS3Encryption struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#encryption_mode SyntheticsCanary#encryption_mode}.
EncryptionMode *string `field:"optional" json:"encryptionMode" yaml:"encryptionMode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#kms_key_arn SyntheticsCanary#kms_key_arn}.
KmsKeyArn *string `field:"optional" json:"kmsKeyArn" yaml:"kmsKeyArn"`
}
type SyntheticsCanaryArtifactConfigS3EncryptionOutputReference ¶
type SyntheticsCanaryArtifactConfigS3EncryptionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EncryptionMode() *string
SetEncryptionMode(val *string)
EncryptionModeInput() *string
// Experimental.
Fqn() *string
InternalValue() *SyntheticsCanaryArtifactConfigS3Encryption
SetInternalValue(val *SyntheticsCanaryArtifactConfigS3Encryption)
KmsKeyArn() *string
SetKmsKeyArn(val *string)
KmsKeyArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEncryptionMode()
ResetKmsKeyArn()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSyntheticsCanaryArtifactConfigS3EncryptionOutputReference ¶
func NewSyntheticsCanaryArtifactConfigS3EncryptionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SyntheticsCanaryArtifactConfigS3EncryptionOutputReference
type SyntheticsCanaryConfig ¶
type SyntheticsCanaryConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#artifact_s3_location SyntheticsCanary#artifact_s3_location}.
ArtifactS3Location *string `field:"required" json:"artifactS3Location" yaml:"artifactS3Location"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#execution_role_arn SyntheticsCanary#execution_role_arn}.
ExecutionRoleArn *string `field:"required" json:"executionRoleArn" yaml:"executionRoleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#handler SyntheticsCanary#handler}.
Handler *string `field:"required" json:"handler" yaml:"handler"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#name SyntheticsCanary#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#runtime_version SyntheticsCanary#runtime_version}.
RuntimeVersion *string `field:"required" json:"runtimeVersion" yaml:"runtimeVersion"`
// schedule block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#schedule SyntheticsCanary#schedule}
Schedule *SyntheticsCanarySchedule `field:"required" json:"schedule" yaml:"schedule"`
// artifact_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#artifact_config SyntheticsCanary#artifact_config}
ArtifactConfig *SyntheticsCanaryArtifactConfig `field:"optional" json:"artifactConfig" yaml:"artifactConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#delete_lambda SyntheticsCanary#delete_lambda}.
DeleteLambda interface{} `field:"optional" json:"deleteLambda" yaml:"deleteLambda"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#failure_retention_period SyntheticsCanary#failure_retention_period}.
FailureRetentionPeriod *float64 `field:"optional" json:"failureRetentionPeriod" yaml:"failureRetentionPeriod"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#id SyntheticsCanary#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// run_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#run_config SyntheticsCanary#run_config}
RunConfig *SyntheticsCanaryRunConfig `field:"optional" json:"runConfig" yaml:"runConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#s3_bucket SyntheticsCanary#s3_bucket}.
S3Bucket *string `field:"optional" json:"s3Bucket" yaml:"s3Bucket"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#s3_key SyntheticsCanary#s3_key}.
S3Key *string `field:"optional" json:"s3Key" yaml:"s3Key"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#s3_version SyntheticsCanary#s3_version}.
S3Version *string `field:"optional" json:"s3Version" yaml:"s3Version"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#start_canary SyntheticsCanary#start_canary}.
StartCanary interface{} `field:"optional" json:"startCanary" yaml:"startCanary"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#success_retention_period SyntheticsCanary#success_retention_period}.
SuccessRetentionPeriod *float64 `field:"optional" json:"successRetentionPeriod" yaml:"successRetentionPeriod"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#tags SyntheticsCanary#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#tags_all SyntheticsCanary#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// vpc_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#vpc_config SyntheticsCanary#vpc_config}
VpcConfig *SyntheticsCanaryVpcConfig `field:"optional" json:"vpcConfig" yaml:"vpcConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#zip_file SyntheticsCanary#zip_file}.
ZipFile *string `field:"optional" json:"zipFile" yaml:"zipFile"`
}
type SyntheticsCanaryRunConfig ¶
type SyntheticsCanaryRunConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#active_tracing SyntheticsCanary#active_tracing}.
ActiveTracing interface{} `field:"optional" json:"activeTracing" yaml:"activeTracing"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#environment_variables SyntheticsCanary#environment_variables}.
EnvironmentVariables *map[string]*string `field:"optional" json:"environmentVariables" yaml:"environmentVariables"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#memory_in_mb SyntheticsCanary#memory_in_mb}.
MemoryInMb *float64 `field:"optional" json:"memoryInMb" yaml:"memoryInMb"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#timeout_in_seconds SyntheticsCanary#timeout_in_seconds}.
TimeoutInSeconds *float64 `field:"optional" json:"timeoutInSeconds" yaml:"timeoutInSeconds"`
}
type SyntheticsCanaryRunConfigOutputReference ¶
type SyntheticsCanaryRunConfigOutputReference interface {
cdktf.ComplexObject
ActiveTracing() interface{}
SetActiveTracing(val interface{})
ActiveTracingInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EnvironmentVariables() *map[string]*string
SetEnvironmentVariables(val *map[string]*string)
EnvironmentVariablesInput() *map[string]*string
// Experimental.
Fqn() *string
InternalValue() *SyntheticsCanaryRunConfig
SetInternalValue(val *SyntheticsCanaryRunConfig)
MemoryInMb() *float64
SetMemoryInMb(val *float64)
MemoryInMbInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TimeoutInSeconds() *float64
SetTimeoutInSeconds(val *float64)
TimeoutInSecondsInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetActiveTracing()
ResetEnvironmentVariables()
ResetMemoryInMb()
ResetTimeoutInSeconds()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSyntheticsCanaryRunConfigOutputReference ¶
func NewSyntheticsCanaryRunConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SyntheticsCanaryRunConfigOutputReference
type SyntheticsCanarySchedule ¶
type SyntheticsCanarySchedule struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#expression SyntheticsCanary#expression}.
Expression *string `field:"required" json:"expression" yaml:"expression"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#duration_in_seconds SyntheticsCanary#duration_in_seconds}.
DurationInSeconds *float64 `field:"optional" json:"durationInSeconds" yaml:"durationInSeconds"`
}
type SyntheticsCanaryScheduleOutputReference ¶
type SyntheticsCanaryScheduleOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DurationInSeconds() *float64
SetDurationInSeconds(val *float64)
DurationInSecondsInput() *float64
Expression() *string
SetExpression(val *string)
ExpressionInput() *string
// Experimental.
Fqn() *string
InternalValue() *SyntheticsCanarySchedule
SetInternalValue(val *SyntheticsCanarySchedule)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDurationInSeconds()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSyntheticsCanaryScheduleOutputReference ¶
func NewSyntheticsCanaryScheduleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SyntheticsCanaryScheduleOutputReference
type SyntheticsCanaryTimeline ¶
type SyntheticsCanaryTimeline struct {
}
type SyntheticsCanaryTimelineList ¶
type SyntheticsCanaryTimelineList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SyntheticsCanaryTimelineOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSyntheticsCanaryTimelineList ¶
func NewSyntheticsCanaryTimelineList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SyntheticsCanaryTimelineList
type SyntheticsCanaryTimelineOutputReference ¶
type SyntheticsCanaryTimelineOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Created() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SyntheticsCanaryTimeline
SetInternalValue(val *SyntheticsCanaryTimeline)
LastModified() *string
LastStarted() *string
LastStopped() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSyntheticsCanaryTimelineOutputReference ¶
func NewSyntheticsCanaryTimelineOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SyntheticsCanaryTimelineOutputReference
type SyntheticsCanaryVpcConfig ¶
type SyntheticsCanaryVpcConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#security_group_ids SyntheticsCanary#security_group_ids}.
SecurityGroupIds *[]*string `field:"optional" json:"securityGroupIds" yaml:"securityGroupIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/synthetics_canary#subnet_ids SyntheticsCanary#subnet_ids}.
SubnetIds *[]*string `field:"optional" json:"subnetIds" yaml:"subnetIds"`
}
type SyntheticsCanaryVpcConfigOutputReference ¶
type SyntheticsCanaryVpcConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SyntheticsCanaryVpcConfig
SetInternalValue(val *SyntheticsCanaryVpcConfig)
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
SubnetIds() *[]*string
SetSubnetIds(val *[]*string)
SubnetIdsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VpcId() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetSecurityGroupIds()
ResetSubnetIds()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSyntheticsCanaryVpcConfigOutputReference ¶
func NewSyntheticsCanaryVpcConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SyntheticsCanaryVpcConfigOutputReference
Source Files
¶
- SyntheticsCanary.go
- SyntheticsCanaryArtifactConfig.go
- SyntheticsCanaryArtifactConfigOutputReference.go
- SyntheticsCanaryArtifactConfigOutputReference__checks.go
- SyntheticsCanaryArtifactConfigS3Encryption.go
- SyntheticsCanaryArtifactConfigS3EncryptionOutputReference.go
- SyntheticsCanaryArtifactConfigS3EncryptionOutputReference__checks.go
- SyntheticsCanaryConfig.go
- SyntheticsCanaryRunConfig.go
- SyntheticsCanaryRunConfigOutputReference.go
- SyntheticsCanaryRunConfigOutputReference__checks.go
- SyntheticsCanarySchedule.go
- SyntheticsCanaryScheduleOutputReference.go
- SyntheticsCanaryScheduleOutputReference__checks.go
- SyntheticsCanaryTimeline.go
- SyntheticsCanaryTimelineList.go
- SyntheticsCanaryTimelineList__checks.go
- SyntheticsCanaryTimelineOutputReference.go
- SyntheticsCanaryTimelineOutputReference__checks.go
- SyntheticsCanaryVpcConfig.go
- SyntheticsCanaryVpcConfigOutputReference.go
- SyntheticsCanaryVpcConfigOutputReference__checks.go
- SyntheticsCanary__checks.go
- main.go