Documentation
¶
Index ¶
- func NewTransferUserHomeDirectoryMappingsList_Override(t TransferUserHomeDirectoryMappingsList, ...)
- func NewTransferUserHomeDirectoryMappingsOutputReference_Override(t TransferUserHomeDirectoryMappingsOutputReference, ...)
- func NewTransferUserPosixProfileOutputReference_Override(t TransferUserPosixProfileOutputReference, ...)
- func NewTransferUserTimeoutsOutputReference_Override(t TransferUserTimeoutsOutputReference, ...)
- func NewTransferUser_Override(t TransferUser, scope constructs.Construct, id *string, ...)
- func TransferUser_IsConstruct(x interface{}) *bool
- func TransferUser_IsTerraformElement(x interface{}) *bool
- func TransferUser_IsTerraformResource(x interface{}) *bool
- func TransferUser_TfResourceType() *string
- type TransferUser
- type TransferUserConfig
- type TransferUserHomeDirectoryMappings
- type TransferUserHomeDirectoryMappingsList
- type TransferUserHomeDirectoryMappingsOutputReference
- type TransferUserPosixProfile
- type TransferUserPosixProfileOutputReference
- type TransferUserTimeouts
- type TransferUserTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewTransferUserHomeDirectoryMappingsList_Override ¶
func NewTransferUserHomeDirectoryMappingsList_Override(t TransferUserHomeDirectoryMappingsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewTransferUserHomeDirectoryMappingsOutputReference_Override ¶
func NewTransferUserHomeDirectoryMappingsOutputReference_Override(t TransferUserHomeDirectoryMappingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewTransferUserPosixProfileOutputReference_Override ¶
func NewTransferUserPosixProfileOutputReference_Override(t TransferUserPosixProfileOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewTransferUserTimeoutsOutputReference_Override ¶ added in v12.0.7
func NewTransferUserTimeoutsOutputReference_Override(t TransferUserTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewTransferUser_Override ¶
func NewTransferUser_Override(t TransferUser, scope constructs.Construct, id *string, config *TransferUserConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/transfer_user aws_transfer_user} Resource.
func TransferUser_IsConstruct ¶
func TransferUser_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func TransferUser_IsTerraformElement ¶
func TransferUser_IsTerraformElement(x interface{}) *bool
Experimental.
func TransferUser_IsTerraformResource ¶
func TransferUser_IsTerraformResource(x interface{}) *bool
Experimental.
func TransferUser_TfResourceType ¶
func TransferUser_TfResourceType() *string
Types ¶
type TransferUser ¶
type TransferUser interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HomeDirectory() *string
SetHomeDirectory(val *string)
HomeDirectoryInput() *string
HomeDirectoryMappings() TransferUserHomeDirectoryMappingsList
HomeDirectoryMappingsInput() interface{}
HomeDirectoryType() *string
SetHomeDirectoryType(val *string)
HomeDirectoryTypeInput() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
Policy() *string
SetPolicy(val *string)
PolicyInput() *string
PosixProfile() TransferUserPosixProfileOutputReference
PosixProfileInput() *TransferUserPosixProfile
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Role() *string
SetRole(val *string)
RoleInput() *string
ServerId() *string
SetServerId(val *string)
ServerIdInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() TransferUserTimeoutsOutputReference
TimeoutsInput() interface{}
UserName() *string
SetUserName(val *string)
UserNameInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutHomeDirectoryMappings(value interface{})
PutPosixProfile(value *TransferUserPosixProfile)
PutTimeouts(value *TransferUserTimeouts)
ResetHomeDirectory()
ResetHomeDirectoryMappings()
ResetHomeDirectoryType()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPolicy()
ResetPosixProfile()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/transfer_user aws_transfer_user}.
func NewTransferUser ¶
func NewTransferUser(scope constructs.Construct, id *string, config *TransferUserConfig) TransferUser
Create a new {@link https://www.terraform.io/docs/providers/aws/r/transfer_user aws_transfer_user} Resource.
type TransferUserConfig ¶
type TransferUserConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user#role TransferUser#role}.
Role *string `field:"required" json:"role" yaml:"role"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user#server_id TransferUser#server_id}.
ServerId *string `field:"required" json:"serverId" yaml:"serverId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user#user_name TransferUser#user_name}.
UserName *string `field:"required" json:"userName" yaml:"userName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user#home_directory TransferUser#home_directory}.
HomeDirectory *string `field:"optional" json:"homeDirectory" yaml:"homeDirectory"`
// home_directory_mappings block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user#home_directory_mappings TransferUser#home_directory_mappings}
HomeDirectoryMappings interface{} `field:"optional" json:"homeDirectoryMappings" yaml:"homeDirectoryMappings"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user#home_directory_type TransferUser#home_directory_type}.
HomeDirectoryType *string `field:"optional" json:"homeDirectoryType" yaml:"homeDirectoryType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user#id TransferUser#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user#policy TransferUser#policy}.
Policy *string `field:"optional" json:"policy" yaml:"policy"`
// posix_profile block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user#posix_profile TransferUser#posix_profile}
PosixProfile *TransferUserPosixProfile `field:"optional" json:"posixProfile" yaml:"posixProfile"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user#tags TransferUser#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user#tags_all TransferUser#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user#timeouts TransferUser#timeouts}
Timeouts *TransferUserTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type TransferUserHomeDirectoryMappings ¶
type TransferUserHomeDirectoryMappings struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user#entry TransferUser#entry}.
Entry *string `field:"required" json:"entry" yaml:"entry"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user#target TransferUser#target}.
Target *string `field:"required" json:"target" yaml:"target"`
}
type TransferUserHomeDirectoryMappingsList ¶
type TransferUserHomeDirectoryMappingsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) TransferUserHomeDirectoryMappingsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewTransferUserHomeDirectoryMappingsList ¶
func NewTransferUserHomeDirectoryMappingsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) TransferUserHomeDirectoryMappingsList
type TransferUserHomeDirectoryMappingsOutputReference ¶
type TransferUserHomeDirectoryMappingsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Entry() *string
SetEntry(val *string)
EntryInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Target() *string
SetTarget(val *string)
TargetInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewTransferUserHomeDirectoryMappingsOutputReference ¶
func NewTransferUserHomeDirectoryMappingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) TransferUserHomeDirectoryMappingsOutputReference
type TransferUserPosixProfile ¶
type TransferUserPosixProfile struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user#gid TransferUser#gid}.
Gid *float64 `field:"required" json:"gid" yaml:"gid"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user#uid TransferUser#uid}.
Uid *float64 `field:"required" json:"uid" yaml:"uid"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user#secondary_gids TransferUser#secondary_gids}.
SecondaryGids *[]*float64 `field:"optional" json:"secondaryGids" yaml:"secondaryGids"`
}
type TransferUserPosixProfileOutputReference ¶
type TransferUserPosixProfileOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Gid() *float64
SetGid(val *float64)
GidInput() *float64
InternalValue() *TransferUserPosixProfile
SetInternalValue(val *TransferUserPosixProfile)
SecondaryGids() *[]*float64
SetSecondaryGids(val *[]*float64)
SecondaryGidsInput() *[]*float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Uid() *float64
SetUid(val *float64)
UidInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetSecondaryGids()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewTransferUserPosixProfileOutputReference ¶
func NewTransferUserPosixProfileOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) TransferUserPosixProfileOutputReference
type TransferUserTimeouts ¶ added in v12.0.7
type TransferUserTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user#delete TransferUser#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type TransferUserTimeoutsOutputReference ¶ added in v12.0.7
type TransferUserTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewTransferUserTimeoutsOutputReference ¶ added in v12.0.7
func NewTransferUserTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) TransferUserTimeoutsOutputReference
Source Files
¶
- TransferUser.go
- TransferUserConfig.go
- TransferUserHomeDirectoryMappings.go
- TransferUserHomeDirectoryMappingsList.go
- TransferUserHomeDirectoryMappingsList__checks.go
- TransferUserHomeDirectoryMappingsOutputReference.go
- TransferUserHomeDirectoryMappingsOutputReference__checks.go
- TransferUserPosixProfile.go
- TransferUserPosixProfileOutputReference.go
- TransferUserPosixProfileOutputReference__checks.go
- TransferUserTimeouts.go
- TransferUserTimeoutsOutputReference.go
- TransferUserTimeoutsOutputReference__checks.go
- TransferUser__checks.go
- main.go