Documentation
¶
Index ¶
- func NewVpclatticeServiceDnsEntryList_Override(v VpclatticeServiceDnsEntryList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewVpclatticeServiceDnsEntryOutputReference_Override(v VpclatticeServiceDnsEntryOutputReference, ...)
- func NewVpclatticeServiceTimeoutsOutputReference_Override(v VpclatticeServiceTimeoutsOutputReference, ...)
- func NewVpclatticeService_Override(v VpclatticeService, scope constructs.Construct, id *string, ...)
- func VpclatticeService_IsConstruct(x interface{}) *bool
- func VpclatticeService_IsTerraformElement(x interface{}) *bool
- func VpclatticeService_IsTerraformResource(x interface{}) *bool
- func VpclatticeService_TfResourceType() *string
- type VpclatticeService
- type VpclatticeServiceConfig
- type VpclatticeServiceDnsEntry
- type VpclatticeServiceDnsEntryList
- type VpclatticeServiceDnsEntryOutputReference
- type VpclatticeServiceTimeouts
- type VpclatticeServiceTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewVpclatticeServiceDnsEntryList_Override ¶
func NewVpclatticeServiceDnsEntryList_Override(v VpclatticeServiceDnsEntryList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewVpclatticeServiceDnsEntryOutputReference_Override ¶
func NewVpclatticeServiceDnsEntryOutputReference_Override(v VpclatticeServiceDnsEntryOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewVpclatticeServiceTimeoutsOutputReference_Override ¶
func NewVpclatticeServiceTimeoutsOutputReference_Override(v VpclatticeServiceTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVpclatticeService_Override ¶
func NewVpclatticeService_Override(v VpclatticeService, scope constructs.Construct, id *string, config *VpclatticeServiceConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpclattice_service aws_vpclattice_service} Resource.
func VpclatticeService_IsConstruct ¶
func VpclatticeService_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func VpclatticeService_IsTerraformElement ¶
func VpclatticeService_IsTerraformElement(x interface{}) *bool
Experimental.
func VpclatticeService_IsTerraformResource ¶
func VpclatticeService_IsTerraformResource(x interface{}) *bool
Experimental.
func VpclatticeService_TfResourceType ¶
func VpclatticeService_TfResourceType() *string
Types ¶
type VpclatticeService ¶
type VpclatticeService interface {
cdktf.TerraformResource
Arn() *string
AuthType() *string
SetAuthType(val *string)
AuthTypeInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CertificateArn() *string
SetCertificateArn(val *string)
CertificateArnInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CustomDomainName() *string
SetCustomDomainName(val *string)
CustomDomainNameInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DnsEntry() VpclatticeServiceDnsEntryList
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Status() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() VpclatticeServiceTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *VpclatticeServiceTimeouts)
ResetAuthType()
ResetCertificateArn()
ResetCustomDomainName()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpclattice_service aws_vpclattice_service}.
func NewVpclatticeService ¶
func NewVpclatticeService(scope constructs.Construct, id *string, config *VpclatticeServiceConfig) VpclatticeService
Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpclattice_service aws_vpclattice_service} Resource.
type VpclatticeServiceConfig ¶
type VpclatticeServiceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpclattice_service#name VpclatticeService#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpclattice_service#auth_type VpclatticeService#auth_type}.
AuthType *string `field:"optional" json:"authType" yaml:"authType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpclattice_service#certificate_arn VpclatticeService#certificate_arn}.
CertificateArn *string `field:"optional" json:"certificateArn" yaml:"certificateArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpclattice_service#custom_domain_name VpclatticeService#custom_domain_name}.
CustomDomainName *string `field:"optional" json:"customDomainName" yaml:"customDomainName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpclattice_service#id VpclatticeService#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpclattice_service#tags VpclatticeService#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpclattice_service#tags_all VpclatticeService#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpclattice_service#timeouts VpclatticeService#timeouts}
Timeouts *VpclatticeServiceTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type VpclatticeServiceDnsEntry ¶
type VpclatticeServiceDnsEntry struct {
}
type VpclatticeServiceDnsEntryList ¶
type VpclatticeServiceDnsEntryList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) VpclatticeServiceDnsEntryOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpclatticeServiceDnsEntryList ¶
func NewVpclatticeServiceDnsEntryList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) VpclatticeServiceDnsEntryList
type VpclatticeServiceDnsEntryOutputReference ¶
type VpclatticeServiceDnsEntryOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DomainName() *string
// Experimental.
Fqn() *string
HostedZoneId() *string
InternalValue() *VpclatticeServiceDnsEntry
SetInternalValue(val *VpclatticeServiceDnsEntry)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpclatticeServiceDnsEntryOutputReference ¶
func NewVpclatticeServiceDnsEntryOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) VpclatticeServiceDnsEntryOutputReference
type VpclatticeServiceTimeouts ¶
type VpclatticeServiceTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpclattice_service#create VpclatticeService#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpclattice_service#delete VpclatticeService#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpclattice_service#update VpclatticeService#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type VpclatticeServiceTimeoutsOutputReference ¶
type VpclatticeServiceTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpclatticeServiceTimeoutsOutputReference ¶
func NewVpclatticeServiceTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VpclatticeServiceTimeoutsOutputReference
Source Files
¶
- VpclatticeService.go
- VpclatticeServiceConfig.go
- VpclatticeServiceDnsEntry.go
- VpclatticeServiceDnsEntryList.go
- VpclatticeServiceDnsEntryList__checks.go
- VpclatticeServiceDnsEntryOutputReference.go
- VpclatticeServiceDnsEntryOutputReference__checks.go
- VpclatticeServiceTimeouts.go
- VpclatticeServiceTimeoutsOutputReference.go
- VpclatticeServiceTimeoutsOutputReference__checks.go
- VpclatticeService__checks.go
- main.go