Documentation
¶
Index ¶
- func AmiCopy_IsConstruct(x interface{}) *bool
- func AmiCopy_IsTerraformElement(x interface{}) *bool
- func AmiCopy_IsTerraformResource(x interface{}) *bool
- func AmiCopy_TfResourceType() *string
- func NewAmiCopyEbsBlockDeviceList_Override(a AmiCopyEbsBlockDeviceList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewAmiCopyEbsBlockDeviceOutputReference_Override(a AmiCopyEbsBlockDeviceOutputReference, ...)
- func NewAmiCopyEphemeralBlockDeviceList_Override(a AmiCopyEphemeralBlockDeviceList, ...)
- func NewAmiCopyEphemeralBlockDeviceOutputReference_Override(a AmiCopyEphemeralBlockDeviceOutputReference, ...)
- func NewAmiCopyTimeoutsOutputReference_Override(a AmiCopyTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, ...)
- func NewAmiCopy_Override(a AmiCopy, scope constructs.Construct, id *string, config *AmiCopyConfig)
- type AmiCopy
- type AmiCopyConfig
- type AmiCopyEbsBlockDevice
- type AmiCopyEbsBlockDeviceList
- type AmiCopyEbsBlockDeviceOutputReference
- type AmiCopyEphemeralBlockDevice
- type AmiCopyEphemeralBlockDeviceList
- type AmiCopyEphemeralBlockDeviceOutputReference
- type AmiCopyTimeouts
- type AmiCopyTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AmiCopy_IsConstruct ¶
func AmiCopy_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AmiCopy_IsTerraformElement ¶
func AmiCopy_IsTerraformElement(x interface{}) *bool
Experimental.
func AmiCopy_IsTerraformResource ¶
func AmiCopy_IsTerraformResource(x interface{}) *bool
Experimental.
func AmiCopy_TfResourceType ¶
func AmiCopy_TfResourceType() *string
func NewAmiCopyEbsBlockDeviceList_Override ¶
func NewAmiCopyEbsBlockDeviceList_Override(a AmiCopyEbsBlockDeviceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAmiCopyEbsBlockDeviceOutputReference_Override ¶
func NewAmiCopyEbsBlockDeviceOutputReference_Override(a AmiCopyEbsBlockDeviceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAmiCopyEphemeralBlockDeviceList_Override ¶
func NewAmiCopyEphemeralBlockDeviceList_Override(a AmiCopyEphemeralBlockDeviceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAmiCopyEphemeralBlockDeviceOutputReference_Override ¶
func NewAmiCopyEphemeralBlockDeviceOutputReference_Override(a AmiCopyEphemeralBlockDeviceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAmiCopyTimeoutsOutputReference_Override ¶
func NewAmiCopyTimeoutsOutputReference_Override(a AmiCopyTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAmiCopy_Override ¶
func NewAmiCopy_Override(a AmiCopy, scope constructs.Construct, id *string, config *AmiCopyConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ami_copy aws_ami_copy} Resource.
Types ¶
type AmiCopy ¶
type AmiCopy interface {
cdktf.TerraformResource
Architecture() *string
Arn() *string
BootMode() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeprecationTime() *string
SetDeprecationTime(val *string)
DeprecationTimeInput() *string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DestinationOutpostArn() *string
SetDestinationOutpostArn(val *string)
DestinationOutpostArnInput() *string
EbsBlockDevice() AmiCopyEbsBlockDeviceList
EbsBlockDeviceInput() interface{}
EnaSupport() cdktf.IResolvable
Encrypted() interface{}
SetEncrypted(val interface{})
EncryptedInput() interface{}
EphemeralBlockDevice() AmiCopyEphemeralBlockDeviceList
EphemeralBlockDeviceInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Hypervisor() *string
Id() *string
SetId(val *string)
IdInput() *string
ImageLocation() *string
ImageOwnerAlias() *string
ImageType() *string
ImdsSupport() *string
KernelId() *string
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
ManageEbsSnapshots() cdktf.IResolvable
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
OwnerId() *string
Platform() *string
PlatformDetails() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
Public() cdktf.IResolvable
RamdiskId() *string
// Experimental.
RawOverrides() interface{}
RootDeviceName() *string
RootSnapshotId() *string
SourceAmiId() *string
SetSourceAmiId(val *string)
SourceAmiIdInput() *string
SourceAmiRegion() *string
SetSourceAmiRegion(val *string)
SourceAmiRegionInput() *string
SriovNetSupport() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() AmiCopyTimeoutsOutputReference
TimeoutsInput() interface{}
TpmSupport() *string
UsageOperation() *string
VirtualizationType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutEbsBlockDevice(value interface{})
PutEphemeralBlockDevice(value interface{})
PutTimeouts(value *AmiCopyTimeouts)
ResetDeprecationTime()
ResetDescription()
ResetDestinationOutpostArn()
ResetEbsBlockDevice()
ResetEncrypted()
ResetEphemeralBlockDevice()
ResetId()
ResetKmsKeyId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/ami_copy aws_ami_copy}.
func NewAmiCopy ¶
func NewAmiCopy(scope constructs.Construct, id *string, config *AmiCopyConfig) AmiCopy
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ami_copy aws_ami_copy} Resource.
type AmiCopyConfig ¶
type AmiCopyConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami_copy#name AmiCopy#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami_copy#source_ami_id AmiCopy#source_ami_id}.
SourceAmiId *string `field:"required" json:"sourceAmiId" yaml:"sourceAmiId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami_copy#source_ami_region AmiCopy#source_ami_region}.
SourceAmiRegion *string `field:"required" json:"sourceAmiRegion" yaml:"sourceAmiRegion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami_copy#deprecation_time AmiCopy#deprecation_time}.
DeprecationTime *string `field:"optional" json:"deprecationTime" yaml:"deprecationTime"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami_copy#description AmiCopy#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami_copy#destination_outpost_arn AmiCopy#destination_outpost_arn}.
DestinationOutpostArn *string `field:"optional" json:"destinationOutpostArn" yaml:"destinationOutpostArn"`
// ebs_block_device block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami_copy#ebs_block_device AmiCopy#ebs_block_device}
EbsBlockDevice interface{} `field:"optional" json:"ebsBlockDevice" yaml:"ebsBlockDevice"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami_copy#encrypted AmiCopy#encrypted}.
Encrypted interface{} `field:"optional" json:"encrypted" yaml:"encrypted"`
// ephemeral_block_device block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami_copy#ephemeral_block_device AmiCopy#ephemeral_block_device}
EphemeralBlockDevice interface{} `field:"optional" json:"ephemeralBlockDevice" yaml:"ephemeralBlockDevice"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami_copy#id AmiCopy#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami_copy#kms_key_id AmiCopy#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami_copy#tags AmiCopy#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami_copy#tags_all AmiCopy#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami_copy#timeouts AmiCopy#timeouts}
Timeouts *AmiCopyTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type AmiCopyEbsBlockDevice ¶
type AmiCopyEbsBlockDevice struct {
}
type AmiCopyEbsBlockDeviceList ¶
type AmiCopyEbsBlockDeviceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) AmiCopyEbsBlockDeviceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAmiCopyEbsBlockDeviceList ¶
func NewAmiCopyEbsBlockDeviceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AmiCopyEbsBlockDeviceList
type AmiCopyEbsBlockDeviceOutputReference ¶
type AmiCopyEbsBlockDeviceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeleteOnTermination() cdktf.IResolvable
DeviceName() *string
Encrypted() cdktf.IResolvable
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Iops() *float64
OutpostArn() *string
SnapshotId() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Throughput() *float64
VolumeSize() *float64
VolumeType() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAmiCopyEbsBlockDeviceOutputReference ¶
func NewAmiCopyEbsBlockDeviceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AmiCopyEbsBlockDeviceOutputReference
type AmiCopyEphemeralBlockDevice ¶
type AmiCopyEphemeralBlockDevice struct {
}
type AmiCopyEphemeralBlockDeviceList ¶
type AmiCopyEphemeralBlockDeviceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) AmiCopyEphemeralBlockDeviceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAmiCopyEphemeralBlockDeviceList ¶
func NewAmiCopyEphemeralBlockDeviceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AmiCopyEphemeralBlockDeviceList
type AmiCopyEphemeralBlockDeviceOutputReference ¶
type AmiCopyEphemeralBlockDeviceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeviceName() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VirtualName() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAmiCopyEphemeralBlockDeviceOutputReference ¶
func NewAmiCopyEphemeralBlockDeviceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AmiCopyEphemeralBlockDeviceOutputReference
type AmiCopyTimeouts ¶
type AmiCopyTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami_copy#create AmiCopy#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami_copy#delete AmiCopy#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ami_copy#update AmiCopy#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type AmiCopyTimeoutsOutputReference ¶
type AmiCopyTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAmiCopyTimeoutsOutputReference ¶
func NewAmiCopyTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AmiCopyTimeoutsOutputReference
Source Files
¶
- AmiCopy.go
- AmiCopyConfig.go
- AmiCopyEbsBlockDevice.go
- AmiCopyEbsBlockDeviceList.go
- AmiCopyEbsBlockDeviceList__checks.go
- AmiCopyEbsBlockDeviceOutputReference.go
- AmiCopyEbsBlockDeviceOutputReference__checks.go
- AmiCopyEphemeralBlockDevice.go
- AmiCopyEphemeralBlockDeviceList.go
- AmiCopyEphemeralBlockDeviceList__checks.go
- AmiCopyEphemeralBlockDeviceOutputReference.go
- AmiCopyEphemeralBlockDeviceOutputReference__checks.go
- AmiCopyTimeouts.go
- AmiCopyTimeoutsOutputReference.go
- AmiCopyTimeoutsOutputReference__checks.go
- AmiCopy__checks.go
- main.go