Documentation
¶
Index ¶
- func ApiGatewayIntegration_IsConstruct(x interface{}) *bool
- func ApiGatewayIntegration_IsTerraformElement(x interface{}) *bool
- func ApiGatewayIntegration_IsTerraformResource(x interface{}) *bool
- func ApiGatewayIntegration_TfResourceType() *string
- func NewApiGatewayIntegrationTlsConfigOutputReference_Override(a ApiGatewayIntegrationTlsConfigOutputReference, ...)
- func NewApiGatewayIntegration_Override(a ApiGatewayIntegration, scope constructs.Construct, id *string, ...)
- type ApiGatewayIntegration
- type ApiGatewayIntegrationConfig
- type ApiGatewayIntegrationTlsConfig
- type ApiGatewayIntegrationTlsConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ApiGatewayIntegration_IsConstruct ¶
func ApiGatewayIntegration_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ApiGatewayIntegration_IsTerraformElement ¶
func ApiGatewayIntegration_IsTerraformElement(x interface{}) *bool
Experimental.
func ApiGatewayIntegration_IsTerraformResource ¶
func ApiGatewayIntegration_IsTerraformResource(x interface{}) *bool
Experimental.
func ApiGatewayIntegration_TfResourceType ¶
func ApiGatewayIntegration_TfResourceType() *string
func NewApiGatewayIntegrationTlsConfigOutputReference_Override ¶
func NewApiGatewayIntegrationTlsConfigOutputReference_Override(a ApiGatewayIntegrationTlsConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewApiGatewayIntegration_Override ¶
func NewApiGatewayIntegration_Override(a ApiGatewayIntegration, scope constructs.Construct, id *string, config *ApiGatewayIntegrationConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration aws_api_gateway_integration} Resource.
Types ¶
type ApiGatewayIntegration ¶
type ApiGatewayIntegration interface {
cdktf.TerraformResource
CacheKeyParameters() *[]*string
SetCacheKeyParameters(val *[]*string)
CacheKeyParametersInput() *[]*string
CacheNamespace() *string
SetCacheNamespace(val *string)
CacheNamespaceInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
ConnectionId() *string
SetConnectionId(val *string)
ConnectionIdInput() *string
ConnectionType() *string
SetConnectionType(val *string)
ConnectionTypeInput() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ContentHandling() *string
SetContentHandling(val *string)
ContentHandlingInput() *string
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
Credentials() *string
SetCredentials(val *string)
CredentialsInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HttpMethod() *string
SetHttpMethod(val *string)
HttpMethodInput() *string
Id() *string
SetId(val *string)
IdInput() *string
IntegrationHttpMethod() *string
SetIntegrationHttpMethod(val *string)
IntegrationHttpMethodInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
PassthroughBehavior() *string
SetPassthroughBehavior(val *string)
PassthroughBehaviorInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RequestParameters() *map[string]*string
SetRequestParameters(val *map[string]*string)
RequestParametersInput() *map[string]*string
RequestTemplates() *map[string]*string
SetRequestTemplates(val *map[string]*string)
RequestTemplatesInput() *map[string]*string
ResourceId() *string
SetResourceId(val *string)
ResourceIdInput() *string
RestApiId() *string
SetRestApiId(val *string)
RestApiIdInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
TimeoutMilliseconds() *float64
SetTimeoutMilliseconds(val *float64)
TimeoutMillisecondsInput() *float64
TlsConfig() ApiGatewayIntegrationTlsConfigOutputReference
TlsConfigInput() *ApiGatewayIntegrationTlsConfig
Type() *string
SetType(val *string)
TypeInput() *string
Uri() *string
SetUri(val *string)
UriInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTlsConfig(value *ApiGatewayIntegrationTlsConfig)
ResetCacheKeyParameters()
ResetCacheNamespace()
ResetConnectionId()
ResetConnectionType()
ResetContentHandling()
ResetCredentials()
ResetId()
ResetIntegrationHttpMethod()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPassthroughBehavior()
ResetRequestParameters()
ResetRequestTemplates()
ResetTimeoutMilliseconds()
ResetTlsConfig()
ResetUri()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration aws_api_gateway_integration}.
func NewApiGatewayIntegration ¶
func NewApiGatewayIntegration(scope constructs.Construct, id *string, config *ApiGatewayIntegrationConfig) ApiGatewayIntegration
Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration aws_api_gateway_integration} Resource.
type ApiGatewayIntegrationConfig ¶
type ApiGatewayIntegrationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#http_method ApiGatewayIntegration#http_method}.
HttpMethod *string `field:"required" json:"httpMethod" yaml:"httpMethod"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#resource_id ApiGatewayIntegration#resource_id}.
ResourceId *string `field:"required" json:"resourceId" yaml:"resourceId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#rest_api_id ApiGatewayIntegration#rest_api_id}.
RestApiId *string `field:"required" json:"restApiId" yaml:"restApiId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#type ApiGatewayIntegration#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#cache_key_parameters ApiGatewayIntegration#cache_key_parameters}.
CacheKeyParameters *[]*string `field:"optional" json:"cacheKeyParameters" yaml:"cacheKeyParameters"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#cache_namespace ApiGatewayIntegration#cache_namespace}.
CacheNamespace *string `field:"optional" json:"cacheNamespace" yaml:"cacheNamespace"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#connection_id ApiGatewayIntegration#connection_id}.
ConnectionId *string `field:"optional" json:"connectionId" yaml:"connectionId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#connection_type ApiGatewayIntegration#connection_type}.
ConnectionType *string `field:"optional" json:"connectionType" yaml:"connectionType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#content_handling ApiGatewayIntegration#content_handling}.
ContentHandling *string `field:"optional" json:"contentHandling" yaml:"contentHandling"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#credentials ApiGatewayIntegration#credentials}.
Credentials *string `field:"optional" json:"credentials" yaml:"credentials"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#id ApiGatewayIntegration#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#integration_http_method ApiGatewayIntegration#integration_http_method}.
IntegrationHttpMethod *string `field:"optional" json:"integrationHttpMethod" yaml:"integrationHttpMethod"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#passthrough_behavior ApiGatewayIntegration#passthrough_behavior}.
PassthroughBehavior *string `field:"optional" json:"passthroughBehavior" yaml:"passthroughBehavior"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#request_parameters ApiGatewayIntegration#request_parameters}.
RequestParameters *map[string]*string `field:"optional" json:"requestParameters" yaml:"requestParameters"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#request_templates ApiGatewayIntegration#request_templates}.
RequestTemplates *map[string]*string `field:"optional" json:"requestTemplates" yaml:"requestTemplates"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#timeout_milliseconds ApiGatewayIntegration#timeout_milliseconds}.
TimeoutMilliseconds *float64 `field:"optional" json:"timeoutMilliseconds" yaml:"timeoutMilliseconds"`
// tls_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#tls_config ApiGatewayIntegration#tls_config}
TlsConfig *ApiGatewayIntegrationTlsConfig `field:"optional" json:"tlsConfig" yaml:"tlsConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#uri ApiGatewayIntegration#uri}.
Uri *string `field:"optional" json:"uri" yaml:"uri"`
}
type ApiGatewayIntegrationTlsConfig ¶
type ApiGatewayIntegrationTlsConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#insecure_skip_verification ApiGatewayIntegration#insecure_skip_verification}.
InsecureSkipVerification interface{} `field:"optional" json:"insecureSkipVerification" yaml:"insecureSkipVerification"`
}
type ApiGatewayIntegrationTlsConfigOutputReference ¶
type ApiGatewayIntegrationTlsConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InsecureSkipVerification() interface{}
SetInsecureSkipVerification(val interface{})
InsecureSkipVerificationInput() interface{}
InternalValue() *ApiGatewayIntegrationTlsConfig
SetInternalValue(val *ApiGatewayIntegrationTlsConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetInsecureSkipVerification()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApiGatewayIntegrationTlsConfigOutputReference ¶
func NewApiGatewayIntegrationTlsConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ApiGatewayIntegrationTlsConfigOutputReference