Documentation
¶
Index ¶
- func ApiGatewayStage_IsConstruct(x interface{}) *bool
- func ApiGatewayStage_IsTerraformElement(x interface{}) *bool
- func ApiGatewayStage_IsTerraformResource(x interface{}) *bool
- func ApiGatewayStage_TfResourceType() *string
- func NewApiGatewayStageAccessLogSettingsOutputReference_Override(a ApiGatewayStageAccessLogSettingsOutputReference, ...)
- func NewApiGatewayStageCanarySettingsOutputReference_Override(a ApiGatewayStageCanarySettingsOutputReference, ...)
- func NewApiGatewayStage_Override(a ApiGatewayStage, scope constructs.Construct, id *string, ...)
- type ApiGatewayStage
- type ApiGatewayStageAccessLogSettings
- type ApiGatewayStageAccessLogSettingsOutputReference
- type ApiGatewayStageCanarySettings
- type ApiGatewayStageCanarySettingsOutputReference
- type ApiGatewayStageConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ApiGatewayStage_IsConstruct ¶
func ApiGatewayStage_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ApiGatewayStage_IsTerraformElement ¶
func ApiGatewayStage_IsTerraformElement(x interface{}) *bool
Experimental.
func ApiGatewayStage_IsTerraformResource ¶
func ApiGatewayStage_IsTerraformResource(x interface{}) *bool
Experimental.
func ApiGatewayStage_TfResourceType ¶
func ApiGatewayStage_TfResourceType() *string
func NewApiGatewayStageAccessLogSettingsOutputReference_Override ¶
func NewApiGatewayStageAccessLogSettingsOutputReference_Override(a ApiGatewayStageAccessLogSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewApiGatewayStageCanarySettingsOutputReference_Override ¶
func NewApiGatewayStageCanarySettingsOutputReference_Override(a ApiGatewayStageCanarySettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewApiGatewayStage_Override ¶
func NewApiGatewayStage_Override(a ApiGatewayStage, scope constructs.Construct, id *string, config *ApiGatewayStageConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage aws_api_gateway_stage} Resource.
Types ¶
type ApiGatewayStage ¶
type ApiGatewayStage interface {
cdktf.TerraformResource
AccessLogSettings() ApiGatewayStageAccessLogSettingsOutputReference
AccessLogSettingsInput() *ApiGatewayStageAccessLogSettings
Arn() *string
CacheClusterEnabled() interface{}
SetCacheClusterEnabled(val interface{})
CacheClusterEnabledInput() interface{}
CacheClusterSize() *string
SetCacheClusterSize(val *string)
CacheClusterSizeInput() *string
CanarySettings() ApiGatewayStageCanarySettingsOutputReference
CanarySettingsInput() *ApiGatewayStageCanarySettings
// Experimental.
CdktfStack() cdktf.TerraformStack
ClientCertificateId() *string
SetClientCertificateId(val *string)
ClientCertificateIdInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeploymentId() *string
SetDeploymentId(val *string)
DeploymentIdInput() *string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DocumentationVersion() *string
SetDocumentationVersion(val *string)
DocumentationVersionInput() *string
ExecutionArn() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InvokeUrl() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RestApiId() *string
SetRestApiId(val *string)
RestApiIdInput() *string
StageName() *string
SetStageName(val *string)
StageNameInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Variables() *map[string]*string
SetVariables(val *map[string]*string)
VariablesInput() *map[string]*string
WebAclArn() *string
XrayTracingEnabled() interface{}
SetXrayTracingEnabled(val interface{})
XrayTracingEnabledInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAccessLogSettings(value *ApiGatewayStageAccessLogSettings)
PutCanarySettings(value *ApiGatewayStageCanarySettings)
ResetAccessLogSettings()
ResetCacheClusterEnabled()
ResetCacheClusterSize()
ResetCanarySettings()
ResetClientCertificateId()
ResetDescription()
ResetDocumentationVersion()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
ResetVariables()
ResetXrayTracingEnabled()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage aws_api_gateway_stage}.
func NewApiGatewayStage ¶
func NewApiGatewayStage(scope constructs.Construct, id *string, config *ApiGatewayStageConfig) ApiGatewayStage
Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage aws_api_gateway_stage} Resource.
type ApiGatewayStageAccessLogSettings ¶
type ApiGatewayStageAccessLogSettings struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#destination_arn ApiGatewayStage#destination_arn}.
DestinationArn *string `field:"required" json:"destinationArn" yaml:"destinationArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#format ApiGatewayStage#format}.
Format *string `field:"required" json:"format" yaml:"format"`
}
type ApiGatewayStageAccessLogSettingsOutputReference ¶
type ApiGatewayStageAccessLogSettingsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DestinationArn() *string
SetDestinationArn(val *string)
DestinationArnInput() *string
Format() *string
SetFormat(val *string)
FormatInput() *string
// Experimental.
Fqn() *string
InternalValue() *ApiGatewayStageAccessLogSettings
SetInternalValue(val *ApiGatewayStageAccessLogSettings)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApiGatewayStageAccessLogSettingsOutputReference ¶
func NewApiGatewayStageAccessLogSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ApiGatewayStageAccessLogSettingsOutputReference
type ApiGatewayStageCanarySettings ¶
type ApiGatewayStageCanarySettings struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#percent_traffic ApiGatewayStage#percent_traffic}.
PercentTraffic *float64 `field:"optional" json:"percentTraffic" yaml:"percentTraffic"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#stage_variable_overrides ApiGatewayStage#stage_variable_overrides}.
StageVariableOverrides *map[string]*string `field:"optional" json:"stageVariableOverrides" yaml:"stageVariableOverrides"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#use_stage_cache ApiGatewayStage#use_stage_cache}.
UseStageCache interface{} `field:"optional" json:"useStageCache" yaml:"useStageCache"`
}
type ApiGatewayStageCanarySettingsOutputReference ¶
type ApiGatewayStageCanarySettingsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ApiGatewayStageCanarySettings
SetInternalValue(val *ApiGatewayStageCanarySettings)
PercentTraffic() *float64
SetPercentTraffic(val *float64)
PercentTrafficInput() *float64
StageVariableOverrides() *map[string]*string
SetStageVariableOverrides(val *map[string]*string)
StageVariableOverridesInput() *map[string]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UseStageCache() interface{}
SetUseStageCache(val interface{})
UseStageCacheInput() interface{}
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetPercentTraffic()
ResetStageVariableOverrides()
ResetUseStageCache()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApiGatewayStageCanarySettingsOutputReference ¶
func NewApiGatewayStageCanarySettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ApiGatewayStageCanarySettingsOutputReference
type ApiGatewayStageConfig ¶
type ApiGatewayStageConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#deployment_id ApiGatewayStage#deployment_id}.
DeploymentId *string `field:"required" json:"deploymentId" yaml:"deploymentId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#rest_api_id ApiGatewayStage#rest_api_id}.
RestApiId *string `field:"required" json:"restApiId" yaml:"restApiId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#stage_name ApiGatewayStage#stage_name}.
StageName *string `field:"required" json:"stageName" yaml:"stageName"`
// access_log_settings block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#access_log_settings ApiGatewayStage#access_log_settings}
AccessLogSettings *ApiGatewayStageAccessLogSettings `field:"optional" json:"accessLogSettings" yaml:"accessLogSettings"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#cache_cluster_enabled ApiGatewayStage#cache_cluster_enabled}.
CacheClusterEnabled interface{} `field:"optional" json:"cacheClusterEnabled" yaml:"cacheClusterEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#cache_cluster_size ApiGatewayStage#cache_cluster_size}.
CacheClusterSize *string `field:"optional" json:"cacheClusterSize" yaml:"cacheClusterSize"`
// canary_settings block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#canary_settings ApiGatewayStage#canary_settings}
CanarySettings *ApiGatewayStageCanarySettings `field:"optional" json:"canarySettings" yaml:"canarySettings"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#client_certificate_id ApiGatewayStage#client_certificate_id}.
ClientCertificateId *string `field:"optional" json:"clientCertificateId" yaml:"clientCertificateId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#description ApiGatewayStage#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#documentation_version ApiGatewayStage#documentation_version}.
DocumentationVersion *string `field:"optional" json:"documentationVersion" yaml:"documentationVersion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#id ApiGatewayStage#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#tags ApiGatewayStage#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#tags_all ApiGatewayStage#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#variables ApiGatewayStage#variables}.
Variables *map[string]*string `field:"optional" json:"variables" yaml:"variables"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage#xray_tracing_enabled ApiGatewayStage#xray_tracing_enabled}.
XrayTracingEnabled interface{} `field:"optional" json:"xrayTracingEnabled" yaml:"xrayTracingEnabled"`
}
Source Files
¶
- ApiGatewayStage.go
- ApiGatewayStageAccessLogSettings.go
- ApiGatewayStageAccessLogSettingsOutputReference.go
- ApiGatewayStageAccessLogSettingsOutputReference__checks.go
- ApiGatewayStageCanarySettings.go
- ApiGatewayStageCanarySettingsOutputReference.go
- ApiGatewayStageCanarySettingsOutputReference__checks.go
- ApiGatewayStageConfig.go
- ApiGatewayStage__checks.go
- main.go