Documentation
¶
Index ¶
- func ApiGatewayUsagePlan_IsConstruct(x interface{}) *bool
- func ApiGatewayUsagePlan_IsTerraformElement(x interface{}) *bool
- func ApiGatewayUsagePlan_IsTerraformResource(x interface{}) *bool
- func ApiGatewayUsagePlan_TfResourceType() *string
- func NewApiGatewayUsagePlanApiStagesList_Override(a ApiGatewayUsagePlanApiStagesList, ...)
- func NewApiGatewayUsagePlanApiStagesOutputReference_Override(a ApiGatewayUsagePlanApiStagesOutputReference, ...)
- func NewApiGatewayUsagePlanApiStagesThrottleList_Override(a ApiGatewayUsagePlanApiStagesThrottleList, ...)
- func NewApiGatewayUsagePlanApiStagesThrottleOutputReference_Override(a ApiGatewayUsagePlanApiStagesThrottleOutputReference, ...)
- func NewApiGatewayUsagePlanQuotaSettingsOutputReference_Override(a ApiGatewayUsagePlanQuotaSettingsOutputReference, ...)
- func NewApiGatewayUsagePlanThrottleSettingsOutputReference_Override(a ApiGatewayUsagePlanThrottleSettingsOutputReference, ...)
- func NewApiGatewayUsagePlan_Override(a ApiGatewayUsagePlan, scope constructs.Construct, id *string, ...)
- type ApiGatewayUsagePlan
- type ApiGatewayUsagePlanApiStages
- type ApiGatewayUsagePlanApiStagesList
- type ApiGatewayUsagePlanApiStagesOutputReference
- type ApiGatewayUsagePlanApiStagesThrottle
- type ApiGatewayUsagePlanApiStagesThrottleList
- type ApiGatewayUsagePlanApiStagesThrottleOutputReference
- type ApiGatewayUsagePlanConfig
- type ApiGatewayUsagePlanQuotaSettings
- type ApiGatewayUsagePlanQuotaSettingsOutputReference
- type ApiGatewayUsagePlanThrottleSettings
- type ApiGatewayUsagePlanThrottleSettingsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ApiGatewayUsagePlan_IsConstruct ¶
func ApiGatewayUsagePlan_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ApiGatewayUsagePlan_IsTerraformElement ¶
func ApiGatewayUsagePlan_IsTerraformElement(x interface{}) *bool
Experimental.
func ApiGatewayUsagePlan_IsTerraformResource ¶
func ApiGatewayUsagePlan_IsTerraformResource(x interface{}) *bool
Experimental.
func ApiGatewayUsagePlan_TfResourceType ¶
func ApiGatewayUsagePlan_TfResourceType() *string
func NewApiGatewayUsagePlanApiStagesList_Override ¶
func NewApiGatewayUsagePlanApiStagesList_Override(a ApiGatewayUsagePlanApiStagesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewApiGatewayUsagePlanApiStagesOutputReference_Override ¶
func NewApiGatewayUsagePlanApiStagesOutputReference_Override(a ApiGatewayUsagePlanApiStagesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewApiGatewayUsagePlanApiStagesThrottleList_Override ¶
func NewApiGatewayUsagePlanApiStagesThrottleList_Override(a ApiGatewayUsagePlanApiStagesThrottleList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewApiGatewayUsagePlanApiStagesThrottleOutputReference_Override ¶
func NewApiGatewayUsagePlanApiStagesThrottleOutputReference_Override(a ApiGatewayUsagePlanApiStagesThrottleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewApiGatewayUsagePlanQuotaSettingsOutputReference_Override ¶
func NewApiGatewayUsagePlanQuotaSettingsOutputReference_Override(a ApiGatewayUsagePlanQuotaSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewApiGatewayUsagePlanThrottleSettingsOutputReference_Override ¶
func NewApiGatewayUsagePlanThrottleSettingsOutputReference_Override(a ApiGatewayUsagePlanThrottleSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewApiGatewayUsagePlan_Override ¶
func NewApiGatewayUsagePlan_Override(a ApiGatewayUsagePlan, scope constructs.Construct, id *string, config *ApiGatewayUsagePlanConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan aws_api_gateway_usage_plan} Resource.
Types ¶
type ApiGatewayUsagePlan ¶
type ApiGatewayUsagePlan interface {
cdktf.TerraformResource
ApiStages() ApiGatewayUsagePlanApiStagesList
ApiStagesInput() interface{}
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
ProductCode() *string
SetProductCode(val *string)
ProductCodeInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
QuotaSettings() ApiGatewayUsagePlanQuotaSettingsOutputReference
QuotaSettingsInput() *ApiGatewayUsagePlanQuotaSettings
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
ThrottleSettings() ApiGatewayUsagePlanThrottleSettingsOutputReference
ThrottleSettingsInput() *ApiGatewayUsagePlanThrottleSettings
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutApiStages(value interface{})
PutQuotaSettings(value *ApiGatewayUsagePlanQuotaSettings)
PutThrottleSettings(value *ApiGatewayUsagePlanThrottleSettings)
ResetApiStages()
ResetDescription()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProductCode()
ResetQuotaSettings()
ResetTags()
ResetTagsAll()
ResetThrottleSettings()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan aws_api_gateway_usage_plan}.
func NewApiGatewayUsagePlan ¶
func NewApiGatewayUsagePlan(scope constructs.Construct, id *string, config *ApiGatewayUsagePlanConfig) ApiGatewayUsagePlan
Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan aws_api_gateway_usage_plan} Resource.
type ApiGatewayUsagePlanApiStages ¶
type ApiGatewayUsagePlanApiStages struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#api_id ApiGatewayUsagePlan#api_id}.
ApiId *string `field:"required" json:"apiId" yaml:"apiId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#stage ApiGatewayUsagePlan#stage}.
Stage *string `field:"required" json:"stage" yaml:"stage"`
// throttle block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#throttle ApiGatewayUsagePlan#throttle}
Throttle interface{} `field:"optional" json:"throttle" yaml:"throttle"`
}
type ApiGatewayUsagePlanApiStagesList ¶
type ApiGatewayUsagePlanApiStagesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ApiGatewayUsagePlanApiStagesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApiGatewayUsagePlanApiStagesList ¶
func NewApiGatewayUsagePlanApiStagesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ApiGatewayUsagePlanApiStagesList
type ApiGatewayUsagePlanApiStagesOutputReference ¶
type ApiGatewayUsagePlanApiStagesOutputReference interface {
cdktf.ComplexObject
ApiId() *string
SetApiId(val *string)
ApiIdInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Stage() *string
SetStage(val *string)
StageInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Throttle() ApiGatewayUsagePlanApiStagesThrottleList
ThrottleInput() interface{}
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutThrottle(value interface{})
ResetThrottle()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApiGatewayUsagePlanApiStagesOutputReference ¶
func NewApiGatewayUsagePlanApiStagesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ApiGatewayUsagePlanApiStagesOutputReference
type ApiGatewayUsagePlanApiStagesThrottle ¶
type ApiGatewayUsagePlanApiStagesThrottle struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#path ApiGatewayUsagePlan#path}.
Path *string `field:"required" json:"path" yaml:"path"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#burst_limit ApiGatewayUsagePlan#burst_limit}.
BurstLimit *float64 `field:"optional" json:"burstLimit" yaml:"burstLimit"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#rate_limit ApiGatewayUsagePlan#rate_limit}.
RateLimit *float64 `field:"optional" json:"rateLimit" yaml:"rateLimit"`
}
type ApiGatewayUsagePlanApiStagesThrottleList ¶
type ApiGatewayUsagePlanApiStagesThrottleList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ApiGatewayUsagePlanApiStagesThrottleOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApiGatewayUsagePlanApiStagesThrottleList ¶
func NewApiGatewayUsagePlanApiStagesThrottleList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ApiGatewayUsagePlanApiStagesThrottleList
type ApiGatewayUsagePlanApiStagesThrottleOutputReference ¶
type ApiGatewayUsagePlanApiStagesThrottleOutputReference interface {
cdktf.ComplexObject
BurstLimit() *float64
SetBurstLimit(val *float64)
BurstLimitInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Path() *string
SetPath(val *string)
PathInput() *string
RateLimit() *float64
SetRateLimit(val *float64)
RateLimitInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBurstLimit()
ResetRateLimit()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApiGatewayUsagePlanApiStagesThrottleOutputReference ¶
func NewApiGatewayUsagePlanApiStagesThrottleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ApiGatewayUsagePlanApiStagesThrottleOutputReference
type ApiGatewayUsagePlanConfig ¶
type ApiGatewayUsagePlanConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#name ApiGatewayUsagePlan#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// api_stages block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#api_stages ApiGatewayUsagePlan#api_stages}
ApiStages interface{} `field:"optional" json:"apiStages" yaml:"apiStages"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#description ApiGatewayUsagePlan#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#id ApiGatewayUsagePlan#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#product_code ApiGatewayUsagePlan#product_code}.
ProductCode *string `field:"optional" json:"productCode" yaml:"productCode"`
// quota_settings block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#quota_settings ApiGatewayUsagePlan#quota_settings}
QuotaSettings *ApiGatewayUsagePlanQuotaSettings `field:"optional" json:"quotaSettings" yaml:"quotaSettings"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#tags ApiGatewayUsagePlan#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#tags_all ApiGatewayUsagePlan#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// throttle_settings block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#throttle_settings ApiGatewayUsagePlan#throttle_settings}
ThrottleSettings *ApiGatewayUsagePlanThrottleSettings `field:"optional" json:"throttleSettings" yaml:"throttleSettings"`
}
type ApiGatewayUsagePlanQuotaSettings ¶
type ApiGatewayUsagePlanQuotaSettings struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#limit ApiGatewayUsagePlan#limit}.
Limit *float64 `field:"required" json:"limit" yaml:"limit"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#period ApiGatewayUsagePlan#period}.
Period *string `field:"required" json:"period" yaml:"period"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#offset ApiGatewayUsagePlan#offset}.
Offset *float64 `field:"optional" json:"offset" yaml:"offset"`
}
type ApiGatewayUsagePlanQuotaSettingsOutputReference ¶
type ApiGatewayUsagePlanQuotaSettingsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ApiGatewayUsagePlanQuotaSettings
SetInternalValue(val *ApiGatewayUsagePlanQuotaSettings)
Limit() *float64
SetLimit(val *float64)
LimitInput() *float64
Offset() *float64
SetOffset(val *float64)
OffsetInput() *float64
Period() *string
SetPeriod(val *string)
PeriodInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetOffset()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApiGatewayUsagePlanQuotaSettingsOutputReference ¶
func NewApiGatewayUsagePlanQuotaSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ApiGatewayUsagePlanQuotaSettingsOutputReference
type ApiGatewayUsagePlanThrottleSettings ¶
type ApiGatewayUsagePlanThrottleSettings struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#burst_limit ApiGatewayUsagePlan#burst_limit}.
BurstLimit *float64 `field:"optional" json:"burstLimit" yaml:"burstLimit"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan#rate_limit ApiGatewayUsagePlan#rate_limit}.
RateLimit *float64 `field:"optional" json:"rateLimit" yaml:"rateLimit"`
}
type ApiGatewayUsagePlanThrottleSettingsOutputReference ¶
type ApiGatewayUsagePlanThrottleSettingsOutputReference interface {
cdktf.ComplexObject
BurstLimit() *float64
SetBurstLimit(val *float64)
BurstLimitInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ApiGatewayUsagePlanThrottleSettings
SetInternalValue(val *ApiGatewayUsagePlanThrottleSettings)
RateLimit() *float64
SetRateLimit(val *float64)
RateLimitInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBurstLimit()
ResetRateLimit()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApiGatewayUsagePlanThrottleSettingsOutputReference ¶
func NewApiGatewayUsagePlanThrottleSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ApiGatewayUsagePlanThrottleSettingsOutputReference
Source Files
¶
- ApiGatewayUsagePlan.go
- ApiGatewayUsagePlanApiStages.go
- ApiGatewayUsagePlanApiStagesList.go
- ApiGatewayUsagePlanApiStagesList__checks.go
- ApiGatewayUsagePlanApiStagesOutputReference.go
- ApiGatewayUsagePlanApiStagesOutputReference__checks.go
- ApiGatewayUsagePlanApiStagesThrottle.go
- ApiGatewayUsagePlanApiStagesThrottleList.go
- ApiGatewayUsagePlanApiStagesThrottleList__checks.go
- ApiGatewayUsagePlanApiStagesThrottleOutputReference.go
- ApiGatewayUsagePlanApiStagesThrottleOutputReference__checks.go
- ApiGatewayUsagePlanConfig.go
- ApiGatewayUsagePlanQuotaSettings.go
- ApiGatewayUsagePlanQuotaSettingsOutputReference.go
- ApiGatewayUsagePlanQuotaSettingsOutputReference__checks.go
- ApiGatewayUsagePlanThrottleSettings.go
- ApiGatewayUsagePlanThrottleSettingsOutputReference.go
- ApiGatewayUsagePlanThrottleSettingsOutputReference__checks.go
- ApiGatewayUsagePlan__checks.go
- main.go