Documentation
¶
Index ¶
- func Apigatewayv2Stage_IsConstruct(x interface{}) *bool
- func Apigatewayv2Stage_IsTerraformElement(x interface{}) *bool
- func Apigatewayv2Stage_IsTerraformResource(x interface{}) *bool
- func Apigatewayv2Stage_TfResourceType() *string
- func NewApigatewayv2StageAccessLogSettingsOutputReference_Override(a Apigatewayv2StageAccessLogSettingsOutputReference, ...)
- func NewApigatewayv2StageDefaultRouteSettingsOutputReference_Override(a Apigatewayv2StageDefaultRouteSettingsOutputReference, ...)
- func NewApigatewayv2StageRouteSettingsList_Override(a Apigatewayv2StageRouteSettingsList, ...)
- func NewApigatewayv2StageRouteSettingsOutputReference_Override(a Apigatewayv2StageRouteSettingsOutputReference, ...)
- func NewApigatewayv2Stage_Override(a Apigatewayv2Stage, scope constructs.Construct, id *string, ...)
- type Apigatewayv2Stage
- type Apigatewayv2StageAccessLogSettings
- type Apigatewayv2StageAccessLogSettingsOutputReference
- type Apigatewayv2StageConfig
- type Apigatewayv2StageDefaultRouteSettings
- type Apigatewayv2StageDefaultRouteSettingsOutputReference
- type Apigatewayv2StageRouteSettings
- type Apigatewayv2StageRouteSettingsList
- type Apigatewayv2StageRouteSettingsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Apigatewayv2Stage_IsConstruct ¶
func Apigatewayv2Stage_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func Apigatewayv2Stage_IsTerraformElement ¶
func Apigatewayv2Stage_IsTerraformElement(x interface{}) *bool
Experimental.
func Apigatewayv2Stage_IsTerraformResource ¶
func Apigatewayv2Stage_IsTerraformResource(x interface{}) *bool
Experimental.
func Apigatewayv2Stage_TfResourceType ¶
func Apigatewayv2Stage_TfResourceType() *string
func NewApigatewayv2StageAccessLogSettingsOutputReference_Override ¶
func NewApigatewayv2StageAccessLogSettingsOutputReference_Override(a Apigatewayv2StageAccessLogSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewApigatewayv2StageDefaultRouteSettingsOutputReference_Override ¶
func NewApigatewayv2StageDefaultRouteSettingsOutputReference_Override(a Apigatewayv2StageDefaultRouteSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewApigatewayv2StageRouteSettingsList_Override ¶
func NewApigatewayv2StageRouteSettingsList_Override(a Apigatewayv2StageRouteSettingsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewApigatewayv2StageRouteSettingsOutputReference_Override ¶
func NewApigatewayv2StageRouteSettingsOutputReference_Override(a Apigatewayv2StageRouteSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewApigatewayv2Stage_Override ¶
func NewApigatewayv2Stage_Override(a Apigatewayv2Stage, scope constructs.Construct, id *string, config *Apigatewayv2StageConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage aws_apigatewayv2_stage} Resource.
Types ¶
type Apigatewayv2Stage ¶
type Apigatewayv2Stage interface {
cdktf.TerraformResource
AccessLogSettings() Apigatewayv2StageAccessLogSettingsOutputReference
AccessLogSettingsInput() *Apigatewayv2StageAccessLogSettings
ApiId() *string
SetApiId(val *string)
ApiIdInput() *string
Arn() *string
AutoDeploy() interface{}
SetAutoDeploy(val interface{})
AutoDeployInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
ClientCertificateId() *string
SetClientCertificateId(val *string)
ClientCertificateIdInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DefaultRouteSettings() Apigatewayv2StageDefaultRouteSettingsOutputReference
DefaultRouteSettingsInput() *Apigatewayv2StageDefaultRouteSettings
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeploymentId() *string
SetDeploymentId(val *string)
DeploymentIdInput() *string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
ExecutionArn() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InvokeUrl() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RouteSettings() Apigatewayv2StageRouteSettingsList
RouteSettingsInput() interface{}
StageVariables() *map[string]*string
SetStageVariables(val *map[string]*string)
StageVariablesInput() *map[string]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAccessLogSettings(value *Apigatewayv2StageAccessLogSettings)
PutDefaultRouteSettings(value *Apigatewayv2StageDefaultRouteSettings)
PutRouteSettings(value interface{})
ResetAccessLogSettings()
ResetAutoDeploy()
ResetClientCertificateId()
ResetDefaultRouteSettings()
ResetDeploymentId()
ResetDescription()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRouteSettings()
ResetStageVariables()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage aws_apigatewayv2_stage}.
func NewApigatewayv2Stage ¶
func NewApigatewayv2Stage(scope constructs.Construct, id *string, config *Apigatewayv2StageConfig) Apigatewayv2Stage
Create a new {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage aws_apigatewayv2_stage} Resource.
type Apigatewayv2StageAccessLogSettings ¶
type Apigatewayv2StageAccessLogSettings struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#destination_arn Apigatewayv2Stage#destination_arn}.
DestinationArn *string `field:"required" json:"destinationArn" yaml:"destinationArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#format Apigatewayv2Stage#format}.
Format *string `field:"required" json:"format" yaml:"format"`
}
type Apigatewayv2StageAccessLogSettingsOutputReference ¶
type Apigatewayv2StageAccessLogSettingsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DestinationArn() *string
SetDestinationArn(val *string)
DestinationArnInput() *string
Format() *string
SetFormat(val *string)
FormatInput() *string
// Experimental.
Fqn() *string
InternalValue() *Apigatewayv2StageAccessLogSettings
SetInternalValue(val *Apigatewayv2StageAccessLogSettings)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApigatewayv2StageAccessLogSettingsOutputReference ¶
func NewApigatewayv2StageAccessLogSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Apigatewayv2StageAccessLogSettingsOutputReference
type Apigatewayv2StageConfig ¶
type Apigatewayv2StageConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#api_id Apigatewayv2Stage#api_id}.
ApiId *string `field:"required" json:"apiId" yaml:"apiId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#name Apigatewayv2Stage#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// access_log_settings block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#access_log_settings Apigatewayv2Stage#access_log_settings}
AccessLogSettings *Apigatewayv2StageAccessLogSettings `field:"optional" json:"accessLogSettings" yaml:"accessLogSettings"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#auto_deploy Apigatewayv2Stage#auto_deploy}.
AutoDeploy interface{} `field:"optional" json:"autoDeploy" yaml:"autoDeploy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#client_certificate_id Apigatewayv2Stage#client_certificate_id}.
ClientCertificateId *string `field:"optional" json:"clientCertificateId" yaml:"clientCertificateId"`
// default_route_settings block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#default_route_settings Apigatewayv2Stage#default_route_settings}
DefaultRouteSettings *Apigatewayv2StageDefaultRouteSettings `field:"optional" json:"defaultRouteSettings" yaml:"defaultRouteSettings"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#deployment_id Apigatewayv2Stage#deployment_id}.
DeploymentId *string `field:"optional" json:"deploymentId" yaml:"deploymentId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#description Apigatewayv2Stage#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#id Apigatewayv2Stage#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// route_settings block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#route_settings Apigatewayv2Stage#route_settings}
RouteSettings interface{} `field:"optional" json:"routeSettings" yaml:"routeSettings"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#stage_variables Apigatewayv2Stage#stage_variables}.
StageVariables *map[string]*string `field:"optional" json:"stageVariables" yaml:"stageVariables"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#tags Apigatewayv2Stage#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#tags_all Apigatewayv2Stage#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type Apigatewayv2StageDefaultRouteSettings ¶
type Apigatewayv2StageDefaultRouteSettings struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#data_trace_enabled Apigatewayv2Stage#data_trace_enabled}.
DataTraceEnabled interface{} `field:"optional" json:"dataTraceEnabled" yaml:"dataTraceEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#detailed_metrics_enabled Apigatewayv2Stage#detailed_metrics_enabled}.
DetailedMetricsEnabled interface{} `field:"optional" json:"detailedMetricsEnabled" yaml:"detailedMetricsEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#logging_level Apigatewayv2Stage#logging_level}.
LoggingLevel *string `field:"optional" json:"loggingLevel" yaml:"loggingLevel"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#throttling_burst_limit Apigatewayv2Stage#throttling_burst_limit}.
ThrottlingBurstLimit *float64 `field:"optional" json:"throttlingBurstLimit" yaml:"throttlingBurstLimit"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#throttling_rate_limit Apigatewayv2Stage#throttling_rate_limit}.
ThrottlingRateLimit *float64 `field:"optional" json:"throttlingRateLimit" yaml:"throttlingRateLimit"`
}
type Apigatewayv2StageDefaultRouteSettingsOutputReference ¶
type Apigatewayv2StageDefaultRouteSettingsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DataTraceEnabled() interface{}
SetDataTraceEnabled(val interface{})
DataTraceEnabledInput() interface{}
DetailedMetricsEnabled() interface{}
SetDetailedMetricsEnabled(val interface{})
DetailedMetricsEnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *Apigatewayv2StageDefaultRouteSettings
SetInternalValue(val *Apigatewayv2StageDefaultRouteSettings)
LoggingLevel() *string
SetLoggingLevel(val *string)
LoggingLevelInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ThrottlingBurstLimit() *float64
SetThrottlingBurstLimit(val *float64)
ThrottlingBurstLimitInput() *float64
ThrottlingRateLimit() *float64
SetThrottlingRateLimit(val *float64)
ThrottlingRateLimitInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDataTraceEnabled()
ResetDetailedMetricsEnabled()
ResetLoggingLevel()
ResetThrottlingBurstLimit()
ResetThrottlingRateLimit()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApigatewayv2StageDefaultRouteSettingsOutputReference ¶
func NewApigatewayv2StageDefaultRouteSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Apigatewayv2StageDefaultRouteSettingsOutputReference
type Apigatewayv2StageRouteSettings ¶
type Apigatewayv2StageRouteSettings struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#route_key Apigatewayv2Stage#route_key}.
RouteKey *string `field:"required" json:"routeKey" yaml:"routeKey"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#data_trace_enabled Apigatewayv2Stage#data_trace_enabled}.
DataTraceEnabled interface{} `field:"optional" json:"dataTraceEnabled" yaml:"dataTraceEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#detailed_metrics_enabled Apigatewayv2Stage#detailed_metrics_enabled}.
DetailedMetricsEnabled interface{} `field:"optional" json:"detailedMetricsEnabled" yaml:"detailedMetricsEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#logging_level Apigatewayv2Stage#logging_level}.
LoggingLevel *string `field:"optional" json:"loggingLevel" yaml:"loggingLevel"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#throttling_burst_limit Apigatewayv2Stage#throttling_burst_limit}.
ThrottlingBurstLimit *float64 `field:"optional" json:"throttlingBurstLimit" yaml:"throttlingBurstLimit"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apigatewayv2_stage#throttling_rate_limit Apigatewayv2Stage#throttling_rate_limit}.
ThrottlingRateLimit *float64 `field:"optional" json:"throttlingRateLimit" yaml:"throttlingRateLimit"`
}
type Apigatewayv2StageRouteSettingsList ¶
type Apigatewayv2StageRouteSettingsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) Apigatewayv2StageRouteSettingsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApigatewayv2StageRouteSettingsList ¶
func NewApigatewayv2StageRouteSettingsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) Apigatewayv2StageRouteSettingsList
type Apigatewayv2StageRouteSettingsOutputReference ¶
type Apigatewayv2StageRouteSettingsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DataTraceEnabled() interface{}
SetDataTraceEnabled(val interface{})
DataTraceEnabledInput() interface{}
DetailedMetricsEnabled() interface{}
SetDetailedMetricsEnabled(val interface{})
DetailedMetricsEnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
LoggingLevel() *string
SetLoggingLevel(val *string)
LoggingLevelInput() *string
RouteKey() *string
SetRouteKey(val *string)
RouteKeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ThrottlingBurstLimit() *float64
SetThrottlingBurstLimit(val *float64)
ThrottlingBurstLimitInput() *float64
ThrottlingRateLimit() *float64
SetThrottlingRateLimit(val *float64)
ThrottlingRateLimitInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDataTraceEnabled()
ResetDetailedMetricsEnabled()
ResetLoggingLevel()
ResetThrottlingBurstLimit()
ResetThrottlingRateLimit()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApigatewayv2StageRouteSettingsOutputReference ¶
func NewApigatewayv2StageRouteSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) Apigatewayv2StageRouteSettingsOutputReference
Source Files
¶
- Apigatewayv2Stage.go
- Apigatewayv2StageAccessLogSettings.go
- Apigatewayv2StageAccessLogSettingsOutputReference.go
- Apigatewayv2StageAccessLogSettingsOutputReference__checks.go
- Apigatewayv2StageConfig.go
- Apigatewayv2StageDefaultRouteSettings.go
- Apigatewayv2StageDefaultRouteSettingsOutputReference.go
- Apigatewayv2StageDefaultRouteSettingsOutputReference__checks.go
- Apigatewayv2StageRouteSettings.go
- Apigatewayv2StageRouteSettingsList.go
- Apigatewayv2StageRouteSettingsList__checks.go
- Apigatewayv2StageRouteSettingsOutputReference.go
- Apigatewayv2StageRouteSettingsOutputReference__checks.go
- Apigatewayv2Stage__checks.go
- main.go