Documentation
¶
Index ¶
- func BatchComputeEnvironment_IsConstruct(x interface{}) *bool
- func BatchComputeEnvironment_IsTerraformElement(x interface{}) *bool
- func BatchComputeEnvironment_IsTerraformResource(x interface{}) *bool
- func BatchComputeEnvironment_TfResourceType() *string
- func NewBatchComputeEnvironmentComputeResourcesEc2ConfigurationList_Override(b BatchComputeEnvironmentComputeResourcesEc2ConfigurationList, ...)
- func NewBatchComputeEnvironmentComputeResourcesEc2ConfigurationOutputReference_Override(b BatchComputeEnvironmentComputeResourcesEc2ConfigurationOutputReference, ...)
- func NewBatchComputeEnvironmentComputeResourcesLaunchTemplateOutputReference_Override(b BatchComputeEnvironmentComputeResourcesLaunchTemplateOutputReference, ...)
- func NewBatchComputeEnvironmentComputeResourcesOutputReference_Override(b BatchComputeEnvironmentComputeResourcesOutputReference, ...)
- func NewBatchComputeEnvironmentEksConfigurationOutputReference_Override(b BatchComputeEnvironmentEksConfigurationOutputReference, ...)
- func NewBatchComputeEnvironment_Override(b BatchComputeEnvironment, scope constructs.Construct, id *string, ...)
- type BatchComputeEnvironment
- type BatchComputeEnvironmentComputeResources
- type BatchComputeEnvironmentComputeResourcesEc2Configuration
- type BatchComputeEnvironmentComputeResourcesEc2ConfigurationList
- type BatchComputeEnvironmentComputeResourcesEc2ConfigurationOutputReference
- type BatchComputeEnvironmentComputeResourcesLaunchTemplate
- type BatchComputeEnvironmentComputeResourcesLaunchTemplateOutputReference
- type BatchComputeEnvironmentComputeResourcesOutputReference
- type BatchComputeEnvironmentConfig
- type BatchComputeEnvironmentEksConfiguration
- type BatchComputeEnvironmentEksConfigurationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BatchComputeEnvironment_IsConstruct ¶
func BatchComputeEnvironment_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func BatchComputeEnvironment_IsTerraformElement ¶
func BatchComputeEnvironment_IsTerraformElement(x interface{}) *bool
Experimental.
func BatchComputeEnvironment_IsTerraformResource ¶
func BatchComputeEnvironment_IsTerraformResource(x interface{}) *bool
Experimental.
func BatchComputeEnvironment_TfResourceType ¶
func BatchComputeEnvironment_TfResourceType() *string
func NewBatchComputeEnvironmentComputeResourcesEc2ConfigurationList_Override ¶
func NewBatchComputeEnvironmentComputeResourcesEc2ConfigurationList_Override(b BatchComputeEnvironmentComputeResourcesEc2ConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewBatchComputeEnvironmentComputeResourcesEc2ConfigurationOutputReference_Override ¶
func NewBatchComputeEnvironmentComputeResourcesEc2ConfigurationOutputReference_Override(b BatchComputeEnvironmentComputeResourcesEc2ConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewBatchComputeEnvironmentComputeResourcesLaunchTemplateOutputReference_Override ¶
func NewBatchComputeEnvironmentComputeResourcesLaunchTemplateOutputReference_Override(b BatchComputeEnvironmentComputeResourcesLaunchTemplateOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBatchComputeEnvironmentComputeResourcesOutputReference_Override ¶
func NewBatchComputeEnvironmentComputeResourcesOutputReference_Override(b BatchComputeEnvironmentComputeResourcesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBatchComputeEnvironmentEksConfigurationOutputReference_Override ¶
func NewBatchComputeEnvironmentEksConfigurationOutputReference_Override(b BatchComputeEnvironmentEksConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBatchComputeEnvironment_Override ¶
func NewBatchComputeEnvironment_Override(b BatchComputeEnvironment, scope constructs.Construct, id *string, config *BatchComputeEnvironmentConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment aws_batch_compute_environment} Resource.
Types ¶
type BatchComputeEnvironment ¶
type BatchComputeEnvironment interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ComputeEnvironmentName() *string
SetComputeEnvironmentName(val *string)
ComputeEnvironmentNameInput() *string
ComputeEnvironmentNamePrefix() *string
SetComputeEnvironmentNamePrefix(val *string)
ComputeEnvironmentNamePrefixInput() *string
ComputeResources() BatchComputeEnvironmentComputeResourcesOutputReference
ComputeResourcesInput() *BatchComputeEnvironmentComputeResources
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EcsClusterArn() *string
EksConfiguration() BatchComputeEnvironmentEksConfigurationOutputReference
EksConfigurationInput() *BatchComputeEnvironmentEksConfiguration
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ServiceRole() *string
SetServiceRole(val *string)
ServiceRoleInput() *string
State() *string
SetState(val *string)
StateInput() *string
Status() *string
StatusReason() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutComputeResources(value *BatchComputeEnvironmentComputeResources)
PutEksConfiguration(value *BatchComputeEnvironmentEksConfiguration)
ResetComputeEnvironmentName()
ResetComputeEnvironmentNamePrefix()
ResetComputeResources()
ResetEksConfiguration()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetServiceRole()
ResetState()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment aws_batch_compute_environment}.
func NewBatchComputeEnvironment ¶
func NewBatchComputeEnvironment(scope constructs.Construct, id *string, config *BatchComputeEnvironmentConfig) BatchComputeEnvironment
Create a new {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment aws_batch_compute_environment} Resource.
type BatchComputeEnvironmentComputeResources ¶
type BatchComputeEnvironmentComputeResources struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#max_vcpus BatchComputeEnvironment#max_vcpus}.
MaxVcpus *float64 `field:"required" json:"maxVcpus" yaml:"maxVcpus"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#subnets BatchComputeEnvironment#subnets}.
Subnets *[]*string `field:"required" json:"subnets" yaml:"subnets"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#type BatchComputeEnvironment#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#allocation_strategy BatchComputeEnvironment#allocation_strategy}.
AllocationStrategy *string `field:"optional" json:"allocationStrategy" yaml:"allocationStrategy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#bid_percentage BatchComputeEnvironment#bid_percentage}.
BidPercentage *float64 `field:"optional" json:"bidPercentage" yaml:"bidPercentage"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#desired_vcpus BatchComputeEnvironment#desired_vcpus}.
DesiredVcpus *float64 `field:"optional" json:"desiredVcpus" yaml:"desiredVcpus"`
// ec2_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#ec2_configuration BatchComputeEnvironment#ec2_configuration}
Ec2Configuration interface{} `field:"optional" json:"ec2Configuration" yaml:"ec2Configuration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#ec2_key_pair BatchComputeEnvironment#ec2_key_pair}.
Ec2KeyPair *string `field:"optional" json:"ec2KeyPair" yaml:"ec2KeyPair"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#image_id BatchComputeEnvironment#image_id}.
ImageId *string `field:"optional" json:"imageId" yaml:"imageId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#instance_role BatchComputeEnvironment#instance_role}.
InstanceRole *string `field:"optional" json:"instanceRole" yaml:"instanceRole"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#instance_type BatchComputeEnvironment#instance_type}.
InstanceType *[]*string `field:"optional" json:"instanceType" yaml:"instanceType"`
// launch_template block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#launch_template BatchComputeEnvironment#launch_template}
LaunchTemplate *BatchComputeEnvironmentComputeResourcesLaunchTemplate `field:"optional" json:"launchTemplate" yaml:"launchTemplate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#min_vcpus BatchComputeEnvironment#min_vcpus}.
MinVcpus *float64 `field:"optional" json:"minVcpus" yaml:"minVcpus"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#security_group_ids BatchComputeEnvironment#security_group_ids}.
SecurityGroupIds *[]*string `field:"optional" json:"securityGroupIds" yaml:"securityGroupIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#spot_iam_fleet_role BatchComputeEnvironment#spot_iam_fleet_role}.
SpotIamFleetRole *string `field:"optional" json:"spotIamFleetRole" yaml:"spotIamFleetRole"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#tags BatchComputeEnvironment#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type BatchComputeEnvironmentComputeResourcesEc2Configuration ¶
type BatchComputeEnvironmentComputeResourcesEc2Configuration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#image_id_override BatchComputeEnvironment#image_id_override}.
ImageIdOverride *string `field:"optional" json:"imageIdOverride" yaml:"imageIdOverride"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#image_type BatchComputeEnvironment#image_type}.
ImageType *string `field:"optional" json:"imageType" yaml:"imageType"`
}
type BatchComputeEnvironmentComputeResourcesEc2ConfigurationList ¶
type BatchComputeEnvironmentComputeResourcesEc2ConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) BatchComputeEnvironmentComputeResourcesEc2ConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBatchComputeEnvironmentComputeResourcesEc2ConfigurationList ¶
func NewBatchComputeEnvironmentComputeResourcesEc2ConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) BatchComputeEnvironmentComputeResourcesEc2ConfigurationList
type BatchComputeEnvironmentComputeResourcesEc2ConfigurationOutputReference ¶
type BatchComputeEnvironmentComputeResourcesEc2ConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
ImageIdOverride() *string
SetImageIdOverride(val *string)
ImageIdOverrideInput() *string
ImageType() *string
SetImageType(val *string)
ImageTypeInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetImageIdOverride()
ResetImageType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBatchComputeEnvironmentComputeResourcesEc2ConfigurationOutputReference ¶
func NewBatchComputeEnvironmentComputeResourcesEc2ConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) BatchComputeEnvironmentComputeResourcesEc2ConfigurationOutputReference
type BatchComputeEnvironmentComputeResourcesLaunchTemplate ¶
type BatchComputeEnvironmentComputeResourcesLaunchTemplate struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#launch_template_id BatchComputeEnvironment#launch_template_id}.
LaunchTemplateId *string `field:"optional" json:"launchTemplateId" yaml:"launchTemplateId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#launch_template_name BatchComputeEnvironment#launch_template_name}.
LaunchTemplateName *string `field:"optional" json:"launchTemplateName" yaml:"launchTemplateName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#version BatchComputeEnvironment#version}.
Version *string `field:"optional" json:"version" yaml:"version"`
}
type BatchComputeEnvironmentComputeResourcesLaunchTemplateOutputReference ¶
type BatchComputeEnvironmentComputeResourcesLaunchTemplateOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *BatchComputeEnvironmentComputeResourcesLaunchTemplate
SetInternalValue(val *BatchComputeEnvironmentComputeResourcesLaunchTemplate)
LaunchTemplateId() *string
SetLaunchTemplateId(val *string)
LaunchTemplateIdInput() *string
LaunchTemplateName() *string
SetLaunchTemplateName(val *string)
LaunchTemplateNameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Version() *string
SetVersion(val *string)
VersionInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetLaunchTemplateId()
ResetLaunchTemplateName()
ResetVersion()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBatchComputeEnvironmentComputeResourcesLaunchTemplateOutputReference ¶
func NewBatchComputeEnvironmentComputeResourcesLaunchTemplateOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BatchComputeEnvironmentComputeResourcesLaunchTemplateOutputReference
type BatchComputeEnvironmentComputeResourcesOutputReference ¶
type BatchComputeEnvironmentComputeResourcesOutputReference interface {
cdktf.ComplexObject
AllocationStrategy() *string
SetAllocationStrategy(val *string)
AllocationStrategyInput() *string
BidPercentage() *float64
SetBidPercentage(val *float64)
BidPercentageInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DesiredVcpus() *float64
SetDesiredVcpus(val *float64)
DesiredVcpusInput() *float64
Ec2Configuration() BatchComputeEnvironmentComputeResourcesEc2ConfigurationList
Ec2ConfigurationInput() interface{}
Ec2KeyPair() *string
SetEc2KeyPair(val *string)
Ec2KeyPairInput() *string
// Experimental.
Fqn() *string
ImageId() *string
SetImageId(val *string)
ImageIdInput() *string
InstanceRole() *string
SetInstanceRole(val *string)
InstanceRoleInput() *string
InstanceType() *[]*string
SetInstanceType(val *[]*string)
InstanceTypeInput() *[]*string
InternalValue() *BatchComputeEnvironmentComputeResources
SetInternalValue(val *BatchComputeEnvironmentComputeResources)
LaunchTemplate() BatchComputeEnvironmentComputeResourcesLaunchTemplateOutputReference
LaunchTemplateInput() *BatchComputeEnvironmentComputeResourcesLaunchTemplate
MaxVcpus() *float64
SetMaxVcpus(val *float64)
MaxVcpusInput() *float64
MinVcpus() *float64
SetMinVcpus(val *float64)
MinVcpusInput() *float64
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
SpotIamFleetRole() *string
SetSpotIamFleetRole(val *string)
SpotIamFleetRoleInput() *string
Subnets() *[]*string
SetSubnets(val *[]*string)
SubnetsInput() *[]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutEc2Configuration(value interface{})
PutLaunchTemplate(value *BatchComputeEnvironmentComputeResourcesLaunchTemplate)
ResetAllocationStrategy()
ResetBidPercentage()
ResetDesiredVcpus()
ResetEc2Configuration()
ResetEc2KeyPair()
ResetImageId()
ResetInstanceRole()
ResetInstanceType()
ResetLaunchTemplate()
ResetMinVcpus()
ResetSecurityGroupIds()
ResetSpotIamFleetRole()
ResetTags()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBatchComputeEnvironmentComputeResourcesOutputReference ¶
func NewBatchComputeEnvironmentComputeResourcesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BatchComputeEnvironmentComputeResourcesOutputReference
type BatchComputeEnvironmentConfig ¶
type BatchComputeEnvironmentConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#type BatchComputeEnvironment#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#compute_environment_name BatchComputeEnvironment#compute_environment_name}.
ComputeEnvironmentName *string `field:"optional" json:"computeEnvironmentName" yaml:"computeEnvironmentName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#compute_environment_name_prefix BatchComputeEnvironment#compute_environment_name_prefix}.
ComputeEnvironmentNamePrefix *string `field:"optional" json:"computeEnvironmentNamePrefix" yaml:"computeEnvironmentNamePrefix"`
// compute_resources block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#compute_resources BatchComputeEnvironment#compute_resources}
ComputeResources *BatchComputeEnvironmentComputeResources `field:"optional" json:"computeResources" yaml:"computeResources"`
// eks_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#eks_configuration BatchComputeEnvironment#eks_configuration}
EksConfiguration *BatchComputeEnvironmentEksConfiguration `field:"optional" json:"eksConfiguration" yaml:"eksConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#id BatchComputeEnvironment#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#service_role BatchComputeEnvironment#service_role}.
ServiceRole *string `field:"optional" json:"serviceRole" yaml:"serviceRole"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#state BatchComputeEnvironment#state}.
State *string `field:"optional" json:"state" yaml:"state"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#tags BatchComputeEnvironment#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#tags_all BatchComputeEnvironment#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type BatchComputeEnvironmentEksConfiguration ¶
type BatchComputeEnvironmentEksConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#eks_cluster_arn BatchComputeEnvironment#eks_cluster_arn}.
EksClusterArn *string `field:"required" json:"eksClusterArn" yaml:"eksClusterArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/batch_compute_environment#kubernetes_namespace BatchComputeEnvironment#kubernetes_namespace}.
KubernetesNamespace *string `field:"required" json:"kubernetesNamespace" yaml:"kubernetesNamespace"`
}
type BatchComputeEnvironmentEksConfigurationOutputReference ¶
type BatchComputeEnvironmentEksConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EksClusterArn() *string
SetEksClusterArn(val *string)
EksClusterArnInput() *string
// Experimental.
Fqn() *string
InternalValue() *BatchComputeEnvironmentEksConfiguration
SetInternalValue(val *BatchComputeEnvironmentEksConfiguration)
KubernetesNamespace() *string
SetKubernetesNamespace(val *string)
KubernetesNamespaceInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBatchComputeEnvironmentEksConfigurationOutputReference ¶
func NewBatchComputeEnvironmentEksConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BatchComputeEnvironmentEksConfigurationOutputReference
Source Files
¶
- BatchComputeEnvironment.go
- BatchComputeEnvironmentComputeResources.go
- BatchComputeEnvironmentComputeResourcesEc2Configuration.go
- BatchComputeEnvironmentComputeResourcesEc2ConfigurationList.go
- BatchComputeEnvironmentComputeResourcesEc2ConfigurationList__checks.go
- BatchComputeEnvironmentComputeResourcesEc2ConfigurationOutputReference.go
- BatchComputeEnvironmentComputeResourcesEc2ConfigurationOutputReference__checks.go
- BatchComputeEnvironmentComputeResourcesLaunchTemplate.go
- BatchComputeEnvironmentComputeResourcesLaunchTemplateOutputReference.go
- BatchComputeEnvironmentComputeResourcesLaunchTemplateOutputReference__checks.go
- BatchComputeEnvironmentComputeResourcesOutputReference.go
- BatchComputeEnvironmentComputeResourcesOutputReference__checks.go
- BatchComputeEnvironmentConfig.go
- BatchComputeEnvironmentEksConfiguration.go
- BatchComputeEnvironmentEksConfigurationOutputReference.go
- BatchComputeEnvironmentEksConfigurationOutputReference__checks.go
- BatchComputeEnvironment__checks.go
- main.go