Documentation
¶
Index ¶
- func CodeartifactRepository_IsConstruct(x interface{}) *bool
- func CodeartifactRepository_IsTerraformElement(x interface{}) *bool
- func CodeartifactRepository_IsTerraformResource(x interface{}) *bool
- func CodeartifactRepository_TfResourceType() *string
- func NewCodeartifactRepositoryExternalConnectionsOutputReference_Override(c CodeartifactRepositoryExternalConnectionsOutputReference, ...)
- func NewCodeartifactRepositoryUpstreamList_Override(c CodeartifactRepositoryUpstreamList, ...)
- func NewCodeartifactRepositoryUpstreamOutputReference_Override(c CodeartifactRepositoryUpstreamOutputReference, ...)
- func NewCodeartifactRepository_Override(c CodeartifactRepository, scope constructs.Construct, id *string, ...)
- type CodeartifactRepository
- type CodeartifactRepositoryConfig
- type CodeartifactRepositoryExternalConnections
- type CodeartifactRepositoryExternalConnectionsOutputReference
- type CodeartifactRepositoryUpstream
- type CodeartifactRepositoryUpstreamList
- type CodeartifactRepositoryUpstreamOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CodeartifactRepository_IsConstruct ¶
func CodeartifactRepository_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func CodeartifactRepository_IsTerraformElement ¶
func CodeartifactRepository_IsTerraformElement(x interface{}) *bool
Experimental.
func CodeartifactRepository_IsTerraformResource ¶
func CodeartifactRepository_IsTerraformResource(x interface{}) *bool
Experimental.
func CodeartifactRepository_TfResourceType ¶
func CodeartifactRepository_TfResourceType() *string
func NewCodeartifactRepositoryExternalConnectionsOutputReference_Override ¶
func NewCodeartifactRepositoryExternalConnectionsOutputReference_Override(c CodeartifactRepositoryExternalConnectionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCodeartifactRepositoryUpstreamList_Override ¶
func NewCodeartifactRepositoryUpstreamList_Override(c CodeartifactRepositoryUpstreamList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCodeartifactRepositoryUpstreamOutputReference_Override ¶
func NewCodeartifactRepositoryUpstreamOutputReference_Override(c CodeartifactRepositoryUpstreamOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCodeartifactRepository_Override ¶
func NewCodeartifactRepository_Override(c CodeartifactRepository, scope constructs.Construct, id *string, config *CodeartifactRepositoryConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository aws_codeartifact_repository} Resource.
Types ¶
type CodeartifactRepository ¶
type CodeartifactRepository interface {
cdktf.TerraformResource
AdministratorAccount() *string
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Domain() *string
SetDomain(val *string)
DomainInput() *string
DomainOwner() *string
SetDomainOwner(val *string)
DomainOwnerInput() *string
ExternalConnections() CodeartifactRepositoryExternalConnectionsOutputReference
ExternalConnectionsInput() *CodeartifactRepositoryExternalConnections
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Repository() *string
SetRepository(val *string)
RepositoryInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Upstream() CodeartifactRepositoryUpstreamList
UpstreamInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutExternalConnections(value *CodeartifactRepositoryExternalConnections)
PutUpstream(value interface{})
ResetDescription()
ResetDomainOwner()
ResetExternalConnections()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
ResetUpstream()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository aws_codeartifact_repository}.
func NewCodeartifactRepository ¶
func NewCodeartifactRepository(scope constructs.Construct, id *string, config *CodeartifactRepositoryConfig) CodeartifactRepository
Create a new {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository aws_codeartifact_repository} Resource.
type CodeartifactRepositoryConfig ¶
type CodeartifactRepositoryConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#domain CodeartifactRepository#domain}.
Domain *string `field:"required" json:"domain" yaml:"domain"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#repository CodeartifactRepository#repository}.
Repository *string `field:"required" json:"repository" yaml:"repository"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#description CodeartifactRepository#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#domain_owner CodeartifactRepository#domain_owner}.
DomainOwner *string `field:"optional" json:"domainOwner" yaml:"domainOwner"`
// external_connections block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#external_connections CodeartifactRepository#external_connections}
ExternalConnections *CodeartifactRepositoryExternalConnections `field:"optional" json:"externalConnections" yaml:"externalConnections"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#id CodeartifactRepository#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#tags CodeartifactRepository#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#tags_all CodeartifactRepository#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// upstream block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#upstream CodeartifactRepository#upstream}
Upstream interface{} `field:"optional" json:"upstream" yaml:"upstream"`
}
type CodeartifactRepositoryExternalConnections ¶
type CodeartifactRepositoryExternalConnections struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#external_connection_name CodeartifactRepository#external_connection_name}.
ExternalConnectionName *string `field:"required" json:"externalConnectionName" yaml:"externalConnectionName"`
}
type CodeartifactRepositoryExternalConnectionsOutputReference ¶
type CodeartifactRepositoryExternalConnectionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
ExternalConnectionName() *string
SetExternalConnectionName(val *string)
ExternalConnectionNameInput() *string
// Experimental.
Fqn() *string
InternalValue() *CodeartifactRepositoryExternalConnections
SetInternalValue(val *CodeartifactRepositoryExternalConnections)
PackageFormat() *string
Status() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCodeartifactRepositoryExternalConnectionsOutputReference ¶
func NewCodeartifactRepositoryExternalConnectionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CodeartifactRepositoryExternalConnectionsOutputReference
type CodeartifactRepositoryUpstream ¶
type CodeartifactRepositoryUpstream struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#repository_name CodeartifactRepository#repository_name}.
RepositoryName *string `field:"required" json:"repositoryName" yaml:"repositoryName"`
}
type CodeartifactRepositoryUpstreamList ¶
type CodeartifactRepositoryUpstreamList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CodeartifactRepositoryUpstreamOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCodeartifactRepositoryUpstreamList ¶
func NewCodeartifactRepositoryUpstreamList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CodeartifactRepositoryUpstreamList
type CodeartifactRepositoryUpstreamOutputReference ¶
type CodeartifactRepositoryUpstreamOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
RepositoryName() *string
SetRepositoryName(val *string)
RepositoryNameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCodeartifactRepositoryUpstreamOutputReference ¶
func NewCodeartifactRepositoryUpstreamOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CodeartifactRepositoryUpstreamOutputReference
Source Files
¶
- CodeartifactRepository.go
- CodeartifactRepositoryConfig.go
- CodeartifactRepositoryExternalConnections.go
- CodeartifactRepositoryExternalConnectionsOutputReference.go
- CodeartifactRepositoryExternalConnectionsOutputReference__checks.go
- CodeartifactRepositoryUpstream.go
- CodeartifactRepositoryUpstreamList.go
- CodeartifactRepositoryUpstreamList__checks.go
- CodeartifactRepositoryUpstreamOutputReference.go
- CodeartifactRepositoryUpstreamOutputReference__checks.go
- CodeartifactRepository__checks.go
- main.go