Documentation
¶
Index ¶
- func CognitoManagedUserPoolClient_IsConstruct(x interface{}) *bool
- func CognitoManagedUserPoolClient_IsTerraformElement(x interface{}) *bool
- func CognitoManagedUserPoolClient_IsTerraformResource(x interface{}) *bool
- func CognitoManagedUserPoolClient_TfResourceType() *string
- func NewCognitoManagedUserPoolClientAnalyticsConfigurationList_Override(c CognitoManagedUserPoolClientAnalyticsConfigurationList, ...)
- func NewCognitoManagedUserPoolClientAnalyticsConfigurationOutputReference_Override(c CognitoManagedUserPoolClientAnalyticsConfigurationOutputReference, ...)
- func NewCognitoManagedUserPoolClientTokenValidityUnitsList_Override(c CognitoManagedUserPoolClientTokenValidityUnitsList, ...)
- func NewCognitoManagedUserPoolClientTokenValidityUnitsOutputReference_Override(c CognitoManagedUserPoolClientTokenValidityUnitsOutputReference, ...)
- func NewCognitoManagedUserPoolClient_Override(c CognitoManagedUserPoolClient, scope constructs.Construct, id *string, ...)
- type CognitoManagedUserPoolClient
- type CognitoManagedUserPoolClientAnalyticsConfiguration
- type CognitoManagedUserPoolClientAnalyticsConfigurationList
- type CognitoManagedUserPoolClientAnalyticsConfigurationOutputReference
- type CognitoManagedUserPoolClientConfig
- type CognitoManagedUserPoolClientTokenValidityUnits
- type CognitoManagedUserPoolClientTokenValidityUnitsList
- type CognitoManagedUserPoolClientTokenValidityUnitsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CognitoManagedUserPoolClient_IsConstruct ¶
func CognitoManagedUserPoolClient_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func CognitoManagedUserPoolClient_IsTerraformElement ¶
func CognitoManagedUserPoolClient_IsTerraformElement(x interface{}) *bool
Experimental.
func CognitoManagedUserPoolClient_IsTerraformResource ¶
func CognitoManagedUserPoolClient_IsTerraformResource(x interface{}) *bool
Experimental.
func CognitoManagedUserPoolClient_TfResourceType ¶
func CognitoManagedUserPoolClient_TfResourceType() *string
func NewCognitoManagedUserPoolClientAnalyticsConfigurationList_Override ¶
func NewCognitoManagedUserPoolClientAnalyticsConfigurationList_Override(c CognitoManagedUserPoolClientAnalyticsConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCognitoManagedUserPoolClientAnalyticsConfigurationOutputReference_Override ¶
func NewCognitoManagedUserPoolClientAnalyticsConfigurationOutputReference_Override(c CognitoManagedUserPoolClientAnalyticsConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCognitoManagedUserPoolClientTokenValidityUnitsList_Override ¶
func NewCognitoManagedUserPoolClientTokenValidityUnitsList_Override(c CognitoManagedUserPoolClientTokenValidityUnitsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCognitoManagedUserPoolClientTokenValidityUnitsOutputReference_Override ¶
func NewCognitoManagedUserPoolClientTokenValidityUnitsOutputReference_Override(c CognitoManagedUserPoolClientTokenValidityUnitsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCognitoManagedUserPoolClient_Override ¶
func NewCognitoManagedUserPoolClient_Override(c CognitoManagedUserPoolClient, scope constructs.Construct, id *string, config *CognitoManagedUserPoolClientConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client aws_cognito_managed_user_pool_client} Resource.
Types ¶
type CognitoManagedUserPoolClient ¶
type CognitoManagedUserPoolClient interface {
cdktf.TerraformResource
AccessTokenValidity() *float64
SetAccessTokenValidity(val *float64)
AccessTokenValidityInput() *float64
AllowedOauthFlows() *[]*string
SetAllowedOauthFlows(val *[]*string)
AllowedOauthFlowsInput() *[]*string
AllowedOauthFlowsUserPoolClient() interface{}
SetAllowedOauthFlowsUserPoolClient(val interface{})
AllowedOauthFlowsUserPoolClientInput() interface{}
AllowedOauthScopes() *[]*string
SetAllowedOauthScopes(val *[]*string)
AllowedOauthScopesInput() *[]*string
AnalyticsConfiguration() CognitoManagedUserPoolClientAnalyticsConfigurationList
AnalyticsConfigurationInput() interface{}
AuthSessionValidity() *float64
SetAuthSessionValidity(val *float64)
AuthSessionValidityInput() *float64
CallbackUrls() *[]*string
SetCallbackUrls(val *[]*string)
CallbackUrlsInput() *[]*string
// Experimental.
CdktfStack() cdktf.TerraformStack
ClientSecret() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DefaultRedirectUri() *string
SetDefaultRedirectUri(val *string)
DefaultRedirectUriInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EnablePropagateAdditionalUserContextData() interface{}
SetEnablePropagateAdditionalUserContextData(val interface{})
EnablePropagateAdditionalUserContextDataInput() interface{}
EnableTokenRevocation() interface{}
SetEnableTokenRevocation(val interface{})
EnableTokenRevocationInput() interface{}
ExplicitAuthFlows() *[]*string
SetExplicitAuthFlows(val *[]*string)
ExplicitAuthFlowsInput() *[]*string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
IdTokenValidity() *float64
SetIdTokenValidity(val *float64)
IdTokenValidityInput() *float64
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LogoutUrls() *[]*string
SetLogoutUrls(val *[]*string)
LogoutUrlsInput() *[]*string
Name() *string
NamePattern() *string
SetNamePattern(val *string)
NamePatternInput() *string
NamePrefix() *string
SetNamePrefix(val *string)
NamePrefixInput() *string
// The tree node.
Node() constructs.Node
PreventUserExistenceErrors() *string
SetPreventUserExistenceErrors(val *string)
PreventUserExistenceErrorsInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ReadAttributes() *[]*string
SetReadAttributes(val *[]*string)
ReadAttributesInput() *[]*string
RefreshTokenValidity() *float64
SetRefreshTokenValidity(val *float64)
RefreshTokenValidityInput() *float64
SupportedIdentityProviders() *[]*string
SetSupportedIdentityProviders(val *[]*string)
SupportedIdentityProvidersInput() *[]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
TokenValidityUnits() CognitoManagedUserPoolClientTokenValidityUnitsList
TokenValidityUnitsInput() interface{}
UserPoolId() *string
SetUserPoolId(val *string)
UserPoolIdInput() *string
WriteAttributes() *[]*string
SetWriteAttributes(val *[]*string)
WriteAttributesInput() *[]*string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAnalyticsConfiguration(value interface{})
PutTokenValidityUnits(value interface{})
ResetAccessTokenValidity()
ResetAllowedOauthFlows()
ResetAllowedOauthFlowsUserPoolClient()
ResetAllowedOauthScopes()
ResetAnalyticsConfiguration()
ResetAuthSessionValidity()
ResetCallbackUrls()
ResetDefaultRedirectUri()
ResetEnablePropagateAdditionalUserContextData()
ResetEnableTokenRevocation()
ResetExplicitAuthFlows()
ResetIdTokenValidity()
ResetLogoutUrls()
ResetNamePattern()
ResetNamePrefix()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPreventUserExistenceErrors()
ResetReadAttributes()
ResetRefreshTokenValidity()
ResetSupportedIdentityProviders()
ResetTokenValidityUnits()
ResetWriteAttributes()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client aws_cognito_managed_user_pool_client}.
func NewCognitoManagedUserPoolClient ¶
func NewCognitoManagedUserPoolClient(scope constructs.Construct, id *string, config *CognitoManagedUserPoolClientConfig) CognitoManagedUserPoolClient
Create a new {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client aws_cognito_managed_user_pool_client} Resource.
type CognitoManagedUserPoolClientAnalyticsConfiguration ¶
type CognitoManagedUserPoolClientAnalyticsConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#application_arn CognitoManagedUserPoolClient#application_arn}.
ApplicationArn *string `field:"optional" json:"applicationArn" yaml:"applicationArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#application_id CognitoManagedUserPoolClient#application_id}.
ApplicationId *string `field:"optional" json:"applicationId" yaml:"applicationId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#external_id CognitoManagedUserPoolClient#external_id}.
ExternalId *string `field:"optional" json:"externalId" yaml:"externalId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#role_arn CognitoManagedUserPoolClient#role_arn}.
RoleArn *string `field:"optional" json:"roleArn" yaml:"roleArn"`
UserDataShared interface{} `field:"optional" json:"userDataShared" yaml:"userDataShared"`
}
type CognitoManagedUserPoolClientAnalyticsConfigurationList ¶
type CognitoManagedUserPoolClientAnalyticsConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CognitoManagedUserPoolClientAnalyticsConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCognitoManagedUserPoolClientAnalyticsConfigurationList ¶
func NewCognitoManagedUserPoolClientAnalyticsConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CognitoManagedUserPoolClientAnalyticsConfigurationList
type CognitoManagedUserPoolClientAnalyticsConfigurationOutputReference ¶
type CognitoManagedUserPoolClientAnalyticsConfigurationOutputReference interface {
cdktf.ComplexObject
ApplicationArn() *string
SetApplicationArn(val *string)
ApplicationArnInput() *string
ApplicationId() *string
SetApplicationId(val *string)
ApplicationIdInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
ExternalId() *string
SetExternalId(val *string)
ExternalIdInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetApplicationArn()
ResetApplicationId()
ResetExternalId()
ResetRoleArn()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCognitoManagedUserPoolClientAnalyticsConfigurationOutputReference ¶
func NewCognitoManagedUserPoolClientAnalyticsConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CognitoManagedUserPoolClientAnalyticsConfigurationOutputReference
type CognitoManagedUserPoolClientConfig ¶
type CognitoManagedUserPoolClientConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#user_pool_id CognitoManagedUserPoolClient#user_pool_id}.
UserPoolId *string `field:"required" json:"userPoolId" yaml:"userPoolId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#access_token_validity CognitoManagedUserPoolClient#access_token_validity}.
AccessTokenValidity *float64 `field:"optional" json:"accessTokenValidity" yaml:"accessTokenValidity"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#allowed_oauth_flows CognitoManagedUserPoolClient#allowed_oauth_flows}.
AllowedOauthFlows *[]*string `field:"optional" json:"allowedOauthFlows" yaml:"allowedOauthFlows"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#allowed_oauth_flows_user_pool_client CognitoManagedUserPoolClient#allowed_oauth_flows_user_pool_client}.
AllowedOauthFlowsUserPoolClient interface{} `field:"optional" json:"allowedOauthFlowsUserPoolClient" yaml:"allowedOauthFlowsUserPoolClient"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#allowed_oauth_scopes CognitoManagedUserPoolClient#allowed_oauth_scopes}.
AllowedOauthScopes *[]*string `field:"optional" json:"allowedOauthScopes" yaml:"allowedOauthScopes"`
// analytics_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#analytics_configuration CognitoManagedUserPoolClient#analytics_configuration}
AnalyticsConfiguration interface{} `field:"optional" json:"analyticsConfiguration" yaml:"analyticsConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#auth_session_validity CognitoManagedUserPoolClient#auth_session_validity}.
AuthSessionValidity *float64 `field:"optional" json:"authSessionValidity" yaml:"authSessionValidity"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#callback_urls CognitoManagedUserPoolClient#callback_urls}.
CallbackUrls *[]*string `field:"optional" json:"callbackUrls" yaml:"callbackUrls"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#default_redirect_uri CognitoManagedUserPoolClient#default_redirect_uri}.
DefaultRedirectUri *string `field:"optional" json:"defaultRedirectUri" yaml:"defaultRedirectUri"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#enable_propagate_additional_user_context_data CognitoManagedUserPoolClient#enable_propagate_additional_user_context_data}.
EnablePropagateAdditionalUserContextData interface{} `field:"optional" json:"enablePropagateAdditionalUserContextData" yaml:"enablePropagateAdditionalUserContextData"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#enable_token_revocation CognitoManagedUserPoolClient#enable_token_revocation}.
EnableTokenRevocation interface{} `field:"optional" json:"enableTokenRevocation" yaml:"enableTokenRevocation"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#explicit_auth_flows CognitoManagedUserPoolClient#explicit_auth_flows}.
ExplicitAuthFlows *[]*string `field:"optional" json:"explicitAuthFlows" yaml:"explicitAuthFlows"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#id_token_validity CognitoManagedUserPoolClient#id_token_validity}.
IdTokenValidity *float64 `field:"optional" json:"idTokenValidity" yaml:"idTokenValidity"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#logout_urls CognitoManagedUserPoolClient#logout_urls}.
LogoutUrls *[]*string `field:"optional" json:"logoutUrls" yaml:"logoutUrls"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#name_pattern CognitoManagedUserPoolClient#name_pattern}.
NamePattern *string `field:"optional" json:"namePattern" yaml:"namePattern"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#name_prefix CognitoManagedUserPoolClient#name_prefix}.
NamePrefix *string `field:"optional" json:"namePrefix" yaml:"namePrefix"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#prevent_user_existence_errors CognitoManagedUserPoolClient#prevent_user_existence_errors}.
PreventUserExistenceErrors *string `field:"optional" json:"preventUserExistenceErrors" yaml:"preventUserExistenceErrors"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#read_attributes CognitoManagedUserPoolClient#read_attributes}.
ReadAttributes *[]*string `field:"optional" json:"readAttributes" yaml:"readAttributes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#refresh_token_validity CognitoManagedUserPoolClient#refresh_token_validity}.
RefreshTokenValidity *float64 `field:"optional" json:"refreshTokenValidity" yaml:"refreshTokenValidity"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#supported_identity_providers CognitoManagedUserPoolClient#supported_identity_providers}.
SupportedIdentityProviders *[]*string `field:"optional" json:"supportedIdentityProviders" yaml:"supportedIdentityProviders"`
// token_validity_units block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#token_validity_units CognitoManagedUserPoolClient#token_validity_units}
TokenValidityUnits interface{} `field:"optional" json:"tokenValidityUnits" yaml:"tokenValidityUnits"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#write_attributes CognitoManagedUserPoolClient#write_attributes}.
WriteAttributes *[]*string `field:"optional" json:"writeAttributes" yaml:"writeAttributes"`
}
type CognitoManagedUserPoolClientTokenValidityUnits ¶
type CognitoManagedUserPoolClientTokenValidityUnits struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#access_token CognitoManagedUserPoolClient#access_token}.
AccessToken *string `field:"optional" json:"accessToken" yaml:"accessToken"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#id_token CognitoManagedUserPoolClient#id_token}.
IdToken *string `field:"optional" json:"idToken" yaml:"idToken"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_managed_user_pool_client#refresh_token CognitoManagedUserPoolClient#refresh_token}.
RefreshToken *string `field:"optional" json:"refreshToken" yaml:"refreshToken"`
}
type CognitoManagedUserPoolClientTokenValidityUnitsList ¶
type CognitoManagedUserPoolClientTokenValidityUnitsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CognitoManagedUserPoolClientTokenValidityUnitsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCognitoManagedUserPoolClientTokenValidityUnitsList ¶
func NewCognitoManagedUserPoolClientTokenValidityUnitsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CognitoManagedUserPoolClientTokenValidityUnitsList
type CognitoManagedUserPoolClientTokenValidityUnitsOutputReference ¶
type CognitoManagedUserPoolClientTokenValidityUnitsOutputReference interface {
cdktf.ComplexObject
AccessToken() *string
SetAccessToken(val *string)
AccessTokenInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IdToken() *string
SetIdToken(val *string)
IdTokenInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
RefreshToken() *string
SetRefreshToken(val *string)
RefreshTokenInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAccessToken()
ResetIdToken()
ResetRefreshToken()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCognitoManagedUserPoolClientTokenValidityUnitsOutputReference ¶
func NewCognitoManagedUserPoolClientTokenValidityUnitsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CognitoManagedUserPoolClientTokenValidityUnitsOutputReference
Source Files
¶
- CognitoManagedUserPoolClient.go
- CognitoManagedUserPoolClientAnalyticsConfiguration.go
- CognitoManagedUserPoolClientAnalyticsConfigurationList.go
- CognitoManagedUserPoolClientAnalyticsConfigurationList__checks.go
- CognitoManagedUserPoolClientAnalyticsConfigurationOutputReference.go
- CognitoManagedUserPoolClientAnalyticsConfigurationOutputReference__checks.go
- CognitoManagedUserPoolClientConfig.go
- CognitoManagedUserPoolClientTokenValidityUnits.go
- CognitoManagedUserPoolClientTokenValidityUnitsList.go
- CognitoManagedUserPoolClientTokenValidityUnitsList__checks.go
- CognitoManagedUserPoolClientTokenValidityUnitsOutputReference.go
- CognitoManagedUserPoolClientTokenValidityUnitsOutputReference__checks.go
- CognitoManagedUserPoolClient__checks.go
- main.go