Documentation
¶
Index ¶
- func ConfigRemediationConfiguration_IsConstruct(x interface{}) *bool
- func ConfigRemediationConfiguration_IsTerraformElement(x interface{}) *bool
- func ConfigRemediationConfiguration_IsTerraformResource(x interface{}) *bool
- func ConfigRemediationConfiguration_TfResourceType() *string
- func NewConfigRemediationConfigurationExecutionControlsOutputReference_Override(c ConfigRemediationConfigurationExecutionControlsOutputReference, ...)
- func NewConfigRemediationConfigurationExecutionControlsSsmControlsOutputReference_Override(c ConfigRemediationConfigurationExecutionControlsSsmControlsOutputReference, ...)
- func NewConfigRemediationConfigurationParameterList_Override(c ConfigRemediationConfigurationParameterList, ...)
- func NewConfigRemediationConfigurationParameterOutputReference_Override(c ConfigRemediationConfigurationParameterOutputReference, ...)
- func NewConfigRemediationConfiguration_Override(c ConfigRemediationConfiguration, scope constructs.Construct, id *string, ...)
- type ConfigRemediationConfiguration
- type ConfigRemediationConfigurationConfig
- type ConfigRemediationConfigurationExecutionControls
- type ConfigRemediationConfigurationExecutionControlsOutputReference
- type ConfigRemediationConfigurationExecutionControlsSsmControls
- type ConfigRemediationConfigurationExecutionControlsSsmControlsOutputReference
- type ConfigRemediationConfigurationParameter
- type ConfigRemediationConfigurationParameterList
- type ConfigRemediationConfigurationParameterOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConfigRemediationConfiguration_IsConstruct ¶
func ConfigRemediationConfiguration_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ConfigRemediationConfiguration_IsTerraformElement ¶
func ConfigRemediationConfiguration_IsTerraformElement(x interface{}) *bool
Experimental.
func ConfigRemediationConfiguration_IsTerraformResource ¶
func ConfigRemediationConfiguration_IsTerraformResource(x interface{}) *bool
Experimental.
func ConfigRemediationConfiguration_TfResourceType ¶
func ConfigRemediationConfiguration_TfResourceType() *string
func NewConfigRemediationConfigurationExecutionControlsOutputReference_Override ¶
func NewConfigRemediationConfigurationExecutionControlsOutputReference_Override(c ConfigRemediationConfigurationExecutionControlsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewConfigRemediationConfigurationExecutionControlsSsmControlsOutputReference_Override ¶
func NewConfigRemediationConfigurationExecutionControlsSsmControlsOutputReference_Override(c ConfigRemediationConfigurationExecutionControlsSsmControlsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewConfigRemediationConfigurationParameterList_Override ¶
func NewConfigRemediationConfigurationParameterList_Override(c ConfigRemediationConfigurationParameterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewConfigRemediationConfigurationParameterOutputReference_Override ¶
func NewConfigRemediationConfigurationParameterOutputReference_Override(c ConfigRemediationConfigurationParameterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewConfigRemediationConfiguration_Override ¶
func NewConfigRemediationConfiguration_Override(c ConfigRemediationConfiguration, scope constructs.Construct, id *string, config *ConfigRemediationConfigurationConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration aws_config_remediation_configuration} Resource.
Types ¶
type ConfigRemediationConfiguration ¶
type ConfigRemediationConfiguration interface {
cdktf.TerraformResource
Arn() *string
Automatic() interface{}
SetAutomatic(val interface{})
AutomaticInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
ConfigRuleName() *string
SetConfigRuleName(val *string)
ConfigRuleNameInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
ExecutionControls() ConfigRemediationConfigurationExecutionControlsOutputReference
ExecutionControlsInput() *ConfigRemediationConfigurationExecutionControls
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaximumAutomaticAttempts() *float64
SetMaximumAutomaticAttempts(val *float64)
MaximumAutomaticAttemptsInput() *float64
// The tree node.
Node() constructs.Node
Parameter() ConfigRemediationConfigurationParameterList
ParameterInput() interface{}
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ResourceType() *string
SetResourceType(val *string)
ResourceTypeInput() *string
RetryAttemptSeconds() *float64
SetRetryAttemptSeconds(val *float64)
RetryAttemptSecondsInput() *float64
TargetId() *string
SetTargetId(val *string)
TargetIdInput() *string
TargetType() *string
SetTargetType(val *string)
TargetTypeInput() *string
TargetVersion() *string
SetTargetVersion(val *string)
TargetVersionInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutExecutionControls(value *ConfigRemediationConfigurationExecutionControls)
PutParameter(value interface{})
ResetAutomatic()
ResetExecutionControls()
ResetId()
ResetMaximumAutomaticAttempts()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetParameter()
ResetResourceType()
ResetRetryAttemptSeconds()
ResetTargetVersion()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration aws_config_remediation_configuration}.
func NewConfigRemediationConfiguration ¶
func NewConfigRemediationConfiguration(scope constructs.Construct, id *string, config *ConfigRemediationConfigurationConfig) ConfigRemediationConfiguration
Create a new {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration aws_config_remediation_configuration} Resource.
type ConfigRemediationConfigurationConfig ¶
type ConfigRemediationConfigurationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration#config_rule_name ConfigRemediationConfiguration#config_rule_name}.
ConfigRuleName *string `field:"required" json:"configRuleName" yaml:"configRuleName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration#target_id ConfigRemediationConfiguration#target_id}.
TargetId *string `field:"required" json:"targetId" yaml:"targetId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration#target_type ConfigRemediationConfiguration#target_type}.
TargetType *string `field:"required" json:"targetType" yaml:"targetType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration#automatic ConfigRemediationConfiguration#automatic}.
Automatic interface{} `field:"optional" json:"automatic" yaml:"automatic"`
// execution_controls block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration#execution_controls ConfigRemediationConfiguration#execution_controls}
ExecutionControls *ConfigRemediationConfigurationExecutionControls `field:"optional" json:"executionControls" yaml:"executionControls"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration#id ConfigRemediationConfiguration#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration#maximum_automatic_attempts ConfigRemediationConfiguration#maximum_automatic_attempts}.
MaximumAutomaticAttempts *float64 `field:"optional" json:"maximumAutomaticAttempts" yaml:"maximumAutomaticAttempts"`
// parameter block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration#parameter ConfigRemediationConfiguration#parameter}
Parameter interface{} `field:"optional" json:"parameter" yaml:"parameter"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration#resource_type ConfigRemediationConfiguration#resource_type}.
ResourceType *string `field:"optional" json:"resourceType" yaml:"resourceType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration#retry_attempt_seconds ConfigRemediationConfiguration#retry_attempt_seconds}.
RetryAttemptSeconds *float64 `field:"optional" json:"retryAttemptSeconds" yaml:"retryAttemptSeconds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration#target_version ConfigRemediationConfiguration#target_version}.
TargetVersion *string `field:"optional" json:"targetVersion" yaml:"targetVersion"`
}
type ConfigRemediationConfigurationExecutionControls ¶
type ConfigRemediationConfigurationExecutionControls struct {
// ssm_controls block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration#ssm_controls ConfigRemediationConfiguration#ssm_controls}
SsmControls *ConfigRemediationConfigurationExecutionControlsSsmControls `field:"optional" json:"ssmControls" yaml:"ssmControls"`
}
type ConfigRemediationConfigurationExecutionControlsOutputReference ¶
type ConfigRemediationConfigurationExecutionControlsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ConfigRemediationConfigurationExecutionControls
SetInternalValue(val *ConfigRemediationConfigurationExecutionControls)
SsmControls() ConfigRemediationConfigurationExecutionControlsSsmControlsOutputReference
SsmControlsInput() *ConfigRemediationConfigurationExecutionControlsSsmControls
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutSsmControls(value *ConfigRemediationConfigurationExecutionControlsSsmControls)
ResetSsmControls()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConfigRemediationConfigurationExecutionControlsOutputReference ¶
func NewConfigRemediationConfigurationExecutionControlsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ConfigRemediationConfigurationExecutionControlsOutputReference
type ConfigRemediationConfigurationExecutionControlsSsmControls ¶
type ConfigRemediationConfigurationExecutionControlsSsmControls struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration#concurrent_execution_rate_percentage ConfigRemediationConfiguration#concurrent_execution_rate_percentage}.
ConcurrentExecutionRatePercentage *float64 `field:"optional" json:"concurrentExecutionRatePercentage" yaml:"concurrentExecutionRatePercentage"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration#error_percentage ConfigRemediationConfiguration#error_percentage}.
ErrorPercentage *float64 `field:"optional" json:"errorPercentage" yaml:"errorPercentage"`
}
type ConfigRemediationConfigurationExecutionControlsSsmControlsOutputReference ¶
type ConfigRemediationConfigurationExecutionControlsSsmControlsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ConcurrentExecutionRatePercentage() *float64
SetConcurrentExecutionRatePercentage(val *float64)
ConcurrentExecutionRatePercentageInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
ErrorPercentage() *float64
SetErrorPercentage(val *float64)
ErrorPercentageInput() *float64
// Experimental.
Fqn() *string
InternalValue() *ConfigRemediationConfigurationExecutionControlsSsmControls
SetInternalValue(val *ConfigRemediationConfigurationExecutionControlsSsmControls)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetConcurrentExecutionRatePercentage()
ResetErrorPercentage()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConfigRemediationConfigurationExecutionControlsSsmControlsOutputReference ¶
func NewConfigRemediationConfigurationExecutionControlsSsmControlsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ConfigRemediationConfigurationExecutionControlsSsmControlsOutputReference
type ConfigRemediationConfigurationParameter ¶
type ConfigRemediationConfigurationParameter struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration#name ConfigRemediationConfiguration#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration#resource_value ConfigRemediationConfiguration#resource_value}.
ResourceValue *string `field:"optional" json:"resourceValue" yaml:"resourceValue"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration#static_value ConfigRemediationConfiguration#static_value}.
StaticValue *string `field:"optional" json:"staticValue" yaml:"staticValue"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_remediation_configuration#static_values ConfigRemediationConfiguration#static_values}.
StaticValues *[]*string `field:"optional" json:"staticValues" yaml:"staticValues"`
}
type ConfigRemediationConfigurationParameterList ¶
type ConfigRemediationConfigurationParameterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ConfigRemediationConfigurationParameterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConfigRemediationConfigurationParameterList ¶
func NewConfigRemediationConfigurationParameterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ConfigRemediationConfigurationParameterList
type ConfigRemediationConfigurationParameterOutputReference ¶
type ConfigRemediationConfigurationParameterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
ResourceValue() *string
SetResourceValue(val *string)
ResourceValueInput() *string
StaticValue() *string
SetStaticValue(val *string)
StaticValueInput() *string
StaticValues() *[]*string
SetStaticValues(val *[]*string)
StaticValuesInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetResourceValue()
ResetStaticValue()
ResetStaticValues()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConfigRemediationConfigurationParameterOutputReference ¶
func NewConfigRemediationConfigurationParameterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ConfigRemediationConfigurationParameterOutputReference
Source Files
¶
- ConfigRemediationConfiguration.go
- ConfigRemediationConfigurationConfig.go
- ConfigRemediationConfigurationExecutionControls.go
- ConfigRemediationConfigurationExecutionControlsOutputReference.go
- ConfigRemediationConfigurationExecutionControlsOutputReference__checks.go
- ConfigRemediationConfigurationExecutionControlsSsmControls.go
- ConfigRemediationConfigurationExecutionControlsSsmControlsOutputReference.go
- ConfigRemediationConfigurationExecutionControlsSsmControlsOutputReference__checks.go
- ConfigRemediationConfigurationParameter.go
- ConfigRemediationConfigurationParameterList.go
- ConfigRemediationConfigurationParameterList__checks.go
- ConfigRemediationConfigurationParameterOutputReference.go
- ConfigRemediationConfigurationParameterOutputReference__checks.go
- ConfigRemediationConfiguration__checks.go
- main.go