Documentation
¶
Index ¶
- func ConnectUserHierarchyGroup_IsConstruct(x interface{}) *bool
- func ConnectUserHierarchyGroup_IsTerraformElement(x interface{}) *bool
- func ConnectUserHierarchyGroup_IsTerraformResource(x interface{}) *bool
- func ConnectUserHierarchyGroup_TfResourceType() *string
- func NewConnectUserHierarchyGroupHierarchyPathLevelFiveList_Override(c ConnectUserHierarchyGroupHierarchyPathLevelFiveList, ...)
- func NewConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference_Override(c ConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference, ...)
- func NewConnectUserHierarchyGroupHierarchyPathLevelFourList_Override(c ConnectUserHierarchyGroupHierarchyPathLevelFourList, ...)
- func NewConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference_Override(c ConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference, ...)
- func NewConnectUserHierarchyGroupHierarchyPathLevelOneList_Override(c ConnectUserHierarchyGroupHierarchyPathLevelOneList, ...)
- func NewConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference_Override(c ConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference, ...)
- func NewConnectUserHierarchyGroupHierarchyPathLevelThreeList_Override(c ConnectUserHierarchyGroupHierarchyPathLevelThreeList, ...)
- func NewConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference_Override(c ConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference, ...)
- func NewConnectUserHierarchyGroupHierarchyPathLevelTwoList_Override(c ConnectUserHierarchyGroupHierarchyPathLevelTwoList, ...)
- func NewConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference_Override(c ConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference, ...)
- func NewConnectUserHierarchyGroupHierarchyPathList_Override(c ConnectUserHierarchyGroupHierarchyPathList, ...)
- func NewConnectUserHierarchyGroupHierarchyPathOutputReference_Override(c ConnectUserHierarchyGroupHierarchyPathOutputReference, ...)
- func NewConnectUserHierarchyGroup_Override(c ConnectUserHierarchyGroup, scope constructs.Construct, id *string, ...)
- type ConnectUserHierarchyGroup
- type ConnectUserHierarchyGroupConfig
- type ConnectUserHierarchyGroupHierarchyPath
- type ConnectUserHierarchyGroupHierarchyPathLevelFive
- type ConnectUserHierarchyGroupHierarchyPathLevelFiveList
- type ConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference
- type ConnectUserHierarchyGroupHierarchyPathLevelFour
- type ConnectUserHierarchyGroupHierarchyPathLevelFourList
- type ConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference
- type ConnectUserHierarchyGroupHierarchyPathLevelOne
- type ConnectUserHierarchyGroupHierarchyPathLevelOneList
- type ConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference
- type ConnectUserHierarchyGroupHierarchyPathLevelThree
- type ConnectUserHierarchyGroupHierarchyPathLevelThreeList
- type ConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference
- type ConnectUserHierarchyGroupHierarchyPathLevelTwo
- type ConnectUserHierarchyGroupHierarchyPathLevelTwoList
- type ConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference
- type ConnectUserHierarchyGroupHierarchyPathList
- type ConnectUserHierarchyGroupHierarchyPathOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConnectUserHierarchyGroup_IsConstruct ¶
func ConnectUserHierarchyGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ConnectUserHierarchyGroup_IsTerraformElement ¶
func ConnectUserHierarchyGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func ConnectUserHierarchyGroup_IsTerraformResource ¶
func ConnectUserHierarchyGroup_IsTerraformResource(x interface{}) *bool
Experimental.
func ConnectUserHierarchyGroup_TfResourceType ¶
func ConnectUserHierarchyGroup_TfResourceType() *string
func NewConnectUserHierarchyGroupHierarchyPathLevelFiveList_Override ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelFiveList_Override(c ConnectUserHierarchyGroupHierarchyPathLevelFiveList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference_Override ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference_Override(c ConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewConnectUserHierarchyGroupHierarchyPathLevelFourList_Override ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelFourList_Override(c ConnectUserHierarchyGroupHierarchyPathLevelFourList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference_Override ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference_Override(c ConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewConnectUserHierarchyGroupHierarchyPathLevelOneList_Override ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelOneList_Override(c ConnectUserHierarchyGroupHierarchyPathLevelOneList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference_Override ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference_Override(c ConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewConnectUserHierarchyGroupHierarchyPathLevelThreeList_Override ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelThreeList_Override(c ConnectUserHierarchyGroupHierarchyPathLevelThreeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference_Override ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference_Override(c ConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewConnectUserHierarchyGroupHierarchyPathLevelTwoList_Override ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelTwoList_Override(c ConnectUserHierarchyGroupHierarchyPathLevelTwoList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference_Override ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference_Override(c ConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewConnectUserHierarchyGroupHierarchyPathList_Override ¶
func NewConnectUserHierarchyGroupHierarchyPathList_Override(c ConnectUserHierarchyGroupHierarchyPathList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewConnectUserHierarchyGroupHierarchyPathOutputReference_Override ¶
func NewConnectUserHierarchyGroupHierarchyPathOutputReference_Override(c ConnectUserHierarchyGroupHierarchyPathOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewConnectUserHierarchyGroup_Override ¶
func NewConnectUserHierarchyGroup_Override(c ConnectUserHierarchyGroup, scope constructs.Construct, id *string, config *ConnectUserHierarchyGroupConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/connect_user_hierarchy_group aws_connect_user_hierarchy_group} Resource.
Types ¶
type ConnectUserHierarchyGroup ¶
type ConnectUserHierarchyGroup interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HierarchyGroupId() *string
HierarchyPath() ConnectUserHierarchyGroupHierarchyPathList
Id() *string
SetId(val *string)
IdInput() *string
InstanceId() *string
SetInstanceId(val *string)
InstanceIdInput() *string
LevelId() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
ParentGroupId() *string
SetParentGroupId(val *string)
ParentGroupIdInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetParentGroupId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/connect_user_hierarchy_group aws_connect_user_hierarchy_group}.
func NewConnectUserHierarchyGroup ¶
func NewConnectUserHierarchyGroup(scope constructs.Construct, id *string, config *ConnectUserHierarchyGroupConfig) ConnectUserHierarchyGroup
Create a new {@link https://www.terraform.io/docs/providers/aws/r/connect_user_hierarchy_group aws_connect_user_hierarchy_group} Resource.
type ConnectUserHierarchyGroupConfig ¶
type ConnectUserHierarchyGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user_hierarchy_group#instance_id ConnectUserHierarchyGroup#instance_id}.
InstanceId *string `field:"required" json:"instanceId" yaml:"instanceId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user_hierarchy_group#name ConnectUserHierarchyGroup#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user_hierarchy_group#id ConnectUserHierarchyGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user_hierarchy_group#parent_group_id ConnectUserHierarchyGroup#parent_group_id}.
ParentGroupId *string `field:"optional" json:"parentGroupId" yaml:"parentGroupId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user_hierarchy_group#tags ConnectUserHierarchyGroup#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_user_hierarchy_group#tags_all ConnectUserHierarchyGroup#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type ConnectUserHierarchyGroupHierarchyPath ¶
type ConnectUserHierarchyGroupHierarchyPath struct {
}
type ConnectUserHierarchyGroupHierarchyPathLevelFive ¶
type ConnectUserHierarchyGroupHierarchyPathLevelFive struct {
}
type ConnectUserHierarchyGroupHierarchyPathLevelFiveList ¶
type ConnectUserHierarchyGroupHierarchyPathLevelFiveList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectUserHierarchyGroupHierarchyPathLevelFiveList ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelFiveList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ConnectUserHierarchyGroupHierarchyPathLevelFiveList
type ConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference ¶
type ConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *ConnectUserHierarchyGroupHierarchyPathLevelFive
SetInternalValue(val *ConnectUserHierarchyGroupHierarchyPathLevelFive)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference
type ConnectUserHierarchyGroupHierarchyPathLevelFour ¶
type ConnectUserHierarchyGroupHierarchyPathLevelFour struct {
}
type ConnectUserHierarchyGroupHierarchyPathLevelFourList ¶
type ConnectUserHierarchyGroupHierarchyPathLevelFourList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectUserHierarchyGroupHierarchyPathLevelFourList ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelFourList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ConnectUserHierarchyGroupHierarchyPathLevelFourList
type ConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference ¶
type ConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *ConnectUserHierarchyGroupHierarchyPathLevelFour
SetInternalValue(val *ConnectUserHierarchyGroupHierarchyPathLevelFour)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference
type ConnectUserHierarchyGroupHierarchyPathLevelOne ¶
type ConnectUserHierarchyGroupHierarchyPathLevelOne struct {
}
type ConnectUserHierarchyGroupHierarchyPathLevelOneList ¶
type ConnectUserHierarchyGroupHierarchyPathLevelOneList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectUserHierarchyGroupHierarchyPathLevelOneList ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelOneList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ConnectUserHierarchyGroupHierarchyPathLevelOneList
type ConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference ¶
type ConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *ConnectUserHierarchyGroupHierarchyPathLevelOne
SetInternalValue(val *ConnectUserHierarchyGroupHierarchyPathLevelOne)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference
type ConnectUserHierarchyGroupHierarchyPathLevelThree ¶
type ConnectUserHierarchyGroupHierarchyPathLevelThree struct {
}
type ConnectUserHierarchyGroupHierarchyPathLevelThreeList ¶
type ConnectUserHierarchyGroupHierarchyPathLevelThreeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectUserHierarchyGroupHierarchyPathLevelThreeList ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelThreeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ConnectUserHierarchyGroupHierarchyPathLevelThreeList
type ConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference ¶
type ConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *ConnectUserHierarchyGroupHierarchyPathLevelThree
SetInternalValue(val *ConnectUserHierarchyGroupHierarchyPathLevelThree)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference
type ConnectUserHierarchyGroupHierarchyPathLevelTwo ¶
type ConnectUserHierarchyGroupHierarchyPathLevelTwo struct {
}
type ConnectUserHierarchyGroupHierarchyPathLevelTwoList ¶
type ConnectUserHierarchyGroupHierarchyPathLevelTwoList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectUserHierarchyGroupHierarchyPathLevelTwoList ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelTwoList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ConnectUserHierarchyGroupHierarchyPathLevelTwoList
type ConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference ¶
type ConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *ConnectUserHierarchyGroupHierarchyPathLevelTwo
SetInternalValue(val *ConnectUserHierarchyGroupHierarchyPathLevelTwo)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference ¶
func NewConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference
type ConnectUserHierarchyGroupHierarchyPathList ¶
type ConnectUserHierarchyGroupHierarchyPathList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ConnectUserHierarchyGroupHierarchyPathOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectUserHierarchyGroupHierarchyPathList ¶
func NewConnectUserHierarchyGroupHierarchyPathList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ConnectUserHierarchyGroupHierarchyPathList
type ConnectUserHierarchyGroupHierarchyPathOutputReference ¶
type ConnectUserHierarchyGroupHierarchyPathOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ConnectUserHierarchyGroupHierarchyPath
SetInternalValue(val *ConnectUserHierarchyGroupHierarchyPath)
LevelFive() ConnectUserHierarchyGroupHierarchyPathLevelFiveList
LevelFour() ConnectUserHierarchyGroupHierarchyPathLevelFourList
LevelOne() ConnectUserHierarchyGroupHierarchyPathLevelOneList
LevelThree() ConnectUserHierarchyGroupHierarchyPathLevelThreeList
LevelTwo() ConnectUserHierarchyGroupHierarchyPathLevelTwoList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectUserHierarchyGroupHierarchyPathOutputReference ¶
func NewConnectUserHierarchyGroupHierarchyPathOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ConnectUserHierarchyGroupHierarchyPathOutputReference
Source Files
¶
- ConnectUserHierarchyGroup.go
- ConnectUserHierarchyGroupConfig.go
- ConnectUserHierarchyGroupHierarchyPath.go
- ConnectUserHierarchyGroupHierarchyPathLevelFive.go
- ConnectUserHierarchyGroupHierarchyPathLevelFiveList.go
- ConnectUserHierarchyGroupHierarchyPathLevelFiveList__checks.go
- ConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference.go
- ConnectUserHierarchyGroupHierarchyPathLevelFiveOutputReference__checks.go
- ConnectUserHierarchyGroupHierarchyPathLevelFour.go
- ConnectUserHierarchyGroupHierarchyPathLevelFourList.go
- ConnectUserHierarchyGroupHierarchyPathLevelFourList__checks.go
- ConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference.go
- ConnectUserHierarchyGroupHierarchyPathLevelFourOutputReference__checks.go
- ConnectUserHierarchyGroupHierarchyPathLevelOne.go
- ConnectUserHierarchyGroupHierarchyPathLevelOneList.go
- ConnectUserHierarchyGroupHierarchyPathLevelOneList__checks.go
- ConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference.go
- ConnectUserHierarchyGroupHierarchyPathLevelOneOutputReference__checks.go
- ConnectUserHierarchyGroupHierarchyPathLevelThree.go
- ConnectUserHierarchyGroupHierarchyPathLevelThreeList.go
- ConnectUserHierarchyGroupHierarchyPathLevelThreeList__checks.go
- ConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference.go
- ConnectUserHierarchyGroupHierarchyPathLevelThreeOutputReference__checks.go
- ConnectUserHierarchyGroupHierarchyPathLevelTwo.go
- ConnectUserHierarchyGroupHierarchyPathLevelTwoList.go
- ConnectUserHierarchyGroupHierarchyPathLevelTwoList__checks.go
- ConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference.go
- ConnectUserHierarchyGroupHierarchyPathLevelTwoOutputReference__checks.go
- ConnectUserHierarchyGroupHierarchyPathList.go
- ConnectUserHierarchyGroupHierarchyPathList__checks.go
- ConnectUserHierarchyGroupHierarchyPathOutputReference.go
- ConnectUserHierarchyGroupHierarchyPathOutputReference__checks.go
- ConnectUserHierarchyGroup__checks.go
- main.go