Documentation
¶
Index ¶
- func DataAwsConnectUserHierarchyStructure_IsConstruct(x interface{}) *bool
- func DataAwsConnectUserHierarchyStructure_IsTerraformDataSource(x interface{}) *bool
- func DataAwsConnectUserHierarchyStructure_IsTerraformElement(x interface{}) *bool
- func DataAwsConnectUserHierarchyStructure_TfResourceType() *string
- func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveList_Override(d DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveList, ...)
- func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveOutputReference_Override(...)
- func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourList_Override(d DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourList, ...)
- func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourOutputReference_Override(...)
- func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneList_Override(d DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneList, ...)
- func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneOutputReference_Override(...)
- func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeList_Override(d DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeList, ...)
- func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeOutputReference_Override(...)
- func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoList_Override(d DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoList, ...)
- func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoOutputReference_Override(...)
- func NewDataAwsConnectUserHierarchyStructureHierarchyStructureList_Override(d DataAwsConnectUserHierarchyStructureHierarchyStructureList, ...)
- func NewDataAwsConnectUserHierarchyStructureHierarchyStructureOutputReference_Override(d DataAwsConnectUserHierarchyStructureHierarchyStructureOutputReference, ...)
- func NewDataAwsConnectUserHierarchyStructure_Override(d DataAwsConnectUserHierarchyStructure, scope constructs.Construct, id *string, ...)
- type DataAwsConnectUserHierarchyStructure
- type DataAwsConnectUserHierarchyStructureConfig
- type DataAwsConnectUserHierarchyStructureHierarchyStructure
- type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFive
- type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveList
- type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveOutputReference
- type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFour
- type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourList
- type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourOutputReference
- type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOne
- type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneList
- type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneOutputReference
- type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThree
- type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeList
- type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeOutputReference
- type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwo
- type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoList
- type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoOutputReference
- type DataAwsConnectUserHierarchyStructureHierarchyStructureList
- type DataAwsConnectUserHierarchyStructureHierarchyStructureOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsConnectUserHierarchyStructure_IsConstruct ¶
func DataAwsConnectUserHierarchyStructure_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsConnectUserHierarchyStructure_IsTerraformDataSource ¶
func DataAwsConnectUserHierarchyStructure_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsConnectUserHierarchyStructure_IsTerraformElement ¶
func DataAwsConnectUserHierarchyStructure_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsConnectUserHierarchyStructure_TfResourceType ¶
func DataAwsConnectUserHierarchyStructure_TfResourceType() *string
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveList_Override ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveList_Override(d DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveOutputReference_Override ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveOutputReference_Override(d DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourList_Override ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourList_Override(d DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourOutputReference_Override ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourOutputReference_Override(d DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneList_Override ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneList_Override(d DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneOutputReference_Override ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneOutputReference_Override(d DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeList_Override ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeList_Override(d DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeOutputReference_Override ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeOutputReference_Override(d DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoList_Override ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoList_Override(d DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoOutputReference_Override ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoOutputReference_Override(d DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureList_Override ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureList_Override(d DataAwsConnectUserHierarchyStructureHierarchyStructureList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureOutputReference_Override ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureOutputReference_Override(d DataAwsConnectUserHierarchyStructureHierarchyStructureOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsConnectUserHierarchyStructure_Override ¶
func NewDataAwsConnectUserHierarchyStructure_Override(d DataAwsConnectUserHierarchyStructure, scope constructs.Construct, id *string, config *DataAwsConnectUserHierarchyStructureConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/connect_user_hierarchy_structure aws_connect_user_hierarchy_structure} Data Source.
Types ¶
type DataAwsConnectUserHierarchyStructure ¶
type DataAwsConnectUserHierarchyStructure interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HierarchyStructure() DataAwsConnectUserHierarchyStructureHierarchyStructureList
Id() *string
SetId(val *string)
IdInput() *string
InstanceId() *string
SetInstanceId(val *string)
InstanceIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/connect_user_hierarchy_structure aws_connect_user_hierarchy_structure}.
func NewDataAwsConnectUserHierarchyStructure ¶
func NewDataAwsConnectUserHierarchyStructure(scope constructs.Construct, id *string, config *DataAwsConnectUserHierarchyStructureConfig) DataAwsConnectUserHierarchyStructure
Create a new {@link https://www.terraform.io/docs/providers/aws/d/connect_user_hierarchy_structure aws_connect_user_hierarchy_structure} Data Source.
type DataAwsConnectUserHierarchyStructureConfig ¶
type DataAwsConnectUserHierarchyStructureConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/connect_user_hierarchy_structure#instance_id DataAwsConnectUserHierarchyStructure#instance_id}.
InstanceId *string `field:"required" json:"instanceId" yaml:"instanceId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/connect_user_hierarchy_structure#id DataAwsConnectUserHierarchyStructure#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type DataAwsConnectUserHierarchyStructureHierarchyStructure ¶
type DataAwsConnectUserHierarchyStructureHierarchyStructure struct {
}
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFive ¶
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFive struct {
}
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveList ¶
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveList ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveList
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveOutputReference ¶
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFive
SetInternalValue(val *DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFive)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveOutputReference ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveOutputReference
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFour ¶
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFour struct {
}
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourList ¶
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourList ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourList
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourOutputReference ¶
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFour
SetInternalValue(val *DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFour)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourOutputReference ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourOutputReference
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOne ¶
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOne struct {
}
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneList ¶
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneList ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneList
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneOutputReference ¶
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOne
SetInternalValue(val *DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOne)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneOutputReference ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneOutputReference
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThree ¶
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThree struct {
}
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeList ¶
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeList ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeList
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeOutputReference ¶
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThree
SetInternalValue(val *DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThree)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeOutputReference ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeOutputReference
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwo ¶
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwo struct {
}
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoList ¶
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoList ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoList
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoOutputReference ¶
type DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwo
SetInternalValue(val *DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwo)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoOutputReference ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoOutputReference
type DataAwsConnectUserHierarchyStructureHierarchyStructureList ¶
type DataAwsConnectUserHierarchyStructureHierarchyStructureList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsConnectUserHierarchyStructureHierarchyStructureOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureList ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsConnectUserHierarchyStructureHierarchyStructureList
type DataAwsConnectUserHierarchyStructureHierarchyStructureOutputReference ¶
type DataAwsConnectUserHierarchyStructureHierarchyStructureOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsConnectUserHierarchyStructureHierarchyStructure
SetInternalValue(val *DataAwsConnectUserHierarchyStructureHierarchyStructure)
LevelFive() DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveList
LevelFour() DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourList
LevelOne() DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneList
LevelThree() DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeList
LevelTwo() DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureOutputReference ¶
func NewDataAwsConnectUserHierarchyStructureHierarchyStructureOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsConnectUserHierarchyStructureHierarchyStructureOutputReference
Source Files
¶
- DataAwsConnectUserHierarchyStructure.go
- DataAwsConnectUserHierarchyStructureConfig.go
- DataAwsConnectUserHierarchyStructureHierarchyStructure.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFive.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveList.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveList__checks.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveOutputReference.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFiveOutputReference__checks.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFour.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourList.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourList__checks.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourOutputReference.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelFourOutputReference__checks.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOne.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneList.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneList__checks.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneOutputReference.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelOneOutputReference__checks.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThree.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeList.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeList__checks.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeOutputReference.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelThreeOutputReference__checks.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwo.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoList.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoList__checks.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoOutputReference.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureLevelTwoOutputReference__checks.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureList.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureList__checks.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureOutputReference.go
- DataAwsConnectUserHierarchyStructureHierarchyStructureOutputReference__checks.go
- DataAwsConnectUserHierarchyStructure__checks.go
- main.go