Documentation
¶
Index ¶
- func DataAwsDbClusterSnapshot_IsConstruct(x interface{}) *bool
- func DataAwsDbClusterSnapshot_IsTerraformDataSource(x interface{}) *bool
- func DataAwsDbClusterSnapshot_IsTerraformElement(x interface{}) *bool
- func DataAwsDbClusterSnapshot_TfResourceType() *string
- func NewDataAwsDbClusterSnapshot_Override(d DataAwsDbClusterSnapshot, scope constructs.Construct, id *string, ...)
- type DataAwsDbClusterSnapshot
- type DataAwsDbClusterSnapshotConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsDbClusterSnapshot_IsConstruct ¶
func DataAwsDbClusterSnapshot_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsDbClusterSnapshot_IsTerraformDataSource ¶
func DataAwsDbClusterSnapshot_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsDbClusterSnapshot_IsTerraformElement ¶
func DataAwsDbClusterSnapshot_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsDbClusterSnapshot_TfResourceType ¶
func DataAwsDbClusterSnapshot_TfResourceType() *string
func NewDataAwsDbClusterSnapshot_Override ¶
func NewDataAwsDbClusterSnapshot_Override(d DataAwsDbClusterSnapshot, scope constructs.Construct, id *string, config *DataAwsDbClusterSnapshotConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/db_cluster_snapshot aws_db_cluster_snapshot} Data Source.
Types ¶
type DataAwsDbClusterSnapshot ¶
type DataAwsDbClusterSnapshot interface {
cdktf.TerraformDataSource
AllocatedStorage() *float64
AvailabilityZones() *[]*string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DbClusterIdentifier() *string
SetDbClusterIdentifier(val *string)
DbClusterIdentifierInput() *string
DbClusterSnapshotArn() *string
DbClusterSnapshotIdentifier() *string
SetDbClusterSnapshotIdentifier(val *string)
DbClusterSnapshotIdentifierInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Engine() *string
EngineVersion() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IncludePublic() interface{}
SetIncludePublic(val interface{})
IncludePublicInput() interface{}
KmsKeyId() *string
LicenseModel() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MostRecent() interface{}
SetMostRecent(val interface{})
MostRecentInput() interface{}
// The tree node.
Node() constructs.Node
Port() *float64
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
SnapshotCreateTime() *string
SnapshotType() *string
SetSnapshotType(val *string)
SnapshotTypeInput() *string
SourceDbClusterSnapshotArn() *string
Status() *string
StorageEncrypted() cdktf.IResolvable
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
VpcId() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetDbClusterIdentifier()
ResetDbClusterSnapshotIdentifier()
ResetId()
ResetIncludePublic()
ResetMostRecent()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSnapshotType()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/db_cluster_snapshot aws_db_cluster_snapshot}.
func NewDataAwsDbClusterSnapshot ¶
func NewDataAwsDbClusterSnapshot(scope constructs.Construct, id *string, config *DataAwsDbClusterSnapshotConfig) DataAwsDbClusterSnapshot
Create a new {@link https://www.terraform.io/docs/providers/aws/d/db_cluster_snapshot aws_db_cluster_snapshot} Data Source.
type DataAwsDbClusterSnapshotConfig ¶
type DataAwsDbClusterSnapshotConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_cluster_snapshot#db_cluster_identifier DataAwsDbClusterSnapshot#db_cluster_identifier}.
DbClusterIdentifier *string `field:"optional" json:"dbClusterIdentifier" yaml:"dbClusterIdentifier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_cluster_snapshot#db_cluster_snapshot_identifier DataAwsDbClusterSnapshot#db_cluster_snapshot_identifier}.
DbClusterSnapshotIdentifier *string `field:"optional" json:"dbClusterSnapshotIdentifier" yaml:"dbClusterSnapshotIdentifier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_cluster_snapshot#id DataAwsDbClusterSnapshot#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_cluster_snapshot#include_public DataAwsDbClusterSnapshot#include_public}.
IncludePublic interface{} `field:"optional" json:"includePublic" yaml:"includePublic"`
IncludeShared interface{} `field:"optional" json:"includeShared" yaml:"includeShared"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_cluster_snapshot#most_recent DataAwsDbClusterSnapshot#most_recent}.
MostRecent interface{} `field:"optional" json:"mostRecent" yaml:"mostRecent"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_cluster_snapshot#snapshot_type DataAwsDbClusterSnapshot#snapshot_type}.
SnapshotType *string `field:"optional" json:"snapshotType" yaml:"snapshotType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_cluster_snapshot#tags DataAwsDbClusterSnapshot#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}