Documentation
¶
Index ¶
- func DataAwsDynamodbTable_IsConstruct(x interface{}) *bool
- func DataAwsDynamodbTable_IsTerraformDataSource(x interface{}) *bool
- func DataAwsDynamodbTable_IsTerraformElement(x interface{}) *bool
- func DataAwsDynamodbTable_TfResourceType() *string
- func NewDataAwsDynamodbTableAttributeList_Override(d DataAwsDynamodbTableAttributeList, ...)
- func NewDataAwsDynamodbTableAttributeOutputReference_Override(d DataAwsDynamodbTableAttributeOutputReference, ...)
- func NewDataAwsDynamodbTableGlobalSecondaryIndexList_Override(d DataAwsDynamodbTableGlobalSecondaryIndexList, ...)
- func NewDataAwsDynamodbTableGlobalSecondaryIndexOutputReference_Override(d DataAwsDynamodbTableGlobalSecondaryIndexOutputReference, ...)
- func NewDataAwsDynamodbTableLocalSecondaryIndexList_Override(d DataAwsDynamodbTableLocalSecondaryIndexList, ...)
- func NewDataAwsDynamodbTableLocalSecondaryIndexOutputReference_Override(d DataAwsDynamodbTableLocalSecondaryIndexOutputReference, ...)
- func NewDataAwsDynamodbTablePointInTimeRecoveryList_Override(d DataAwsDynamodbTablePointInTimeRecoveryList, ...)
- func NewDataAwsDynamodbTablePointInTimeRecoveryOutputReference_Override(d DataAwsDynamodbTablePointInTimeRecoveryOutputReference, ...)
- func NewDataAwsDynamodbTableReplicaList_Override(d DataAwsDynamodbTableReplicaList, ...)
- func NewDataAwsDynamodbTableReplicaOutputReference_Override(d DataAwsDynamodbTableReplicaOutputReference, ...)
- func NewDataAwsDynamodbTableServerSideEncryptionOutputReference_Override(d DataAwsDynamodbTableServerSideEncryptionOutputReference, ...)
- func NewDataAwsDynamodbTableTtlList_Override(d DataAwsDynamodbTableTtlList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewDataAwsDynamodbTableTtlOutputReference_Override(d DataAwsDynamodbTableTtlOutputReference, ...)
- func NewDataAwsDynamodbTable_Override(d DataAwsDynamodbTable, scope constructs.Construct, id *string, ...)
- type DataAwsDynamodbTable
- type DataAwsDynamodbTableAttribute
- type DataAwsDynamodbTableAttributeList
- type DataAwsDynamodbTableAttributeOutputReference
- type DataAwsDynamodbTableConfig
- type DataAwsDynamodbTableGlobalSecondaryIndex
- type DataAwsDynamodbTableGlobalSecondaryIndexList
- type DataAwsDynamodbTableGlobalSecondaryIndexOutputReference
- type DataAwsDynamodbTableLocalSecondaryIndex
- type DataAwsDynamodbTableLocalSecondaryIndexList
- type DataAwsDynamodbTableLocalSecondaryIndexOutputReference
- type DataAwsDynamodbTablePointInTimeRecovery
- type DataAwsDynamodbTablePointInTimeRecoveryList
- type DataAwsDynamodbTablePointInTimeRecoveryOutputReference
- type DataAwsDynamodbTableReplica
- type DataAwsDynamodbTableReplicaList
- type DataAwsDynamodbTableReplicaOutputReference
- type DataAwsDynamodbTableServerSideEncryption
- type DataAwsDynamodbTableServerSideEncryptionOutputReference
- type DataAwsDynamodbTableTtl
- type DataAwsDynamodbTableTtlList
- type DataAwsDynamodbTableTtlOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsDynamodbTable_IsConstruct ¶
func DataAwsDynamodbTable_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsDynamodbTable_IsTerraformDataSource ¶
func DataAwsDynamodbTable_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsDynamodbTable_IsTerraformElement ¶
func DataAwsDynamodbTable_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsDynamodbTable_TfResourceType ¶
func DataAwsDynamodbTable_TfResourceType() *string
func NewDataAwsDynamodbTableAttributeList_Override ¶
func NewDataAwsDynamodbTableAttributeList_Override(d DataAwsDynamodbTableAttributeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsDynamodbTableAttributeOutputReference_Override ¶
func NewDataAwsDynamodbTableAttributeOutputReference_Override(d DataAwsDynamodbTableAttributeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsDynamodbTableGlobalSecondaryIndexList_Override ¶
func NewDataAwsDynamodbTableGlobalSecondaryIndexList_Override(d DataAwsDynamodbTableGlobalSecondaryIndexList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsDynamodbTableGlobalSecondaryIndexOutputReference_Override ¶
func NewDataAwsDynamodbTableGlobalSecondaryIndexOutputReference_Override(d DataAwsDynamodbTableGlobalSecondaryIndexOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsDynamodbTableLocalSecondaryIndexList_Override ¶
func NewDataAwsDynamodbTableLocalSecondaryIndexList_Override(d DataAwsDynamodbTableLocalSecondaryIndexList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsDynamodbTableLocalSecondaryIndexOutputReference_Override ¶
func NewDataAwsDynamodbTableLocalSecondaryIndexOutputReference_Override(d DataAwsDynamodbTableLocalSecondaryIndexOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsDynamodbTablePointInTimeRecoveryList_Override ¶
func NewDataAwsDynamodbTablePointInTimeRecoveryList_Override(d DataAwsDynamodbTablePointInTimeRecoveryList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsDynamodbTablePointInTimeRecoveryOutputReference_Override ¶
func NewDataAwsDynamodbTablePointInTimeRecoveryOutputReference_Override(d DataAwsDynamodbTablePointInTimeRecoveryOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsDynamodbTableReplicaList_Override ¶
func NewDataAwsDynamodbTableReplicaList_Override(d DataAwsDynamodbTableReplicaList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsDynamodbTableReplicaOutputReference_Override ¶
func NewDataAwsDynamodbTableReplicaOutputReference_Override(d DataAwsDynamodbTableReplicaOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsDynamodbTableServerSideEncryptionOutputReference_Override ¶
func NewDataAwsDynamodbTableServerSideEncryptionOutputReference_Override(d DataAwsDynamodbTableServerSideEncryptionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsDynamodbTableTtlList_Override ¶
func NewDataAwsDynamodbTableTtlList_Override(d DataAwsDynamodbTableTtlList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsDynamodbTableTtlOutputReference_Override ¶
func NewDataAwsDynamodbTableTtlOutputReference_Override(d DataAwsDynamodbTableTtlOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsDynamodbTable_Override ¶
func NewDataAwsDynamodbTable_Override(d DataAwsDynamodbTable, scope constructs.Construct, id *string, config *DataAwsDynamodbTableConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/dynamodb_table aws_dynamodb_table} Data Source.
Types ¶
type DataAwsDynamodbTable ¶
type DataAwsDynamodbTable interface {
cdktf.TerraformDataSource
Arn() *string
Attribute() DataAwsDynamodbTableAttributeList
BillingMode() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DeletionProtectionEnabled() cdktf.IResolvable
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GlobalSecondaryIndex() DataAwsDynamodbTableGlobalSecondaryIndexList
HashKey() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LocalSecondaryIndex() DataAwsDynamodbTableLocalSecondaryIndexList
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
PointInTimeRecovery() DataAwsDynamodbTablePointInTimeRecoveryList
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
RangeKey() *string
// Experimental.
RawOverrides() interface{}
ReadCapacity() *float64
Replica() DataAwsDynamodbTableReplicaList
ServerSideEncryption() DataAwsDynamodbTableServerSideEncryptionOutputReference
ServerSideEncryptionInput() *DataAwsDynamodbTableServerSideEncryption
StreamArn() *string
StreamEnabled() cdktf.IResolvable
StreamLabel() *string
StreamViewType() *string
TableClass() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Ttl() DataAwsDynamodbTableTtlList
WriteCapacity() *float64
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutServerSideEncryption(value *DataAwsDynamodbTableServerSideEncryption)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetServerSideEncryption()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/dynamodb_table aws_dynamodb_table}.
func NewDataAwsDynamodbTable ¶
func NewDataAwsDynamodbTable(scope constructs.Construct, id *string, config *DataAwsDynamodbTableConfig) DataAwsDynamodbTable
Create a new {@link https://www.terraform.io/docs/providers/aws/d/dynamodb_table aws_dynamodb_table} Data Source.
type DataAwsDynamodbTableAttribute ¶
type DataAwsDynamodbTableAttribute struct {
}
type DataAwsDynamodbTableAttributeList ¶
type DataAwsDynamodbTableAttributeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsDynamodbTableAttributeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDynamodbTableAttributeList ¶
func NewDataAwsDynamodbTableAttributeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsDynamodbTableAttributeList
type DataAwsDynamodbTableAttributeOutputReference ¶
type DataAwsDynamodbTableAttributeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsDynamodbTableAttribute
SetInternalValue(val *DataAwsDynamodbTableAttribute)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDynamodbTableAttributeOutputReference ¶
func NewDataAwsDynamodbTableAttributeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsDynamodbTableAttributeOutputReference
type DataAwsDynamodbTableConfig ¶
type DataAwsDynamodbTableConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/dynamodb_table#name DataAwsDynamodbTable#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/dynamodb_table#id DataAwsDynamodbTable#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// server_side_encryption block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/dynamodb_table#server_side_encryption DataAwsDynamodbTable#server_side_encryption}
ServerSideEncryption *DataAwsDynamodbTableServerSideEncryption `field:"optional" json:"serverSideEncryption" yaml:"serverSideEncryption"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/dynamodb_table#tags DataAwsDynamodbTable#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsDynamodbTableGlobalSecondaryIndex ¶
type DataAwsDynamodbTableGlobalSecondaryIndex struct {
}
type DataAwsDynamodbTableGlobalSecondaryIndexList ¶
type DataAwsDynamodbTableGlobalSecondaryIndexList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsDynamodbTableGlobalSecondaryIndexOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDynamodbTableGlobalSecondaryIndexList ¶
func NewDataAwsDynamodbTableGlobalSecondaryIndexList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsDynamodbTableGlobalSecondaryIndexList
type DataAwsDynamodbTableGlobalSecondaryIndexOutputReference ¶
type DataAwsDynamodbTableGlobalSecondaryIndexOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HashKey() *string
InternalValue() *DataAwsDynamodbTableGlobalSecondaryIndex
SetInternalValue(val *DataAwsDynamodbTableGlobalSecondaryIndex)
Name() *string
NonKeyAttributes() *[]*string
ProjectionType() *string
RangeKey() *string
ReadCapacity() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
WriteCapacity() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDynamodbTableGlobalSecondaryIndexOutputReference ¶
func NewDataAwsDynamodbTableGlobalSecondaryIndexOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsDynamodbTableGlobalSecondaryIndexOutputReference
type DataAwsDynamodbTableLocalSecondaryIndex ¶
type DataAwsDynamodbTableLocalSecondaryIndex struct {
}
type DataAwsDynamodbTableLocalSecondaryIndexList ¶
type DataAwsDynamodbTableLocalSecondaryIndexList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsDynamodbTableLocalSecondaryIndexOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDynamodbTableLocalSecondaryIndexList ¶
func NewDataAwsDynamodbTableLocalSecondaryIndexList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsDynamodbTableLocalSecondaryIndexList
type DataAwsDynamodbTableLocalSecondaryIndexOutputReference ¶
type DataAwsDynamodbTableLocalSecondaryIndexOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsDynamodbTableLocalSecondaryIndex
SetInternalValue(val *DataAwsDynamodbTableLocalSecondaryIndex)
Name() *string
NonKeyAttributes() *[]*string
ProjectionType() *string
RangeKey() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDynamodbTableLocalSecondaryIndexOutputReference ¶
func NewDataAwsDynamodbTableLocalSecondaryIndexOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsDynamodbTableLocalSecondaryIndexOutputReference
type DataAwsDynamodbTablePointInTimeRecovery ¶
type DataAwsDynamodbTablePointInTimeRecovery struct {
}
type DataAwsDynamodbTablePointInTimeRecoveryList ¶
type DataAwsDynamodbTablePointInTimeRecoveryList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsDynamodbTablePointInTimeRecoveryOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDynamodbTablePointInTimeRecoveryList ¶
func NewDataAwsDynamodbTablePointInTimeRecoveryList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsDynamodbTablePointInTimeRecoveryList
type DataAwsDynamodbTablePointInTimeRecoveryOutputReference ¶
type DataAwsDynamodbTablePointInTimeRecoveryOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() cdktf.IResolvable
// Experimental.
Fqn() *string
InternalValue() *DataAwsDynamodbTablePointInTimeRecovery
SetInternalValue(val *DataAwsDynamodbTablePointInTimeRecovery)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDynamodbTablePointInTimeRecoveryOutputReference ¶
func NewDataAwsDynamodbTablePointInTimeRecoveryOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsDynamodbTablePointInTimeRecoveryOutputReference
type DataAwsDynamodbTableReplica ¶
type DataAwsDynamodbTableReplica struct {
}
type DataAwsDynamodbTableReplicaList ¶
type DataAwsDynamodbTableReplicaList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsDynamodbTableReplicaOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDynamodbTableReplicaList ¶
func NewDataAwsDynamodbTableReplicaList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsDynamodbTableReplicaList
type DataAwsDynamodbTableReplicaOutputReference ¶
type DataAwsDynamodbTableReplicaOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsDynamodbTableReplica
SetInternalValue(val *DataAwsDynamodbTableReplica)
KmsKeyArn() *string
RegionName() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDynamodbTableReplicaOutputReference ¶
func NewDataAwsDynamodbTableReplicaOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsDynamodbTableReplicaOutputReference
type DataAwsDynamodbTableServerSideEncryption ¶
type DataAwsDynamodbTableServerSideEncryption struct {
}
type DataAwsDynamodbTableServerSideEncryptionOutputReference ¶
type DataAwsDynamodbTableServerSideEncryptionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() cdktf.IResolvable
// Experimental.
Fqn() *string
InternalValue() *DataAwsDynamodbTableServerSideEncryption
SetInternalValue(val *DataAwsDynamodbTableServerSideEncryption)
KmsKeyArn() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDynamodbTableServerSideEncryptionOutputReference ¶
func NewDataAwsDynamodbTableServerSideEncryptionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsDynamodbTableServerSideEncryptionOutputReference
type DataAwsDynamodbTableTtl ¶
type DataAwsDynamodbTableTtl struct {
}
type DataAwsDynamodbTableTtlList ¶
type DataAwsDynamodbTableTtlList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsDynamodbTableTtlOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDynamodbTableTtlList ¶
func NewDataAwsDynamodbTableTtlList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsDynamodbTableTtlList
type DataAwsDynamodbTableTtlOutputReference ¶
type DataAwsDynamodbTableTtlOutputReference interface {
cdktf.ComplexObject
AttributeName() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() cdktf.IResolvable
// Experimental.
Fqn() *string
InternalValue() *DataAwsDynamodbTableTtl
SetInternalValue(val *DataAwsDynamodbTableTtl)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDynamodbTableTtlOutputReference ¶
func NewDataAwsDynamodbTableTtlOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsDynamodbTableTtlOutputReference
Source Files
¶
- DataAwsDynamodbTable.go
- DataAwsDynamodbTableAttribute.go
- DataAwsDynamodbTableAttributeList.go
- DataAwsDynamodbTableAttributeList__checks.go
- DataAwsDynamodbTableAttributeOutputReference.go
- DataAwsDynamodbTableAttributeOutputReference__checks.go
- DataAwsDynamodbTableConfig.go
- DataAwsDynamodbTableGlobalSecondaryIndex.go
- DataAwsDynamodbTableGlobalSecondaryIndexList.go
- DataAwsDynamodbTableGlobalSecondaryIndexList__checks.go
- DataAwsDynamodbTableGlobalSecondaryIndexOutputReference.go
- DataAwsDynamodbTableGlobalSecondaryIndexOutputReference__checks.go
- DataAwsDynamodbTableLocalSecondaryIndex.go
- DataAwsDynamodbTableLocalSecondaryIndexList.go
- DataAwsDynamodbTableLocalSecondaryIndexList__checks.go
- DataAwsDynamodbTableLocalSecondaryIndexOutputReference.go
- DataAwsDynamodbTableLocalSecondaryIndexOutputReference__checks.go
- DataAwsDynamodbTablePointInTimeRecovery.go
- DataAwsDynamodbTablePointInTimeRecoveryList.go
- DataAwsDynamodbTablePointInTimeRecoveryList__checks.go
- DataAwsDynamodbTablePointInTimeRecoveryOutputReference.go
- DataAwsDynamodbTablePointInTimeRecoveryOutputReference__checks.go
- DataAwsDynamodbTableReplica.go
- DataAwsDynamodbTableReplicaList.go
- DataAwsDynamodbTableReplicaList__checks.go
- DataAwsDynamodbTableReplicaOutputReference.go
- DataAwsDynamodbTableReplicaOutputReference__checks.go
- DataAwsDynamodbTableServerSideEncryption.go
- DataAwsDynamodbTableServerSideEncryptionOutputReference.go
- DataAwsDynamodbTableServerSideEncryptionOutputReference__checks.go
- DataAwsDynamodbTableTtl.go
- DataAwsDynamodbTableTtlList.go
- DataAwsDynamodbTableTtlList__checks.go
- DataAwsDynamodbTableTtlOutputReference.go
- DataAwsDynamodbTableTtlOutputReference__checks.go
- DataAwsDynamodbTable__checks.go
- main.go