Documentation
¶
Index ¶
- func DataAwsEc2PublicIpv4Pool_IsConstruct(x interface{}) *bool
- func DataAwsEc2PublicIpv4Pool_IsTerraformDataSource(x interface{}) *bool
- func DataAwsEc2PublicIpv4Pool_IsTerraformElement(x interface{}) *bool
- func DataAwsEc2PublicIpv4Pool_TfResourceType() *string
- func NewDataAwsEc2PublicIpv4PoolPoolAddressRangesList_Override(d DataAwsEc2PublicIpv4PoolPoolAddressRangesList, ...)
- func NewDataAwsEc2PublicIpv4PoolPoolAddressRangesOutputReference_Override(d DataAwsEc2PublicIpv4PoolPoolAddressRangesOutputReference, ...)
- func NewDataAwsEc2PublicIpv4Pool_Override(d DataAwsEc2PublicIpv4Pool, scope constructs.Construct, id *string, ...)
- type DataAwsEc2PublicIpv4Pool
- type DataAwsEc2PublicIpv4PoolConfig
- type DataAwsEc2PublicIpv4PoolPoolAddressRanges
- type DataAwsEc2PublicIpv4PoolPoolAddressRangesList
- type DataAwsEc2PublicIpv4PoolPoolAddressRangesOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsEc2PublicIpv4Pool_IsConstruct ¶
func DataAwsEc2PublicIpv4Pool_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsEc2PublicIpv4Pool_IsTerraformDataSource ¶
func DataAwsEc2PublicIpv4Pool_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsEc2PublicIpv4Pool_IsTerraformElement ¶
func DataAwsEc2PublicIpv4Pool_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsEc2PublicIpv4Pool_TfResourceType ¶
func DataAwsEc2PublicIpv4Pool_TfResourceType() *string
func NewDataAwsEc2PublicIpv4PoolPoolAddressRangesList_Override ¶
func NewDataAwsEc2PublicIpv4PoolPoolAddressRangesList_Override(d DataAwsEc2PublicIpv4PoolPoolAddressRangesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEc2PublicIpv4PoolPoolAddressRangesOutputReference_Override ¶
func NewDataAwsEc2PublicIpv4PoolPoolAddressRangesOutputReference_Override(d DataAwsEc2PublicIpv4PoolPoolAddressRangesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEc2PublicIpv4Pool_Override ¶
func NewDataAwsEc2PublicIpv4Pool_Override(d DataAwsEc2PublicIpv4Pool, scope constructs.Construct, id *string, config *DataAwsEc2PublicIpv4PoolConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/ec2_public_ipv4_pool aws_ec2_public_ipv4_pool} Data Source.
Types ¶
type DataAwsEc2PublicIpv4Pool ¶
type DataAwsEc2PublicIpv4Pool interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
NetworkBorderGroup() *string
// The tree node.
Node() constructs.Node
PoolAddressRanges() DataAwsEc2PublicIpv4PoolPoolAddressRangesList
PoolId() *string
SetPoolId(val *string)
PoolIdInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
TotalAddressCount() *float64
TotalAvailableAddressCount() *float64
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/ec2_public_ipv4_pool aws_ec2_public_ipv4_pool}.
func NewDataAwsEc2PublicIpv4Pool ¶
func NewDataAwsEc2PublicIpv4Pool(scope constructs.Construct, id *string, config *DataAwsEc2PublicIpv4PoolConfig) DataAwsEc2PublicIpv4Pool
Create a new {@link https://www.terraform.io/docs/providers/aws/d/ec2_public_ipv4_pool aws_ec2_public_ipv4_pool} Data Source.
type DataAwsEc2PublicIpv4PoolConfig ¶
type DataAwsEc2PublicIpv4PoolConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_public_ipv4_pool#pool_id DataAwsEc2PublicIpv4Pool#pool_id}.
PoolId *string `field:"required" json:"poolId" yaml:"poolId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_public_ipv4_pool#id DataAwsEc2PublicIpv4Pool#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_public_ipv4_pool#tags DataAwsEc2PublicIpv4Pool#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsEc2PublicIpv4PoolPoolAddressRanges ¶
type DataAwsEc2PublicIpv4PoolPoolAddressRanges struct {
}
type DataAwsEc2PublicIpv4PoolPoolAddressRangesList ¶
type DataAwsEc2PublicIpv4PoolPoolAddressRangesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEc2PublicIpv4PoolPoolAddressRangesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2PublicIpv4PoolPoolAddressRangesList ¶
func NewDataAwsEc2PublicIpv4PoolPoolAddressRangesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEc2PublicIpv4PoolPoolAddressRangesList
type DataAwsEc2PublicIpv4PoolPoolAddressRangesOutputReference ¶
type DataAwsEc2PublicIpv4PoolPoolAddressRangesOutputReference interface {
cdktf.ComplexObject
AddressCount() *float64
AvailableAddressCount() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FirstAddress() *string
// Experimental.
Fqn() *string
InternalValue() *DataAwsEc2PublicIpv4PoolPoolAddressRanges
SetInternalValue(val *DataAwsEc2PublicIpv4PoolPoolAddressRanges)
LastAddress() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2PublicIpv4PoolPoolAddressRangesOutputReference ¶
func NewDataAwsEc2PublicIpv4PoolPoolAddressRangesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEc2PublicIpv4PoolPoolAddressRangesOutputReference
Source Files
¶
- DataAwsEc2PublicIpv4Pool.go
- DataAwsEc2PublicIpv4PoolConfig.go
- DataAwsEc2PublicIpv4PoolPoolAddressRanges.go
- DataAwsEc2PublicIpv4PoolPoolAddressRangesList.go
- DataAwsEc2PublicIpv4PoolPoolAddressRangesList__checks.go
- DataAwsEc2PublicIpv4PoolPoolAddressRangesOutputReference.go
- DataAwsEc2PublicIpv4PoolPoolAddressRangesOutputReference__checks.go
- DataAwsEc2PublicIpv4Pool__checks.go
- main.go