Documentation
¶
Index ¶
- func DataAwsEfsFileSystem_IsConstruct(x interface{}) *bool
- func DataAwsEfsFileSystem_IsTerraformDataSource(x interface{}) *bool
- func DataAwsEfsFileSystem_IsTerraformElement(x interface{}) *bool
- func DataAwsEfsFileSystem_TfResourceType() *string
- func NewDataAwsEfsFileSystemLifecyclePolicyList_Override(d DataAwsEfsFileSystemLifecyclePolicyList, ...)
- func NewDataAwsEfsFileSystemLifecyclePolicyOutputReference_Override(d DataAwsEfsFileSystemLifecyclePolicyOutputReference, ...)
- func NewDataAwsEfsFileSystem_Override(d DataAwsEfsFileSystem, scope constructs.Construct, id *string, ...)
- type DataAwsEfsFileSystem
- type DataAwsEfsFileSystemConfig
- type DataAwsEfsFileSystemLifecyclePolicy
- type DataAwsEfsFileSystemLifecyclePolicyList
- type DataAwsEfsFileSystemLifecyclePolicyOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsEfsFileSystem_IsConstruct ¶
func DataAwsEfsFileSystem_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsEfsFileSystem_IsTerraformDataSource ¶
func DataAwsEfsFileSystem_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsEfsFileSystem_IsTerraformElement ¶
func DataAwsEfsFileSystem_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsEfsFileSystem_TfResourceType ¶
func DataAwsEfsFileSystem_TfResourceType() *string
func NewDataAwsEfsFileSystemLifecyclePolicyList_Override ¶
func NewDataAwsEfsFileSystemLifecyclePolicyList_Override(d DataAwsEfsFileSystemLifecyclePolicyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEfsFileSystemLifecyclePolicyOutputReference_Override ¶
func NewDataAwsEfsFileSystemLifecyclePolicyOutputReference_Override(d DataAwsEfsFileSystemLifecyclePolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEfsFileSystem_Override ¶
func NewDataAwsEfsFileSystem_Override(d DataAwsEfsFileSystem, scope constructs.Construct, id *string, config *DataAwsEfsFileSystemConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/efs_file_system aws_efs_file_system} Data Source.
Types ¶
type DataAwsEfsFileSystem ¶
type DataAwsEfsFileSystem interface {
cdktf.TerraformDataSource
Arn() *string
AvailabilityZoneId() *string
AvailabilityZoneName() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreationToken() *string
SetCreationToken(val *string)
CreationTokenInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DnsName() *string
Encrypted() cdktf.IResolvable
FileSystemId() *string
SetFileSystemId(val *string)
FileSystemIdInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
KmsKeyId() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LifecyclePolicy() DataAwsEfsFileSystemLifecyclePolicyList
// The tree node.
Node() constructs.Node
PerformanceMode() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
ProvisionedThroughputInMibps() *float64
// Experimental.
RawOverrides() interface{}
SizeInBytes() *float64
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
ThroughputMode() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetCreationToken()
ResetFileSystemId()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/efs_file_system aws_efs_file_system}.
func NewDataAwsEfsFileSystem ¶
func NewDataAwsEfsFileSystem(scope constructs.Construct, id *string, config *DataAwsEfsFileSystemConfig) DataAwsEfsFileSystem
Create a new {@link https://www.terraform.io/docs/providers/aws/d/efs_file_system aws_efs_file_system} Data Source.
type DataAwsEfsFileSystemConfig ¶
type DataAwsEfsFileSystemConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/efs_file_system#creation_token DataAwsEfsFileSystem#creation_token}.
CreationToken *string `field:"optional" json:"creationToken" yaml:"creationToken"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/efs_file_system#file_system_id DataAwsEfsFileSystem#file_system_id}.
FileSystemId *string `field:"optional" json:"fileSystemId" yaml:"fileSystemId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/efs_file_system#id DataAwsEfsFileSystem#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/efs_file_system#tags DataAwsEfsFileSystem#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsEfsFileSystemLifecyclePolicy ¶
type DataAwsEfsFileSystemLifecyclePolicy struct {
}
type DataAwsEfsFileSystemLifecyclePolicyList ¶
type DataAwsEfsFileSystemLifecyclePolicyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEfsFileSystemLifecyclePolicyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEfsFileSystemLifecyclePolicyList ¶
func NewDataAwsEfsFileSystemLifecyclePolicyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEfsFileSystemLifecyclePolicyList
type DataAwsEfsFileSystemLifecyclePolicyOutputReference ¶
type DataAwsEfsFileSystemLifecyclePolicyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsEfsFileSystemLifecyclePolicy
SetInternalValue(val *DataAwsEfsFileSystemLifecyclePolicy)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TransitionToIa() *string
TransitionToPrimaryStorageClass() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEfsFileSystemLifecyclePolicyOutputReference ¶
func NewDataAwsEfsFileSystemLifecyclePolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEfsFileSystemLifecyclePolicyOutputReference
Source Files
¶
- DataAwsEfsFileSystem.go
- DataAwsEfsFileSystemConfig.go
- DataAwsEfsFileSystemLifecyclePolicy.go
- DataAwsEfsFileSystemLifecyclePolicyList.go
- DataAwsEfsFileSystemLifecyclePolicyList__checks.go
- DataAwsEfsFileSystemLifecyclePolicyOutputReference.go
- DataAwsEfsFileSystemLifecyclePolicyOutputReference__checks.go
- DataAwsEfsFileSystem__checks.go
- main.go