Documentation
¶
Index ¶
- func DataAwsNetworkmanagerDevice_IsConstruct(x interface{}) *bool
- func DataAwsNetworkmanagerDevice_IsTerraformDataSource(x interface{}) *bool
- func DataAwsNetworkmanagerDevice_IsTerraformElement(x interface{}) *bool
- func DataAwsNetworkmanagerDevice_TfResourceType() *string
- func NewDataAwsNetworkmanagerDeviceAwsLocationList_Override(d DataAwsNetworkmanagerDeviceAwsLocationList, ...)
- func NewDataAwsNetworkmanagerDeviceAwsLocationOutputReference_Override(d DataAwsNetworkmanagerDeviceAwsLocationOutputReference, ...)
- func NewDataAwsNetworkmanagerDeviceLocationList_Override(d DataAwsNetworkmanagerDeviceLocationList, ...)
- func NewDataAwsNetworkmanagerDeviceLocationOutputReference_Override(d DataAwsNetworkmanagerDeviceLocationOutputReference, ...)
- func NewDataAwsNetworkmanagerDevice_Override(d DataAwsNetworkmanagerDevice, scope constructs.Construct, id *string, ...)
- type DataAwsNetworkmanagerDevice
- type DataAwsNetworkmanagerDeviceAwsLocation
- type DataAwsNetworkmanagerDeviceAwsLocationList
- type DataAwsNetworkmanagerDeviceAwsLocationOutputReference
- type DataAwsNetworkmanagerDeviceConfig
- type DataAwsNetworkmanagerDeviceLocation
- type DataAwsNetworkmanagerDeviceLocationList
- type DataAwsNetworkmanagerDeviceLocationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsNetworkmanagerDevice_IsConstruct ¶
func DataAwsNetworkmanagerDevice_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsNetworkmanagerDevice_IsTerraformDataSource ¶
func DataAwsNetworkmanagerDevice_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsNetworkmanagerDevice_IsTerraformElement ¶
func DataAwsNetworkmanagerDevice_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsNetworkmanagerDevice_TfResourceType ¶
func DataAwsNetworkmanagerDevice_TfResourceType() *string
func NewDataAwsNetworkmanagerDeviceAwsLocationList_Override ¶
func NewDataAwsNetworkmanagerDeviceAwsLocationList_Override(d DataAwsNetworkmanagerDeviceAwsLocationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsNetworkmanagerDeviceAwsLocationOutputReference_Override ¶
func NewDataAwsNetworkmanagerDeviceAwsLocationOutputReference_Override(d DataAwsNetworkmanagerDeviceAwsLocationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsNetworkmanagerDeviceLocationList_Override ¶
func NewDataAwsNetworkmanagerDeviceLocationList_Override(d DataAwsNetworkmanagerDeviceLocationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsNetworkmanagerDeviceLocationOutputReference_Override ¶
func NewDataAwsNetworkmanagerDeviceLocationOutputReference_Override(d DataAwsNetworkmanagerDeviceLocationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsNetworkmanagerDevice_Override ¶
func NewDataAwsNetworkmanagerDevice_Override(d DataAwsNetworkmanagerDevice, scope constructs.Construct, id *string, config *DataAwsNetworkmanagerDeviceConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/networkmanager_device aws_networkmanager_device} Data Source.
Types ¶
type DataAwsNetworkmanagerDevice ¶
type DataAwsNetworkmanagerDevice interface {
cdktf.TerraformDataSource
Arn() *string
AwsLocation() DataAwsNetworkmanagerDeviceAwsLocationList
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
DeviceId() *string
SetDeviceId(val *string)
DeviceIdInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GlobalNetworkId() *string
SetGlobalNetworkId(val *string)
GlobalNetworkIdInput() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() DataAwsNetworkmanagerDeviceLocationList
Model() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
SerialNumber() *string
SiteId() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Type() *string
Vendor() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/networkmanager_device aws_networkmanager_device}.
func NewDataAwsNetworkmanagerDevice ¶
func NewDataAwsNetworkmanagerDevice(scope constructs.Construct, id *string, config *DataAwsNetworkmanagerDeviceConfig) DataAwsNetworkmanagerDevice
Create a new {@link https://www.terraform.io/docs/providers/aws/d/networkmanager_device aws_networkmanager_device} Data Source.
type DataAwsNetworkmanagerDeviceAwsLocation ¶
type DataAwsNetworkmanagerDeviceAwsLocation struct {
}
type DataAwsNetworkmanagerDeviceAwsLocationList ¶
type DataAwsNetworkmanagerDeviceAwsLocationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsNetworkmanagerDeviceAwsLocationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkmanagerDeviceAwsLocationList ¶
func NewDataAwsNetworkmanagerDeviceAwsLocationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsNetworkmanagerDeviceAwsLocationList
type DataAwsNetworkmanagerDeviceAwsLocationOutputReference ¶
type DataAwsNetworkmanagerDeviceAwsLocationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsNetworkmanagerDeviceAwsLocation
SetInternalValue(val *DataAwsNetworkmanagerDeviceAwsLocation)
SubnetArn() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Zone() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkmanagerDeviceAwsLocationOutputReference ¶
func NewDataAwsNetworkmanagerDeviceAwsLocationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsNetworkmanagerDeviceAwsLocationOutputReference
type DataAwsNetworkmanagerDeviceConfig ¶
type DataAwsNetworkmanagerDeviceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/networkmanager_device#device_id DataAwsNetworkmanagerDevice#device_id}.
DeviceId *string `field:"required" json:"deviceId" yaml:"deviceId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/networkmanager_device#global_network_id DataAwsNetworkmanagerDevice#global_network_id}.
GlobalNetworkId *string `field:"required" json:"globalNetworkId" yaml:"globalNetworkId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/networkmanager_device#id DataAwsNetworkmanagerDevice#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/networkmanager_device#tags DataAwsNetworkmanagerDevice#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsNetworkmanagerDeviceLocation ¶
type DataAwsNetworkmanagerDeviceLocation struct {
}
type DataAwsNetworkmanagerDeviceLocationList ¶
type DataAwsNetworkmanagerDeviceLocationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsNetworkmanagerDeviceLocationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkmanagerDeviceLocationList ¶
func NewDataAwsNetworkmanagerDeviceLocationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsNetworkmanagerDeviceLocationList
type DataAwsNetworkmanagerDeviceLocationOutputReference ¶
type DataAwsNetworkmanagerDeviceLocationOutputReference interface {
cdktf.ComplexObject
Address() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsNetworkmanagerDeviceLocation
SetInternalValue(val *DataAwsNetworkmanagerDeviceLocation)
Latitude() *string
Longitude() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkmanagerDeviceLocationOutputReference ¶
func NewDataAwsNetworkmanagerDeviceLocationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsNetworkmanagerDeviceLocationOutputReference
Source Files
¶
- DataAwsNetworkmanagerDevice.go
- DataAwsNetworkmanagerDeviceAwsLocation.go
- DataAwsNetworkmanagerDeviceAwsLocationList.go
- DataAwsNetworkmanagerDeviceAwsLocationList__checks.go
- DataAwsNetworkmanagerDeviceAwsLocationOutputReference.go
- DataAwsNetworkmanagerDeviceAwsLocationOutputReference__checks.go
- DataAwsNetworkmanagerDeviceConfig.go
- DataAwsNetworkmanagerDeviceLocation.go
- DataAwsNetworkmanagerDeviceLocationList.go
- DataAwsNetworkmanagerDeviceLocationList__checks.go
- DataAwsNetworkmanagerDeviceLocationOutputReference.go
- DataAwsNetworkmanagerDeviceLocationOutputReference__checks.go
- DataAwsNetworkmanagerDevice__checks.go
- main.go