Documentation
¶
Index ¶
- func DataAwsServiceDiscoveryService_IsConstruct(x interface{}) *bool
- func DataAwsServiceDiscoveryService_IsTerraformDataSource(x interface{}) *bool
- func DataAwsServiceDiscoveryService_IsTerraformElement(x interface{}) *bool
- func DataAwsServiceDiscoveryService_TfResourceType() *string
- func NewDataAwsServiceDiscoveryServiceDnsConfigDnsRecordsList_Override(d DataAwsServiceDiscoveryServiceDnsConfigDnsRecordsList, ...)
- func NewDataAwsServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference_Override(d DataAwsServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference, ...)
- func NewDataAwsServiceDiscoveryServiceDnsConfigList_Override(d DataAwsServiceDiscoveryServiceDnsConfigList, ...)
- func NewDataAwsServiceDiscoveryServiceDnsConfigOutputReference_Override(d DataAwsServiceDiscoveryServiceDnsConfigOutputReference, ...)
- func NewDataAwsServiceDiscoveryServiceHealthCheckConfigList_Override(d DataAwsServiceDiscoveryServiceHealthCheckConfigList, ...)
- func NewDataAwsServiceDiscoveryServiceHealthCheckConfigOutputReference_Override(d DataAwsServiceDiscoveryServiceHealthCheckConfigOutputReference, ...)
- func NewDataAwsServiceDiscoveryServiceHealthCheckCustomConfigList_Override(d DataAwsServiceDiscoveryServiceHealthCheckCustomConfigList, ...)
- func NewDataAwsServiceDiscoveryServiceHealthCheckCustomConfigOutputReference_Override(d DataAwsServiceDiscoveryServiceHealthCheckCustomConfigOutputReference, ...)
- func NewDataAwsServiceDiscoveryService_Override(d DataAwsServiceDiscoveryService, scope constructs.Construct, id *string, ...)
- type DataAwsServiceDiscoveryService
- type DataAwsServiceDiscoveryServiceConfig
- type DataAwsServiceDiscoveryServiceDnsConfig
- type DataAwsServiceDiscoveryServiceDnsConfigDnsRecords
- type DataAwsServiceDiscoveryServiceDnsConfigDnsRecordsList
- type DataAwsServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference
- type DataAwsServiceDiscoveryServiceDnsConfigList
- type DataAwsServiceDiscoveryServiceDnsConfigOutputReference
- type DataAwsServiceDiscoveryServiceHealthCheckConfig
- type DataAwsServiceDiscoveryServiceHealthCheckConfigList
- type DataAwsServiceDiscoveryServiceHealthCheckConfigOutputReference
- type DataAwsServiceDiscoveryServiceHealthCheckCustomConfig
- type DataAwsServiceDiscoveryServiceHealthCheckCustomConfigList
- type DataAwsServiceDiscoveryServiceHealthCheckCustomConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsServiceDiscoveryService_IsConstruct ¶
func DataAwsServiceDiscoveryService_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsServiceDiscoveryService_IsTerraformDataSource ¶
func DataAwsServiceDiscoveryService_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsServiceDiscoveryService_IsTerraformElement ¶
func DataAwsServiceDiscoveryService_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsServiceDiscoveryService_TfResourceType ¶
func DataAwsServiceDiscoveryService_TfResourceType() *string
func NewDataAwsServiceDiscoveryServiceDnsConfigDnsRecordsList_Override ¶
func NewDataAwsServiceDiscoveryServiceDnsConfigDnsRecordsList_Override(d DataAwsServiceDiscoveryServiceDnsConfigDnsRecordsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference_Override ¶
func NewDataAwsServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference_Override(d DataAwsServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsServiceDiscoveryServiceDnsConfigList_Override ¶
func NewDataAwsServiceDiscoveryServiceDnsConfigList_Override(d DataAwsServiceDiscoveryServiceDnsConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsServiceDiscoveryServiceDnsConfigOutputReference_Override ¶
func NewDataAwsServiceDiscoveryServiceDnsConfigOutputReference_Override(d DataAwsServiceDiscoveryServiceDnsConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsServiceDiscoveryServiceHealthCheckConfigList_Override ¶
func NewDataAwsServiceDiscoveryServiceHealthCheckConfigList_Override(d DataAwsServiceDiscoveryServiceHealthCheckConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsServiceDiscoveryServiceHealthCheckConfigOutputReference_Override ¶
func NewDataAwsServiceDiscoveryServiceHealthCheckConfigOutputReference_Override(d DataAwsServiceDiscoveryServiceHealthCheckConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsServiceDiscoveryServiceHealthCheckCustomConfigList_Override ¶
func NewDataAwsServiceDiscoveryServiceHealthCheckCustomConfigList_Override(d DataAwsServiceDiscoveryServiceHealthCheckCustomConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsServiceDiscoveryServiceHealthCheckCustomConfigOutputReference_Override ¶
func NewDataAwsServiceDiscoveryServiceHealthCheckCustomConfigOutputReference_Override(d DataAwsServiceDiscoveryServiceHealthCheckCustomConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsServiceDiscoveryService_Override ¶
func NewDataAwsServiceDiscoveryService_Override(d DataAwsServiceDiscoveryService, scope constructs.Construct, id *string, config *DataAwsServiceDiscoveryServiceConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/service_discovery_service aws_service_discovery_service} Data Source.
Types ¶
type DataAwsServiceDiscoveryService ¶
type DataAwsServiceDiscoveryService interface {
cdktf.TerraformDataSource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
DnsConfig() DataAwsServiceDiscoveryServiceDnsConfigList
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HealthCheckConfig() DataAwsServiceDiscoveryServiceHealthCheckConfigList
HealthCheckCustomConfig() DataAwsServiceDiscoveryServiceHealthCheckCustomConfigList
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
NamespaceId() *string
SetNamespaceId(val *string)
NamespaceIdInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/service_discovery_service aws_service_discovery_service}.
func NewDataAwsServiceDiscoveryService ¶
func NewDataAwsServiceDiscoveryService(scope constructs.Construct, id *string, config *DataAwsServiceDiscoveryServiceConfig) DataAwsServiceDiscoveryService
Create a new {@link https://www.terraform.io/docs/providers/aws/d/service_discovery_service aws_service_discovery_service} Data Source.
type DataAwsServiceDiscoveryServiceConfig ¶
type DataAwsServiceDiscoveryServiceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/service_discovery_service#name DataAwsServiceDiscoveryService#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/service_discovery_service#namespace_id DataAwsServiceDiscoveryService#namespace_id}.
NamespaceId *string `field:"required" json:"namespaceId" yaml:"namespaceId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/service_discovery_service#id DataAwsServiceDiscoveryService#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/service_discovery_service#tags DataAwsServiceDiscoveryService#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/service_discovery_service#tags_all DataAwsServiceDiscoveryService#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type DataAwsServiceDiscoveryServiceDnsConfig ¶
type DataAwsServiceDiscoveryServiceDnsConfig struct {
}
type DataAwsServiceDiscoveryServiceDnsConfigDnsRecords ¶
type DataAwsServiceDiscoveryServiceDnsConfigDnsRecords struct {
}
type DataAwsServiceDiscoveryServiceDnsConfigDnsRecordsList ¶
type DataAwsServiceDiscoveryServiceDnsConfigDnsRecordsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsServiceDiscoveryServiceDnsConfigDnsRecordsList ¶
func NewDataAwsServiceDiscoveryServiceDnsConfigDnsRecordsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsServiceDiscoveryServiceDnsConfigDnsRecordsList
type DataAwsServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference ¶
type DataAwsServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsServiceDiscoveryServiceDnsConfigDnsRecords
SetInternalValue(val *DataAwsServiceDiscoveryServiceDnsConfigDnsRecords)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Ttl() *float64
Type() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference ¶
func NewDataAwsServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference
type DataAwsServiceDiscoveryServiceDnsConfigList ¶
type DataAwsServiceDiscoveryServiceDnsConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsServiceDiscoveryServiceDnsConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsServiceDiscoveryServiceDnsConfigList ¶
func NewDataAwsServiceDiscoveryServiceDnsConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsServiceDiscoveryServiceDnsConfigList
type DataAwsServiceDiscoveryServiceDnsConfigOutputReference ¶
type DataAwsServiceDiscoveryServiceDnsConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DnsRecords() DataAwsServiceDiscoveryServiceDnsConfigDnsRecordsList
// Experimental.
Fqn() *string
InternalValue() *DataAwsServiceDiscoveryServiceDnsConfig
SetInternalValue(val *DataAwsServiceDiscoveryServiceDnsConfig)
NamespaceId() *string
RoutingPolicy() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsServiceDiscoveryServiceDnsConfigOutputReference ¶
func NewDataAwsServiceDiscoveryServiceDnsConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsServiceDiscoveryServiceDnsConfigOutputReference
type DataAwsServiceDiscoveryServiceHealthCheckConfig ¶
type DataAwsServiceDiscoveryServiceHealthCheckConfig struct {
}
type DataAwsServiceDiscoveryServiceHealthCheckConfigList ¶
type DataAwsServiceDiscoveryServiceHealthCheckConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsServiceDiscoveryServiceHealthCheckConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsServiceDiscoveryServiceHealthCheckConfigList ¶
func NewDataAwsServiceDiscoveryServiceHealthCheckConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsServiceDiscoveryServiceHealthCheckConfigList
type DataAwsServiceDiscoveryServiceHealthCheckConfigOutputReference ¶
type DataAwsServiceDiscoveryServiceHealthCheckConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FailureThreshold() *float64
// Experimental.
Fqn() *string
InternalValue() *DataAwsServiceDiscoveryServiceHealthCheckConfig
SetInternalValue(val *DataAwsServiceDiscoveryServiceHealthCheckConfig)
ResourcePath() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsServiceDiscoveryServiceHealthCheckConfigOutputReference ¶
func NewDataAwsServiceDiscoveryServiceHealthCheckConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsServiceDiscoveryServiceHealthCheckConfigOutputReference
type DataAwsServiceDiscoveryServiceHealthCheckCustomConfig ¶
type DataAwsServiceDiscoveryServiceHealthCheckCustomConfig struct {
}
type DataAwsServiceDiscoveryServiceHealthCheckCustomConfigList ¶
type DataAwsServiceDiscoveryServiceHealthCheckCustomConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsServiceDiscoveryServiceHealthCheckCustomConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsServiceDiscoveryServiceHealthCheckCustomConfigList ¶
func NewDataAwsServiceDiscoveryServiceHealthCheckCustomConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsServiceDiscoveryServiceHealthCheckCustomConfigList
type DataAwsServiceDiscoveryServiceHealthCheckCustomConfigOutputReference ¶
type DataAwsServiceDiscoveryServiceHealthCheckCustomConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FailureThreshold() *float64
// Experimental.
Fqn() *string
InternalValue() *DataAwsServiceDiscoveryServiceHealthCheckCustomConfig
SetInternalValue(val *DataAwsServiceDiscoveryServiceHealthCheckCustomConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsServiceDiscoveryServiceHealthCheckCustomConfigOutputReference ¶
func NewDataAwsServiceDiscoveryServiceHealthCheckCustomConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsServiceDiscoveryServiceHealthCheckCustomConfigOutputReference
Source Files
¶
- DataAwsServiceDiscoveryService.go
- DataAwsServiceDiscoveryServiceConfig.go
- DataAwsServiceDiscoveryServiceDnsConfig.go
- DataAwsServiceDiscoveryServiceDnsConfigDnsRecords.go
- DataAwsServiceDiscoveryServiceDnsConfigDnsRecordsList.go
- DataAwsServiceDiscoveryServiceDnsConfigDnsRecordsList__checks.go
- DataAwsServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference.go
- DataAwsServiceDiscoveryServiceDnsConfigDnsRecordsOutputReference__checks.go
- DataAwsServiceDiscoveryServiceDnsConfigList.go
- DataAwsServiceDiscoveryServiceDnsConfigList__checks.go
- DataAwsServiceDiscoveryServiceDnsConfigOutputReference.go
- DataAwsServiceDiscoveryServiceDnsConfigOutputReference__checks.go
- DataAwsServiceDiscoveryServiceHealthCheckConfig.go
- DataAwsServiceDiscoveryServiceHealthCheckConfigList.go
- DataAwsServiceDiscoveryServiceHealthCheckConfigList__checks.go
- DataAwsServiceDiscoveryServiceHealthCheckConfigOutputReference.go
- DataAwsServiceDiscoveryServiceHealthCheckConfigOutputReference__checks.go
- DataAwsServiceDiscoveryServiceHealthCheckCustomConfig.go
- DataAwsServiceDiscoveryServiceHealthCheckCustomConfigList.go
- DataAwsServiceDiscoveryServiceHealthCheckCustomConfigList__checks.go
- DataAwsServiceDiscoveryServiceHealthCheckCustomConfigOutputReference.go
- DataAwsServiceDiscoveryServiceHealthCheckCustomConfigOutputReference__checks.go
- DataAwsServiceDiscoveryService__checks.go
- main.go