Documentation
¶
Index ¶
- func DataAwsSsmincidentsReplicationSet_IsConstruct(x interface{}) *bool
- func DataAwsSsmincidentsReplicationSet_IsTerraformDataSource(x interface{}) *bool
- func DataAwsSsmincidentsReplicationSet_IsTerraformElement(x interface{}) *bool
- func DataAwsSsmincidentsReplicationSet_TfResourceType() *string
- func NewDataAwsSsmincidentsReplicationSetRegionList_Override(d DataAwsSsmincidentsReplicationSetRegionList, ...)
- func NewDataAwsSsmincidentsReplicationSetRegionOutputReference_Override(d DataAwsSsmincidentsReplicationSetRegionOutputReference, ...)
- func NewDataAwsSsmincidentsReplicationSet_Override(d DataAwsSsmincidentsReplicationSet, scope constructs.Construct, id *string, ...)
- type DataAwsSsmincidentsReplicationSet
- type DataAwsSsmincidentsReplicationSetConfig
- type DataAwsSsmincidentsReplicationSetRegion
- type DataAwsSsmincidentsReplicationSetRegionList
- type DataAwsSsmincidentsReplicationSetRegionOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsSsmincidentsReplicationSet_IsConstruct ¶
func DataAwsSsmincidentsReplicationSet_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsSsmincidentsReplicationSet_IsTerraformDataSource ¶
func DataAwsSsmincidentsReplicationSet_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsSsmincidentsReplicationSet_IsTerraformElement ¶
func DataAwsSsmincidentsReplicationSet_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsSsmincidentsReplicationSet_TfResourceType ¶
func DataAwsSsmincidentsReplicationSet_TfResourceType() *string
func NewDataAwsSsmincidentsReplicationSetRegionList_Override ¶
func NewDataAwsSsmincidentsReplicationSetRegionList_Override(d DataAwsSsmincidentsReplicationSetRegionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsSsmincidentsReplicationSetRegionOutputReference_Override ¶
func NewDataAwsSsmincidentsReplicationSetRegionOutputReference_Override(d DataAwsSsmincidentsReplicationSetRegionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsSsmincidentsReplicationSet_Override ¶
func NewDataAwsSsmincidentsReplicationSet_Override(d DataAwsSsmincidentsReplicationSet, scope constructs.Construct, id *string, config *DataAwsSsmincidentsReplicationSetConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/ssmincidents_replication_set aws_ssmincidents_replication_set} Data Source.
Types ¶
type DataAwsSsmincidentsReplicationSet ¶
type DataAwsSsmincidentsReplicationSet interface {
cdktf.TerraformDataSource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreatedBy() *string
DeletionProtected() cdktf.IResolvable
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
LastModifiedBy() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Region() DataAwsSsmincidentsReplicationSetRegionList
Status() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/ssmincidents_replication_set aws_ssmincidents_replication_set}.
func NewDataAwsSsmincidentsReplicationSet ¶
func NewDataAwsSsmincidentsReplicationSet(scope constructs.Construct, id *string, config *DataAwsSsmincidentsReplicationSetConfig) DataAwsSsmincidentsReplicationSet
Create a new {@link https://www.terraform.io/docs/providers/aws/d/ssmincidents_replication_set aws_ssmincidents_replication_set} Data Source.
type DataAwsSsmincidentsReplicationSetConfig ¶
type DataAwsSsmincidentsReplicationSetConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ssmincidents_replication_set#id DataAwsSsmincidentsReplicationSet#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ssmincidents_replication_set#tags DataAwsSsmincidentsReplicationSet#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsSsmincidentsReplicationSetRegion ¶
type DataAwsSsmincidentsReplicationSetRegion struct {
}
type DataAwsSsmincidentsReplicationSetRegionList ¶
type DataAwsSsmincidentsReplicationSetRegionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsSsmincidentsReplicationSetRegionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSsmincidentsReplicationSetRegionList ¶
func NewDataAwsSsmincidentsReplicationSetRegionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsSsmincidentsReplicationSetRegionList
type DataAwsSsmincidentsReplicationSetRegionOutputReference ¶
type DataAwsSsmincidentsReplicationSetRegionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsSsmincidentsReplicationSetRegion
SetInternalValue(val *DataAwsSsmincidentsReplicationSetRegion)
KmsKeyArn() *string
Name() *string
Status() *string
StatusMessage() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSsmincidentsReplicationSetRegionOutputReference ¶
func NewDataAwsSsmincidentsReplicationSetRegionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsSsmincidentsReplicationSetRegionOutputReference
Source Files
¶
- DataAwsSsmincidentsReplicationSet.go
- DataAwsSsmincidentsReplicationSetConfig.go
- DataAwsSsmincidentsReplicationSetRegion.go
- DataAwsSsmincidentsReplicationSetRegionList.go
- DataAwsSsmincidentsReplicationSetRegionList__checks.go
- DataAwsSsmincidentsReplicationSetRegionOutputReference.go
- DataAwsSsmincidentsReplicationSetRegionOutputReference__checks.go
- DataAwsSsmincidentsReplicationSet__checks.go
- main.go