Documentation
¶
Index ¶
- func DataAwsWorkspacesDirectory_IsConstruct(x interface{}) *bool
- func DataAwsWorkspacesDirectory_IsTerraformDataSource(x interface{}) *bool
- func DataAwsWorkspacesDirectory_IsTerraformElement(x interface{}) *bool
- func DataAwsWorkspacesDirectory_TfResourceType() *string
- func NewDataAwsWorkspacesDirectorySelfServicePermissionsList_Override(d DataAwsWorkspacesDirectorySelfServicePermissionsList, ...)
- func NewDataAwsWorkspacesDirectorySelfServicePermissionsOutputReference_Override(d DataAwsWorkspacesDirectorySelfServicePermissionsOutputReference, ...)
- func NewDataAwsWorkspacesDirectoryWorkspaceAccessPropertiesList_Override(d DataAwsWorkspacesDirectoryWorkspaceAccessPropertiesList, ...)
- func NewDataAwsWorkspacesDirectoryWorkspaceAccessPropertiesOutputReference_Override(d DataAwsWorkspacesDirectoryWorkspaceAccessPropertiesOutputReference, ...)
- func NewDataAwsWorkspacesDirectoryWorkspaceCreationPropertiesList_Override(d DataAwsWorkspacesDirectoryWorkspaceCreationPropertiesList, ...)
- func NewDataAwsWorkspacesDirectoryWorkspaceCreationPropertiesOutputReference_Override(d DataAwsWorkspacesDirectoryWorkspaceCreationPropertiesOutputReference, ...)
- func NewDataAwsWorkspacesDirectory_Override(d DataAwsWorkspacesDirectory, scope constructs.Construct, id *string, ...)
- type DataAwsWorkspacesDirectory
- type DataAwsWorkspacesDirectoryConfig
- type DataAwsWorkspacesDirectorySelfServicePermissions
- type DataAwsWorkspacesDirectorySelfServicePermissionsList
- type DataAwsWorkspacesDirectorySelfServicePermissionsOutputReference
- type DataAwsWorkspacesDirectoryWorkspaceAccessProperties
- type DataAwsWorkspacesDirectoryWorkspaceAccessPropertiesList
- type DataAwsWorkspacesDirectoryWorkspaceAccessPropertiesOutputReference
- type DataAwsWorkspacesDirectoryWorkspaceCreationProperties
- type DataAwsWorkspacesDirectoryWorkspaceCreationPropertiesList
- type DataAwsWorkspacesDirectoryWorkspaceCreationPropertiesOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsWorkspacesDirectory_IsConstruct ¶
func DataAwsWorkspacesDirectory_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsWorkspacesDirectory_IsTerraformDataSource ¶
func DataAwsWorkspacesDirectory_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsWorkspacesDirectory_IsTerraformElement ¶
func DataAwsWorkspacesDirectory_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsWorkspacesDirectory_TfResourceType ¶
func DataAwsWorkspacesDirectory_TfResourceType() *string
func NewDataAwsWorkspacesDirectorySelfServicePermissionsList_Override ¶
func NewDataAwsWorkspacesDirectorySelfServicePermissionsList_Override(d DataAwsWorkspacesDirectorySelfServicePermissionsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsWorkspacesDirectorySelfServicePermissionsOutputReference_Override ¶
func NewDataAwsWorkspacesDirectorySelfServicePermissionsOutputReference_Override(d DataAwsWorkspacesDirectorySelfServicePermissionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsWorkspacesDirectoryWorkspaceAccessPropertiesList_Override ¶
func NewDataAwsWorkspacesDirectoryWorkspaceAccessPropertiesList_Override(d DataAwsWorkspacesDirectoryWorkspaceAccessPropertiesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsWorkspacesDirectoryWorkspaceAccessPropertiesOutputReference_Override ¶
func NewDataAwsWorkspacesDirectoryWorkspaceAccessPropertiesOutputReference_Override(d DataAwsWorkspacesDirectoryWorkspaceAccessPropertiesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsWorkspacesDirectoryWorkspaceCreationPropertiesList_Override ¶
func NewDataAwsWorkspacesDirectoryWorkspaceCreationPropertiesList_Override(d DataAwsWorkspacesDirectoryWorkspaceCreationPropertiesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsWorkspacesDirectoryWorkspaceCreationPropertiesOutputReference_Override ¶
func NewDataAwsWorkspacesDirectoryWorkspaceCreationPropertiesOutputReference_Override(d DataAwsWorkspacesDirectoryWorkspaceCreationPropertiesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsWorkspacesDirectory_Override ¶
func NewDataAwsWorkspacesDirectory_Override(d DataAwsWorkspacesDirectory, scope constructs.Construct, id *string, config *DataAwsWorkspacesDirectoryConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/d/workspaces_directory aws_workspaces_directory} Data Source.
Types ¶
type DataAwsWorkspacesDirectory ¶
type DataAwsWorkspacesDirectory interface {
cdktf.TerraformDataSource
Alias() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CustomerUserName() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DirectoryId() *string
SetDirectoryId(val *string)
DirectoryIdInput() *string
DirectoryName() *string
DirectoryType() *string
DnsIpAddresses() *[]*string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
IamRoleId() *string
Id() *string
SetId(val *string)
IdInput() *string
IpGroupIds() *[]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
RegistrationCode() *string
SelfServicePermissions() DataAwsWorkspacesDirectorySelfServicePermissionsList
SubnetIds() *[]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
WorkspaceAccessProperties() DataAwsWorkspacesDirectoryWorkspaceAccessPropertiesList
WorkspaceCreationProperties() DataAwsWorkspacesDirectoryWorkspaceCreationPropertiesList
WorkspaceSecurityGroupId() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/d/workspaces_directory aws_workspaces_directory}.
func NewDataAwsWorkspacesDirectory ¶
func NewDataAwsWorkspacesDirectory(scope constructs.Construct, id *string, config *DataAwsWorkspacesDirectoryConfig) DataAwsWorkspacesDirectory
Create a new {@link https://www.terraform.io/docs/providers/aws/d/workspaces_directory aws_workspaces_directory} Data Source.
type DataAwsWorkspacesDirectoryConfig ¶
type DataAwsWorkspacesDirectoryConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/workspaces_directory#directory_id DataAwsWorkspacesDirectory#directory_id}.
DirectoryId *string `field:"required" json:"directoryId" yaml:"directoryId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/workspaces_directory#id DataAwsWorkspacesDirectory#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/workspaces_directory#tags DataAwsWorkspacesDirectory#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsWorkspacesDirectorySelfServicePermissions ¶
type DataAwsWorkspacesDirectorySelfServicePermissions struct {
}
type DataAwsWorkspacesDirectorySelfServicePermissionsList ¶
type DataAwsWorkspacesDirectorySelfServicePermissionsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsWorkspacesDirectorySelfServicePermissionsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsWorkspacesDirectorySelfServicePermissionsList ¶
func NewDataAwsWorkspacesDirectorySelfServicePermissionsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsWorkspacesDirectorySelfServicePermissionsList
type DataAwsWorkspacesDirectorySelfServicePermissionsOutputReference ¶
type DataAwsWorkspacesDirectorySelfServicePermissionsOutputReference interface {
cdktf.ComplexObject
ChangeComputeType() cdktf.IResolvable
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IncreaseVolumeSize() cdktf.IResolvable
InternalValue() *DataAwsWorkspacesDirectorySelfServicePermissions
SetInternalValue(val *DataAwsWorkspacesDirectorySelfServicePermissions)
RebuildWorkspace() cdktf.IResolvable
RestartWorkspace() cdktf.IResolvable
SwitchRunningMode() cdktf.IResolvable
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsWorkspacesDirectorySelfServicePermissionsOutputReference ¶
func NewDataAwsWorkspacesDirectorySelfServicePermissionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsWorkspacesDirectorySelfServicePermissionsOutputReference
type DataAwsWorkspacesDirectoryWorkspaceAccessProperties ¶
type DataAwsWorkspacesDirectoryWorkspaceAccessProperties struct {
}
type DataAwsWorkspacesDirectoryWorkspaceAccessPropertiesList ¶
type DataAwsWorkspacesDirectoryWorkspaceAccessPropertiesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsWorkspacesDirectoryWorkspaceAccessPropertiesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsWorkspacesDirectoryWorkspaceAccessPropertiesList ¶
func NewDataAwsWorkspacesDirectoryWorkspaceAccessPropertiesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsWorkspacesDirectoryWorkspaceAccessPropertiesList
type DataAwsWorkspacesDirectoryWorkspaceAccessPropertiesOutputReference ¶
type DataAwsWorkspacesDirectoryWorkspaceAccessPropertiesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeviceTypeAndroid() *string
DeviceTypeChromeos() *string
DeviceTypeIos() *string
DeviceTypeLinux() *string
DeviceTypeOsx() *string
DeviceTypeWeb() *string
DeviceTypeWindows() *string
DeviceTypeZeroclient() *string
// Experimental.
Fqn() *string
InternalValue() *DataAwsWorkspacesDirectoryWorkspaceAccessProperties
SetInternalValue(val *DataAwsWorkspacesDirectoryWorkspaceAccessProperties)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsWorkspacesDirectoryWorkspaceAccessPropertiesOutputReference ¶
func NewDataAwsWorkspacesDirectoryWorkspaceAccessPropertiesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsWorkspacesDirectoryWorkspaceAccessPropertiesOutputReference
type DataAwsWorkspacesDirectoryWorkspaceCreationProperties ¶
type DataAwsWorkspacesDirectoryWorkspaceCreationProperties struct {
}
type DataAwsWorkspacesDirectoryWorkspaceCreationPropertiesList ¶
type DataAwsWorkspacesDirectoryWorkspaceCreationPropertiesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsWorkspacesDirectoryWorkspaceCreationPropertiesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsWorkspacesDirectoryWorkspaceCreationPropertiesList ¶
func NewDataAwsWorkspacesDirectoryWorkspaceCreationPropertiesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsWorkspacesDirectoryWorkspaceCreationPropertiesList
type DataAwsWorkspacesDirectoryWorkspaceCreationPropertiesOutputReference ¶
type DataAwsWorkspacesDirectoryWorkspaceCreationPropertiesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
CustomSecurityGroupId() *string
DefaultOu() *string
EnableInternetAccess() cdktf.IResolvable
EnableMaintenanceMode() cdktf.IResolvable
// Experimental.
Fqn() *string
InternalValue() *DataAwsWorkspacesDirectoryWorkspaceCreationProperties
SetInternalValue(val *DataAwsWorkspacesDirectoryWorkspaceCreationProperties)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UserEnabledAsLocalAdministrator() cdktf.IResolvable
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsWorkspacesDirectoryWorkspaceCreationPropertiesOutputReference ¶
func NewDataAwsWorkspacesDirectoryWorkspaceCreationPropertiesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsWorkspacesDirectoryWorkspaceCreationPropertiesOutputReference
Source Files
¶
- DataAwsWorkspacesDirectory.go
- DataAwsWorkspacesDirectoryConfig.go
- DataAwsWorkspacesDirectorySelfServicePermissions.go
- DataAwsWorkspacesDirectorySelfServicePermissionsList.go
- DataAwsWorkspacesDirectorySelfServicePermissionsList__checks.go
- DataAwsWorkspacesDirectorySelfServicePermissionsOutputReference.go
- DataAwsWorkspacesDirectorySelfServicePermissionsOutputReference__checks.go
- DataAwsWorkspacesDirectoryWorkspaceAccessProperties.go
- DataAwsWorkspacesDirectoryWorkspaceAccessPropertiesList.go
- DataAwsWorkspacesDirectoryWorkspaceAccessPropertiesList__checks.go
- DataAwsWorkspacesDirectoryWorkspaceAccessPropertiesOutputReference.go
- DataAwsWorkspacesDirectoryWorkspaceAccessPropertiesOutputReference__checks.go
- DataAwsWorkspacesDirectoryWorkspaceCreationProperties.go
- DataAwsWorkspacesDirectoryWorkspaceCreationPropertiesList.go
- DataAwsWorkspacesDirectoryWorkspaceCreationPropertiesList__checks.go
- DataAwsWorkspacesDirectoryWorkspaceCreationPropertiesOutputReference.go
- DataAwsWorkspacesDirectoryWorkspaceCreationPropertiesOutputReference__checks.go
- DataAwsWorkspacesDirectory__checks.go
- main.go