Documentation
¶
Index ¶
- func DbSnapshotCopy_IsConstruct(x interface{}) *bool
- func DbSnapshotCopy_IsTerraformElement(x interface{}) *bool
- func DbSnapshotCopy_IsTerraformResource(x interface{}) *bool
- func DbSnapshotCopy_TfResourceType() *string
- func NewDbSnapshotCopyTimeoutsOutputReference_Override(d DbSnapshotCopyTimeoutsOutputReference, ...)
- func NewDbSnapshotCopy_Override(d DbSnapshotCopy, scope constructs.Construct, id *string, ...)
- type DbSnapshotCopy
- type DbSnapshotCopyConfig
- type DbSnapshotCopyTimeouts
- type DbSnapshotCopyTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DbSnapshotCopy_IsConstruct ¶
func DbSnapshotCopy_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DbSnapshotCopy_IsTerraformElement ¶
func DbSnapshotCopy_IsTerraformElement(x interface{}) *bool
Experimental.
func DbSnapshotCopy_IsTerraformResource ¶
func DbSnapshotCopy_IsTerraformResource(x interface{}) *bool
Experimental.
func DbSnapshotCopy_TfResourceType ¶
func DbSnapshotCopy_TfResourceType() *string
func NewDbSnapshotCopyTimeoutsOutputReference_Override ¶
func NewDbSnapshotCopyTimeoutsOutputReference_Override(d DbSnapshotCopyTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDbSnapshotCopy_Override ¶
func NewDbSnapshotCopy_Override(d DbSnapshotCopy, scope constructs.Construct, id *string, config *DbSnapshotCopyConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot_copy aws_db_snapshot_copy} Resource.
Types ¶
type DbSnapshotCopy ¶
type DbSnapshotCopy interface {
cdktf.TerraformResource
AllocatedStorage() *float64
AvailabilityZone() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
CopyTags() interface{}
SetCopyTags(val interface{})
CopyTagsInput() interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DbSnapshotArn() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DestinationRegion() *string
SetDestinationRegion(val *string)
DestinationRegionInput() *string
Encrypted() cdktf.IResolvable
Engine() *string
EngineVersion() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Iops() *float64
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
LicenseModel() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
OptionGroupName() *string
SetOptionGroupName(val *string)
OptionGroupNameInput() *string
Port() *float64
PresignedUrl() *string
SetPresignedUrl(val *string)
PresignedUrlInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SnapshotType() *string
SourceDbSnapshotIdentifier() *string
SetSourceDbSnapshotIdentifier(val *string)
SourceDbSnapshotIdentifierInput() *string
SourceRegion() *string
StorageType() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
TargetCustomAvailabilityZone() *string
SetTargetCustomAvailabilityZone(val *string)
TargetCustomAvailabilityZoneInput() *string
TargetDbSnapshotIdentifier() *string
SetTargetDbSnapshotIdentifier(val *string)
TargetDbSnapshotIdentifierInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DbSnapshotCopyTimeoutsOutputReference
TimeoutsInput() interface{}
VpcId() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *DbSnapshotCopyTimeouts)
ResetCopyTags()
ResetDestinationRegion()
ResetId()
ResetKmsKeyId()
ResetOptionGroupName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPresignedUrl()
ResetTags()
ResetTagsAll()
ResetTargetCustomAvailabilityZone()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot_copy aws_db_snapshot_copy}.
func NewDbSnapshotCopy ¶
func NewDbSnapshotCopy(scope constructs.Construct, id *string, config *DbSnapshotCopyConfig) DbSnapshotCopy
Create a new {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot_copy aws_db_snapshot_copy} Resource.
type DbSnapshotCopyConfig ¶
type DbSnapshotCopyConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot_copy#source_db_snapshot_identifier DbSnapshotCopy#source_db_snapshot_identifier}.
SourceDbSnapshotIdentifier *string `field:"required" json:"sourceDbSnapshotIdentifier" yaml:"sourceDbSnapshotIdentifier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot_copy#target_db_snapshot_identifier DbSnapshotCopy#target_db_snapshot_identifier}.
TargetDbSnapshotIdentifier *string `field:"required" json:"targetDbSnapshotIdentifier" yaml:"targetDbSnapshotIdentifier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot_copy#copy_tags DbSnapshotCopy#copy_tags}.
CopyTags interface{} `field:"optional" json:"copyTags" yaml:"copyTags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot_copy#destination_region DbSnapshotCopy#destination_region}.
DestinationRegion *string `field:"optional" json:"destinationRegion" yaml:"destinationRegion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot_copy#id DbSnapshotCopy#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot_copy#kms_key_id DbSnapshotCopy#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot_copy#option_group_name DbSnapshotCopy#option_group_name}.
OptionGroupName *string `field:"optional" json:"optionGroupName" yaml:"optionGroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot_copy#presigned_url DbSnapshotCopy#presigned_url}.
PresignedUrl *string `field:"optional" json:"presignedUrl" yaml:"presignedUrl"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot_copy#tags DbSnapshotCopy#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot_copy#tags_all DbSnapshotCopy#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot_copy#target_custom_availability_zone DbSnapshotCopy#target_custom_availability_zone}.
TargetCustomAvailabilityZone *string `field:"optional" json:"targetCustomAvailabilityZone" yaml:"targetCustomAvailabilityZone"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot_copy#timeouts DbSnapshotCopy#timeouts}
Timeouts *DbSnapshotCopyTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type DbSnapshotCopyTimeouts ¶
type DbSnapshotCopyTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot_copy#create DbSnapshotCopy#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
}
type DbSnapshotCopyTimeoutsOutputReference ¶
type DbSnapshotCopyTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDbSnapshotCopyTimeoutsOutputReference ¶
func NewDbSnapshotCopyTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DbSnapshotCopyTimeoutsOutputReference