Documentation
¶
Index ¶
- func DefaultSecurityGroup_IsConstruct(x interface{}) *bool
- func DefaultSecurityGroup_IsTerraformElement(x interface{}) *bool
- func DefaultSecurityGroup_IsTerraformResource(x interface{}) *bool
- func DefaultSecurityGroup_TfResourceType() *string
- func NewDefaultSecurityGroupEgressList_Override(d DefaultSecurityGroupEgressList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewDefaultSecurityGroupEgressOutputReference_Override(d DefaultSecurityGroupEgressOutputReference, ...)
- func NewDefaultSecurityGroupIngressList_Override(d DefaultSecurityGroupIngressList, ...)
- func NewDefaultSecurityGroupIngressOutputReference_Override(d DefaultSecurityGroupIngressOutputReference, ...)
- func NewDefaultSecurityGroup_Override(d DefaultSecurityGroup, scope constructs.Construct, id *string, ...)
- type DefaultSecurityGroup
- type DefaultSecurityGroupConfig
- type DefaultSecurityGroupEgress
- type DefaultSecurityGroupEgressList
- type DefaultSecurityGroupEgressOutputReference
- type DefaultSecurityGroupIngress
- type DefaultSecurityGroupIngressList
- type DefaultSecurityGroupIngressOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DefaultSecurityGroup_IsConstruct ¶
func DefaultSecurityGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DefaultSecurityGroup_IsTerraformElement ¶
func DefaultSecurityGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func DefaultSecurityGroup_IsTerraformResource ¶
func DefaultSecurityGroup_IsTerraformResource(x interface{}) *bool
Experimental.
func DefaultSecurityGroup_TfResourceType ¶
func DefaultSecurityGroup_TfResourceType() *string
func NewDefaultSecurityGroupEgressList_Override ¶
func NewDefaultSecurityGroupEgressList_Override(d DefaultSecurityGroupEgressList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDefaultSecurityGroupEgressOutputReference_Override ¶
func NewDefaultSecurityGroupEgressOutputReference_Override(d DefaultSecurityGroupEgressOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDefaultSecurityGroupIngressList_Override ¶
func NewDefaultSecurityGroupIngressList_Override(d DefaultSecurityGroupIngressList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDefaultSecurityGroupIngressOutputReference_Override ¶
func NewDefaultSecurityGroupIngressOutputReference_Override(d DefaultSecurityGroupIngressOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDefaultSecurityGroup_Override ¶
func NewDefaultSecurityGroup_Override(d DefaultSecurityGroup, scope constructs.Construct, id *string, config *DefaultSecurityGroupConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/default_security_group aws_default_security_group} Resource.
Types ¶
type DefaultSecurityGroup ¶
type DefaultSecurityGroup interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
Egress() DefaultSecurityGroupEgressList
EgressInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Ingress() DefaultSecurityGroupIngressList
IngressInput() interface{}
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
NamePrefix() *string
// The tree node.
Node() constructs.Node
OwnerId() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RevokeRulesOnDelete() interface{}
SetRevokeRulesOnDelete(val interface{})
RevokeRulesOnDeleteInput() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
VpcId() *string
SetVpcId(val *string)
VpcIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutEgress(value interface{})
PutIngress(value interface{})
ResetEgress()
ResetId()
ResetIngress()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRevokeRulesOnDelete()
ResetTags()
ResetTagsAll()
ResetVpcId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/default_security_group aws_default_security_group}.
func NewDefaultSecurityGroup ¶
func NewDefaultSecurityGroup(scope constructs.Construct, id *string, config *DefaultSecurityGroupConfig) DefaultSecurityGroup
Create a new {@link https://www.terraform.io/docs/providers/aws/r/default_security_group aws_default_security_group} Resource.
type DefaultSecurityGroupConfig ¶
type DefaultSecurityGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#egress DefaultSecurityGroup#egress}.
Egress interface{} `field:"optional" json:"egress" yaml:"egress"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#id DefaultSecurityGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#ingress DefaultSecurityGroup#ingress}.
Ingress interface{} `field:"optional" json:"ingress" yaml:"ingress"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#revoke_rules_on_delete DefaultSecurityGroup#revoke_rules_on_delete}.
RevokeRulesOnDelete interface{} `field:"optional" json:"revokeRulesOnDelete" yaml:"revokeRulesOnDelete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#tags DefaultSecurityGroup#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#tags_all DefaultSecurityGroup#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#vpc_id DefaultSecurityGroup#vpc_id}.
VpcId *string `field:"optional" json:"vpcId" yaml:"vpcId"`
}
type DefaultSecurityGroupEgress ¶
type DefaultSecurityGroupEgress struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#cidr_blocks DefaultSecurityGroup#cidr_blocks}.
CidrBlocks *[]*string `field:"optional" json:"cidrBlocks" yaml:"cidrBlocks"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#description DefaultSecurityGroup#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#from_port DefaultSecurityGroup#from_port}.
FromPort *float64 `field:"optional" json:"fromPort" yaml:"fromPort"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#ipv6_cidr_blocks DefaultSecurityGroup#ipv6_cidr_blocks}.
Ipv6CidrBlocks *[]*string `field:"optional" json:"ipv6CidrBlocks" yaml:"ipv6CidrBlocks"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#prefix_list_ids DefaultSecurityGroup#prefix_list_ids}.
PrefixListIds *[]*string `field:"optional" json:"prefixListIds" yaml:"prefixListIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#protocol DefaultSecurityGroup#protocol}.
Protocol *string `field:"optional" json:"protocol" yaml:"protocol"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#security_groups DefaultSecurityGroup#security_groups}.
SecurityGroups *[]*string `field:"optional" json:"securityGroups" yaml:"securityGroups"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#self DefaultSecurityGroup#self}.
SelfAttribute interface{} `field:"optional" json:"selfAttribute" yaml:"selfAttribute"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#to_port DefaultSecurityGroup#to_port}.
ToPort *float64 `field:"optional" json:"toPort" yaml:"toPort"`
}
type DefaultSecurityGroupEgressList ¶
type DefaultSecurityGroupEgressList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DefaultSecurityGroupEgressOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDefaultSecurityGroupEgressList ¶
func NewDefaultSecurityGroupEgressList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DefaultSecurityGroupEgressList
type DefaultSecurityGroupEgressOutputReference ¶
type DefaultSecurityGroupEgressOutputReference interface {
cdktf.ComplexObject
CidrBlocks() *[]*string
SetCidrBlocks(val *[]*string)
CidrBlocksInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
Fqn() *string
FromPort() *float64
SetFromPort(val *float64)
FromPortInput() *float64
InternalValue() interface{}
SetInternalValue(val interface{})
Ipv6CidrBlocks() *[]*string
SetIpv6CidrBlocks(val *[]*string)
Ipv6CidrBlocksInput() *[]*string
PrefixListIds() *[]*string
SetPrefixListIds(val *[]*string)
PrefixListIdsInput() *[]*string
Protocol() *string
SetProtocol(val *string)
ProtocolInput() *string
SecurityGroups() *[]*string
SetSecurityGroups(val *[]*string)
SecurityGroupsInput() *[]*string
SelfAttribute() interface{}
SetSelfAttribute(val interface{})
SelfAttributeInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ToPort() *float64
SetToPort(val *float64)
ToPortInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCidrBlocks()
ResetDescription()
ResetFromPort()
ResetIpv6CidrBlocks()
ResetPrefixListIds()
ResetProtocol()
ResetSecurityGroups()
ResetSelfAttribute()
ResetToPort()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDefaultSecurityGroupEgressOutputReference ¶
func NewDefaultSecurityGroupEgressOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DefaultSecurityGroupEgressOutputReference
type DefaultSecurityGroupIngress ¶
type DefaultSecurityGroupIngress struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#cidr_blocks DefaultSecurityGroup#cidr_blocks}.
CidrBlocks *[]*string `field:"optional" json:"cidrBlocks" yaml:"cidrBlocks"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#description DefaultSecurityGroup#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#from_port DefaultSecurityGroup#from_port}.
FromPort *float64 `field:"optional" json:"fromPort" yaml:"fromPort"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#ipv6_cidr_blocks DefaultSecurityGroup#ipv6_cidr_blocks}.
Ipv6CidrBlocks *[]*string `field:"optional" json:"ipv6CidrBlocks" yaml:"ipv6CidrBlocks"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#prefix_list_ids DefaultSecurityGroup#prefix_list_ids}.
PrefixListIds *[]*string `field:"optional" json:"prefixListIds" yaml:"prefixListIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#protocol DefaultSecurityGroup#protocol}.
Protocol *string `field:"optional" json:"protocol" yaml:"protocol"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#security_groups DefaultSecurityGroup#security_groups}.
SecurityGroups *[]*string `field:"optional" json:"securityGroups" yaml:"securityGroups"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#self DefaultSecurityGroup#self}.
SelfAttribute interface{} `field:"optional" json:"selfAttribute" yaml:"selfAttribute"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group#to_port DefaultSecurityGroup#to_port}.
ToPort *float64 `field:"optional" json:"toPort" yaml:"toPort"`
}
type DefaultSecurityGroupIngressList ¶
type DefaultSecurityGroupIngressList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DefaultSecurityGroupIngressOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDefaultSecurityGroupIngressList ¶
func NewDefaultSecurityGroupIngressList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DefaultSecurityGroupIngressList
type DefaultSecurityGroupIngressOutputReference ¶
type DefaultSecurityGroupIngressOutputReference interface {
cdktf.ComplexObject
CidrBlocks() *[]*string
SetCidrBlocks(val *[]*string)
CidrBlocksInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
Fqn() *string
FromPort() *float64
SetFromPort(val *float64)
FromPortInput() *float64
InternalValue() interface{}
SetInternalValue(val interface{})
Ipv6CidrBlocks() *[]*string
SetIpv6CidrBlocks(val *[]*string)
Ipv6CidrBlocksInput() *[]*string
PrefixListIds() *[]*string
SetPrefixListIds(val *[]*string)
PrefixListIdsInput() *[]*string
Protocol() *string
SetProtocol(val *string)
ProtocolInput() *string
SecurityGroups() *[]*string
SetSecurityGroups(val *[]*string)
SecurityGroupsInput() *[]*string
SelfAttribute() interface{}
SetSelfAttribute(val interface{})
SelfAttributeInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ToPort() *float64
SetToPort(val *float64)
ToPortInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCidrBlocks()
ResetDescription()
ResetFromPort()
ResetIpv6CidrBlocks()
ResetPrefixListIds()
ResetProtocol()
ResetSecurityGroups()
ResetSelfAttribute()
ResetToPort()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDefaultSecurityGroupIngressOutputReference ¶
func NewDefaultSecurityGroupIngressOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DefaultSecurityGroupIngressOutputReference
Source Files
¶
- DefaultSecurityGroup.go
- DefaultSecurityGroupConfig.go
- DefaultSecurityGroupEgress.go
- DefaultSecurityGroupEgressList.go
- DefaultSecurityGroupEgressList__checks.go
- DefaultSecurityGroupEgressOutputReference.go
- DefaultSecurityGroupEgressOutputReference__checks.go
- DefaultSecurityGroupIngress.go
- DefaultSecurityGroupIngressList.go
- DefaultSecurityGroupIngressList__checks.go
- DefaultSecurityGroupIngressOutputReference.go
- DefaultSecurityGroupIngressOutputReference__checks.go
- DefaultSecurityGroup__checks.go
- main.go