Documentation
¶
Index ¶
- func DirectoryServiceSharedDirectory_IsConstruct(x interface{}) *bool
- func DirectoryServiceSharedDirectory_IsTerraformElement(x interface{}) *bool
- func DirectoryServiceSharedDirectory_IsTerraformResource(x interface{}) *bool
- func DirectoryServiceSharedDirectory_TfResourceType() *string
- func NewDirectoryServiceSharedDirectoryTargetOutputReference_Override(d DirectoryServiceSharedDirectoryTargetOutputReference, ...)
- func NewDirectoryServiceSharedDirectoryTimeoutsOutputReference_Override(d DirectoryServiceSharedDirectoryTimeoutsOutputReference, ...)
- func NewDirectoryServiceSharedDirectory_Override(d DirectoryServiceSharedDirectory, scope constructs.Construct, id *string, ...)
- type DirectoryServiceSharedDirectory
- type DirectoryServiceSharedDirectoryConfig
- type DirectoryServiceSharedDirectoryTarget
- type DirectoryServiceSharedDirectoryTargetOutputReference
- type DirectoryServiceSharedDirectoryTimeouts
- type DirectoryServiceSharedDirectoryTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DirectoryServiceSharedDirectory_IsConstruct ¶
func DirectoryServiceSharedDirectory_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DirectoryServiceSharedDirectory_IsTerraformElement ¶
func DirectoryServiceSharedDirectory_IsTerraformElement(x interface{}) *bool
Experimental.
func DirectoryServiceSharedDirectory_IsTerraformResource ¶
func DirectoryServiceSharedDirectory_IsTerraformResource(x interface{}) *bool
Experimental.
func DirectoryServiceSharedDirectory_TfResourceType ¶
func DirectoryServiceSharedDirectory_TfResourceType() *string
func NewDirectoryServiceSharedDirectoryTargetOutputReference_Override ¶
func NewDirectoryServiceSharedDirectoryTargetOutputReference_Override(d DirectoryServiceSharedDirectoryTargetOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDirectoryServiceSharedDirectoryTimeoutsOutputReference_Override ¶
func NewDirectoryServiceSharedDirectoryTimeoutsOutputReference_Override(d DirectoryServiceSharedDirectoryTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDirectoryServiceSharedDirectory_Override ¶
func NewDirectoryServiceSharedDirectory_Override(d DirectoryServiceSharedDirectory, scope constructs.Construct, id *string, config *DirectoryServiceSharedDirectoryConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/directory_service_shared_directory aws_directory_service_shared_directory} Resource.
Types ¶
type DirectoryServiceSharedDirectory ¶
type DirectoryServiceSharedDirectory interface {
cdktf.TerraformResource
CdktfStack() cdktf.TerraformStack
Connection() interface{}
SetConnection(val interface{})
ConstructNodeMetadata() *map[string]interface{}
Count() *float64
SetCount(val *float64)
DependsOn() *[]*string
// Experimental.
ForEach() cdktf.ITerraformIterator
SetForEach(val cdktf.ITerraformIterator)
Fqn() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
// The tree node.
Provider() cdktf.TerraformProvider
SetProvider(val cdktf.TerraformProvider)
Provisioners() *[]interface{}
SetProvisioners(val *[]interface{})
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformMetaArguments() *map[string]interface{}
// Experimental.
AddOverride(path *string, value interface{})
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ToMetadata() interface{}
ToString() *string
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/directory_service_shared_directory aws_directory_service_shared_directory}.
func NewDirectoryServiceSharedDirectory ¶
func NewDirectoryServiceSharedDirectory(scope constructs.Construct, id *string, config *DirectoryServiceSharedDirectoryConfig) DirectoryServiceSharedDirectory
Create a new {@link https://www.terraform.io/docs/providers/aws/r/directory_service_shared_directory aws_directory_service_shared_directory} Resource.
type DirectoryServiceSharedDirectoryConfig ¶
type DirectoryServiceSharedDirectoryConfig struct {
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
Count *float64 `field:"optional" json:"count" yaml:"count"`
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
DirectoryId *string `field:"required" json:"directoryId" yaml:"directoryId"`
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_shared_directory#target DirectoryServiceSharedDirectory#target}
Target *DirectoryServiceSharedDirectoryTarget `field:"required" json:"target" yaml:"target"`
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
Method *string `field:"optional" json:"method" yaml:"method"`
Notes *string `field:"optional" json:"notes" yaml:"notes"`
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_shared_directory#timeouts DirectoryServiceSharedDirectory#timeouts}
Timeouts *DirectoryServiceSharedDirectoryTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type DirectoryServiceSharedDirectoryTarget ¶
type DirectoryServiceSharedDirectoryTarget struct {
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"required" json:"id" yaml:"id"`
Type *string `field:"optional" json:"type" yaml:"type"`
}
type DirectoryServiceSharedDirectoryTargetOutputReference ¶
type DirectoryServiceSharedDirectoryTargetOutputReference interface {
cdktf.ComplexObject
// Experimental.
ComplexObjectIndex() interface{}
SetComplexObjectIndex(val interface{})
// Experimental.
ComplexObjectIsFromSet() *bool
SetComplexObjectIsFromSet(val *bool)
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
ComputeFqn() *string
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationAsList() cdktf.IResolvable
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDirectoryServiceSharedDirectoryTargetOutputReference ¶
func NewDirectoryServiceSharedDirectoryTargetOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DirectoryServiceSharedDirectoryTargetOutputReference
type DirectoryServiceSharedDirectoryTimeouts ¶
type DirectoryServiceSharedDirectoryTimeouts struct {
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type DirectoryServiceSharedDirectoryTimeoutsOutputReference ¶
type DirectoryServiceSharedDirectoryTimeoutsOutputReference interface {
cdktf.ComplexObject
// Experimental.
ComplexObjectIndex() interface{}
SetComplexObjectIndex(val interface{})
// Experimental.
ComplexObjectIsFromSet() *bool
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
// Experimental.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
ComputeFqn() *string
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationAsList() cdktf.IResolvable
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDirectoryServiceSharedDirectoryTimeoutsOutputReference ¶
func NewDirectoryServiceSharedDirectoryTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DirectoryServiceSharedDirectoryTimeoutsOutputReference
Source Files
¶
- DirectoryServiceSharedDirectory.go
- DirectoryServiceSharedDirectoryConfig.go
- DirectoryServiceSharedDirectoryTarget.go
- DirectoryServiceSharedDirectoryTargetOutputReference.go
- DirectoryServiceSharedDirectoryTargetOutputReference__checks.go
- DirectoryServiceSharedDirectoryTimeouts.go
- DirectoryServiceSharedDirectoryTimeoutsOutputReference.go
- DirectoryServiceSharedDirectoryTimeoutsOutputReference__checks.go
- DirectoryServiceSharedDirectory__checks.go
- main.go