Documentation
¶
Index ¶
- func EcsCapacityProvider_IsConstruct(x interface{}) *bool
- func EcsCapacityProvider_IsTerraformElement(x interface{}) *bool
- func EcsCapacityProvider_IsTerraformResource(x interface{}) *bool
- func EcsCapacityProvider_TfResourceType() *string
- func NewEcsCapacityProviderAutoScalingGroupProviderManagedScalingOutputReference_Override(e EcsCapacityProviderAutoScalingGroupProviderManagedScalingOutputReference, ...)
- func NewEcsCapacityProviderAutoScalingGroupProviderOutputReference_Override(e EcsCapacityProviderAutoScalingGroupProviderOutputReference, ...)
- func NewEcsCapacityProvider_Override(e EcsCapacityProvider, scope constructs.Construct, id *string, ...)
- type EcsCapacityProvider
- type EcsCapacityProviderAutoScalingGroupProvider
- type EcsCapacityProviderAutoScalingGroupProviderManagedScaling
- type EcsCapacityProviderAutoScalingGroupProviderManagedScalingOutputReference
- type EcsCapacityProviderAutoScalingGroupProviderOutputReference
- type EcsCapacityProviderConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EcsCapacityProvider_IsConstruct ¶
func EcsCapacityProvider_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func EcsCapacityProvider_IsTerraformElement ¶
func EcsCapacityProvider_IsTerraformElement(x interface{}) *bool
Experimental.
func EcsCapacityProvider_IsTerraformResource ¶
func EcsCapacityProvider_IsTerraformResource(x interface{}) *bool
Experimental.
func EcsCapacityProvider_TfResourceType ¶
func EcsCapacityProvider_TfResourceType() *string
func NewEcsCapacityProviderAutoScalingGroupProviderManagedScalingOutputReference_Override ¶
func NewEcsCapacityProviderAutoScalingGroupProviderManagedScalingOutputReference_Override(e EcsCapacityProviderAutoScalingGroupProviderManagedScalingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEcsCapacityProviderAutoScalingGroupProviderOutputReference_Override ¶
func NewEcsCapacityProviderAutoScalingGroupProviderOutputReference_Override(e EcsCapacityProviderAutoScalingGroupProviderOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEcsCapacityProvider_Override ¶
func NewEcsCapacityProvider_Override(e EcsCapacityProvider, scope constructs.Construct, id *string, config *EcsCapacityProviderConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider aws_ecs_capacity_provider} Resource.
Types ¶
type EcsCapacityProvider ¶
type EcsCapacityProvider interface {
cdktf.TerraformResource
Arn() *string
AutoScalingGroupProvider() EcsCapacityProviderAutoScalingGroupProviderOutputReference
AutoScalingGroupProviderInput() *EcsCapacityProviderAutoScalingGroupProvider
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAutoScalingGroupProvider(value *EcsCapacityProviderAutoScalingGroupProvider)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider aws_ecs_capacity_provider}.
func NewEcsCapacityProvider ¶
func NewEcsCapacityProvider(scope constructs.Construct, id *string, config *EcsCapacityProviderConfig) EcsCapacityProvider
Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider aws_ecs_capacity_provider} Resource.
type EcsCapacityProviderAutoScalingGroupProvider ¶
type EcsCapacityProviderAutoScalingGroupProvider struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#auto_scaling_group_arn EcsCapacityProvider#auto_scaling_group_arn}.
AutoScalingGroupArn *string `field:"required" json:"autoScalingGroupArn" yaml:"autoScalingGroupArn"`
// managed_scaling block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#managed_scaling EcsCapacityProvider#managed_scaling}
ManagedScaling *EcsCapacityProviderAutoScalingGroupProviderManagedScaling `field:"optional" json:"managedScaling" yaml:"managedScaling"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#managed_termination_protection EcsCapacityProvider#managed_termination_protection}.
ManagedTerminationProtection *string `field:"optional" json:"managedTerminationProtection" yaml:"managedTerminationProtection"`
}
type EcsCapacityProviderAutoScalingGroupProviderManagedScaling ¶
type EcsCapacityProviderAutoScalingGroupProviderManagedScaling struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#instance_warmup_period EcsCapacityProvider#instance_warmup_period}.
InstanceWarmupPeriod *float64 `field:"optional" json:"instanceWarmupPeriod" yaml:"instanceWarmupPeriod"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#maximum_scaling_step_size EcsCapacityProvider#maximum_scaling_step_size}.
MaximumScalingStepSize *float64 `field:"optional" json:"maximumScalingStepSize" yaml:"maximumScalingStepSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#minimum_scaling_step_size EcsCapacityProvider#minimum_scaling_step_size}.
MinimumScalingStepSize *float64 `field:"optional" json:"minimumScalingStepSize" yaml:"minimumScalingStepSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#status EcsCapacityProvider#status}.
Status *string `field:"optional" json:"status" yaml:"status"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#target_capacity EcsCapacityProvider#target_capacity}.
TargetCapacity *float64 `field:"optional" json:"targetCapacity" yaml:"targetCapacity"`
}
type EcsCapacityProviderAutoScalingGroupProviderManagedScalingOutputReference ¶
type EcsCapacityProviderAutoScalingGroupProviderManagedScalingOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InstanceWarmupPeriod() *float64
SetInstanceWarmupPeriod(val *float64)
InstanceWarmupPeriodInput() *float64
InternalValue() *EcsCapacityProviderAutoScalingGroupProviderManagedScaling
SetInternalValue(val *EcsCapacityProviderAutoScalingGroupProviderManagedScaling)
MaximumScalingStepSize() *float64
SetMaximumScalingStepSize(val *float64)
MaximumScalingStepSizeInput() *float64
MinimumScalingStepSize() *float64
SetMinimumScalingStepSize(val *float64)
MinimumScalingStepSizeInput() *float64
Status() *string
SetStatus(val *string)
StatusInput() *string
TargetCapacity() *float64
SetTargetCapacity(val *float64)
TargetCapacityInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetInstanceWarmupPeriod()
ResetMaximumScalingStepSize()
ResetMinimumScalingStepSize()
ResetStatus()
ResetTargetCapacity()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcsCapacityProviderAutoScalingGroupProviderManagedScalingOutputReference ¶
func NewEcsCapacityProviderAutoScalingGroupProviderManagedScalingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EcsCapacityProviderAutoScalingGroupProviderManagedScalingOutputReference
type EcsCapacityProviderAutoScalingGroupProviderOutputReference ¶
type EcsCapacityProviderAutoScalingGroupProviderOutputReference interface {
cdktf.ComplexObject
AutoScalingGroupArn() *string
SetAutoScalingGroupArn(val *string)
AutoScalingGroupArnInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EcsCapacityProviderAutoScalingGroupProvider
SetInternalValue(val *EcsCapacityProviderAutoScalingGroupProvider)
ManagedScaling() EcsCapacityProviderAutoScalingGroupProviderManagedScalingOutputReference
ManagedScalingInput() *EcsCapacityProviderAutoScalingGroupProviderManagedScaling
ManagedTerminationProtection() *string
SetManagedTerminationProtection(val *string)
ManagedTerminationProtectionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutManagedScaling(value *EcsCapacityProviderAutoScalingGroupProviderManagedScaling)
ResetManagedScaling()
ResetManagedTerminationProtection()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcsCapacityProviderAutoScalingGroupProviderOutputReference ¶
func NewEcsCapacityProviderAutoScalingGroupProviderOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EcsCapacityProviderAutoScalingGroupProviderOutputReference
type EcsCapacityProviderConfig ¶
type EcsCapacityProviderConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// auto_scaling_group_provider block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#auto_scaling_group_provider EcsCapacityProvider#auto_scaling_group_provider}
AutoScalingGroupProvider *EcsCapacityProviderAutoScalingGroupProvider `field:"required" json:"autoScalingGroupProvider" yaml:"autoScalingGroupProvider"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#name EcsCapacityProvider#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#id EcsCapacityProvider#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#tags EcsCapacityProvider#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider#tags_all EcsCapacityProvider#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
Source Files
¶
- EcsCapacityProvider.go
- EcsCapacityProviderAutoScalingGroupProvider.go
- EcsCapacityProviderAutoScalingGroupProviderManagedScaling.go
- EcsCapacityProviderAutoScalingGroupProviderManagedScalingOutputReference.go
- EcsCapacityProviderAutoScalingGroupProviderManagedScalingOutputReference__checks.go
- EcsCapacityProviderAutoScalingGroupProviderOutputReference.go
- EcsCapacityProviderAutoScalingGroupProviderOutputReference__checks.go
- EcsCapacityProviderConfig.go
- EcsCapacityProvider__checks.go
- main.go