Documentation
¶
Index ¶
- func EfsAccessPoint_IsConstruct(x interface{}) *bool
- func EfsAccessPoint_IsTerraformElement(x interface{}) *bool
- func EfsAccessPoint_IsTerraformResource(x interface{}) *bool
- func EfsAccessPoint_TfResourceType() *string
- func NewEfsAccessPointPosixUserOutputReference_Override(e EfsAccessPointPosixUserOutputReference, ...)
- func NewEfsAccessPointRootDirectoryCreationInfoOutputReference_Override(e EfsAccessPointRootDirectoryCreationInfoOutputReference, ...)
- func NewEfsAccessPointRootDirectoryOutputReference_Override(e EfsAccessPointRootDirectoryOutputReference, ...)
- func NewEfsAccessPoint_Override(e EfsAccessPoint, scope constructs.Construct, id *string, ...)
- type EfsAccessPoint
- type EfsAccessPointConfig
- type EfsAccessPointPosixUser
- type EfsAccessPointPosixUserOutputReference
- type EfsAccessPointRootDirectory
- type EfsAccessPointRootDirectoryCreationInfo
- type EfsAccessPointRootDirectoryCreationInfoOutputReference
- type EfsAccessPointRootDirectoryOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EfsAccessPoint_IsConstruct ¶
func EfsAccessPoint_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func EfsAccessPoint_IsTerraformElement ¶
func EfsAccessPoint_IsTerraformElement(x interface{}) *bool
Experimental.
func EfsAccessPoint_IsTerraformResource ¶
func EfsAccessPoint_IsTerraformResource(x interface{}) *bool
Experimental.
func EfsAccessPoint_TfResourceType ¶
func EfsAccessPoint_TfResourceType() *string
func NewEfsAccessPointPosixUserOutputReference_Override ¶
func NewEfsAccessPointPosixUserOutputReference_Override(e EfsAccessPointPosixUserOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEfsAccessPointRootDirectoryCreationInfoOutputReference_Override ¶
func NewEfsAccessPointRootDirectoryCreationInfoOutputReference_Override(e EfsAccessPointRootDirectoryCreationInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEfsAccessPointRootDirectoryOutputReference_Override ¶
func NewEfsAccessPointRootDirectoryOutputReference_Override(e EfsAccessPointRootDirectoryOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEfsAccessPoint_Override ¶
func NewEfsAccessPoint_Override(e EfsAccessPoint, scope constructs.Construct, id *string, config *EfsAccessPointConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point aws_efs_access_point} Resource.
Types ¶
type EfsAccessPoint ¶
type EfsAccessPoint interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
FileSystemArn() *string
FileSystemId() *string
SetFileSystemId(val *string)
FileSystemIdInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
OwnerId() *string
PosixUser() EfsAccessPointPosixUserOutputReference
PosixUserInput() *EfsAccessPointPosixUser
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RootDirectory() EfsAccessPointRootDirectoryOutputReference
RootDirectoryInput() *EfsAccessPointRootDirectory
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutPosixUser(value *EfsAccessPointPosixUser)
PutRootDirectory(value *EfsAccessPointRootDirectory)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPosixUser()
ResetRootDirectory()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point aws_efs_access_point}.
func NewEfsAccessPoint ¶
func NewEfsAccessPoint(scope constructs.Construct, id *string, config *EfsAccessPointConfig) EfsAccessPoint
Create a new {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point aws_efs_access_point} Resource.
type EfsAccessPointConfig ¶
type EfsAccessPointConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#file_system_id EfsAccessPoint#file_system_id}.
FileSystemId *string `field:"required" json:"fileSystemId" yaml:"fileSystemId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#id EfsAccessPoint#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// posix_user block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#posix_user EfsAccessPoint#posix_user}
PosixUser *EfsAccessPointPosixUser `field:"optional" json:"posixUser" yaml:"posixUser"`
// root_directory block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#root_directory EfsAccessPoint#root_directory}
RootDirectory *EfsAccessPointRootDirectory `field:"optional" json:"rootDirectory" yaml:"rootDirectory"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#tags EfsAccessPoint#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#tags_all EfsAccessPoint#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type EfsAccessPointPosixUser ¶
type EfsAccessPointPosixUser struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#gid EfsAccessPoint#gid}.
Gid *float64 `field:"required" json:"gid" yaml:"gid"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#uid EfsAccessPoint#uid}.
Uid *float64 `field:"required" json:"uid" yaml:"uid"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#secondary_gids EfsAccessPoint#secondary_gids}.
SecondaryGids *[]*float64 `field:"optional" json:"secondaryGids" yaml:"secondaryGids"`
}
type EfsAccessPointPosixUserOutputReference ¶
type EfsAccessPointPosixUserOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Gid() *float64
SetGid(val *float64)
GidInput() *float64
InternalValue() *EfsAccessPointPosixUser
SetInternalValue(val *EfsAccessPointPosixUser)
SecondaryGids() *[]*float64
SetSecondaryGids(val *[]*float64)
SecondaryGidsInput() *[]*float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Uid() *float64
SetUid(val *float64)
UidInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetSecondaryGids()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEfsAccessPointPosixUserOutputReference ¶
func NewEfsAccessPointPosixUserOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EfsAccessPointPosixUserOutputReference
type EfsAccessPointRootDirectory ¶
type EfsAccessPointRootDirectory struct {
// creation_info block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#creation_info EfsAccessPoint#creation_info}
CreationInfo *EfsAccessPointRootDirectoryCreationInfo `field:"optional" json:"creationInfo" yaml:"creationInfo"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#path EfsAccessPoint#path}.
Path *string `field:"optional" json:"path" yaml:"path"`
}
type EfsAccessPointRootDirectoryCreationInfo ¶
type EfsAccessPointRootDirectoryCreationInfo struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#owner_gid EfsAccessPoint#owner_gid}.
OwnerGid *float64 `field:"required" json:"ownerGid" yaml:"ownerGid"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#owner_uid EfsAccessPoint#owner_uid}.
OwnerUid *float64 `field:"required" json:"ownerUid" yaml:"ownerUid"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point#permissions EfsAccessPoint#permissions}.
Permissions *string `field:"required" json:"permissions" yaml:"permissions"`
}
type EfsAccessPointRootDirectoryCreationInfoOutputReference ¶
type EfsAccessPointRootDirectoryCreationInfoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EfsAccessPointRootDirectoryCreationInfo
SetInternalValue(val *EfsAccessPointRootDirectoryCreationInfo)
OwnerGid() *float64
SetOwnerGid(val *float64)
OwnerGidInput() *float64
OwnerUid() *float64
SetOwnerUid(val *float64)
OwnerUidInput() *float64
Permissions() *string
SetPermissions(val *string)
PermissionsInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEfsAccessPointRootDirectoryCreationInfoOutputReference ¶
func NewEfsAccessPointRootDirectoryCreationInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EfsAccessPointRootDirectoryCreationInfoOutputReference
type EfsAccessPointRootDirectoryOutputReference ¶
type EfsAccessPointRootDirectoryOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CreationInfo() EfsAccessPointRootDirectoryCreationInfoOutputReference
CreationInfoInput() *EfsAccessPointRootDirectoryCreationInfo
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EfsAccessPointRootDirectory
SetInternalValue(val *EfsAccessPointRootDirectory)
Path() *string
SetPath(val *string)
PathInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutCreationInfo(value *EfsAccessPointRootDirectoryCreationInfo)
ResetCreationInfo()
ResetPath()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEfsAccessPointRootDirectoryOutputReference ¶
func NewEfsAccessPointRootDirectoryOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EfsAccessPointRootDirectoryOutputReference
Source Files
¶
- EfsAccessPoint.go
- EfsAccessPointConfig.go
- EfsAccessPointPosixUser.go
- EfsAccessPointPosixUserOutputReference.go
- EfsAccessPointPosixUserOutputReference__checks.go
- EfsAccessPointRootDirectory.go
- EfsAccessPointRootDirectoryCreationInfo.go
- EfsAccessPointRootDirectoryCreationInfoOutputReference.go
- EfsAccessPointRootDirectoryCreationInfoOutputReference__checks.go
- EfsAccessPointRootDirectoryOutputReference.go
- EfsAccessPointRootDirectoryOutputReference__checks.go
- EfsAccessPoint__checks.go
- main.go