Documentation
¶
Index ¶
- func EksCluster_IsConstruct(x interface{}) *bool
- func EksCluster_IsTerraformElement(x interface{}) *bool
- func EksCluster_IsTerraformResource(x interface{}) *bool
- func EksCluster_TfResourceType() *string
- func NewEksClusterCertificateAuthorityList_Override(e EksClusterCertificateAuthorityList, ...)
- func NewEksClusterCertificateAuthorityOutputReference_Override(e EksClusterCertificateAuthorityOutputReference, ...)
- func NewEksClusterEncryptionConfigOutputReference_Override(e EksClusterEncryptionConfigOutputReference, ...)
- func NewEksClusterEncryptionConfigProviderOutputReference_Override(e EksClusterEncryptionConfigProviderOutputReference, ...)
- func NewEksClusterIdentityList_Override(e EksClusterIdentityList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewEksClusterIdentityOidcList_Override(e EksClusterIdentityOidcList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewEksClusterIdentityOidcOutputReference_Override(e EksClusterIdentityOidcOutputReference, ...)
- func NewEksClusterIdentityOutputReference_Override(e EksClusterIdentityOutputReference, ...)
- func NewEksClusterKubernetesNetworkConfigOutputReference_Override(e EksClusterKubernetesNetworkConfigOutputReference, ...)
- func NewEksClusterOutpostConfigControlPlanePlacementOutputReference_Override(e EksClusterOutpostConfigControlPlanePlacementOutputReference, ...)
- func NewEksClusterOutpostConfigOutputReference_Override(e EksClusterOutpostConfigOutputReference, ...)
- func NewEksClusterTimeoutsOutputReference_Override(e EksClusterTimeoutsOutputReference, ...)
- func NewEksClusterVpcConfigOutputReference_Override(e EksClusterVpcConfigOutputReference, ...)
- func NewEksCluster_Override(e EksCluster, scope constructs.Construct, id *string, config *EksClusterConfig)
- type EksCluster
- type EksClusterCertificateAuthority
- type EksClusterCertificateAuthorityList
- type EksClusterCertificateAuthorityOutputReference
- type EksClusterConfig
- type EksClusterEncryptionConfig
- type EksClusterEncryptionConfigOutputReference
- type EksClusterEncryptionConfigProvider
- type EksClusterEncryptionConfigProviderOutputReference
- type EksClusterIdentity
- type EksClusterIdentityList
- type EksClusterIdentityOidc
- type EksClusterIdentityOidcList
- type EksClusterIdentityOidcOutputReference
- type EksClusterIdentityOutputReference
- type EksClusterKubernetesNetworkConfig
- type EksClusterKubernetesNetworkConfigOutputReference
- type EksClusterOutpostConfig
- type EksClusterOutpostConfigControlPlanePlacement
- type EksClusterOutpostConfigControlPlanePlacementOutputReference
- type EksClusterOutpostConfigOutputReference
- type EksClusterTimeouts
- type EksClusterTimeoutsOutputReference
- type EksClusterVpcConfig
- type EksClusterVpcConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EksCluster_IsConstruct ¶
func EksCluster_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func EksCluster_IsTerraformElement ¶
func EksCluster_IsTerraformElement(x interface{}) *bool
Experimental.
func EksCluster_IsTerraformResource ¶
func EksCluster_IsTerraformResource(x interface{}) *bool
Experimental.
func EksCluster_TfResourceType ¶
func EksCluster_TfResourceType() *string
func NewEksClusterCertificateAuthorityList_Override ¶
func NewEksClusterCertificateAuthorityList_Override(e EksClusterCertificateAuthorityList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEksClusterCertificateAuthorityOutputReference_Override ¶
func NewEksClusterCertificateAuthorityOutputReference_Override(e EksClusterCertificateAuthorityOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEksClusterEncryptionConfigOutputReference_Override ¶
func NewEksClusterEncryptionConfigOutputReference_Override(e EksClusterEncryptionConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEksClusterEncryptionConfigProviderOutputReference_Override ¶
func NewEksClusterEncryptionConfigProviderOutputReference_Override(e EksClusterEncryptionConfigProviderOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEksClusterIdentityList_Override ¶
func NewEksClusterIdentityList_Override(e EksClusterIdentityList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEksClusterIdentityOidcList_Override ¶
func NewEksClusterIdentityOidcList_Override(e EksClusterIdentityOidcList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEksClusterIdentityOidcOutputReference_Override ¶
func NewEksClusterIdentityOidcOutputReference_Override(e EksClusterIdentityOidcOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEksClusterIdentityOutputReference_Override ¶
func NewEksClusterIdentityOutputReference_Override(e EksClusterIdentityOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEksClusterKubernetesNetworkConfigOutputReference_Override ¶
func NewEksClusterKubernetesNetworkConfigOutputReference_Override(e EksClusterKubernetesNetworkConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEksClusterOutpostConfigControlPlanePlacementOutputReference_Override ¶
func NewEksClusterOutpostConfigControlPlanePlacementOutputReference_Override(e EksClusterOutpostConfigControlPlanePlacementOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEksClusterOutpostConfigOutputReference_Override ¶
func NewEksClusterOutpostConfigOutputReference_Override(e EksClusterOutpostConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEksClusterTimeoutsOutputReference_Override ¶
func NewEksClusterTimeoutsOutputReference_Override(e EksClusterTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEksClusterVpcConfigOutputReference_Override ¶
func NewEksClusterVpcConfigOutputReference_Override(e EksClusterVpcConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEksCluster_Override ¶
func NewEksCluster_Override(e EksCluster, scope constructs.Construct, id *string, config *EksClusterConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster aws_eks_cluster} Resource.
Types ¶
type EksCluster ¶
type EksCluster interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CertificateAuthority() EksClusterCertificateAuthorityList
ClusterId() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreatedAt() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EnabledClusterLogTypes() *[]*string
SetEnabledClusterLogTypes(val *[]*string)
EnabledClusterLogTypesInput() *[]*string
EncryptionConfig() EksClusterEncryptionConfigOutputReference
EncryptionConfigInput() *EksClusterEncryptionConfig
Endpoint() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
Identity() EksClusterIdentityList
IdInput() *string
KubernetesNetworkConfig() EksClusterKubernetesNetworkConfigOutputReference
KubernetesNetworkConfigInput() *EksClusterKubernetesNetworkConfig
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
OutpostConfig() EksClusterOutpostConfigOutputReference
OutpostConfigInput() *EksClusterOutpostConfig
PlatformVersion() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
Status() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() EksClusterTimeoutsOutputReference
TimeoutsInput() interface{}
Version() *string
SetVersion(val *string)
VersionInput() *string
VpcConfig() EksClusterVpcConfigOutputReference
VpcConfigInput() *EksClusterVpcConfig
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutEncryptionConfig(value *EksClusterEncryptionConfig)
PutKubernetesNetworkConfig(value *EksClusterKubernetesNetworkConfig)
PutOutpostConfig(value *EksClusterOutpostConfig)
PutTimeouts(value *EksClusterTimeouts)
PutVpcConfig(value *EksClusterVpcConfig)
ResetEnabledClusterLogTypes()
ResetEncryptionConfig()
ResetId()
ResetKubernetesNetworkConfig()
ResetOutpostConfig()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
ResetTimeouts()
ResetVersion()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster aws_eks_cluster}.
func NewEksCluster ¶
func NewEksCluster(scope constructs.Construct, id *string, config *EksClusterConfig) EksCluster
Create a new {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster aws_eks_cluster} Resource.
type EksClusterCertificateAuthority ¶
type EksClusterCertificateAuthority struct {
}
type EksClusterCertificateAuthorityList ¶
type EksClusterCertificateAuthorityList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EksClusterCertificateAuthorityOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksClusterCertificateAuthorityList ¶
func NewEksClusterCertificateAuthorityList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EksClusterCertificateAuthorityList
type EksClusterCertificateAuthorityOutputReference ¶
type EksClusterCertificateAuthorityOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Data() *string
// Experimental.
Fqn() *string
InternalValue() *EksClusterCertificateAuthority
SetInternalValue(val *EksClusterCertificateAuthority)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksClusterCertificateAuthorityOutputReference ¶
func NewEksClusterCertificateAuthorityOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EksClusterCertificateAuthorityOutputReference
type EksClusterConfig ¶
type EksClusterConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#name EksCluster#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#role_arn EksCluster#role_arn}.
RoleArn *string `field:"required" json:"roleArn" yaml:"roleArn"`
// vpc_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#vpc_config EksCluster#vpc_config}
VpcConfig *EksClusterVpcConfig `field:"required" json:"vpcConfig" yaml:"vpcConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#enabled_cluster_log_types EksCluster#enabled_cluster_log_types}.
EnabledClusterLogTypes *[]*string `field:"optional" json:"enabledClusterLogTypes" yaml:"enabledClusterLogTypes"`
// encryption_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#encryption_config EksCluster#encryption_config}
EncryptionConfig *EksClusterEncryptionConfig `field:"optional" json:"encryptionConfig" yaml:"encryptionConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#id EksCluster#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// kubernetes_network_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#kubernetes_network_config EksCluster#kubernetes_network_config}
KubernetesNetworkConfig *EksClusterKubernetesNetworkConfig `field:"optional" json:"kubernetesNetworkConfig" yaml:"kubernetesNetworkConfig"`
// outpost_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#outpost_config EksCluster#outpost_config}
OutpostConfig *EksClusterOutpostConfig `field:"optional" json:"outpostConfig" yaml:"outpostConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#tags EksCluster#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#tags_all EksCluster#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#timeouts EksCluster#timeouts}
Timeouts *EksClusterTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#version EksCluster#version}.
Version *string `field:"optional" json:"version" yaml:"version"`
}
type EksClusterEncryptionConfig ¶
type EksClusterEncryptionConfig struct {
// provider block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#provider EksCluster#provider}
Provider *EksClusterEncryptionConfigProvider `field:"required" json:"provider" yaml:"provider"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#resources EksCluster#resources}.
Resources *[]*string `field:"required" json:"resources" yaml:"resources"`
}
type EksClusterEncryptionConfigOutputReference ¶
type EksClusterEncryptionConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EksClusterEncryptionConfig
SetInternalValue(val *EksClusterEncryptionConfig)
Provider() EksClusterEncryptionConfigProviderOutputReference
ProviderInput() *EksClusterEncryptionConfigProvider
Resources() *[]*string
SetResources(val *[]*string)
ResourcesInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutProvider(value *EksClusterEncryptionConfigProvider)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksClusterEncryptionConfigOutputReference ¶
func NewEksClusterEncryptionConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EksClusterEncryptionConfigOutputReference
type EksClusterEncryptionConfigProvider ¶
type EksClusterEncryptionConfigProvider struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#key_arn EksCluster#key_arn}.
KeyArn *string `field:"required" json:"keyArn" yaml:"keyArn"`
}
type EksClusterEncryptionConfigProviderOutputReference ¶
type EksClusterEncryptionConfigProviderOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EksClusterEncryptionConfigProvider
SetInternalValue(val *EksClusterEncryptionConfigProvider)
KeyArn() *string
SetKeyArn(val *string)
KeyArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksClusterEncryptionConfigProviderOutputReference ¶
func NewEksClusterEncryptionConfigProviderOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EksClusterEncryptionConfigProviderOutputReference
type EksClusterIdentity ¶
type EksClusterIdentity struct {
}
type EksClusterIdentityList ¶
type EksClusterIdentityList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EksClusterIdentityOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksClusterIdentityList ¶
func NewEksClusterIdentityList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EksClusterIdentityList
type EksClusterIdentityOidc ¶
type EksClusterIdentityOidc struct {
}
type EksClusterIdentityOidcList ¶
type EksClusterIdentityOidcList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EksClusterIdentityOidcOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksClusterIdentityOidcList ¶
func NewEksClusterIdentityOidcList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EksClusterIdentityOidcList
type EksClusterIdentityOidcOutputReference ¶
type EksClusterIdentityOidcOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EksClusterIdentityOidc
SetInternalValue(val *EksClusterIdentityOidc)
Issuer() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksClusterIdentityOidcOutputReference ¶
func NewEksClusterIdentityOidcOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EksClusterIdentityOidcOutputReference
type EksClusterIdentityOutputReference ¶
type EksClusterIdentityOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EksClusterIdentity
SetInternalValue(val *EksClusterIdentity)
Oidc() EksClusterIdentityOidcList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksClusterIdentityOutputReference ¶
func NewEksClusterIdentityOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EksClusterIdentityOutputReference
type EksClusterKubernetesNetworkConfig ¶
type EksClusterKubernetesNetworkConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#ip_family EksCluster#ip_family}.
IpFamily *string `field:"optional" json:"ipFamily" yaml:"ipFamily"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#service_ipv4_cidr EksCluster#service_ipv4_cidr}.
ServiceIpv4Cidr *string `field:"optional" json:"serviceIpv4Cidr" yaml:"serviceIpv4Cidr"`
}
type EksClusterKubernetesNetworkConfigOutputReference ¶
type EksClusterKubernetesNetworkConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EksClusterKubernetesNetworkConfig
SetInternalValue(val *EksClusterKubernetesNetworkConfig)
IpFamily() *string
SetIpFamily(val *string)
IpFamilyInput() *string
ServiceIpv4Cidr() *string
SetServiceIpv4Cidr(val *string)
ServiceIpv4CidrInput() *string
ServiceIpv6Cidr() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetIpFamily()
ResetServiceIpv4Cidr()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksClusterKubernetesNetworkConfigOutputReference ¶
func NewEksClusterKubernetesNetworkConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EksClusterKubernetesNetworkConfigOutputReference
type EksClusterOutpostConfig ¶
type EksClusterOutpostConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#control_plane_instance_type EksCluster#control_plane_instance_type}.
ControlPlaneInstanceType *string `field:"required" json:"controlPlaneInstanceType" yaml:"controlPlaneInstanceType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#outpost_arns EksCluster#outpost_arns}.
OutpostArns *[]*string `field:"required" json:"outpostArns" yaml:"outpostArns"`
// control_plane_placement block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#control_plane_placement EksCluster#control_plane_placement}
ControlPlanePlacement *EksClusterOutpostConfigControlPlanePlacement `field:"optional" json:"controlPlanePlacement" yaml:"controlPlanePlacement"`
}
type EksClusterOutpostConfigControlPlanePlacement ¶
type EksClusterOutpostConfigControlPlanePlacement struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#group_name EksCluster#group_name}.
GroupName *string `field:"required" json:"groupName" yaml:"groupName"`
}
type EksClusterOutpostConfigControlPlanePlacementOutputReference ¶
type EksClusterOutpostConfigControlPlanePlacementOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
GroupName() *string
SetGroupName(val *string)
GroupNameInput() *string
InternalValue() *EksClusterOutpostConfigControlPlanePlacement
SetInternalValue(val *EksClusterOutpostConfigControlPlanePlacement)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksClusterOutpostConfigControlPlanePlacementOutputReference ¶
func NewEksClusterOutpostConfigControlPlanePlacementOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EksClusterOutpostConfigControlPlanePlacementOutputReference
type EksClusterOutpostConfigOutputReference ¶
type EksClusterOutpostConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ControlPlaneInstanceType() *string
SetControlPlaneInstanceType(val *string)
ControlPlaneInstanceTypeInput() *string
ControlPlanePlacement() EksClusterOutpostConfigControlPlanePlacementOutputReference
ControlPlanePlacementInput() *EksClusterOutpostConfigControlPlanePlacement
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EksClusterOutpostConfig
SetInternalValue(val *EksClusterOutpostConfig)
OutpostArns() *[]*string
SetOutpostArns(val *[]*string)
OutpostArnsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutControlPlanePlacement(value *EksClusterOutpostConfigControlPlanePlacement)
ResetControlPlanePlacement()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksClusterOutpostConfigOutputReference ¶
func NewEksClusterOutpostConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EksClusterOutpostConfigOutputReference
type EksClusterTimeouts ¶
type EksClusterTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#create EksCluster#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#delete EksCluster#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#update EksCluster#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type EksClusterTimeoutsOutputReference ¶
type EksClusterTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksClusterTimeoutsOutputReference ¶
func NewEksClusterTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EksClusterTimeoutsOutputReference
type EksClusterVpcConfig ¶
type EksClusterVpcConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#subnet_ids EksCluster#subnet_ids}.
SubnetIds *[]*string `field:"required" json:"subnetIds" yaml:"subnetIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#endpoint_private_access EksCluster#endpoint_private_access}.
EndpointPrivateAccess interface{} `field:"optional" json:"endpointPrivateAccess" yaml:"endpointPrivateAccess"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#endpoint_public_access EksCluster#endpoint_public_access}.
EndpointPublicAccess interface{} `field:"optional" json:"endpointPublicAccess" yaml:"endpointPublicAccess"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#public_access_cidrs EksCluster#public_access_cidrs}.
PublicAccessCidrs *[]*string `field:"optional" json:"publicAccessCidrs" yaml:"publicAccessCidrs"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster#security_group_ids EksCluster#security_group_ids}.
SecurityGroupIds *[]*string `field:"optional" json:"securityGroupIds" yaml:"securityGroupIds"`
}
type EksClusterVpcConfigOutputReference ¶
type EksClusterVpcConfigOutputReference interface {
cdktf.ComplexObject
ClusterSecurityGroupId() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EndpointPrivateAccess() interface{}
SetEndpointPrivateAccess(val interface{})
EndpointPrivateAccessInput() interface{}
EndpointPublicAccess() interface{}
SetEndpointPublicAccess(val interface{})
EndpointPublicAccessInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *EksClusterVpcConfig
SetInternalValue(val *EksClusterVpcConfig)
PublicAccessCidrs() *[]*string
SetPublicAccessCidrs(val *[]*string)
PublicAccessCidrsInput() *[]*string
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
SubnetIds() *[]*string
SetSubnetIds(val *[]*string)
SubnetIdsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VpcId() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEndpointPrivateAccess()
ResetEndpointPublicAccess()
ResetPublicAccessCidrs()
ResetSecurityGroupIds()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksClusterVpcConfigOutputReference ¶
func NewEksClusterVpcConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EksClusterVpcConfigOutputReference
Source Files
¶
- EksCluster.go
- EksClusterCertificateAuthority.go
- EksClusterCertificateAuthorityList.go
- EksClusterCertificateAuthorityList__checks.go
- EksClusterCertificateAuthorityOutputReference.go
- EksClusterCertificateAuthorityOutputReference__checks.go
- EksClusterConfig.go
- EksClusterEncryptionConfig.go
- EksClusterEncryptionConfigOutputReference.go
- EksClusterEncryptionConfigOutputReference__checks.go
- EksClusterEncryptionConfigProvider.go
- EksClusterEncryptionConfigProviderOutputReference.go
- EksClusterEncryptionConfigProviderOutputReference__checks.go
- EksClusterIdentity.go
- EksClusterIdentityList.go
- EksClusterIdentityList__checks.go
- EksClusterIdentityOidc.go
- EksClusterIdentityOidcList.go
- EksClusterIdentityOidcList__checks.go
- EksClusterIdentityOidcOutputReference.go
- EksClusterIdentityOidcOutputReference__checks.go
- EksClusterIdentityOutputReference.go
- EksClusterIdentityOutputReference__checks.go
- EksClusterKubernetesNetworkConfig.go
- EksClusterKubernetesNetworkConfigOutputReference.go
- EksClusterKubernetesNetworkConfigOutputReference__checks.go
- EksClusterOutpostConfig.go
- EksClusterOutpostConfigControlPlanePlacement.go
- EksClusterOutpostConfigControlPlanePlacementOutputReference.go
- EksClusterOutpostConfigControlPlanePlacementOutputReference__checks.go
- EksClusterOutpostConfigOutputReference.go
- EksClusterOutpostConfigOutputReference__checks.go
- EksClusterTimeouts.go
- EksClusterTimeoutsOutputReference.go
- EksClusterTimeoutsOutputReference__checks.go
- EksClusterVpcConfig.go
- EksClusterVpcConfigOutputReference.go
- EksClusterVpcConfigOutputReference__checks.go
- EksCluster__checks.go
- main.go