Documentation
¶
Index ¶
- func EmrcontainersVirtualCluster_IsConstruct(x interface{}) *bool
- func EmrcontainersVirtualCluster_IsTerraformElement(x interface{}) *bool
- func EmrcontainersVirtualCluster_IsTerraformResource(x interface{}) *bool
- func EmrcontainersVirtualCluster_TfResourceType() *string
- func NewEmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference_Override(e EmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference, ...)
- func NewEmrcontainersVirtualClusterContainerProviderInfoOutputReference_Override(e EmrcontainersVirtualClusterContainerProviderInfoOutputReference, ...)
- func NewEmrcontainersVirtualClusterContainerProviderOutputReference_Override(e EmrcontainersVirtualClusterContainerProviderOutputReference, ...)
- func NewEmrcontainersVirtualClusterTimeoutsOutputReference_Override(e EmrcontainersVirtualClusterTimeoutsOutputReference, ...)
- func NewEmrcontainersVirtualCluster_Override(e EmrcontainersVirtualCluster, scope constructs.Construct, id *string, ...)
- type EmrcontainersVirtualCluster
- type EmrcontainersVirtualClusterConfig
- type EmrcontainersVirtualClusterContainerProvider
- type EmrcontainersVirtualClusterContainerProviderInfo
- type EmrcontainersVirtualClusterContainerProviderInfoEksInfo
- type EmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference
- type EmrcontainersVirtualClusterContainerProviderInfoOutputReference
- type EmrcontainersVirtualClusterContainerProviderOutputReference
- type EmrcontainersVirtualClusterTimeouts
- type EmrcontainersVirtualClusterTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EmrcontainersVirtualCluster_IsConstruct ¶
func EmrcontainersVirtualCluster_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func EmrcontainersVirtualCluster_IsTerraformElement ¶
func EmrcontainersVirtualCluster_IsTerraformElement(x interface{}) *bool
Experimental.
func EmrcontainersVirtualCluster_IsTerraformResource ¶
func EmrcontainersVirtualCluster_IsTerraformResource(x interface{}) *bool
Experimental.
func EmrcontainersVirtualCluster_TfResourceType ¶
func EmrcontainersVirtualCluster_TfResourceType() *string
func NewEmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference_Override ¶
func NewEmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference_Override(e EmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEmrcontainersVirtualClusterContainerProviderInfoOutputReference_Override ¶
func NewEmrcontainersVirtualClusterContainerProviderInfoOutputReference_Override(e EmrcontainersVirtualClusterContainerProviderInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEmrcontainersVirtualClusterContainerProviderOutputReference_Override ¶
func NewEmrcontainersVirtualClusterContainerProviderOutputReference_Override(e EmrcontainersVirtualClusterContainerProviderOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEmrcontainersVirtualClusterTimeoutsOutputReference_Override ¶
func NewEmrcontainersVirtualClusterTimeoutsOutputReference_Override(e EmrcontainersVirtualClusterTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEmrcontainersVirtualCluster_Override ¶
func NewEmrcontainersVirtualCluster_Override(e EmrcontainersVirtualCluster, scope constructs.Construct, id *string, config *EmrcontainersVirtualClusterConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/emrcontainers_virtual_cluster aws_emrcontainers_virtual_cluster} Resource.
Types ¶
type EmrcontainersVirtualCluster ¶
type EmrcontainersVirtualCluster interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ContainerProvider() EmrcontainersVirtualClusterContainerProviderOutputReference
ContainerProviderInput() *EmrcontainersVirtualClusterContainerProvider
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() EmrcontainersVirtualClusterTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutContainerProvider(value *EmrcontainersVirtualClusterContainerProvider)
PutTimeouts(value *EmrcontainersVirtualClusterTimeouts)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/emrcontainers_virtual_cluster aws_emrcontainers_virtual_cluster}.
func NewEmrcontainersVirtualCluster ¶
func NewEmrcontainersVirtualCluster(scope constructs.Construct, id *string, config *EmrcontainersVirtualClusterConfig) EmrcontainersVirtualCluster
Create a new {@link https://www.terraform.io/docs/providers/aws/r/emrcontainers_virtual_cluster aws_emrcontainers_virtual_cluster} Resource.
type EmrcontainersVirtualClusterConfig ¶
type EmrcontainersVirtualClusterConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// container_provider block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emrcontainers_virtual_cluster#container_provider EmrcontainersVirtualCluster#container_provider}
ContainerProvider *EmrcontainersVirtualClusterContainerProvider `field:"required" json:"containerProvider" yaml:"containerProvider"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emrcontainers_virtual_cluster#name EmrcontainersVirtualCluster#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emrcontainers_virtual_cluster#id EmrcontainersVirtualCluster#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emrcontainers_virtual_cluster#tags EmrcontainersVirtualCluster#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emrcontainers_virtual_cluster#tags_all EmrcontainersVirtualCluster#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emrcontainers_virtual_cluster#timeouts EmrcontainersVirtualCluster#timeouts}
Timeouts *EmrcontainersVirtualClusterTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type EmrcontainersVirtualClusterContainerProvider ¶
type EmrcontainersVirtualClusterContainerProvider struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emrcontainers_virtual_cluster#id EmrcontainersVirtualCluster#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"required" json:"id" yaml:"id"`
// info block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emrcontainers_virtual_cluster#info EmrcontainersVirtualCluster#info}
Info *EmrcontainersVirtualClusterContainerProviderInfo `field:"required" json:"info" yaml:"info"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emrcontainers_virtual_cluster#type EmrcontainersVirtualCluster#type}.
Type *string `field:"required" json:"type" yaml:"type"`
}
type EmrcontainersVirtualClusterContainerProviderInfo ¶
type EmrcontainersVirtualClusterContainerProviderInfo struct {
// eks_info block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emrcontainers_virtual_cluster#eks_info EmrcontainersVirtualCluster#eks_info}
EksInfo *EmrcontainersVirtualClusterContainerProviderInfoEksInfo `field:"required" json:"eksInfo" yaml:"eksInfo"`
}
type EmrcontainersVirtualClusterContainerProviderInfoEksInfo ¶
type EmrcontainersVirtualClusterContainerProviderInfoEksInfo struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emrcontainers_virtual_cluster#namespace EmrcontainersVirtualCluster#namespace}.
Namespace *string `field:"optional" json:"namespace" yaml:"namespace"`
}
type EmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference ¶
type EmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EmrcontainersVirtualClusterContainerProviderInfoEksInfo
SetInternalValue(val *EmrcontainersVirtualClusterContainerProviderInfoEksInfo)
Namespace() *string
SetNamespace(val *string)
NamespaceInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetNamespace()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference ¶
func NewEmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference
type EmrcontainersVirtualClusterContainerProviderInfoOutputReference ¶
type EmrcontainersVirtualClusterContainerProviderInfoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EksInfo() EmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference
EksInfoInput() *EmrcontainersVirtualClusterContainerProviderInfoEksInfo
// Experimental.
Fqn() *string
InternalValue() *EmrcontainersVirtualClusterContainerProviderInfo
SetInternalValue(val *EmrcontainersVirtualClusterContainerProviderInfo)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutEksInfo(value *EmrcontainersVirtualClusterContainerProviderInfoEksInfo)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrcontainersVirtualClusterContainerProviderInfoOutputReference ¶
func NewEmrcontainersVirtualClusterContainerProviderInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EmrcontainersVirtualClusterContainerProviderInfoOutputReference
type EmrcontainersVirtualClusterContainerProviderOutputReference ¶
type EmrcontainersVirtualClusterContainerProviderOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
SetId(val *string)
IdInput() *string
Info() EmrcontainersVirtualClusterContainerProviderInfoOutputReference
InfoInput() *EmrcontainersVirtualClusterContainerProviderInfo
InternalValue() *EmrcontainersVirtualClusterContainerProvider
SetInternalValue(val *EmrcontainersVirtualClusterContainerProvider)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutInfo(value *EmrcontainersVirtualClusterContainerProviderInfo)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrcontainersVirtualClusterContainerProviderOutputReference ¶
func NewEmrcontainersVirtualClusterContainerProviderOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EmrcontainersVirtualClusterContainerProviderOutputReference
type EmrcontainersVirtualClusterTimeouts ¶
type EmrcontainersVirtualClusterTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emrcontainers_virtual_cluster#delete EmrcontainersVirtualCluster#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type EmrcontainersVirtualClusterTimeoutsOutputReference ¶
type EmrcontainersVirtualClusterTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrcontainersVirtualClusterTimeoutsOutputReference ¶
func NewEmrcontainersVirtualClusterTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EmrcontainersVirtualClusterTimeoutsOutputReference
Source Files
¶
- EmrcontainersVirtualCluster.go
- EmrcontainersVirtualClusterConfig.go
- EmrcontainersVirtualClusterContainerProvider.go
- EmrcontainersVirtualClusterContainerProviderInfo.go
- EmrcontainersVirtualClusterContainerProviderInfoEksInfo.go
- EmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference.go
- EmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference__checks.go
- EmrcontainersVirtualClusterContainerProviderInfoOutputReference.go
- EmrcontainersVirtualClusterContainerProviderInfoOutputReference__checks.go
- EmrcontainersVirtualClusterContainerProviderOutputReference.go
- EmrcontainersVirtualClusterContainerProviderOutputReference__checks.go
- EmrcontainersVirtualClusterTimeouts.go
- EmrcontainersVirtualClusterTimeoutsOutputReference.go
- EmrcontainersVirtualClusterTimeoutsOutputReference__checks.go
- EmrcontainersVirtualCluster__checks.go
- main.go