Documentation
¶
Index ¶
- func FmsPolicy_IsConstruct(x interface{}) *bool
- func FmsPolicy_IsTerraformElement(x interface{}) *bool
- func FmsPolicy_IsTerraformResource(x interface{}) *bool
- func FmsPolicy_TfResourceType() *string
- func NewFmsPolicyExcludeMapOutputReference_Override(f FmsPolicyExcludeMapOutputReference, ...)
- func NewFmsPolicyIncludeMapOutputReference_Override(f FmsPolicyIncludeMapOutputReference, ...)
- func NewFmsPolicySecurityServicePolicyDataOutputReference_Override(f FmsPolicySecurityServicePolicyDataOutputReference, ...)
- func NewFmsPolicy_Override(f FmsPolicy, scope constructs.Construct, id *string, config *FmsPolicyConfig)
- type FmsPolicy
- type FmsPolicyConfig
- type FmsPolicyExcludeMap
- type FmsPolicyExcludeMapOutputReference
- type FmsPolicyIncludeMap
- type FmsPolicyIncludeMapOutputReference
- type FmsPolicySecurityServicePolicyData
- type FmsPolicySecurityServicePolicyDataOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FmsPolicy_IsConstruct ¶
func FmsPolicy_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func FmsPolicy_IsTerraformElement ¶
func FmsPolicy_IsTerraformElement(x interface{}) *bool
Experimental.
func FmsPolicy_IsTerraformResource ¶
func FmsPolicy_IsTerraformResource(x interface{}) *bool
Experimental.
func FmsPolicy_TfResourceType ¶
func FmsPolicy_TfResourceType() *string
func NewFmsPolicyExcludeMapOutputReference_Override ¶
func NewFmsPolicyExcludeMapOutputReference_Override(f FmsPolicyExcludeMapOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFmsPolicyIncludeMapOutputReference_Override ¶
func NewFmsPolicyIncludeMapOutputReference_Override(f FmsPolicyIncludeMapOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFmsPolicySecurityServicePolicyDataOutputReference_Override ¶
func NewFmsPolicySecurityServicePolicyDataOutputReference_Override(f FmsPolicySecurityServicePolicyDataOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFmsPolicy_Override ¶
func NewFmsPolicy_Override(f FmsPolicy, scope constructs.Construct, id *string, config *FmsPolicyConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/fms_policy aws_fms_policy} Resource.
Types ¶
type FmsPolicy ¶
type FmsPolicy interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DeleteAllPolicyResources() interface{}
SetDeleteAllPolicyResources(val interface{})
DeleteAllPolicyResourcesInput() interface{}
DeleteUnusedFmManagedResources() interface{}
SetDeleteUnusedFmManagedResources(val interface{})
DeleteUnusedFmManagedResourcesInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
ExcludeMap() FmsPolicyExcludeMapOutputReference
ExcludeMapInput() *FmsPolicyExcludeMap
ExcludeResourceTags() interface{}
SetExcludeResourceTags(val interface{})
ExcludeResourceTagsInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IncludeMap() FmsPolicyIncludeMapOutputReference
IncludeMapInput() *FmsPolicyIncludeMap
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
PolicyUpdateToken() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RemediationEnabled() interface{}
SetRemediationEnabled(val interface{})
RemediationEnabledInput() interface{}
ResourceTags() *map[string]*string
SetResourceTags(val *map[string]*string)
ResourceTagsInput() *map[string]*string
ResourceType() *string
SetResourceType(val *string)
ResourceTypeInput() *string
ResourceTypeList() *[]*string
SetResourceTypeList(val *[]*string)
ResourceTypeListInput() *[]*string
SecurityServicePolicyData() FmsPolicySecurityServicePolicyDataOutputReference
SecurityServicePolicyDataInput() *FmsPolicySecurityServicePolicyData
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutExcludeMap(value *FmsPolicyExcludeMap)
PutIncludeMap(value *FmsPolicyIncludeMap)
PutSecurityServicePolicyData(value *FmsPolicySecurityServicePolicyData)
ResetDeleteAllPolicyResources()
ResetDeleteUnusedFmManagedResources()
ResetDescription()
ResetExcludeMap()
ResetId()
ResetIncludeMap()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRemediationEnabled()
ResetResourceTags()
ResetResourceType()
ResetResourceTypeList()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/fms_policy aws_fms_policy}.
func NewFmsPolicy ¶
func NewFmsPolicy(scope constructs.Construct, id *string, config *FmsPolicyConfig) FmsPolicy
Create a new {@link https://www.terraform.io/docs/providers/aws/r/fms_policy aws_fms_policy} Resource.
type FmsPolicyConfig ¶
type FmsPolicyConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#exclude_resource_tags FmsPolicy#exclude_resource_tags}.
ExcludeResourceTags interface{} `field:"required" json:"excludeResourceTags" yaml:"excludeResourceTags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#name FmsPolicy#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// security_service_policy_data block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#security_service_policy_data FmsPolicy#security_service_policy_data}
SecurityServicePolicyData *FmsPolicySecurityServicePolicyData `field:"required" json:"securityServicePolicyData" yaml:"securityServicePolicyData"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#delete_all_policy_resources FmsPolicy#delete_all_policy_resources}.
DeleteAllPolicyResources interface{} `field:"optional" json:"deleteAllPolicyResources" yaml:"deleteAllPolicyResources"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#delete_unused_fm_managed_resources FmsPolicy#delete_unused_fm_managed_resources}.
DeleteUnusedFmManagedResources interface{} `field:"optional" json:"deleteUnusedFmManagedResources" yaml:"deleteUnusedFmManagedResources"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#description FmsPolicy#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// exclude_map block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#exclude_map FmsPolicy#exclude_map}
ExcludeMap *FmsPolicyExcludeMap `field:"optional" json:"excludeMap" yaml:"excludeMap"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#id FmsPolicy#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// include_map block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#include_map FmsPolicy#include_map}
IncludeMap *FmsPolicyIncludeMap `field:"optional" json:"includeMap" yaml:"includeMap"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#remediation_enabled FmsPolicy#remediation_enabled}.
RemediationEnabled interface{} `field:"optional" json:"remediationEnabled" yaml:"remediationEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#resource_tags FmsPolicy#resource_tags}.
ResourceTags *map[string]*string `field:"optional" json:"resourceTags" yaml:"resourceTags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#resource_type FmsPolicy#resource_type}.
ResourceType *string `field:"optional" json:"resourceType" yaml:"resourceType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#resource_type_list FmsPolicy#resource_type_list}.
ResourceTypeList *[]*string `field:"optional" json:"resourceTypeList" yaml:"resourceTypeList"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#tags FmsPolicy#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#tags_all FmsPolicy#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type FmsPolicyExcludeMap ¶
type FmsPolicyExcludeMap struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#account FmsPolicy#account}.
Account *[]*string `field:"optional" json:"account" yaml:"account"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#orgunit FmsPolicy#orgunit}.
Orgunit *[]*string `field:"optional" json:"orgunit" yaml:"orgunit"`
}
type FmsPolicyExcludeMapOutputReference ¶
type FmsPolicyExcludeMapOutputReference interface {
cdktf.ComplexObject
Account() *[]*string
SetAccount(val *[]*string)
AccountInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *FmsPolicyExcludeMap
SetInternalValue(val *FmsPolicyExcludeMap)
Orgunit() *[]*string
SetOrgunit(val *[]*string)
OrgunitInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAccount()
ResetOrgunit()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFmsPolicyExcludeMapOutputReference ¶
func NewFmsPolicyExcludeMapOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FmsPolicyExcludeMapOutputReference
type FmsPolicyIncludeMap ¶
type FmsPolicyIncludeMap struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#account FmsPolicy#account}.
Account *[]*string `field:"optional" json:"account" yaml:"account"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#orgunit FmsPolicy#orgunit}.
Orgunit *[]*string `field:"optional" json:"orgunit" yaml:"orgunit"`
}
type FmsPolicyIncludeMapOutputReference ¶
type FmsPolicyIncludeMapOutputReference interface {
cdktf.ComplexObject
Account() *[]*string
SetAccount(val *[]*string)
AccountInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *FmsPolicyIncludeMap
SetInternalValue(val *FmsPolicyIncludeMap)
Orgunit() *[]*string
SetOrgunit(val *[]*string)
OrgunitInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAccount()
ResetOrgunit()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFmsPolicyIncludeMapOutputReference ¶
func NewFmsPolicyIncludeMapOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FmsPolicyIncludeMapOutputReference
type FmsPolicySecurityServicePolicyData ¶
type FmsPolicySecurityServicePolicyData struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#type FmsPolicy#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy#managed_service_data FmsPolicy#managed_service_data}.
ManagedServiceData *string `field:"optional" json:"managedServiceData" yaml:"managedServiceData"`
}
type FmsPolicySecurityServicePolicyDataOutputReference ¶
type FmsPolicySecurityServicePolicyDataOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *FmsPolicySecurityServicePolicyData
SetInternalValue(val *FmsPolicySecurityServicePolicyData)
ManagedServiceData() *string
SetManagedServiceData(val *string)
ManagedServiceDataInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetManagedServiceData()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFmsPolicySecurityServicePolicyDataOutputReference ¶
func NewFmsPolicySecurityServicePolicyDataOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FmsPolicySecurityServicePolicyDataOutputReference
Source Files
¶
- FmsPolicy.go
- FmsPolicyConfig.go
- FmsPolicyExcludeMap.go
- FmsPolicyExcludeMapOutputReference.go
- FmsPolicyExcludeMapOutputReference__checks.go
- FmsPolicyIncludeMap.go
- FmsPolicyIncludeMapOutputReference.go
- FmsPolicyIncludeMapOutputReference__checks.go
- FmsPolicySecurityServicePolicyData.go
- FmsPolicySecurityServicePolicyDataOutputReference.go
- FmsPolicySecurityServicePolicyDataOutputReference__checks.go
- FmsPolicy__checks.go
- main.go