Documentation
¶
Index ¶
- func FsxWindowsFileSystem_IsConstruct(x interface{}) *bool
- func FsxWindowsFileSystem_IsTerraformElement(x interface{}) *bool
- func FsxWindowsFileSystem_IsTerraformResource(x interface{}) *bool
- func FsxWindowsFileSystem_TfResourceType() *string
- func NewFsxWindowsFileSystemAuditLogConfigurationOutputReference_Override(f FsxWindowsFileSystemAuditLogConfigurationOutputReference, ...)
- func NewFsxWindowsFileSystemSelfManagedActiveDirectoryOutputReference_Override(f FsxWindowsFileSystemSelfManagedActiveDirectoryOutputReference, ...)
- func NewFsxWindowsFileSystemTimeoutsOutputReference_Override(f FsxWindowsFileSystemTimeoutsOutputReference, ...)
- func NewFsxWindowsFileSystem_Override(f FsxWindowsFileSystem, scope constructs.Construct, id *string, ...)
- type FsxWindowsFileSystem
- type FsxWindowsFileSystemAuditLogConfiguration
- type FsxWindowsFileSystemAuditLogConfigurationOutputReference
- type FsxWindowsFileSystemConfig
- type FsxWindowsFileSystemSelfManagedActiveDirectory
- type FsxWindowsFileSystemSelfManagedActiveDirectoryOutputReference
- type FsxWindowsFileSystemTimeouts
- type FsxWindowsFileSystemTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FsxWindowsFileSystem_IsConstruct ¶
func FsxWindowsFileSystem_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func FsxWindowsFileSystem_IsTerraformElement ¶
func FsxWindowsFileSystem_IsTerraformElement(x interface{}) *bool
Experimental.
func FsxWindowsFileSystem_IsTerraformResource ¶
func FsxWindowsFileSystem_IsTerraformResource(x interface{}) *bool
Experimental.
func FsxWindowsFileSystem_TfResourceType ¶
func FsxWindowsFileSystem_TfResourceType() *string
func NewFsxWindowsFileSystemAuditLogConfigurationOutputReference_Override ¶
func NewFsxWindowsFileSystemAuditLogConfigurationOutputReference_Override(f FsxWindowsFileSystemAuditLogConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFsxWindowsFileSystemSelfManagedActiveDirectoryOutputReference_Override ¶
func NewFsxWindowsFileSystemSelfManagedActiveDirectoryOutputReference_Override(f FsxWindowsFileSystemSelfManagedActiveDirectoryOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFsxWindowsFileSystemTimeoutsOutputReference_Override ¶
func NewFsxWindowsFileSystemTimeoutsOutputReference_Override(f FsxWindowsFileSystemTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFsxWindowsFileSystem_Override ¶
func NewFsxWindowsFileSystem_Override(f FsxWindowsFileSystem, scope constructs.Construct, id *string, config *FsxWindowsFileSystemConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system aws_fsx_windows_file_system} Resource.
Types ¶
type FsxWindowsFileSystem ¶
type FsxWindowsFileSystem interface {
cdktf.TerraformResource
ActiveDirectoryId() *string
SetActiveDirectoryId(val *string)
ActiveDirectoryIdInput() *string
Aliases() *[]*string
SetAliases(val *[]*string)
AliasesInput() *[]*string
Arn() *string
AuditLogConfiguration() FsxWindowsFileSystemAuditLogConfigurationOutputReference
AuditLogConfigurationInput() *FsxWindowsFileSystemAuditLogConfiguration
AutomaticBackupRetentionDays() *float64
SetAutomaticBackupRetentionDays(val *float64)
AutomaticBackupRetentionDaysInput() *float64
BackupId() *string
SetBackupId(val *string)
BackupIdInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
CopyTagsToBackups() interface{}
SetCopyTagsToBackups(val interface{})
CopyTagsToBackupsInput() interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DailyAutomaticBackupStartTime() *string
SetDailyAutomaticBackupStartTime(val *string)
DailyAutomaticBackupStartTimeInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeploymentType() *string
SetDeploymentType(val *string)
DeploymentTypeInput() *string
DnsName() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
NetworkInterfaceIds() *[]*string
// The tree node.
Node() constructs.Node
OwnerId() *string
PreferredFileServerIp() *string
PreferredSubnetId() *string
SetPreferredSubnetId(val *string)
PreferredSubnetIdInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RemoteAdministrationEndpoint() *string
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
SelfManagedActiveDirectory() FsxWindowsFileSystemSelfManagedActiveDirectoryOutputReference
SelfManagedActiveDirectoryInput() *FsxWindowsFileSystemSelfManagedActiveDirectory
SkipFinalBackup() interface{}
SetSkipFinalBackup(val interface{})
SkipFinalBackupInput() interface{}
StorageCapacity() *float64
SetStorageCapacity(val *float64)
StorageCapacityInput() *float64
StorageType() *string
SetStorageType(val *string)
StorageTypeInput() *string
SubnetIds() *[]*string
SetSubnetIds(val *[]*string)
SubnetIdsInput() *[]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
ThroughputCapacity() *float64
SetThroughputCapacity(val *float64)
ThroughputCapacityInput() *float64
Timeouts() FsxWindowsFileSystemTimeoutsOutputReference
TimeoutsInput() interface{}
VpcId() *string
WeeklyMaintenanceStartTime() *string
SetWeeklyMaintenanceStartTime(val *string)
WeeklyMaintenanceStartTimeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAuditLogConfiguration(value *FsxWindowsFileSystemAuditLogConfiguration)
PutSelfManagedActiveDirectory(value *FsxWindowsFileSystemSelfManagedActiveDirectory)
PutTimeouts(value *FsxWindowsFileSystemTimeouts)
ResetActiveDirectoryId()
ResetAliases()
ResetAuditLogConfiguration()
ResetAutomaticBackupRetentionDays()
ResetBackupId()
ResetCopyTagsToBackups()
ResetDailyAutomaticBackupStartTime()
ResetDeploymentType()
ResetId()
ResetKmsKeyId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPreferredSubnetId()
ResetSecurityGroupIds()
ResetSelfManagedActiveDirectory()
ResetSkipFinalBackup()
ResetStorageCapacity()
ResetStorageType()
ResetTags()
ResetTagsAll()
ResetTimeouts()
ResetWeeklyMaintenanceStartTime()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system aws_fsx_windows_file_system}.
func NewFsxWindowsFileSystem ¶
func NewFsxWindowsFileSystem(scope constructs.Construct, id *string, config *FsxWindowsFileSystemConfig) FsxWindowsFileSystem
Create a new {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system aws_fsx_windows_file_system} Resource.
type FsxWindowsFileSystemAuditLogConfiguration ¶
type FsxWindowsFileSystemAuditLogConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#audit_log_destination FsxWindowsFileSystem#audit_log_destination}.
AuditLogDestination *string `field:"optional" json:"auditLogDestination" yaml:"auditLogDestination"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#file_access_audit_log_level FsxWindowsFileSystem#file_access_audit_log_level}.
FileAccessAuditLogLevel *string `field:"optional" json:"fileAccessAuditLogLevel" yaml:"fileAccessAuditLogLevel"`
FileShareAccessAuditLogLevel *string `field:"optional" json:"fileShareAccessAuditLogLevel" yaml:"fileShareAccessAuditLogLevel"`
}
type FsxWindowsFileSystemAuditLogConfigurationOutputReference ¶
type FsxWindowsFileSystemAuditLogConfigurationOutputReference interface {
cdktf.ComplexObject
AuditLogDestination() *string
SetAuditLogDestination(val *string)
AuditLogDestinationInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FileAccessAuditLogLevel() *string
SetFileAccessAuditLogLevel(val *string)
FileAccessAuditLogLevelInput() *string
// Experimental.
Fqn() *string
InternalValue() *FsxWindowsFileSystemAuditLogConfiguration
SetInternalValue(val *FsxWindowsFileSystemAuditLogConfiguration)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAuditLogDestination()
ResetFileAccessAuditLogLevel()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxWindowsFileSystemAuditLogConfigurationOutputReference ¶
func NewFsxWindowsFileSystemAuditLogConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FsxWindowsFileSystemAuditLogConfigurationOutputReference
type FsxWindowsFileSystemConfig ¶
type FsxWindowsFileSystemConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#subnet_ids FsxWindowsFileSystem#subnet_ids}.
SubnetIds *[]*string `field:"required" json:"subnetIds" yaml:"subnetIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#throughput_capacity FsxWindowsFileSystem#throughput_capacity}.
ThroughputCapacity *float64 `field:"required" json:"throughputCapacity" yaml:"throughputCapacity"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#active_directory_id FsxWindowsFileSystem#active_directory_id}.
ActiveDirectoryId *string `field:"optional" json:"activeDirectoryId" yaml:"activeDirectoryId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#aliases FsxWindowsFileSystem#aliases}.
Aliases *[]*string `field:"optional" json:"aliases" yaml:"aliases"`
// audit_log_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#audit_log_configuration FsxWindowsFileSystem#audit_log_configuration}
AuditLogConfiguration *FsxWindowsFileSystemAuditLogConfiguration `field:"optional" json:"auditLogConfiguration" yaml:"auditLogConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#automatic_backup_retention_days FsxWindowsFileSystem#automatic_backup_retention_days}.
AutomaticBackupRetentionDays *float64 `field:"optional" json:"automaticBackupRetentionDays" yaml:"automaticBackupRetentionDays"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#backup_id FsxWindowsFileSystem#backup_id}.
BackupId *string `field:"optional" json:"backupId" yaml:"backupId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#copy_tags_to_backups FsxWindowsFileSystem#copy_tags_to_backups}.
CopyTagsToBackups interface{} `field:"optional" json:"copyTagsToBackups" yaml:"copyTagsToBackups"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#daily_automatic_backup_start_time FsxWindowsFileSystem#daily_automatic_backup_start_time}.
DailyAutomaticBackupStartTime *string `field:"optional" json:"dailyAutomaticBackupStartTime" yaml:"dailyAutomaticBackupStartTime"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#deployment_type FsxWindowsFileSystem#deployment_type}.
DeploymentType *string `field:"optional" json:"deploymentType" yaml:"deploymentType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#id FsxWindowsFileSystem#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#kms_key_id FsxWindowsFileSystem#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#preferred_subnet_id FsxWindowsFileSystem#preferred_subnet_id}.
PreferredSubnetId *string `field:"optional" json:"preferredSubnetId" yaml:"preferredSubnetId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#security_group_ids FsxWindowsFileSystem#security_group_ids}.
SecurityGroupIds *[]*string `field:"optional" json:"securityGroupIds" yaml:"securityGroupIds"`
// self_managed_active_directory block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#self_managed_active_directory FsxWindowsFileSystem#self_managed_active_directory}
SelfManagedActiveDirectory *FsxWindowsFileSystemSelfManagedActiveDirectory `field:"optional" json:"selfManagedActiveDirectory" yaml:"selfManagedActiveDirectory"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#skip_final_backup FsxWindowsFileSystem#skip_final_backup}.
SkipFinalBackup interface{} `field:"optional" json:"skipFinalBackup" yaml:"skipFinalBackup"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#storage_capacity FsxWindowsFileSystem#storage_capacity}.
StorageCapacity *float64 `field:"optional" json:"storageCapacity" yaml:"storageCapacity"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#storage_type FsxWindowsFileSystem#storage_type}.
StorageType *string `field:"optional" json:"storageType" yaml:"storageType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#tags FsxWindowsFileSystem#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#tags_all FsxWindowsFileSystem#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#timeouts FsxWindowsFileSystem#timeouts}
Timeouts *FsxWindowsFileSystemTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#weekly_maintenance_start_time FsxWindowsFileSystem#weekly_maintenance_start_time}.
WeeklyMaintenanceStartTime *string `field:"optional" json:"weeklyMaintenanceStartTime" yaml:"weeklyMaintenanceStartTime"`
}
type FsxWindowsFileSystemSelfManagedActiveDirectory ¶
type FsxWindowsFileSystemSelfManagedActiveDirectory struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#dns_ips FsxWindowsFileSystem#dns_ips}.
DnsIps *[]*string `field:"required" json:"dnsIps" yaml:"dnsIps"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#domain_name FsxWindowsFileSystem#domain_name}.
DomainName *string `field:"required" json:"domainName" yaml:"domainName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#password FsxWindowsFileSystem#password}.
Password *string `field:"required" json:"password" yaml:"password"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#username FsxWindowsFileSystem#username}.
Username *string `field:"required" json:"username" yaml:"username"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#file_system_administrators_group FsxWindowsFileSystem#file_system_administrators_group}.
FileSystemAdministratorsGroup *string `field:"optional" json:"fileSystemAdministratorsGroup" yaml:"fileSystemAdministratorsGroup"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#organizational_unit_distinguished_name FsxWindowsFileSystem#organizational_unit_distinguished_name}.
OrganizationalUnitDistinguishedName *string `field:"optional" json:"organizationalUnitDistinguishedName" yaml:"organizationalUnitDistinguishedName"`
}
type FsxWindowsFileSystemSelfManagedActiveDirectoryOutputReference ¶
type FsxWindowsFileSystemSelfManagedActiveDirectoryOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DnsIps() *[]*string
SetDnsIps(val *[]*string)
DnsIpsInput() *[]*string
DomainName() *string
SetDomainName(val *string)
DomainNameInput() *string
FileSystemAdministratorsGroup() *string
SetFileSystemAdministratorsGroup(val *string)
FileSystemAdministratorsGroupInput() *string
// Experimental.
Fqn() *string
InternalValue() *FsxWindowsFileSystemSelfManagedActiveDirectory
SetInternalValue(val *FsxWindowsFileSystemSelfManagedActiveDirectory)
OrganizationalUnitDistinguishedName() *string
SetOrganizationalUnitDistinguishedName(val *string)
OrganizationalUnitDistinguishedNameInput() *string
Password() *string
SetPassword(val *string)
PasswordInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Username() *string
SetUsername(val *string)
UsernameInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetFileSystemAdministratorsGroup()
ResetOrganizationalUnitDistinguishedName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxWindowsFileSystemSelfManagedActiveDirectoryOutputReference ¶
func NewFsxWindowsFileSystemSelfManagedActiveDirectoryOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FsxWindowsFileSystemSelfManagedActiveDirectoryOutputReference
type FsxWindowsFileSystemTimeouts ¶
type FsxWindowsFileSystemTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#create FsxWindowsFileSystem#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#delete FsxWindowsFileSystem#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system#update FsxWindowsFileSystem#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type FsxWindowsFileSystemTimeoutsOutputReference ¶
type FsxWindowsFileSystemTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxWindowsFileSystemTimeoutsOutputReference ¶
func NewFsxWindowsFileSystemTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FsxWindowsFileSystemTimeoutsOutputReference
Source Files
¶
- FsxWindowsFileSystem.go
- FsxWindowsFileSystemAuditLogConfiguration.go
- FsxWindowsFileSystemAuditLogConfigurationOutputReference.go
- FsxWindowsFileSystemAuditLogConfigurationOutputReference__checks.go
- FsxWindowsFileSystemConfig.go
- FsxWindowsFileSystemSelfManagedActiveDirectory.go
- FsxWindowsFileSystemSelfManagedActiveDirectoryOutputReference.go
- FsxWindowsFileSystemSelfManagedActiveDirectoryOutputReference__checks.go
- FsxWindowsFileSystemTimeouts.go
- FsxWindowsFileSystemTimeoutsOutputReference.go
- FsxWindowsFileSystemTimeoutsOutputReference__checks.go
- FsxWindowsFileSystem__checks.go
- main.go