Documentation
¶
Index ¶
- func GameliftGameServerGroup_IsConstruct(x interface{}) *bool
- func GameliftGameServerGroup_IsTerraformElement(x interface{}) *bool
- func GameliftGameServerGroup_IsTerraformResource(x interface{}) *bool
- func GameliftGameServerGroup_TfResourceType() *string
- func NewGameliftGameServerGroupAutoScalingPolicyOutputReference_Override(g GameliftGameServerGroupAutoScalingPolicyOutputReference, ...)
- func NewGameliftGameServerGroupAutoScalingPolicyTargetTrackingConfigurationOutputReference_Override(...)
- func NewGameliftGameServerGroupInstanceDefinitionList_Override(g GameliftGameServerGroupInstanceDefinitionList, ...)
- func NewGameliftGameServerGroupInstanceDefinitionOutputReference_Override(g GameliftGameServerGroupInstanceDefinitionOutputReference, ...)
- func NewGameliftGameServerGroupLaunchTemplateOutputReference_Override(g GameliftGameServerGroupLaunchTemplateOutputReference, ...)
- func NewGameliftGameServerGroupTimeoutsOutputReference_Override(g GameliftGameServerGroupTimeoutsOutputReference, ...)
- func NewGameliftGameServerGroup_Override(g GameliftGameServerGroup, scope constructs.Construct, id *string, ...)
- type GameliftGameServerGroup
- type GameliftGameServerGroupAutoScalingPolicy
- type GameliftGameServerGroupAutoScalingPolicyOutputReference
- type GameliftGameServerGroupAutoScalingPolicyTargetTrackingConfiguration
- type GameliftGameServerGroupAutoScalingPolicyTargetTrackingConfigurationOutputReference
- type GameliftGameServerGroupConfig
- type GameliftGameServerGroupInstanceDefinition
- type GameliftGameServerGroupInstanceDefinitionList
- type GameliftGameServerGroupInstanceDefinitionOutputReference
- type GameliftGameServerGroupLaunchTemplate
- type GameliftGameServerGroupLaunchTemplateOutputReference
- type GameliftGameServerGroupTimeouts
- type GameliftGameServerGroupTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GameliftGameServerGroup_IsConstruct ¶
func GameliftGameServerGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GameliftGameServerGroup_IsTerraformElement ¶
func GameliftGameServerGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func GameliftGameServerGroup_IsTerraformResource ¶
func GameliftGameServerGroup_IsTerraformResource(x interface{}) *bool
Experimental.
func GameliftGameServerGroup_TfResourceType ¶
func GameliftGameServerGroup_TfResourceType() *string
func NewGameliftGameServerGroupAutoScalingPolicyOutputReference_Override ¶
func NewGameliftGameServerGroupAutoScalingPolicyOutputReference_Override(g GameliftGameServerGroupAutoScalingPolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGameliftGameServerGroupAutoScalingPolicyTargetTrackingConfigurationOutputReference_Override ¶
func NewGameliftGameServerGroupAutoScalingPolicyTargetTrackingConfigurationOutputReference_Override(g GameliftGameServerGroupAutoScalingPolicyTargetTrackingConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGameliftGameServerGroupInstanceDefinitionList_Override ¶
func NewGameliftGameServerGroupInstanceDefinitionList_Override(g GameliftGameServerGroupInstanceDefinitionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGameliftGameServerGroupInstanceDefinitionOutputReference_Override ¶
func NewGameliftGameServerGroupInstanceDefinitionOutputReference_Override(g GameliftGameServerGroupInstanceDefinitionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGameliftGameServerGroupLaunchTemplateOutputReference_Override ¶
func NewGameliftGameServerGroupLaunchTemplateOutputReference_Override(g GameliftGameServerGroupLaunchTemplateOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGameliftGameServerGroupTimeoutsOutputReference_Override ¶
func NewGameliftGameServerGroupTimeoutsOutputReference_Override(g GameliftGameServerGroupTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGameliftGameServerGroup_Override ¶
func NewGameliftGameServerGroup_Override(g GameliftGameServerGroup, scope constructs.Construct, id *string, config *GameliftGameServerGroupConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group aws_gamelift_game_server_group} Resource.
Types ¶
type GameliftGameServerGroup ¶
type GameliftGameServerGroup interface {
cdktf.TerraformResource
Arn() *string
AutoScalingGroupArn() *string
AutoScalingPolicy() GameliftGameServerGroupAutoScalingPolicyOutputReference
AutoScalingPolicyInput() *GameliftGameServerGroupAutoScalingPolicy
BalancingStrategy() *string
SetBalancingStrategy(val *string)
BalancingStrategyInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GameServerGroupName() *string
SetGameServerGroupName(val *string)
GameServerGroupNameInput() *string
GameServerProtectionPolicy() *string
SetGameServerProtectionPolicy(val *string)
GameServerProtectionPolicyInput() *string
Id() *string
SetId(val *string)
IdInput() *string
InstanceDefinition() GameliftGameServerGroupInstanceDefinitionList
InstanceDefinitionInput() interface{}
LaunchTemplate() GameliftGameServerGroupLaunchTemplateOutputReference
LaunchTemplateInput() *GameliftGameServerGroupLaunchTemplate
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaxSize() *float64
SetMaxSize(val *float64)
MaxSizeInput() *float64
MinSize() *float64
SetMinSize(val *float64)
MinSizeInput() *float64
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GameliftGameServerGroupTimeoutsOutputReference
TimeoutsInput() interface{}
VpcSubnets() *[]*string
SetVpcSubnets(val *[]*string)
VpcSubnetsInput() *[]*string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAutoScalingPolicy(value *GameliftGameServerGroupAutoScalingPolicy)
PutInstanceDefinition(value interface{})
PutLaunchTemplate(value *GameliftGameServerGroupLaunchTemplate)
PutTimeouts(value *GameliftGameServerGroupTimeouts)
ResetAutoScalingPolicy()
ResetBalancingStrategy()
ResetGameServerProtectionPolicy()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
ResetTimeouts()
ResetVpcSubnets()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group aws_gamelift_game_server_group}.
func NewGameliftGameServerGroup ¶
func NewGameliftGameServerGroup(scope constructs.Construct, id *string, config *GameliftGameServerGroupConfig) GameliftGameServerGroup
Create a new {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group aws_gamelift_game_server_group} Resource.
type GameliftGameServerGroupAutoScalingPolicy ¶
type GameliftGameServerGroupAutoScalingPolicy struct {
// target_tracking_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#target_tracking_configuration GameliftGameServerGroup#target_tracking_configuration}
TargetTrackingConfiguration *GameliftGameServerGroupAutoScalingPolicyTargetTrackingConfiguration `field:"required" json:"targetTrackingConfiguration" yaml:"targetTrackingConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#estimated_instance_warmup GameliftGameServerGroup#estimated_instance_warmup}.
EstimatedInstanceWarmup *float64 `field:"optional" json:"estimatedInstanceWarmup" yaml:"estimatedInstanceWarmup"`
}
type GameliftGameServerGroupAutoScalingPolicyOutputReference ¶
type GameliftGameServerGroupAutoScalingPolicyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EstimatedInstanceWarmup() *float64
SetEstimatedInstanceWarmup(val *float64)
EstimatedInstanceWarmupInput() *float64
// Experimental.
Fqn() *string
InternalValue() *GameliftGameServerGroupAutoScalingPolicy
SetInternalValue(val *GameliftGameServerGroupAutoScalingPolicy)
TargetTrackingConfiguration() GameliftGameServerGroupAutoScalingPolicyTargetTrackingConfigurationOutputReference
TargetTrackingConfigurationInput() *GameliftGameServerGroupAutoScalingPolicyTargetTrackingConfiguration
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutTargetTrackingConfiguration(value *GameliftGameServerGroupAutoScalingPolicyTargetTrackingConfiguration)
ResetEstimatedInstanceWarmup()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGameliftGameServerGroupAutoScalingPolicyOutputReference ¶
func NewGameliftGameServerGroupAutoScalingPolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GameliftGameServerGroupAutoScalingPolicyOutputReference
type GameliftGameServerGroupAutoScalingPolicyTargetTrackingConfiguration ¶
type GameliftGameServerGroupAutoScalingPolicyTargetTrackingConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#target_value GameliftGameServerGroup#target_value}.
TargetValue *float64 `field:"required" json:"targetValue" yaml:"targetValue"`
}
type GameliftGameServerGroupAutoScalingPolicyTargetTrackingConfigurationOutputReference ¶
type GameliftGameServerGroupAutoScalingPolicyTargetTrackingConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GameliftGameServerGroupAutoScalingPolicyTargetTrackingConfiguration
SetInternalValue(val *GameliftGameServerGroupAutoScalingPolicyTargetTrackingConfiguration)
TargetValue() *float64
SetTargetValue(val *float64)
TargetValueInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGameliftGameServerGroupAutoScalingPolicyTargetTrackingConfigurationOutputReference ¶
func NewGameliftGameServerGroupAutoScalingPolicyTargetTrackingConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GameliftGameServerGroupAutoScalingPolicyTargetTrackingConfigurationOutputReference
type GameliftGameServerGroupConfig ¶
type GameliftGameServerGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#game_server_group_name GameliftGameServerGroup#game_server_group_name}.
GameServerGroupName *string `field:"required" json:"gameServerGroupName" yaml:"gameServerGroupName"`
// instance_definition block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#instance_definition GameliftGameServerGroup#instance_definition}
InstanceDefinition interface{} `field:"required" json:"instanceDefinition" yaml:"instanceDefinition"`
// launch_template block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#launch_template GameliftGameServerGroup#launch_template}
LaunchTemplate *GameliftGameServerGroupLaunchTemplate `field:"required" json:"launchTemplate" yaml:"launchTemplate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#max_size GameliftGameServerGroup#max_size}.
MaxSize *float64 `field:"required" json:"maxSize" yaml:"maxSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#min_size GameliftGameServerGroup#min_size}.
MinSize *float64 `field:"required" json:"minSize" yaml:"minSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#role_arn GameliftGameServerGroup#role_arn}.
RoleArn *string `field:"required" json:"roleArn" yaml:"roleArn"`
// auto_scaling_policy block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#auto_scaling_policy GameliftGameServerGroup#auto_scaling_policy}
AutoScalingPolicy *GameliftGameServerGroupAutoScalingPolicy `field:"optional" json:"autoScalingPolicy" yaml:"autoScalingPolicy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#balancing_strategy GameliftGameServerGroup#balancing_strategy}.
BalancingStrategy *string `field:"optional" json:"balancingStrategy" yaml:"balancingStrategy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#game_server_protection_policy GameliftGameServerGroup#game_server_protection_policy}.
GameServerProtectionPolicy *string `field:"optional" json:"gameServerProtectionPolicy" yaml:"gameServerProtectionPolicy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#id GameliftGameServerGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#tags GameliftGameServerGroup#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#tags_all GameliftGameServerGroup#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#timeouts GameliftGameServerGroup#timeouts}
Timeouts *GameliftGameServerGroupTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#vpc_subnets GameliftGameServerGroup#vpc_subnets}.
VpcSubnets *[]*string `field:"optional" json:"vpcSubnets" yaml:"vpcSubnets"`
}
type GameliftGameServerGroupInstanceDefinition ¶
type GameliftGameServerGroupInstanceDefinition struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#instance_type GameliftGameServerGroup#instance_type}.
InstanceType *string `field:"required" json:"instanceType" yaml:"instanceType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#weighted_capacity GameliftGameServerGroup#weighted_capacity}.
WeightedCapacity *string `field:"optional" json:"weightedCapacity" yaml:"weightedCapacity"`
}
type GameliftGameServerGroupInstanceDefinitionList ¶
type GameliftGameServerGroupInstanceDefinitionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GameliftGameServerGroupInstanceDefinitionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGameliftGameServerGroupInstanceDefinitionList ¶
func NewGameliftGameServerGroupInstanceDefinitionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GameliftGameServerGroupInstanceDefinitionList
type GameliftGameServerGroupInstanceDefinitionOutputReference ¶
type GameliftGameServerGroupInstanceDefinitionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InstanceType() *string
SetInstanceType(val *string)
InstanceTypeInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
WeightedCapacity() *string
SetWeightedCapacity(val *string)
WeightedCapacityInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetWeightedCapacity()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGameliftGameServerGroupInstanceDefinitionOutputReference ¶
func NewGameliftGameServerGroupInstanceDefinitionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GameliftGameServerGroupInstanceDefinitionOutputReference
type GameliftGameServerGroupLaunchTemplate ¶
type GameliftGameServerGroupLaunchTemplate struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#id GameliftGameServerGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#name GameliftGameServerGroup#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#version GameliftGameServerGroup#version}.
Version *string `field:"optional" json:"version" yaml:"version"`
}
type GameliftGameServerGroupLaunchTemplateOutputReference ¶
type GameliftGameServerGroupLaunchTemplateOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
SetId(val *string)
IdInput() *string
InternalValue() *GameliftGameServerGroupLaunchTemplate
SetInternalValue(val *GameliftGameServerGroupLaunchTemplate)
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Version() *string
SetVersion(val *string)
VersionInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetId()
ResetName()
ResetVersion()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGameliftGameServerGroupLaunchTemplateOutputReference ¶
func NewGameliftGameServerGroupLaunchTemplateOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GameliftGameServerGroupLaunchTemplateOutputReference
type GameliftGameServerGroupTimeouts ¶
type GameliftGameServerGroupTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#create GameliftGameServerGroup#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/gamelift_game_server_group#delete GameliftGameServerGroup#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type GameliftGameServerGroupTimeoutsOutputReference ¶
type GameliftGameServerGroupTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGameliftGameServerGroupTimeoutsOutputReference ¶
func NewGameliftGameServerGroupTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GameliftGameServerGroupTimeoutsOutputReference
Source Files
¶
- GameliftGameServerGroup.go
- GameliftGameServerGroupAutoScalingPolicy.go
- GameliftGameServerGroupAutoScalingPolicyOutputReference.go
- GameliftGameServerGroupAutoScalingPolicyOutputReference__checks.go
- GameliftGameServerGroupAutoScalingPolicyTargetTrackingConfiguration.go
- GameliftGameServerGroupAutoScalingPolicyTargetTrackingConfigurationOutputReference.go
- GameliftGameServerGroupAutoScalingPolicyTargetTrackingConfigurationOutputReference__checks.go
- GameliftGameServerGroupConfig.go
- GameliftGameServerGroupInstanceDefinition.go
- GameliftGameServerGroupInstanceDefinitionList.go
- GameliftGameServerGroupInstanceDefinitionList__checks.go
- GameliftGameServerGroupInstanceDefinitionOutputReference.go
- GameliftGameServerGroupInstanceDefinitionOutputReference__checks.go
- GameliftGameServerGroupLaunchTemplate.go
- GameliftGameServerGroupLaunchTemplateOutputReference.go
- GameliftGameServerGroupLaunchTemplateOutputReference__checks.go
- GameliftGameServerGroupTimeouts.go
- GameliftGameServerGroupTimeoutsOutputReference.go
- GameliftGameServerGroupTimeoutsOutputReference__checks.go
- GameliftGameServerGroup__checks.go
- main.go