Documentation
¶
Index ¶
- func GlobalacceleratorEndpointGroup_IsConstruct(x interface{}) *bool
- func GlobalacceleratorEndpointGroup_IsTerraformElement(x interface{}) *bool
- func GlobalacceleratorEndpointGroup_IsTerraformResource(x interface{}) *bool
- func GlobalacceleratorEndpointGroup_TfResourceType() *string
- func NewGlobalacceleratorEndpointGroupEndpointConfigurationList_Override(g GlobalacceleratorEndpointGroupEndpointConfigurationList, ...)
- func NewGlobalacceleratorEndpointGroupEndpointConfigurationOutputReference_Override(g GlobalacceleratorEndpointGroupEndpointConfigurationOutputReference, ...)
- func NewGlobalacceleratorEndpointGroupPortOverrideList_Override(g GlobalacceleratorEndpointGroupPortOverrideList, ...)
- func NewGlobalacceleratorEndpointGroupPortOverrideOutputReference_Override(g GlobalacceleratorEndpointGroupPortOverrideOutputReference, ...)
- func NewGlobalacceleratorEndpointGroupTimeoutsOutputReference_Override(g GlobalacceleratorEndpointGroupTimeoutsOutputReference, ...)
- func NewGlobalacceleratorEndpointGroup_Override(g GlobalacceleratorEndpointGroup, scope constructs.Construct, id *string, ...)
- type GlobalacceleratorEndpointGroup
- type GlobalacceleratorEndpointGroupConfig
- type GlobalacceleratorEndpointGroupEndpointConfiguration
- type GlobalacceleratorEndpointGroupEndpointConfigurationList
- type GlobalacceleratorEndpointGroupEndpointConfigurationOutputReference
- type GlobalacceleratorEndpointGroupPortOverride
- type GlobalacceleratorEndpointGroupPortOverrideList
- type GlobalacceleratorEndpointGroupPortOverrideOutputReference
- type GlobalacceleratorEndpointGroupTimeouts
- type GlobalacceleratorEndpointGroupTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GlobalacceleratorEndpointGroup_IsConstruct ¶
func GlobalacceleratorEndpointGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GlobalacceleratorEndpointGroup_IsTerraformElement ¶
func GlobalacceleratorEndpointGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func GlobalacceleratorEndpointGroup_IsTerraformResource ¶
func GlobalacceleratorEndpointGroup_IsTerraformResource(x interface{}) *bool
Experimental.
func GlobalacceleratorEndpointGroup_TfResourceType ¶
func GlobalacceleratorEndpointGroup_TfResourceType() *string
func NewGlobalacceleratorEndpointGroupEndpointConfigurationList_Override ¶
func NewGlobalacceleratorEndpointGroupEndpointConfigurationList_Override(g GlobalacceleratorEndpointGroupEndpointConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGlobalacceleratorEndpointGroupEndpointConfigurationOutputReference_Override ¶
func NewGlobalacceleratorEndpointGroupEndpointConfigurationOutputReference_Override(g GlobalacceleratorEndpointGroupEndpointConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGlobalacceleratorEndpointGroupPortOverrideList_Override ¶
func NewGlobalacceleratorEndpointGroupPortOverrideList_Override(g GlobalacceleratorEndpointGroupPortOverrideList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGlobalacceleratorEndpointGroupPortOverrideOutputReference_Override ¶
func NewGlobalacceleratorEndpointGroupPortOverrideOutputReference_Override(g GlobalacceleratorEndpointGroupPortOverrideOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGlobalacceleratorEndpointGroupTimeoutsOutputReference_Override ¶
func NewGlobalacceleratorEndpointGroupTimeoutsOutputReference_Override(g GlobalacceleratorEndpointGroupTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGlobalacceleratorEndpointGroup_Override ¶
func NewGlobalacceleratorEndpointGroup_Override(g GlobalacceleratorEndpointGroup, scope constructs.Construct, id *string, config *GlobalacceleratorEndpointGroupConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group aws_globalaccelerator_endpoint_group} Resource.
Types ¶
type GlobalacceleratorEndpointGroup ¶
type GlobalacceleratorEndpointGroup interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EndpointConfiguration() GlobalacceleratorEndpointGroupEndpointConfigurationList
EndpointConfigurationInput() interface{}
EndpointGroupRegion() *string
SetEndpointGroupRegion(val *string)
EndpointGroupRegionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HealthCheckIntervalSeconds() *float64
SetHealthCheckIntervalSeconds(val *float64)
HealthCheckIntervalSecondsInput() *float64
HealthCheckPath() *string
SetHealthCheckPath(val *string)
HealthCheckPathInput() *string
HealthCheckPort() *float64
SetHealthCheckPort(val *float64)
HealthCheckPortInput() *float64
HealthCheckProtocol() *string
SetHealthCheckProtocol(val *string)
HealthCheckProtocolInput() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
ListenerArn() *string
SetListenerArn(val *string)
ListenerArnInput() *string
// The tree node.
Node() constructs.Node
PortOverride() GlobalacceleratorEndpointGroupPortOverrideList
PortOverrideInput() interface{}
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
ThresholdCount() *float64
SetThresholdCount(val *float64)
ThresholdCountInput() *float64
Timeouts() GlobalacceleratorEndpointGroupTimeoutsOutputReference
TimeoutsInput() interface{}
TrafficDialPercentage() *float64
SetTrafficDialPercentage(val *float64)
TrafficDialPercentageInput() *float64
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutEndpointConfiguration(value interface{})
PutPortOverride(value interface{})
PutTimeouts(value *GlobalacceleratorEndpointGroupTimeouts)
ResetEndpointConfiguration()
ResetEndpointGroupRegion()
ResetHealthCheckIntervalSeconds()
ResetHealthCheckPath()
ResetHealthCheckPort()
ResetHealthCheckProtocol()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPortOverride()
ResetThresholdCount()
ResetTimeouts()
ResetTrafficDialPercentage()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group aws_globalaccelerator_endpoint_group}.
func NewGlobalacceleratorEndpointGroup ¶
func NewGlobalacceleratorEndpointGroup(scope constructs.Construct, id *string, config *GlobalacceleratorEndpointGroupConfig) GlobalacceleratorEndpointGroup
Create a new {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group aws_globalaccelerator_endpoint_group} Resource.
type GlobalacceleratorEndpointGroupConfig ¶
type GlobalacceleratorEndpointGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#listener_arn GlobalacceleratorEndpointGroup#listener_arn}.
ListenerArn *string `field:"required" json:"listenerArn" yaml:"listenerArn"`
// endpoint_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#endpoint_configuration GlobalacceleratorEndpointGroup#endpoint_configuration}
EndpointConfiguration interface{} `field:"optional" json:"endpointConfiguration" yaml:"endpointConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#endpoint_group_region GlobalacceleratorEndpointGroup#endpoint_group_region}.
EndpointGroupRegion *string `field:"optional" json:"endpointGroupRegion" yaml:"endpointGroupRegion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#health_check_interval_seconds GlobalacceleratorEndpointGroup#health_check_interval_seconds}.
HealthCheckIntervalSeconds *float64 `field:"optional" json:"healthCheckIntervalSeconds" yaml:"healthCheckIntervalSeconds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#health_check_path GlobalacceleratorEndpointGroup#health_check_path}.
HealthCheckPath *string `field:"optional" json:"healthCheckPath" yaml:"healthCheckPath"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#health_check_port GlobalacceleratorEndpointGroup#health_check_port}.
HealthCheckPort *float64 `field:"optional" json:"healthCheckPort" yaml:"healthCheckPort"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#health_check_protocol GlobalacceleratorEndpointGroup#health_check_protocol}.
HealthCheckProtocol *string `field:"optional" json:"healthCheckProtocol" yaml:"healthCheckProtocol"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#id GlobalacceleratorEndpointGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// port_override block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#port_override GlobalacceleratorEndpointGroup#port_override}
PortOverride interface{} `field:"optional" json:"portOverride" yaml:"portOverride"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#threshold_count GlobalacceleratorEndpointGroup#threshold_count}.
ThresholdCount *float64 `field:"optional" json:"thresholdCount" yaml:"thresholdCount"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#timeouts GlobalacceleratorEndpointGroup#timeouts}
Timeouts *GlobalacceleratorEndpointGroupTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#traffic_dial_percentage GlobalacceleratorEndpointGroup#traffic_dial_percentage}.
TrafficDialPercentage *float64 `field:"optional" json:"trafficDialPercentage" yaml:"trafficDialPercentage"`
}
type GlobalacceleratorEndpointGroupEndpointConfiguration ¶
type GlobalacceleratorEndpointGroupEndpointConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#client_ip_preservation_enabled GlobalacceleratorEndpointGroup#client_ip_preservation_enabled}.
ClientIpPreservationEnabled interface{} `field:"optional" json:"clientIpPreservationEnabled" yaml:"clientIpPreservationEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#endpoint_id GlobalacceleratorEndpointGroup#endpoint_id}.
EndpointId *string `field:"optional" json:"endpointId" yaml:"endpointId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#weight GlobalacceleratorEndpointGroup#weight}.
Weight *float64 `field:"optional" json:"weight" yaml:"weight"`
}
type GlobalacceleratorEndpointGroupEndpointConfigurationList ¶
type GlobalacceleratorEndpointGroupEndpointConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GlobalacceleratorEndpointGroupEndpointConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlobalacceleratorEndpointGroupEndpointConfigurationList ¶
func NewGlobalacceleratorEndpointGroupEndpointConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GlobalacceleratorEndpointGroupEndpointConfigurationList
type GlobalacceleratorEndpointGroupEndpointConfigurationOutputReference ¶
type GlobalacceleratorEndpointGroupEndpointConfigurationOutputReference interface {
cdktf.ComplexObject
ClientIpPreservationEnabled() interface{}
SetClientIpPreservationEnabled(val interface{})
ClientIpPreservationEnabledInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EndpointId() *string
SetEndpointId(val *string)
EndpointIdInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Weight() *float64
SetWeight(val *float64)
WeightInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetClientIpPreservationEnabled()
ResetEndpointId()
ResetWeight()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlobalacceleratorEndpointGroupEndpointConfigurationOutputReference ¶
func NewGlobalacceleratorEndpointGroupEndpointConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GlobalacceleratorEndpointGroupEndpointConfigurationOutputReference
type GlobalacceleratorEndpointGroupPortOverride ¶
type GlobalacceleratorEndpointGroupPortOverride struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#endpoint_port GlobalacceleratorEndpointGroup#endpoint_port}.
EndpointPort *float64 `field:"required" json:"endpointPort" yaml:"endpointPort"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#listener_port GlobalacceleratorEndpointGroup#listener_port}.
ListenerPort *float64 `field:"required" json:"listenerPort" yaml:"listenerPort"`
}
type GlobalacceleratorEndpointGroupPortOverrideList ¶
type GlobalacceleratorEndpointGroupPortOverrideList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GlobalacceleratorEndpointGroupPortOverrideOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlobalacceleratorEndpointGroupPortOverrideList ¶
func NewGlobalacceleratorEndpointGroupPortOverrideList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GlobalacceleratorEndpointGroupPortOverrideList
type GlobalacceleratorEndpointGroupPortOverrideOutputReference ¶
type GlobalacceleratorEndpointGroupPortOverrideOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EndpointPort() *float64
SetEndpointPort(val *float64)
EndpointPortInput() *float64
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
ListenerPort() *float64
SetListenerPort(val *float64)
ListenerPortInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlobalacceleratorEndpointGroupPortOverrideOutputReference ¶
func NewGlobalacceleratorEndpointGroupPortOverrideOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GlobalacceleratorEndpointGroupPortOverrideOutputReference
type GlobalacceleratorEndpointGroupTimeouts ¶
type GlobalacceleratorEndpointGroupTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#create GlobalacceleratorEndpointGroup#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#delete GlobalacceleratorEndpointGroup#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/globalaccelerator_endpoint_group#update GlobalacceleratorEndpointGroup#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GlobalacceleratorEndpointGroupTimeoutsOutputReference ¶
type GlobalacceleratorEndpointGroupTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlobalacceleratorEndpointGroupTimeoutsOutputReference ¶
func NewGlobalacceleratorEndpointGroupTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GlobalacceleratorEndpointGroupTimeoutsOutputReference
Source Files
¶
- GlobalacceleratorEndpointGroup.go
- GlobalacceleratorEndpointGroupConfig.go
- GlobalacceleratorEndpointGroupEndpointConfiguration.go
- GlobalacceleratorEndpointGroupEndpointConfigurationList.go
- GlobalacceleratorEndpointGroupEndpointConfigurationList__checks.go
- GlobalacceleratorEndpointGroupEndpointConfigurationOutputReference.go
- GlobalacceleratorEndpointGroupEndpointConfigurationOutputReference__checks.go
- GlobalacceleratorEndpointGroupPortOverride.go
- GlobalacceleratorEndpointGroupPortOverrideList.go
- GlobalacceleratorEndpointGroupPortOverrideList__checks.go
- GlobalacceleratorEndpointGroupPortOverrideOutputReference.go
- GlobalacceleratorEndpointGroupPortOverrideOutputReference__checks.go
- GlobalacceleratorEndpointGroupTimeouts.go
- GlobalacceleratorEndpointGroupTimeoutsOutputReference.go
- GlobalacceleratorEndpointGroupTimeoutsOutputReference__checks.go
- GlobalacceleratorEndpointGroup__checks.go
- main.go