Documentation
¶
Index ¶
- func GlueJob_IsConstruct(x interface{}) *bool
- func GlueJob_IsTerraformElement(x interface{}) *bool
- func GlueJob_IsTerraformResource(x interface{}) *bool
- func GlueJob_TfResourceType() *string
- func NewGlueJobCommandOutputReference_Override(g GlueJobCommandOutputReference, terraformResource cdktf.IInterpolatingParent, ...)
- func NewGlueJobExecutionPropertyOutputReference_Override(g GlueJobExecutionPropertyOutputReference, ...)
- func NewGlueJobNotificationPropertyOutputReference_Override(g GlueJobNotificationPropertyOutputReference, ...)
- func NewGlueJob_Override(g GlueJob, scope constructs.Construct, id *string, config *GlueJobConfig)
- type GlueJob
- type GlueJobCommand
- type GlueJobCommandOutputReference
- type GlueJobConfig
- type GlueJobExecutionProperty
- type GlueJobExecutionPropertyOutputReference
- type GlueJobNotificationProperty
- type GlueJobNotificationPropertyOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GlueJob_IsConstruct ¶
func GlueJob_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GlueJob_IsTerraformElement ¶
func GlueJob_IsTerraformElement(x interface{}) *bool
Experimental.
func GlueJob_IsTerraformResource ¶
func GlueJob_IsTerraformResource(x interface{}) *bool
Experimental.
func GlueJob_TfResourceType ¶
func GlueJob_TfResourceType() *string
func NewGlueJobCommandOutputReference_Override ¶
func NewGlueJobCommandOutputReference_Override(g GlueJobCommandOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGlueJobExecutionPropertyOutputReference_Override ¶
func NewGlueJobExecutionPropertyOutputReference_Override(g GlueJobExecutionPropertyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGlueJobNotificationPropertyOutputReference_Override ¶
func NewGlueJobNotificationPropertyOutputReference_Override(g GlueJobNotificationPropertyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGlueJob_Override ¶
func NewGlueJob_Override(g GlueJob, scope constructs.Construct, id *string, config *GlueJobConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_job aws_glue_job} Resource.
Types ¶
type GlueJob ¶
type GlueJob interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
Command() GlueJobCommandOutputReference
CommandInput() *GlueJobCommand
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
Connections() *[]*string
SetConnections(val *[]*string)
ConnectionsInput() *[]*string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DefaultArguments() *map[string]*string
SetDefaultArguments(val *map[string]*string)
DefaultArgumentsInput() *map[string]*string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
ExecutionClass() *string
SetExecutionClass(val *string)
ExecutionClassInput() *string
ExecutionProperty() GlueJobExecutionPropertyOutputReference
ExecutionPropertyInput() *GlueJobExecutionProperty
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GlueVersion() *string
SetGlueVersion(val *string)
GlueVersionInput() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaxCapacity() *float64
SetMaxCapacity(val *float64)
MaxCapacityInput() *float64
MaxRetries() *float64
SetMaxRetries(val *float64)
MaxRetriesInput() *float64
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
NonOverridableArguments() *map[string]*string
SetNonOverridableArguments(val *map[string]*string)
NonOverridableArgumentsInput() *map[string]*string
NotificationProperty() GlueJobNotificationPropertyOutputReference
NotificationPropertyInput() *GlueJobNotificationProperty
NumberOfWorkers() *float64
SetNumberOfWorkers(val *float64)
NumberOfWorkersInput() *float64
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
SecurityConfiguration() *string
SetSecurityConfiguration(val *string)
SecurityConfigurationInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeout() *float64
SetTimeout(val *float64)
TimeoutInput() *float64
WorkerType() *string
SetWorkerType(val *string)
WorkerTypeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCommand(value *GlueJobCommand)
PutExecutionProperty(value *GlueJobExecutionProperty)
PutNotificationProperty(value *GlueJobNotificationProperty)
ResetConnections()
ResetDefaultArguments()
ResetDescription()
ResetExecutionClass()
ResetExecutionProperty()
ResetGlueVersion()
ResetId()
ResetMaxCapacity()
ResetMaxRetries()
ResetNonOverridableArguments()
ResetNotificationProperty()
ResetNumberOfWorkers()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSecurityConfiguration()
ResetTags()
ResetTagsAll()
ResetTimeout()
ResetWorkerType()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_job aws_glue_job}.
func NewGlueJob ¶
func NewGlueJob(scope constructs.Construct, id *string, config *GlueJobConfig) GlueJob
Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_job aws_glue_job} Resource.
type GlueJobCommand ¶
type GlueJobCommand struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#script_location GlueJob#script_location}.
ScriptLocation *string `field:"required" json:"scriptLocation" yaml:"scriptLocation"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#name GlueJob#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#python_version GlueJob#python_version}.
PythonVersion *string `field:"optional" json:"pythonVersion" yaml:"pythonVersion"`
}
type GlueJobCommandOutputReference ¶
type GlueJobCommandOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GlueJobCommand
SetInternalValue(val *GlueJobCommand)
Name() *string
SetName(val *string)
NameInput() *string
PythonVersion() *string
SetPythonVersion(val *string)
PythonVersionInput() *string
ScriptLocation() *string
SetScriptLocation(val *string)
ScriptLocationInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetName()
ResetPythonVersion()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueJobCommandOutputReference ¶
func NewGlueJobCommandOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GlueJobCommandOutputReference
type GlueJobConfig ¶
type GlueJobConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// command block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#command GlueJob#command}
Command *GlueJobCommand `field:"required" json:"command" yaml:"command"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#name GlueJob#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#role_arn GlueJob#role_arn}.
RoleArn *string `field:"required" json:"roleArn" yaml:"roleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#connections GlueJob#connections}.
Connections *[]*string `field:"optional" json:"connections" yaml:"connections"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#default_arguments GlueJob#default_arguments}.
DefaultArguments *map[string]*string `field:"optional" json:"defaultArguments" yaml:"defaultArguments"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#description GlueJob#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#execution_class GlueJob#execution_class}.
ExecutionClass *string `field:"optional" json:"executionClass" yaml:"executionClass"`
// execution_property block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#execution_property GlueJob#execution_property}
ExecutionProperty *GlueJobExecutionProperty `field:"optional" json:"executionProperty" yaml:"executionProperty"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#glue_version GlueJob#glue_version}.
GlueVersion *string `field:"optional" json:"glueVersion" yaml:"glueVersion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#id GlueJob#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#max_capacity GlueJob#max_capacity}.
MaxCapacity *float64 `field:"optional" json:"maxCapacity" yaml:"maxCapacity"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#max_retries GlueJob#max_retries}.
MaxRetries *float64 `field:"optional" json:"maxRetries" yaml:"maxRetries"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#non_overridable_arguments GlueJob#non_overridable_arguments}.
NonOverridableArguments *map[string]*string `field:"optional" json:"nonOverridableArguments" yaml:"nonOverridableArguments"`
// notification_property block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#notification_property GlueJob#notification_property}
NotificationProperty *GlueJobNotificationProperty `field:"optional" json:"notificationProperty" yaml:"notificationProperty"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#number_of_workers GlueJob#number_of_workers}.
NumberOfWorkers *float64 `field:"optional" json:"numberOfWorkers" yaml:"numberOfWorkers"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#security_configuration GlueJob#security_configuration}.
SecurityConfiguration *string `field:"optional" json:"securityConfiguration" yaml:"securityConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#tags GlueJob#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#tags_all GlueJob#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#timeout GlueJob#timeout}.
Timeout *float64 `field:"optional" json:"timeout" yaml:"timeout"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#worker_type GlueJob#worker_type}.
WorkerType *string `field:"optional" json:"workerType" yaml:"workerType"`
}
type GlueJobExecutionProperty ¶
type GlueJobExecutionProperty struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#max_concurrent_runs GlueJob#max_concurrent_runs}.
MaxConcurrentRuns *float64 `field:"optional" json:"maxConcurrentRuns" yaml:"maxConcurrentRuns"`
}
type GlueJobExecutionPropertyOutputReference ¶
type GlueJobExecutionPropertyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GlueJobExecutionProperty
SetInternalValue(val *GlueJobExecutionProperty)
MaxConcurrentRuns() *float64
SetMaxConcurrentRuns(val *float64)
MaxConcurrentRunsInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetMaxConcurrentRuns()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueJobExecutionPropertyOutputReference ¶
func NewGlueJobExecutionPropertyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GlueJobExecutionPropertyOutputReference
type GlueJobNotificationProperty ¶
type GlueJobNotificationProperty struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#notify_delay_after GlueJob#notify_delay_after}.
NotifyDelayAfter *float64 `field:"optional" json:"notifyDelayAfter" yaml:"notifyDelayAfter"`
}
type GlueJobNotificationPropertyOutputReference ¶
type GlueJobNotificationPropertyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GlueJobNotificationProperty
SetInternalValue(val *GlueJobNotificationProperty)
NotifyDelayAfter() *float64
SetNotifyDelayAfter(val *float64)
NotifyDelayAfterInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetNotifyDelayAfter()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlueJobNotificationPropertyOutputReference ¶
func NewGlueJobNotificationPropertyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GlueJobNotificationPropertyOutputReference
Source Files
¶
- GlueJob.go
- GlueJobCommand.go
- GlueJobCommandOutputReference.go
- GlueJobCommandOutputReference__checks.go
- GlueJobConfig.go
- GlueJobExecutionProperty.go
- GlueJobExecutionPropertyOutputReference.go
- GlueJobExecutionPropertyOutputReference__checks.go
- GlueJobNotificationProperty.go
- GlueJobNotificationPropertyOutputReference.go
- GlueJobNotificationPropertyOutputReference__checks.go
- GlueJob__checks.go
- main.go