Documentation
¶
Index ¶
- func GuarddutyFilter_IsConstruct(x interface{}) *bool
- func GuarddutyFilter_IsTerraformElement(x interface{}) *bool
- func GuarddutyFilter_IsTerraformResource(x interface{}) *bool
- func GuarddutyFilter_TfResourceType() *string
- func NewGuarddutyFilterFindingCriteriaCriterionList_Override(g GuarddutyFilterFindingCriteriaCriterionList, ...)
- func NewGuarddutyFilterFindingCriteriaCriterionOutputReference_Override(g GuarddutyFilterFindingCriteriaCriterionOutputReference, ...)
- func NewGuarddutyFilterFindingCriteriaOutputReference_Override(g GuarddutyFilterFindingCriteriaOutputReference, ...)
- func NewGuarddutyFilter_Override(g GuarddutyFilter, scope constructs.Construct, id *string, ...)
- type GuarddutyFilter
- type GuarddutyFilterConfig
- type GuarddutyFilterFindingCriteria
- type GuarddutyFilterFindingCriteriaCriterion
- type GuarddutyFilterFindingCriteriaCriterionList
- type GuarddutyFilterFindingCriteriaCriterionOutputReference
- type GuarddutyFilterFindingCriteriaOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GuarddutyFilter_IsConstruct ¶
func GuarddutyFilter_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GuarddutyFilter_IsTerraformElement ¶
func GuarddutyFilter_IsTerraformElement(x interface{}) *bool
Experimental.
func GuarddutyFilter_IsTerraformResource ¶
func GuarddutyFilter_IsTerraformResource(x interface{}) *bool
Experimental.
func GuarddutyFilter_TfResourceType ¶
func GuarddutyFilter_TfResourceType() *string
func NewGuarddutyFilterFindingCriteriaCriterionList_Override ¶
func NewGuarddutyFilterFindingCriteriaCriterionList_Override(g GuarddutyFilterFindingCriteriaCriterionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGuarddutyFilterFindingCriteriaCriterionOutputReference_Override ¶
func NewGuarddutyFilterFindingCriteriaCriterionOutputReference_Override(g GuarddutyFilterFindingCriteriaCriterionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGuarddutyFilterFindingCriteriaOutputReference_Override ¶
func NewGuarddutyFilterFindingCriteriaOutputReference_Override(g GuarddutyFilterFindingCriteriaOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGuarddutyFilter_Override ¶
func NewGuarddutyFilter_Override(g GuarddutyFilter, scope constructs.Construct, id *string, config *GuarddutyFilterConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter aws_guardduty_filter} Resource.
Types ¶
type GuarddutyFilter ¶
type GuarddutyFilter interface {
cdktf.TerraformResource
Action() *string
SetAction(val *string)
ActionInput() *string
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DetectorId() *string
SetDetectorId(val *string)
DetectorIdInput() *string
FindingCriteria() GuarddutyFilterFindingCriteriaOutputReference
FindingCriteriaInput() *GuarddutyFilterFindingCriteria
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
Rank() *float64
SetRank(val *float64)
RankInput() *float64
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutFindingCriteria(value *GuarddutyFilterFindingCriteria)
ResetDescription()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter aws_guardduty_filter}.
func NewGuarddutyFilter ¶
func NewGuarddutyFilter(scope constructs.Construct, id *string, config *GuarddutyFilterConfig) GuarddutyFilter
Create a new {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter aws_guardduty_filter} Resource.
type GuarddutyFilterConfig ¶
type GuarddutyFilterConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter#action GuarddutyFilter#action}.
Action *string `field:"required" json:"action" yaml:"action"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter#detector_id GuarddutyFilter#detector_id}.
DetectorId *string `field:"required" json:"detectorId" yaml:"detectorId"`
// finding_criteria block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter#finding_criteria GuarddutyFilter#finding_criteria}
FindingCriteria *GuarddutyFilterFindingCriteria `field:"required" json:"findingCriteria" yaml:"findingCriteria"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter#name GuarddutyFilter#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter#rank GuarddutyFilter#rank}.
Rank *float64 `field:"required" json:"rank" yaml:"rank"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter#description GuarddutyFilter#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter#id GuarddutyFilter#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter#tags GuarddutyFilter#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter#tags_all GuarddutyFilter#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type GuarddutyFilterFindingCriteria ¶
type GuarddutyFilterFindingCriteria struct {
// criterion block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter#criterion GuarddutyFilter#criterion}
Criterion interface{} `field:"required" json:"criterion" yaml:"criterion"`
}
type GuarddutyFilterFindingCriteriaCriterion ¶
type GuarddutyFilterFindingCriteriaCriterion struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter#field GuarddutyFilter#field}.
Field *string `field:"required" json:"field" yaml:"field"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter#equals GuarddutyFilter#equals}.
EqualTo *[]*string `field:"optional" json:"equalTo" yaml:"equalTo"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter#greater_than GuarddutyFilter#greater_than}.
GreaterThan *string `field:"optional" json:"greaterThan" yaml:"greaterThan"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter#greater_than_or_equal GuarddutyFilter#greater_than_or_equal}.
GreaterThanOrEqual *string `field:"optional" json:"greaterThanOrEqual" yaml:"greaterThanOrEqual"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter#less_than GuarddutyFilter#less_than}.
LessThan *string `field:"optional" json:"lessThan" yaml:"lessThan"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter#less_than_or_equal GuarddutyFilter#less_than_or_equal}.
LessThanOrEqual *string `field:"optional" json:"lessThanOrEqual" yaml:"lessThanOrEqual"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter#not_equals GuarddutyFilter#not_equals}.
NotEquals *[]*string `field:"optional" json:"notEquals" yaml:"notEquals"`
}
type GuarddutyFilterFindingCriteriaCriterionList ¶
type GuarddutyFilterFindingCriteriaCriterionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GuarddutyFilterFindingCriteriaCriterionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGuarddutyFilterFindingCriteriaCriterionList ¶
func NewGuarddutyFilterFindingCriteriaCriterionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GuarddutyFilterFindingCriteriaCriterionList
type GuarddutyFilterFindingCriteriaCriterionOutputReference ¶
type GuarddutyFilterFindingCriteriaCriterionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EqualTo() *[]*string
SetEqualTo(val *[]*string)
EqualToInput() *[]*string
Field() *string
SetField(val *string)
FieldInput() *string
// Experimental.
Fqn() *string
GreaterThan() *string
SetGreaterThan(val *string)
GreaterThanInput() *string
GreaterThanOrEqual() *string
SetGreaterThanOrEqual(val *string)
GreaterThanOrEqualInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
LessThan() *string
SetLessThan(val *string)
LessThanInput() *string
LessThanOrEqual() *string
SetLessThanOrEqual(val *string)
LessThanOrEqualInput() *string
NotEquals() *[]*string
SetNotEquals(val *[]*string)
NotEqualsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEqualTo()
ResetGreaterThan()
ResetGreaterThanOrEqual()
ResetLessThan()
ResetLessThanOrEqual()
ResetNotEquals()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGuarddutyFilterFindingCriteriaCriterionOutputReference ¶
func NewGuarddutyFilterFindingCriteriaCriterionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GuarddutyFilterFindingCriteriaCriterionOutputReference
type GuarddutyFilterFindingCriteriaOutputReference ¶
type GuarddutyFilterFindingCriteriaOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Criterion() GuarddutyFilterFindingCriteriaCriterionList
CriterionInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *GuarddutyFilterFindingCriteria
SetInternalValue(val *GuarddutyFilterFindingCriteria)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutCriterion(value interface{})
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGuarddutyFilterFindingCriteriaOutputReference ¶
func NewGuarddutyFilterFindingCriteriaOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GuarddutyFilterFindingCriteriaOutputReference
Source Files
¶
- GuarddutyFilter.go
- GuarddutyFilterConfig.go
- GuarddutyFilterFindingCriteria.go
- GuarddutyFilterFindingCriteriaCriterion.go
- GuarddutyFilterFindingCriteriaCriterionList.go
- GuarddutyFilterFindingCriteriaCriterionList__checks.go
- GuarddutyFilterFindingCriteriaCriterionOutputReference.go
- GuarddutyFilterFindingCriteriaCriterionOutputReference__checks.go
- GuarddutyFilterFindingCriteriaOutputReference.go
- GuarddutyFilterFindingCriteriaOutputReference__checks.go
- GuarddutyFilter__checks.go
- main.go