Documentation
¶
Index ¶
- func IotIndexingConfiguration_IsConstruct(x interface{}) *bool
- func IotIndexingConfiguration_IsTerraformElement(x interface{}) *bool
- func IotIndexingConfiguration_IsTerraformResource(x interface{}) *bool
- func IotIndexingConfiguration_TfResourceType() *string
- func NewIotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldList_Override(i IotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldList, ...)
- func NewIotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldOutputReference_Override(...)
- func NewIotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldList_Override(i IotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldList, ...)
- func NewIotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldOutputReference_Override(...)
- func NewIotIndexingConfigurationThingGroupIndexingConfigurationOutputReference_Override(i IotIndexingConfigurationThingGroupIndexingConfigurationOutputReference, ...)
- func NewIotIndexingConfigurationThingIndexingConfigurationCustomFieldList_Override(i IotIndexingConfigurationThingIndexingConfigurationCustomFieldList, ...)
- func NewIotIndexingConfigurationThingIndexingConfigurationCustomFieldOutputReference_Override(i IotIndexingConfigurationThingIndexingConfigurationCustomFieldOutputReference, ...)
- func NewIotIndexingConfigurationThingIndexingConfigurationManagedFieldList_Override(i IotIndexingConfigurationThingIndexingConfigurationManagedFieldList, ...)
- func NewIotIndexingConfigurationThingIndexingConfigurationManagedFieldOutputReference_Override(...)
- func NewIotIndexingConfigurationThingIndexingConfigurationOutputReference_Override(i IotIndexingConfigurationThingIndexingConfigurationOutputReference, ...)
- func NewIotIndexingConfiguration_Override(i IotIndexingConfiguration, scope constructs.Construct, id *string, ...)
- type IotIndexingConfiguration
- type IotIndexingConfigurationConfig
- type IotIndexingConfigurationThingGroupIndexingConfiguration
- type IotIndexingConfigurationThingGroupIndexingConfigurationCustomField
- type IotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldList
- type IotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldOutputReference
- type IotIndexingConfigurationThingGroupIndexingConfigurationManagedField
- type IotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldList
- type IotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldOutputReference
- type IotIndexingConfigurationThingGroupIndexingConfigurationOutputReference
- type IotIndexingConfigurationThingIndexingConfiguration
- type IotIndexingConfigurationThingIndexingConfigurationCustomField
- type IotIndexingConfigurationThingIndexingConfigurationCustomFieldList
- type IotIndexingConfigurationThingIndexingConfigurationCustomFieldOutputReference
- type IotIndexingConfigurationThingIndexingConfigurationManagedField
- type IotIndexingConfigurationThingIndexingConfigurationManagedFieldList
- type IotIndexingConfigurationThingIndexingConfigurationManagedFieldOutputReference
- type IotIndexingConfigurationThingIndexingConfigurationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IotIndexingConfiguration_IsConstruct ¶
func IotIndexingConfiguration_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func IotIndexingConfiguration_IsTerraformElement ¶
func IotIndexingConfiguration_IsTerraformElement(x interface{}) *bool
Experimental.
func IotIndexingConfiguration_IsTerraformResource ¶
func IotIndexingConfiguration_IsTerraformResource(x interface{}) *bool
Experimental.
func IotIndexingConfiguration_TfResourceType ¶
func IotIndexingConfiguration_TfResourceType() *string
func NewIotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldList_Override ¶
func NewIotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldList_Override(i IotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewIotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldOutputReference_Override ¶
func NewIotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldOutputReference_Override(i IotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewIotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldList_Override ¶
func NewIotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldList_Override(i IotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewIotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldOutputReference_Override ¶
func NewIotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldOutputReference_Override(i IotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewIotIndexingConfigurationThingGroupIndexingConfigurationOutputReference_Override ¶
func NewIotIndexingConfigurationThingGroupIndexingConfigurationOutputReference_Override(i IotIndexingConfigurationThingGroupIndexingConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewIotIndexingConfigurationThingIndexingConfigurationCustomFieldList_Override ¶
func NewIotIndexingConfigurationThingIndexingConfigurationCustomFieldList_Override(i IotIndexingConfigurationThingIndexingConfigurationCustomFieldList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewIotIndexingConfigurationThingIndexingConfigurationCustomFieldOutputReference_Override ¶
func NewIotIndexingConfigurationThingIndexingConfigurationCustomFieldOutputReference_Override(i IotIndexingConfigurationThingIndexingConfigurationCustomFieldOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewIotIndexingConfigurationThingIndexingConfigurationManagedFieldList_Override ¶
func NewIotIndexingConfigurationThingIndexingConfigurationManagedFieldList_Override(i IotIndexingConfigurationThingIndexingConfigurationManagedFieldList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewIotIndexingConfigurationThingIndexingConfigurationManagedFieldOutputReference_Override ¶
func NewIotIndexingConfigurationThingIndexingConfigurationManagedFieldOutputReference_Override(i IotIndexingConfigurationThingIndexingConfigurationManagedFieldOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewIotIndexingConfigurationThingIndexingConfigurationOutputReference_Override ¶
func NewIotIndexingConfigurationThingIndexingConfigurationOutputReference_Override(i IotIndexingConfigurationThingIndexingConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewIotIndexingConfiguration_Override ¶
func NewIotIndexingConfiguration_Override(i IotIndexingConfiguration, scope constructs.Construct, id *string, config *IotIndexingConfigurationConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration aws_iot_indexing_configuration} Resource.
Types ¶
type IotIndexingConfiguration ¶
type IotIndexingConfiguration interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
ThingGroupIndexingConfiguration() IotIndexingConfigurationThingGroupIndexingConfigurationOutputReference
ThingGroupIndexingConfigurationInput() *IotIndexingConfigurationThingGroupIndexingConfiguration
ThingIndexingConfiguration() IotIndexingConfigurationThingIndexingConfigurationOutputReference
ThingIndexingConfigurationInput() *IotIndexingConfigurationThingIndexingConfiguration
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutThingGroupIndexingConfiguration(value *IotIndexingConfigurationThingGroupIndexingConfiguration)
PutThingIndexingConfiguration(value *IotIndexingConfigurationThingIndexingConfiguration)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetThingGroupIndexingConfiguration()
ResetThingIndexingConfiguration()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration aws_iot_indexing_configuration}.
func NewIotIndexingConfiguration ¶
func NewIotIndexingConfiguration(scope constructs.Construct, id *string, config *IotIndexingConfigurationConfig) IotIndexingConfiguration
Create a new {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration aws_iot_indexing_configuration} Resource.
type IotIndexingConfigurationConfig ¶
type IotIndexingConfigurationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#id IotIndexingConfiguration#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// thing_group_indexing_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#thing_group_indexing_configuration IotIndexingConfiguration#thing_group_indexing_configuration}
ThingGroupIndexingConfiguration *IotIndexingConfigurationThingGroupIndexingConfiguration `field:"optional" json:"thingGroupIndexingConfiguration" yaml:"thingGroupIndexingConfiguration"`
// thing_indexing_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#thing_indexing_configuration IotIndexingConfiguration#thing_indexing_configuration}
ThingIndexingConfiguration *IotIndexingConfigurationThingIndexingConfiguration `field:"optional" json:"thingIndexingConfiguration" yaml:"thingIndexingConfiguration"`
}
type IotIndexingConfigurationThingGroupIndexingConfiguration ¶
type IotIndexingConfigurationThingGroupIndexingConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#thing_group_indexing_mode IotIndexingConfiguration#thing_group_indexing_mode}.
ThingGroupIndexingMode *string `field:"required" json:"thingGroupIndexingMode" yaml:"thingGroupIndexingMode"`
// custom_field block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#custom_field IotIndexingConfiguration#custom_field}
CustomField interface{} `field:"optional" json:"customField" yaml:"customField"`
// managed_field block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#managed_field IotIndexingConfiguration#managed_field}
ManagedField interface{} `field:"optional" json:"managedField" yaml:"managedField"`
}
type IotIndexingConfigurationThingGroupIndexingConfigurationCustomField ¶
type IotIndexingConfigurationThingGroupIndexingConfigurationCustomField struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#name IotIndexingConfiguration#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#type IotIndexingConfiguration#type}.
Type *string `field:"optional" json:"type" yaml:"type"`
}
type IotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldList ¶
type IotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) IotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldList ¶
func NewIotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) IotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldList
type IotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldOutputReference ¶
type IotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetName()
ResetType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldOutputReference ¶
func NewIotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) IotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldOutputReference
type IotIndexingConfigurationThingGroupIndexingConfigurationManagedField ¶
type IotIndexingConfigurationThingGroupIndexingConfigurationManagedField struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#name IotIndexingConfiguration#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#type IotIndexingConfiguration#type}.
Type *string `field:"optional" json:"type" yaml:"type"`
}
type IotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldList ¶
type IotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) IotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldList ¶
func NewIotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) IotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldList
type IotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldOutputReference ¶
type IotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetName()
ResetType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldOutputReference ¶
func NewIotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) IotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldOutputReference
type IotIndexingConfigurationThingGroupIndexingConfigurationOutputReference ¶
type IotIndexingConfigurationThingGroupIndexingConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
CustomField() IotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldList
CustomFieldInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *IotIndexingConfigurationThingGroupIndexingConfiguration
SetInternalValue(val *IotIndexingConfigurationThingGroupIndexingConfiguration)
ManagedField() IotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldList
ManagedFieldInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ThingGroupIndexingMode() *string
SetThingGroupIndexingMode(val *string)
ThingGroupIndexingModeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutCustomField(value interface{})
PutManagedField(value interface{})
ResetCustomField()
ResetManagedField()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIotIndexingConfigurationThingGroupIndexingConfigurationOutputReference ¶
func NewIotIndexingConfigurationThingGroupIndexingConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) IotIndexingConfigurationThingGroupIndexingConfigurationOutputReference
type IotIndexingConfigurationThingIndexingConfiguration ¶
type IotIndexingConfigurationThingIndexingConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#thing_indexing_mode IotIndexingConfiguration#thing_indexing_mode}.
ThingIndexingMode *string `field:"required" json:"thingIndexingMode" yaml:"thingIndexingMode"`
// custom_field block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#custom_field IotIndexingConfiguration#custom_field}
CustomField interface{} `field:"optional" json:"customField" yaml:"customField"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#device_defender_indexing_mode IotIndexingConfiguration#device_defender_indexing_mode}.
DeviceDefenderIndexingMode *string `field:"optional" json:"deviceDefenderIndexingMode" yaml:"deviceDefenderIndexingMode"`
// managed_field block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#managed_field IotIndexingConfiguration#managed_field}
ManagedField interface{} `field:"optional" json:"managedField" yaml:"managedField"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#named_shadow_indexing_mode IotIndexingConfiguration#named_shadow_indexing_mode}.
NamedShadowIndexingMode *string `field:"optional" json:"namedShadowIndexingMode" yaml:"namedShadowIndexingMode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#thing_connectivity_indexing_mode IotIndexingConfiguration#thing_connectivity_indexing_mode}.
ThingConnectivityIndexingMode *string `field:"optional" json:"thingConnectivityIndexingMode" yaml:"thingConnectivityIndexingMode"`
}
type IotIndexingConfigurationThingIndexingConfigurationCustomField ¶
type IotIndexingConfigurationThingIndexingConfigurationCustomField struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#name IotIndexingConfiguration#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#type IotIndexingConfiguration#type}.
Type *string `field:"optional" json:"type" yaml:"type"`
}
type IotIndexingConfigurationThingIndexingConfigurationCustomFieldList ¶
type IotIndexingConfigurationThingIndexingConfigurationCustomFieldList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) IotIndexingConfigurationThingIndexingConfigurationCustomFieldOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIotIndexingConfigurationThingIndexingConfigurationCustomFieldList ¶
func NewIotIndexingConfigurationThingIndexingConfigurationCustomFieldList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) IotIndexingConfigurationThingIndexingConfigurationCustomFieldList
type IotIndexingConfigurationThingIndexingConfigurationCustomFieldOutputReference ¶
type IotIndexingConfigurationThingIndexingConfigurationCustomFieldOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetName()
ResetType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIotIndexingConfigurationThingIndexingConfigurationCustomFieldOutputReference ¶
func NewIotIndexingConfigurationThingIndexingConfigurationCustomFieldOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) IotIndexingConfigurationThingIndexingConfigurationCustomFieldOutputReference
type IotIndexingConfigurationThingIndexingConfigurationManagedField ¶
type IotIndexingConfigurationThingIndexingConfigurationManagedField struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#name IotIndexingConfiguration#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_indexing_configuration#type IotIndexingConfiguration#type}.
Type *string `field:"optional" json:"type" yaml:"type"`
}
type IotIndexingConfigurationThingIndexingConfigurationManagedFieldList ¶
type IotIndexingConfigurationThingIndexingConfigurationManagedFieldList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) IotIndexingConfigurationThingIndexingConfigurationManagedFieldOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIotIndexingConfigurationThingIndexingConfigurationManagedFieldList ¶
func NewIotIndexingConfigurationThingIndexingConfigurationManagedFieldList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) IotIndexingConfigurationThingIndexingConfigurationManagedFieldList
type IotIndexingConfigurationThingIndexingConfigurationManagedFieldOutputReference ¶
type IotIndexingConfigurationThingIndexingConfigurationManagedFieldOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetName()
ResetType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIotIndexingConfigurationThingIndexingConfigurationManagedFieldOutputReference ¶
func NewIotIndexingConfigurationThingIndexingConfigurationManagedFieldOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) IotIndexingConfigurationThingIndexingConfigurationManagedFieldOutputReference
type IotIndexingConfigurationThingIndexingConfigurationOutputReference ¶
type IotIndexingConfigurationThingIndexingConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
CustomField() IotIndexingConfigurationThingIndexingConfigurationCustomFieldList
CustomFieldInput() interface{}
DeviceDefenderIndexingMode() *string
SetDeviceDefenderIndexingMode(val *string)
DeviceDefenderIndexingModeInput() *string
// Experimental.
Fqn() *string
InternalValue() *IotIndexingConfigurationThingIndexingConfiguration
SetInternalValue(val *IotIndexingConfigurationThingIndexingConfiguration)
ManagedField() IotIndexingConfigurationThingIndexingConfigurationManagedFieldList
ManagedFieldInput() interface{}
NamedShadowIndexingMode() *string
SetNamedShadowIndexingMode(val *string)
NamedShadowIndexingModeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ThingConnectivityIndexingMode() *string
SetThingConnectivityIndexingMode(val *string)
ThingConnectivityIndexingModeInput() *string
ThingIndexingMode() *string
SetThingIndexingMode(val *string)
ThingIndexingModeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutCustomField(value interface{})
PutManagedField(value interface{})
ResetCustomField()
ResetDeviceDefenderIndexingMode()
ResetManagedField()
ResetNamedShadowIndexingMode()
ResetThingConnectivityIndexingMode()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIotIndexingConfigurationThingIndexingConfigurationOutputReference ¶
func NewIotIndexingConfigurationThingIndexingConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) IotIndexingConfigurationThingIndexingConfigurationOutputReference
Source Files
¶
- IotIndexingConfiguration.go
- IotIndexingConfigurationConfig.go
- IotIndexingConfigurationThingGroupIndexingConfiguration.go
- IotIndexingConfigurationThingGroupIndexingConfigurationCustomField.go
- IotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldList.go
- IotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldList__checks.go
- IotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldOutputReference.go
- IotIndexingConfigurationThingGroupIndexingConfigurationCustomFieldOutputReference__checks.go
- IotIndexingConfigurationThingGroupIndexingConfigurationManagedField.go
- IotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldList.go
- IotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldList__checks.go
- IotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldOutputReference.go
- IotIndexingConfigurationThingGroupIndexingConfigurationManagedFieldOutputReference__checks.go
- IotIndexingConfigurationThingGroupIndexingConfigurationOutputReference.go
- IotIndexingConfigurationThingGroupIndexingConfigurationOutputReference__checks.go
- IotIndexingConfigurationThingIndexingConfiguration.go
- IotIndexingConfigurationThingIndexingConfigurationCustomField.go
- IotIndexingConfigurationThingIndexingConfigurationCustomFieldList.go
- IotIndexingConfigurationThingIndexingConfigurationCustomFieldList__checks.go
- IotIndexingConfigurationThingIndexingConfigurationCustomFieldOutputReference.go
- IotIndexingConfigurationThingIndexingConfigurationCustomFieldOutputReference__checks.go
- IotIndexingConfigurationThingIndexingConfigurationManagedField.go
- IotIndexingConfigurationThingIndexingConfigurationManagedFieldList.go
- IotIndexingConfigurationThingIndexingConfigurationManagedFieldList__checks.go
- IotIndexingConfigurationThingIndexingConfigurationManagedFieldOutputReference.go
- IotIndexingConfigurationThingIndexingConfigurationManagedFieldOutputReference__checks.go
- IotIndexingConfigurationThingIndexingConfigurationOutputReference.go
- IotIndexingConfigurationThingIndexingConfigurationOutputReference__checks.go
- IotIndexingConfiguration__checks.go
- main.go