Documentation
¶
Index ¶
- func LambdaFunctionEventInvokeConfig_IsConstruct(x interface{}) *bool
- func LambdaFunctionEventInvokeConfig_IsTerraformElement(x interface{}) *bool
- func LambdaFunctionEventInvokeConfig_IsTerraformResource(x interface{}) *bool
- func LambdaFunctionEventInvokeConfig_TfResourceType() *string
- func NewLambdaFunctionEventInvokeConfigDestinationConfigOnFailureOutputReference_Override(l LambdaFunctionEventInvokeConfigDestinationConfigOnFailureOutputReference, ...)
- func NewLambdaFunctionEventInvokeConfigDestinationConfigOnSuccessOutputReference_Override(l LambdaFunctionEventInvokeConfigDestinationConfigOnSuccessOutputReference, ...)
- func NewLambdaFunctionEventInvokeConfigDestinationConfigOutputReference_Override(l LambdaFunctionEventInvokeConfigDestinationConfigOutputReference, ...)
- func NewLambdaFunctionEventInvokeConfig_Override(l LambdaFunctionEventInvokeConfig, scope constructs.Construct, id *string, ...)
- type LambdaFunctionEventInvokeConfig
- type LambdaFunctionEventInvokeConfigConfig
- type LambdaFunctionEventInvokeConfigDestinationConfig
- type LambdaFunctionEventInvokeConfigDestinationConfigOnFailure
- type LambdaFunctionEventInvokeConfigDestinationConfigOnFailureOutputReference
- type LambdaFunctionEventInvokeConfigDestinationConfigOnSuccess
- type LambdaFunctionEventInvokeConfigDestinationConfigOnSuccessOutputReference
- type LambdaFunctionEventInvokeConfigDestinationConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LambdaFunctionEventInvokeConfig_IsConstruct ¶
func LambdaFunctionEventInvokeConfig_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func LambdaFunctionEventInvokeConfig_IsTerraformElement ¶
func LambdaFunctionEventInvokeConfig_IsTerraformElement(x interface{}) *bool
Experimental.
func LambdaFunctionEventInvokeConfig_IsTerraformResource ¶
func LambdaFunctionEventInvokeConfig_IsTerraformResource(x interface{}) *bool
Experimental.
func LambdaFunctionEventInvokeConfig_TfResourceType ¶
func LambdaFunctionEventInvokeConfig_TfResourceType() *string
func NewLambdaFunctionEventInvokeConfigDestinationConfigOnFailureOutputReference_Override ¶
func NewLambdaFunctionEventInvokeConfigDestinationConfigOnFailureOutputReference_Override(l LambdaFunctionEventInvokeConfigDestinationConfigOnFailureOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLambdaFunctionEventInvokeConfigDestinationConfigOnSuccessOutputReference_Override ¶
func NewLambdaFunctionEventInvokeConfigDestinationConfigOnSuccessOutputReference_Override(l LambdaFunctionEventInvokeConfigDestinationConfigOnSuccessOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLambdaFunctionEventInvokeConfigDestinationConfigOutputReference_Override ¶
func NewLambdaFunctionEventInvokeConfigDestinationConfigOutputReference_Override(l LambdaFunctionEventInvokeConfigDestinationConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLambdaFunctionEventInvokeConfig_Override ¶
func NewLambdaFunctionEventInvokeConfig_Override(l LambdaFunctionEventInvokeConfig, scope constructs.Construct, id *string, config *LambdaFunctionEventInvokeConfigConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config aws_lambda_function_event_invoke_config} Resource.
Types ¶
type LambdaFunctionEventInvokeConfig ¶
type LambdaFunctionEventInvokeConfig interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DestinationConfig() LambdaFunctionEventInvokeConfigDestinationConfigOutputReference
DestinationConfigInput() *LambdaFunctionEventInvokeConfigDestinationConfig
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
FunctionName() *string
SetFunctionName(val *string)
FunctionNameInput() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaximumEventAgeInSeconds() *float64
SetMaximumEventAgeInSeconds(val *float64)
MaximumEventAgeInSecondsInput() *float64
MaximumRetryAttempts() *float64
SetMaximumRetryAttempts(val *float64)
MaximumRetryAttemptsInput() *float64
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
Qualifier() *string
SetQualifier(val *string)
QualifierInput() *string
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDestinationConfig(value *LambdaFunctionEventInvokeConfigDestinationConfig)
ResetDestinationConfig()
ResetId()
ResetMaximumEventAgeInSeconds()
ResetMaximumRetryAttempts()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetQualifier()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config aws_lambda_function_event_invoke_config}.
func NewLambdaFunctionEventInvokeConfig ¶
func NewLambdaFunctionEventInvokeConfig(scope constructs.Construct, id *string, config *LambdaFunctionEventInvokeConfigConfig) LambdaFunctionEventInvokeConfig
Create a new {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config aws_lambda_function_event_invoke_config} Resource.
type LambdaFunctionEventInvokeConfigConfig ¶
type LambdaFunctionEventInvokeConfigConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config#function_name LambdaFunctionEventInvokeConfig#function_name}.
FunctionName *string `field:"required" json:"functionName" yaml:"functionName"`
// destination_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config#destination_config LambdaFunctionEventInvokeConfig#destination_config}
DestinationConfig *LambdaFunctionEventInvokeConfigDestinationConfig `field:"optional" json:"destinationConfig" yaml:"destinationConfig"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config#id LambdaFunctionEventInvokeConfig#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config#maximum_event_age_in_seconds LambdaFunctionEventInvokeConfig#maximum_event_age_in_seconds}.
MaximumEventAgeInSeconds *float64 `field:"optional" json:"maximumEventAgeInSeconds" yaml:"maximumEventAgeInSeconds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config#maximum_retry_attempts LambdaFunctionEventInvokeConfig#maximum_retry_attempts}.
MaximumRetryAttempts *float64 `field:"optional" json:"maximumRetryAttempts" yaml:"maximumRetryAttempts"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config#qualifier LambdaFunctionEventInvokeConfig#qualifier}.
Qualifier *string `field:"optional" json:"qualifier" yaml:"qualifier"`
}
type LambdaFunctionEventInvokeConfigDestinationConfig ¶
type LambdaFunctionEventInvokeConfigDestinationConfig struct {
// on_failure block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config#on_failure LambdaFunctionEventInvokeConfig#on_failure}
OnFailure *LambdaFunctionEventInvokeConfigDestinationConfigOnFailure `field:"optional" json:"onFailure" yaml:"onFailure"`
// on_success block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config#on_success LambdaFunctionEventInvokeConfig#on_success}
OnSuccess *LambdaFunctionEventInvokeConfigDestinationConfigOnSuccess `field:"optional" json:"onSuccess" yaml:"onSuccess"`
}
type LambdaFunctionEventInvokeConfigDestinationConfigOnFailure ¶
type LambdaFunctionEventInvokeConfigDestinationConfigOnFailure struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config#destination LambdaFunctionEventInvokeConfig#destination}.
Destination *string `field:"required" json:"destination" yaml:"destination"`
}
type LambdaFunctionEventInvokeConfigDestinationConfigOnFailureOutputReference ¶
type LambdaFunctionEventInvokeConfigDestinationConfigOnFailureOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Destination() *string
SetDestination(val *string)
DestinationInput() *string
// Experimental.
Fqn() *string
InternalValue() *LambdaFunctionEventInvokeConfigDestinationConfigOnFailure
SetInternalValue(val *LambdaFunctionEventInvokeConfigDestinationConfigOnFailure)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLambdaFunctionEventInvokeConfigDestinationConfigOnFailureOutputReference ¶
func NewLambdaFunctionEventInvokeConfigDestinationConfigOnFailureOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LambdaFunctionEventInvokeConfigDestinationConfigOnFailureOutputReference
type LambdaFunctionEventInvokeConfigDestinationConfigOnSuccess ¶
type LambdaFunctionEventInvokeConfigDestinationConfigOnSuccess struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config#destination LambdaFunctionEventInvokeConfig#destination}.
Destination *string `field:"required" json:"destination" yaml:"destination"`
}
type LambdaFunctionEventInvokeConfigDestinationConfigOnSuccessOutputReference ¶
type LambdaFunctionEventInvokeConfigDestinationConfigOnSuccessOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Destination() *string
SetDestination(val *string)
DestinationInput() *string
// Experimental.
Fqn() *string
InternalValue() *LambdaFunctionEventInvokeConfigDestinationConfigOnSuccess
SetInternalValue(val *LambdaFunctionEventInvokeConfigDestinationConfigOnSuccess)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLambdaFunctionEventInvokeConfigDestinationConfigOnSuccessOutputReference ¶
func NewLambdaFunctionEventInvokeConfigDestinationConfigOnSuccessOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LambdaFunctionEventInvokeConfigDestinationConfigOnSuccessOutputReference
type LambdaFunctionEventInvokeConfigDestinationConfigOutputReference ¶
type LambdaFunctionEventInvokeConfigDestinationConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LambdaFunctionEventInvokeConfigDestinationConfig
SetInternalValue(val *LambdaFunctionEventInvokeConfigDestinationConfig)
OnFailure() LambdaFunctionEventInvokeConfigDestinationConfigOnFailureOutputReference
OnFailureInput() *LambdaFunctionEventInvokeConfigDestinationConfigOnFailure
OnSuccess() LambdaFunctionEventInvokeConfigDestinationConfigOnSuccessOutputReference
OnSuccessInput() *LambdaFunctionEventInvokeConfigDestinationConfigOnSuccess
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutOnFailure(value *LambdaFunctionEventInvokeConfigDestinationConfigOnFailure)
PutOnSuccess(value *LambdaFunctionEventInvokeConfigDestinationConfigOnSuccess)
ResetOnFailure()
ResetOnSuccess()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLambdaFunctionEventInvokeConfigDestinationConfigOutputReference ¶
func NewLambdaFunctionEventInvokeConfigDestinationConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LambdaFunctionEventInvokeConfigDestinationConfigOutputReference
Source Files
¶
- LambdaFunctionEventInvokeConfig.go
- LambdaFunctionEventInvokeConfigConfig.go
- LambdaFunctionEventInvokeConfigDestinationConfig.go
- LambdaFunctionEventInvokeConfigDestinationConfigOnFailure.go
- LambdaFunctionEventInvokeConfigDestinationConfigOnFailureOutputReference.go
- LambdaFunctionEventInvokeConfigDestinationConfigOnFailureOutputReference__checks.go
- LambdaFunctionEventInvokeConfigDestinationConfigOnSuccess.go
- LambdaFunctionEventInvokeConfigDestinationConfigOnSuccessOutputReference.go
- LambdaFunctionEventInvokeConfigDestinationConfigOnSuccessOutputReference__checks.go
- LambdaFunctionEventInvokeConfigDestinationConfigOutputReference.go
- LambdaFunctionEventInvokeConfigDestinationConfigOutputReference__checks.go
- LambdaFunctionEventInvokeConfig__checks.go
- main.go