Documentation
¶
Index ¶
- func LightsailContainerService_IsConstruct(x interface{}) *bool
- func LightsailContainerService_IsTerraformElement(x interface{}) *bool
- func LightsailContainerService_IsTerraformResource(x interface{}) *bool
- func LightsailContainerService_TfResourceType() *string
- func NewLightsailContainerServicePrivateRegistryAccessEcrImagePullerRoleOutputReference_Override(...)
- func NewLightsailContainerServicePrivateRegistryAccessOutputReference_Override(l LightsailContainerServicePrivateRegistryAccessOutputReference, ...)
- func NewLightsailContainerServicePublicDomainNamesCertificateList_Override(l LightsailContainerServicePublicDomainNamesCertificateList, ...)
- func NewLightsailContainerServicePublicDomainNamesCertificateOutputReference_Override(l LightsailContainerServicePublicDomainNamesCertificateOutputReference, ...)
- func NewLightsailContainerServicePublicDomainNamesOutputReference_Override(l LightsailContainerServicePublicDomainNamesOutputReference, ...)
- func NewLightsailContainerServiceTimeoutsOutputReference_Override(l LightsailContainerServiceTimeoutsOutputReference, ...)
- func NewLightsailContainerService_Override(l LightsailContainerService, scope constructs.Construct, id *string, ...)
- type LightsailContainerService
- type LightsailContainerServiceConfig
- type LightsailContainerServicePrivateRegistryAccess
- type LightsailContainerServicePrivateRegistryAccessEcrImagePullerRole
- type LightsailContainerServicePrivateRegistryAccessEcrImagePullerRoleOutputReference
- type LightsailContainerServicePrivateRegistryAccessOutputReference
- type LightsailContainerServicePublicDomainNames
- type LightsailContainerServicePublicDomainNamesCertificate
- type LightsailContainerServicePublicDomainNamesCertificateList
- type LightsailContainerServicePublicDomainNamesCertificateOutputReference
- type LightsailContainerServicePublicDomainNamesOutputReference
- type LightsailContainerServiceTimeouts
- type LightsailContainerServiceTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LightsailContainerService_IsConstruct ¶
func LightsailContainerService_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func LightsailContainerService_IsTerraformElement ¶
func LightsailContainerService_IsTerraformElement(x interface{}) *bool
Experimental.
func LightsailContainerService_IsTerraformResource ¶
func LightsailContainerService_IsTerraformResource(x interface{}) *bool
Experimental.
func LightsailContainerService_TfResourceType ¶
func LightsailContainerService_TfResourceType() *string
func NewLightsailContainerServicePrivateRegistryAccessEcrImagePullerRoleOutputReference_Override ¶
func NewLightsailContainerServicePrivateRegistryAccessEcrImagePullerRoleOutputReference_Override(l LightsailContainerServicePrivateRegistryAccessEcrImagePullerRoleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLightsailContainerServicePrivateRegistryAccessOutputReference_Override ¶
func NewLightsailContainerServicePrivateRegistryAccessOutputReference_Override(l LightsailContainerServicePrivateRegistryAccessOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLightsailContainerServicePublicDomainNamesCertificateList_Override ¶
func NewLightsailContainerServicePublicDomainNamesCertificateList_Override(l LightsailContainerServicePublicDomainNamesCertificateList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewLightsailContainerServicePublicDomainNamesCertificateOutputReference_Override ¶
func NewLightsailContainerServicePublicDomainNamesCertificateOutputReference_Override(l LightsailContainerServicePublicDomainNamesCertificateOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewLightsailContainerServicePublicDomainNamesOutputReference_Override ¶
func NewLightsailContainerServicePublicDomainNamesOutputReference_Override(l LightsailContainerServicePublicDomainNamesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLightsailContainerServiceTimeoutsOutputReference_Override ¶
func NewLightsailContainerServiceTimeoutsOutputReference_Override(l LightsailContainerServiceTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLightsailContainerService_Override ¶
func NewLightsailContainerService_Override(l LightsailContainerService, scope constructs.Construct, id *string, config *LightsailContainerServiceConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service aws_lightsail_container_service} Resource.
Types ¶
type LightsailContainerService ¶
type LightsailContainerService interface {
cdktf.TerraformResource
Arn() *string
AvailabilityZone() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreatedAt() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IsDisabled() interface{}
SetIsDisabled(val interface{})
IsDisabledInput() interface{}
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Power() *string
SetPower(val *string)
PowerId() *string
PowerInput() *string
PrincipalArn() *string
PrivateDomainName() *string
PrivateRegistryAccess() LightsailContainerServicePrivateRegistryAccessOutputReference
PrivateRegistryAccessInput() *LightsailContainerServicePrivateRegistryAccess
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
PublicDomainNames() LightsailContainerServicePublicDomainNamesOutputReference
PublicDomainNamesInput() *LightsailContainerServicePublicDomainNames
// Experimental.
RawOverrides() interface{}
ResourceType() *string
Scale() *float64
SetScale(val *float64)
ScaleInput() *float64
State() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() LightsailContainerServiceTimeoutsOutputReference
TimeoutsInput() interface{}
Url() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutPrivateRegistryAccess(value *LightsailContainerServicePrivateRegistryAccess)
PutPublicDomainNames(value *LightsailContainerServicePublicDomainNames)
PutTimeouts(value *LightsailContainerServiceTimeouts)
ResetId()
ResetIsDisabled()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPrivateRegistryAccess()
ResetPublicDomainNames()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service aws_lightsail_container_service}.
func NewLightsailContainerService ¶
func NewLightsailContainerService(scope constructs.Construct, id *string, config *LightsailContainerServiceConfig) LightsailContainerService
Create a new {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service aws_lightsail_container_service} Resource.
type LightsailContainerServiceConfig ¶
type LightsailContainerServiceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service#name LightsailContainerService#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service#power LightsailContainerService#power}.
Power *string `field:"required" json:"power" yaml:"power"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service#scale LightsailContainerService#scale}.
Scale *float64 `field:"required" json:"scale" yaml:"scale"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service#id LightsailContainerService#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service#is_disabled LightsailContainerService#is_disabled}.
IsDisabled interface{} `field:"optional" json:"isDisabled" yaml:"isDisabled"`
// private_registry_access block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service#private_registry_access LightsailContainerService#private_registry_access}
PrivateRegistryAccess *LightsailContainerServicePrivateRegistryAccess `field:"optional" json:"privateRegistryAccess" yaml:"privateRegistryAccess"`
// public_domain_names block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service#public_domain_names LightsailContainerService#public_domain_names}
PublicDomainNames *LightsailContainerServicePublicDomainNames `field:"optional" json:"publicDomainNames" yaml:"publicDomainNames"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service#tags LightsailContainerService#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service#tags_all LightsailContainerService#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service#timeouts LightsailContainerService#timeouts}
Timeouts *LightsailContainerServiceTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type LightsailContainerServicePrivateRegistryAccess ¶
type LightsailContainerServicePrivateRegistryAccess struct {
// ecr_image_puller_role block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service#ecr_image_puller_role LightsailContainerService#ecr_image_puller_role}
EcrImagePullerRole *LightsailContainerServicePrivateRegistryAccessEcrImagePullerRole `field:"optional" json:"ecrImagePullerRole" yaml:"ecrImagePullerRole"`
}
type LightsailContainerServicePrivateRegistryAccessEcrImagePullerRole ¶
type LightsailContainerServicePrivateRegistryAccessEcrImagePullerRole struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service#is_active LightsailContainerService#is_active}.
IsActive interface{} `field:"optional" json:"isActive" yaml:"isActive"`
}
type LightsailContainerServicePrivateRegistryAccessEcrImagePullerRoleOutputReference ¶
type LightsailContainerServicePrivateRegistryAccessEcrImagePullerRoleOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LightsailContainerServicePrivateRegistryAccessEcrImagePullerRole
SetInternalValue(val *LightsailContainerServicePrivateRegistryAccessEcrImagePullerRole)
IsActive() interface{}
SetIsActive(val interface{})
IsActiveInput() interface{}
PrincipalArn() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetIsActive()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailContainerServicePrivateRegistryAccessEcrImagePullerRoleOutputReference ¶
func NewLightsailContainerServicePrivateRegistryAccessEcrImagePullerRoleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LightsailContainerServicePrivateRegistryAccessEcrImagePullerRoleOutputReference
type LightsailContainerServicePrivateRegistryAccessOutputReference ¶
type LightsailContainerServicePrivateRegistryAccessOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EcrImagePullerRole() LightsailContainerServicePrivateRegistryAccessEcrImagePullerRoleOutputReference
EcrImagePullerRoleInput() *LightsailContainerServicePrivateRegistryAccessEcrImagePullerRole
// Experimental.
Fqn() *string
InternalValue() *LightsailContainerServicePrivateRegistryAccess
SetInternalValue(val *LightsailContainerServicePrivateRegistryAccess)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutEcrImagePullerRole(value *LightsailContainerServicePrivateRegistryAccessEcrImagePullerRole)
ResetEcrImagePullerRole()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailContainerServicePrivateRegistryAccessOutputReference ¶
func NewLightsailContainerServicePrivateRegistryAccessOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LightsailContainerServicePrivateRegistryAccessOutputReference
type LightsailContainerServicePublicDomainNames ¶
type LightsailContainerServicePublicDomainNames struct {
// certificate block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service#certificate LightsailContainerService#certificate}
Certificate interface{} `field:"required" json:"certificate" yaml:"certificate"`
}
type LightsailContainerServicePublicDomainNamesCertificate ¶
type LightsailContainerServicePublicDomainNamesCertificate struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service#certificate_name LightsailContainerService#certificate_name}.
CertificateName *string `field:"required" json:"certificateName" yaml:"certificateName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service#domain_names LightsailContainerService#domain_names}.
DomainNames *[]*string `field:"required" json:"domainNames" yaml:"domainNames"`
}
type LightsailContainerServicePublicDomainNamesCertificateList ¶
type LightsailContainerServicePublicDomainNamesCertificateList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) LightsailContainerServicePublicDomainNamesCertificateOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailContainerServicePublicDomainNamesCertificateList ¶
func NewLightsailContainerServicePublicDomainNamesCertificateList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) LightsailContainerServicePublicDomainNamesCertificateList
type LightsailContainerServicePublicDomainNamesCertificateOutputReference ¶
type LightsailContainerServicePublicDomainNamesCertificateOutputReference interface {
cdktf.ComplexObject
CertificateName() *string
SetCertificateName(val *string)
CertificateNameInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DomainNames() *[]*string
SetDomainNames(val *[]*string)
DomainNamesInput() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailContainerServicePublicDomainNamesCertificateOutputReference ¶
func NewLightsailContainerServicePublicDomainNamesCertificateOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) LightsailContainerServicePublicDomainNamesCertificateOutputReference
type LightsailContainerServicePublicDomainNamesOutputReference ¶
type LightsailContainerServicePublicDomainNamesOutputReference interface {
cdktf.ComplexObject
Certificate() LightsailContainerServicePublicDomainNamesCertificateList
CertificateInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LightsailContainerServicePublicDomainNames
SetInternalValue(val *LightsailContainerServicePublicDomainNames)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutCertificate(value interface{})
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailContainerServicePublicDomainNamesOutputReference ¶
func NewLightsailContainerServicePublicDomainNamesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LightsailContainerServicePublicDomainNamesOutputReference
type LightsailContainerServiceTimeouts ¶
type LightsailContainerServiceTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service#create LightsailContainerService#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service#delete LightsailContainerService#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service#update LightsailContainerService#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type LightsailContainerServiceTimeoutsOutputReference ¶
type LightsailContainerServiceTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailContainerServiceTimeoutsOutputReference ¶
func NewLightsailContainerServiceTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LightsailContainerServiceTimeoutsOutputReference
Source Files
¶
- LightsailContainerService.go
- LightsailContainerServiceConfig.go
- LightsailContainerServicePrivateRegistryAccess.go
- LightsailContainerServicePrivateRegistryAccessEcrImagePullerRole.go
- LightsailContainerServicePrivateRegistryAccessEcrImagePullerRoleOutputReference.go
- LightsailContainerServicePrivateRegistryAccessEcrImagePullerRoleOutputReference__checks.go
- LightsailContainerServicePrivateRegistryAccessOutputReference.go
- LightsailContainerServicePrivateRegistryAccessOutputReference__checks.go
- LightsailContainerServicePublicDomainNames.go
- LightsailContainerServicePublicDomainNamesCertificate.go
- LightsailContainerServicePublicDomainNamesCertificateList.go
- LightsailContainerServicePublicDomainNamesCertificateList__checks.go
- LightsailContainerServicePublicDomainNamesCertificateOutputReference.go
- LightsailContainerServicePublicDomainNamesCertificateOutputReference__checks.go
- LightsailContainerServicePublicDomainNamesOutputReference.go
- LightsailContainerServicePublicDomainNamesOutputReference__checks.go
- LightsailContainerServiceTimeouts.go
- LightsailContainerServiceTimeoutsOutputReference.go
- LightsailContainerServiceTimeoutsOutputReference__checks.go
- LightsailContainerService__checks.go
- main.go