Documentation
¶
Index ¶
- func LightsailContainerServiceDeploymentVersion_IsConstruct(x interface{}) *bool
- func LightsailContainerServiceDeploymentVersion_IsTerraformElement(x interface{}) *bool
- func LightsailContainerServiceDeploymentVersion_IsTerraformResource(x interface{}) *bool
- func LightsailContainerServiceDeploymentVersion_TfResourceType() *string
- func NewLightsailContainerServiceDeploymentVersionContainerList_Override(l LightsailContainerServiceDeploymentVersionContainerList, ...)
- func NewLightsailContainerServiceDeploymentVersionContainerOutputReference_Override(l LightsailContainerServiceDeploymentVersionContainerOutputReference, ...)
- func NewLightsailContainerServiceDeploymentVersionPublicEndpointHealthCheckOutputReference_Override(...)
- func NewLightsailContainerServiceDeploymentVersionPublicEndpointOutputReference_Override(l LightsailContainerServiceDeploymentVersionPublicEndpointOutputReference, ...)
- func NewLightsailContainerServiceDeploymentVersionTimeoutsOutputReference_Override(l LightsailContainerServiceDeploymentVersionTimeoutsOutputReference, ...)
- func NewLightsailContainerServiceDeploymentVersion_Override(l LightsailContainerServiceDeploymentVersion, scope constructs.Construct, ...)
- type LightsailContainerServiceDeploymentVersion
- type LightsailContainerServiceDeploymentVersionConfig
- type LightsailContainerServiceDeploymentVersionContainer
- type LightsailContainerServiceDeploymentVersionContainerList
- type LightsailContainerServiceDeploymentVersionContainerOutputReference
- type LightsailContainerServiceDeploymentVersionPublicEndpoint
- type LightsailContainerServiceDeploymentVersionPublicEndpointHealthCheck
- type LightsailContainerServiceDeploymentVersionPublicEndpointHealthCheckOutputReference
- type LightsailContainerServiceDeploymentVersionPublicEndpointOutputReference
- type LightsailContainerServiceDeploymentVersionTimeouts
- type LightsailContainerServiceDeploymentVersionTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LightsailContainerServiceDeploymentVersion_IsConstruct ¶
func LightsailContainerServiceDeploymentVersion_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func LightsailContainerServiceDeploymentVersion_IsTerraformElement ¶
func LightsailContainerServiceDeploymentVersion_IsTerraformElement(x interface{}) *bool
Experimental.
func LightsailContainerServiceDeploymentVersion_IsTerraformResource ¶
func LightsailContainerServiceDeploymentVersion_IsTerraformResource(x interface{}) *bool
Experimental.
func LightsailContainerServiceDeploymentVersion_TfResourceType ¶
func LightsailContainerServiceDeploymentVersion_TfResourceType() *string
func NewLightsailContainerServiceDeploymentVersionContainerList_Override ¶
func NewLightsailContainerServiceDeploymentVersionContainerList_Override(l LightsailContainerServiceDeploymentVersionContainerList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewLightsailContainerServiceDeploymentVersionContainerOutputReference_Override ¶
func NewLightsailContainerServiceDeploymentVersionContainerOutputReference_Override(l LightsailContainerServiceDeploymentVersionContainerOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewLightsailContainerServiceDeploymentVersionPublicEndpointHealthCheckOutputReference_Override ¶
func NewLightsailContainerServiceDeploymentVersionPublicEndpointHealthCheckOutputReference_Override(l LightsailContainerServiceDeploymentVersionPublicEndpointHealthCheckOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLightsailContainerServiceDeploymentVersionPublicEndpointOutputReference_Override ¶
func NewLightsailContainerServiceDeploymentVersionPublicEndpointOutputReference_Override(l LightsailContainerServiceDeploymentVersionPublicEndpointOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLightsailContainerServiceDeploymentVersionTimeoutsOutputReference_Override ¶
func NewLightsailContainerServiceDeploymentVersionTimeoutsOutputReference_Override(l LightsailContainerServiceDeploymentVersionTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLightsailContainerServiceDeploymentVersion_Override ¶
func NewLightsailContainerServiceDeploymentVersion_Override(l LightsailContainerServiceDeploymentVersion, scope constructs.Construct, id *string, config *LightsailContainerServiceDeploymentVersionConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version aws_lightsail_container_service_deployment_version} Resource.
Types ¶
type LightsailContainerServiceDeploymentVersion ¶
type LightsailContainerServiceDeploymentVersion interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
Container() LightsailContainerServiceDeploymentVersionContainerList
ContainerInput() interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CreatedAt() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
PublicEndpoint() LightsailContainerServiceDeploymentVersionPublicEndpointOutputReference
PublicEndpointInput() *LightsailContainerServiceDeploymentVersionPublicEndpoint
// Experimental.
RawOverrides() interface{}
ServiceName() *string
SetServiceName(val *string)
ServiceNameInput() *string
State() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() LightsailContainerServiceDeploymentVersionTimeoutsOutputReference
TimeoutsInput() interface{}
Version() *float64
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutContainer(value interface{})
PutPublicEndpoint(value *LightsailContainerServiceDeploymentVersionPublicEndpoint)
PutTimeouts(value *LightsailContainerServiceDeploymentVersionTimeouts)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPublicEndpoint()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version aws_lightsail_container_service_deployment_version}.
func NewLightsailContainerServiceDeploymentVersion ¶
func NewLightsailContainerServiceDeploymentVersion(scope constructs.Construct, id *string, config *LightsailContainerServiceDeploymentVersionConfig) LightsailContainerServiceDeploymentVersion
Create a new {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version aws_lightsail_container_service_deployment_version} Resource.
type LightsailContainerServiceDeploymentVersionConfig ¶
type LightsailContainerServiceDeploymentVersionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// container block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#container LightsailContainerServiceDeploymentVersion#container}
Container interface{} `field:"required" json:"container" yaml:"container"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#service_name LightsailContainerServiceDeploymentVersion#service_name}.
ServiceName *string `field:"required" json:"serviceName" yaml:"serviceName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#id LightsailContainerServiceDeploymentVersion#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// public_endpoint block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#public_endpoint LightsailContainerServiceDeploymentVersion#public_endpoint}
PublicEndpoint *LightsailContainerServiceDeploymentVersionPublicEndpoint `field:"optional" json:"publicEndpoint" yaml:"publicEndpoint"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#timeouts LightsailContainerServiceDeploymentVersion#timeouts}
Timeouts *LightsailContainerServiceDeploymentVersionTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type LightsailContainerServiceDeploymentVersionContainer ¶
type LightsailContainerServiceDeploymentVersionContainer struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#container_name LightsailContainerServiceDeploymentVersion#container_name}.
ContainerName *string `field:"required" json:"containerName" yaml:"containerName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#image LightsailContainerServiceDeploymentVersion#image}.
Image *string `field:"required" json:"image" yaml:"image"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#command LightsailContainerServiceDeploymentVersion#command}.
Command *[]*string `field:"optional" json:"command" yaml:"command"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#environment LightsailContainerServiceDeploymentVersion#environment}.
Environment *map[string]*string `field:"optional" json:"environment" yaml:"environment"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#ports LightsailContainerServiceDeploymentVersion#ports}.
Ports *map[string]*string `field:"optional" json:"ports" yaml:"ports"`
}
type LightsailContainerServiceDeploymentVersionContainerList ¶
type LightsailContainerServiceDeploymentVersionContainerList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) LightsailContainerServiceDeploymentVersionContainerOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailContainerServiceDeploymentVersionContainerList ¶
func NewLightsailContainerServiceDeploymentVersionContainerList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) LightsailContainerServiceDeploymentVersionContainerList
type LightsailContainerServiceDeploymentVersionContainerOutputReference ¶
type LightsailContainerServiceDeploymentVersionContainerOutputReference interface {
cdktf.ComplexObject
Command() *[]*string
SetCommand(val *[]*string)
CommandInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ContainerName() *string
SetContainerName(val *string)
ContainerNameInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Environment() *map[string]*string
SetEnvironment(val *map[string]*string)
EnvironmentInput() *map[string]*string
// Experimental.
Fqn() *string
Image() *string
SetImage(val *string)
ImageInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Ports() *map[string]*string
SetPorts(val *map[string]*string)
PortsInput() *map[string]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCommand()
ResetEnvironment()
ResetPorts()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailContainerServiceDeploymentVersionContainerOutputReference ¶
func NewLightsailContainerServiceDeploymentVersionContainerOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) LightsailContainerServiceDeploymentVersionContainerOutputReference
type LightsailContainerServiceDeploymentVersionPublicEndpoint ¶
type LightsailContainerServiceDeploymentVersionPublicEndpoint struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#container_name LightsailContainerServiceDeploymentVersion#container_name}.
ContainerName *string `field:"required" json:"containerName" yaml:"containerName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#container_port LightsailContainerServiceDeploymentVersion#container_port}.
ContainerPort *float64 `field:"required" json:"containerPort" yaml:"containerPort"`
// health_check block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#health_check LightsailContainerServiceDeploymentVersion#health_check}
HealthCheck *LightsailContainerServiceDeploymentVersionPublicEndpointHealthCheck `field:"required" json:"healthCheck" yaml:"healthCheck"`
}
type LightsailContainerServiceDeploymentVersionPublicEndpointHealthCheck ¶
type LightsailContainerServiceDeploymentVersionPublicEndpointHealthCheck struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#healthy_threshold LightsailContainerServiceDeploymentVersion#healthy_threshold}.
HealthyThreshold *float64 `field:"optional" json:"healthyThreshold" yaml:"healthyThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#interval_seconds LightsailContainerServiceDeploymentVersion#interval_seconds}.
IntervalSeconds *float64 `field:"optional" json:"intervalSeconds" yaml:"intervalSeconds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#path LightsailContainerServiceDeploymentVersion#path}.
Path *string `field:"optional" json:"path" yaml:"path"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#success_codes LightsailContainerServiceDeploymentVersion#success_codes}.
SuccessCodes *string `field:"optional" json:"successCodes" yaml:"successCodes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#timeout_seconds LightsailContainerServiceDeploymentVersion#timeout_seconds}.
TimeoutSeconds *float64 `field:"optional" json:"timeoutSeconds" yaml:"timeoutSeconds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#unhealthy_threshold LightsailContainerServiceDeploymentVersion#unhealthy_threshold}.
UnhealthyThreshold *float64 `field:"optional" json:"unhealthyThreshold" yaml:"unhealthyThreshold"`
}
type LightsailContainerServiceDeploymentVersionPublicEndpointHealthCheckOutputReference ¶
type LightsailContainerServiceDeploymentVersionPublicEndpointHealthCheckOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HealthyThreshold() *float64
SetHealthyThreshold(val *float64)
HealthyThresholdInput() *float64
InternalValue() *LightsailContainerServiceDeploymentVersionPublicEndpointHealthCheck
SetInternalValue(val *LightsailContainerServiceDeploymentVersionPublicEndpointHealthCheck)
IntervalSeconds() *float64
SetIntervalSeconds(val *float64)
IntervalSecondsInput() *float64
Path() *string
SetPath(val *string)
PathInput() *string
SuccessCodes() *string
SetSuccessCodes(val *string)
SuccessCodesInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TimeoutSeconds() *float64
SetTimeoutSeconds(val *float64)
TimeoutSecondsInput() *float64
UnhealthyThreshold() *float64
SetUnhealthyThreshold(val *float64)
UnhealthyThresholdInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetHealthyThreshold()
ResetIntervalSeconds()
ResetPath()
ResetSuccessCodes()
ResetTimeoutSeconds()
ResetUnhealthyThreshold()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailContainerServiceDeploymentVersionPublicEndpointHealthCheckOutputReference ¶
func NewLightsailContainerServiceDeploymentVersionPublicEndpointHealthCheckOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LightsailContainerServiceDeploymentVersionPublicEndpointHealthCheckOutputReference
type LightsailContainerServiceDeploymentVersionPublicEndpointOutputReference ¶
type LightsailContainerServiceDeploymentVersionPublicEndpointOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ContainerName() *string
SetContainerName(val *string)
ContainerNameInput() *string
ContainerPort() *float64
SetContainerPort(val *float64)
ContainerPortInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HealthCheck() LightsailContainerServiceDeploymentVersionPublicEndpointHealthCheckOutputReference
HealthCheckInput() *LightsailContainerServiceDeploymentVersionPublicEndpointHealthCheck
InternalValue() *LightsailContainerServiceDeploymentVersionPublicEndpoint
SetInternalValue(val *LightsailContainerServiceDeploymentVersionPublicEndpoint)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutHealthCheck(value *LightsailContainerServiceDeploymentVersionPublicEndpointHealthCheck)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailContainerServiceDeploymentVersionPublicEndpointOutputReference ¶
func NewLightsailContainerServiceDeploymentVersionPublicEndpointOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LightsailContainerServiceDeploymentVersionPublicEndpointOutputReference
type LightsailContainerServiceDeploymentVersionTimeouts ¶
type LightsailContainerServiceDeploymentVersionTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_container_service_deployment_version#create LightsailContainerServiceDeploymentVersion#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
}
type LightsailContainerServiceDeploymentVersionTimeoutsOutputReference ¶
type LightsailContainerServiceDeploymentVersionTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailContainerServiceDeploymentVersionTimeoutsOutputReference ¶
func NewLightsailContainerServiceDeploymentVersionTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LightsailContainerServiceDeploymentVersionTimeoutsOutputReference
Source Files
¶
- LightsailContainerServiceDeploymentVersion.go
- LightsailContainerServiceDeploymentVersionConfig.go
- LightsailContainerServiceDeploymentVersionContainer.go
- LightsailContainerServiceDeploymentVersionContainerList.go
- LightsailContainerServiceDeploymentVersionContainerList__checks.go
- LightsailContainerServiceDeploymentVersionContainerOutputReference.go
- LightsailContainerServiceDeploymentVersionContainerOutputReference__checks.go
- LightsailContainerServiceDeploymentVersionPublicEndpoint.go
- LightsailContainerServiceDeploymentVersionPublicEndpointHealthCheck.go
- LightsailContainerServiceDeploymentVersionPublicEndpointHealthCheckOutputReference.go
- LightsailContainerServiceDeploymentVersionPublicEndpointHealthCheckOutputReference__checks.go
- LightsailContainerServiceDeploymentVersionPublicEndpointOutputReference.go
- LightsailContainerServiceDeploymentVersionPublicEndpointOutputReference__checks.go
- LightsailContainerServiceDeploymentVersionTimeouts.go
- LightsailContainerServiceDeploymentVersionTimeoutsOutputReference.go
- LightsailContainerServiceDeploymentVersionTimeoutsOutputReference__checks.go
- LightsailContainerServiceDeploymentVersion__checks.go
- main.go