Documentation
¶
Index ¶
- func NeptuneCluster_IsConstruct(x interface{}) *bool
- func NeptuneCluster_IsTerraformElement(x interface{}) *bool
- func NeptuneCluster_IsTerraformResource(x interface{}) *bool
- func NeptuneCluster_TfResourceType() *string
- func NewNeptuneClusterServerlessV2ScalingConfigurationOutputReference_Override(n NeptuneClusterServerlessV2ScalingConfigurationOutputReference, ...)
- func NewNeptuneClusterTimeoutsOutputReference_Override(n NeptuneClusterTimeoutsOutputReference, ...)
- func NewNeptuneCluster_Override(n NeptuneCluster, scope constructs.Construct, id *string, ...)
- type NeptuneCluster
- type NeptuneClusterConfig
- type NeptuneClusterServerlessV2ScalingConfiguration
- type NeptuneClusterServerlessV2ScalingConfigurationOutputReference
- type NeptuneClusterTimeouts
- type NeptuneClusterTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NeptuneCluster_IsConstruct ¶
func NeptuneCluster_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func NeptuneCluster_IsTerraformElement ¶
func NeptuneCluster_IsTerraformElement(x interface{}) *bool
Experimental.
func NeptuneCluster_IsTerraformResource ¶
func NeptuneCluster_IsTerraformResource(x interface{}) *bool
Experimental.
func NeptuneCluster_TfResourceType ¶
func NeptuneCluster_TfResourceType() *string
func NewNeptuneClusterServerlessV2ScalingConfigurationOutputReference_Override ¶
func NewNeptuneClusterServerlessV2ScalingConfigurationOutputReference_Override(n NeptuneClusterServerlessV2ScalingConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewNeptuneClusterTimeoutsOutputReference_Override ¶
func NewNeptuneClusterTimeoutsOutputReference_Override(n NeptuneClusterTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewNeptuneCluster_Override ¶
func NewNeptuneCluster_Override(n NeptuneCluster, scope constructs.Construct, id *string, config *NeptuneClusterConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster aws_neptune_cluster} Resource.
Types ¶
type NeptuneCluster ¶
type NeptuneCluster interface {
cdktf.TerraformResource
AllowMajorVersionUpgrade() interface{}
SetAllowMajorVersionUpgrade(val interface{})
AllowMajorVersionUpgradeInput() interface{}
ApplyImmediately() interface{}
SetApplyImmediately(val interface{})
ApplyImmediatelyInput() interface{}
Arn() *string
AvailabilityZones() *[]*string
SetAvailabilityZones(val *[]*string)
AvailabilityZonesInput() *[]*string
BackupRetentionPeriod() *float64
SetBackupRetentionPeriod(val *float64)
BackupRetentionPeriodInput() *float64
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterIdentifier() *string
SetClusterIdentifier(val *string)
ClusterIdentifierInput() *string
ClusterIdentifierPrefix() *string
SetClusterIdentifierPrefix(val *string)
ClusterIdentifierPrefixInput() *string
ClusterMembers() *[]*string
ClusterResourceId() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
CopyTagsToSnapshot() interface{}
SetCopyTagsToSnapshot(val interface{})
CopyTagsToSnapshotInput() interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
DeletionProtection() interface{}
SetDeletionProtection(val interface{})
DeletionProtectionInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EnableCloudwatchLogsExports() *[]*string
SetEnableCloudwatchLogsExports(val *[]*string)
EnableCloudwatchLogsExportsInput() *[]*string
Endpoint() *string
Engine() *string
SetEngine(val *string)
EngineInput() *string
EngineVersion() *string
SetEngineVersion(val *string)
EngineVersionInput() *string
FinalSnapshotIdentifier() *string
SetFinalSnapshotIdentifier(val *string)
FinalSnapshotIdentifierInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GlobalClusterIdentifier() *string
SetGlobalClusterIdentifier(val *string)
GlobalClusterIdentifierInput() *string
HostedZoneId() *string
IamDatabaseAuthenticationEnabled() interface{}
SetIamDatabaseAuthenticationEnabled(val interface{})
IamDatabaseAuthenticationEnabledInput() interface{}
IamRoles() *[]*string
SetIamRoles(val *[]*string)
IamRolesInput() *[]*string
Id() *string
SetId(val *string)
IdInput() *string
KmsKeyArn() *string
SetKmsKeyArn(val *string)
KmsKeyArnInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
NeptuneClusterParameterGroupName() *string
SetNeptuneClusterParameterGroupName(val *string)
NeptuneClusterParameterGroupNameInput() *string
NeptuneInstanceParameterGroupName() *string
SetNeptuneInstanceParameterGroupName(val *string)
NeptuneInstanceParameterGroupNameInput() *string
NeptuneSubnetGroupName() *string
SetNeptuneSubnetGroupName(val *string)
NeptuneSubnetGroupNameInput() *string
// The tree node.
Node() constructs.Node
Port() *float64
SetPort(val *float64)
PortInput() *float64
PreferredBackupWindow() *string
SetPreferredBackupWindow(val *string)
PreferredBackupWindowInput() *string
PreferredMaintenanceWindow() *string
SetPreferredMaintenanceWindow(val *string)
PreferredMaintenanceWindowInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ReaderEndpoint() *string
ReplicationSourceIdentifier() *string
SetReplicationSourceIdentifier(val *string)
ReplicationSourceIdentifierInput() *string
ServerlessV2ScalingConfiguration() NeptuneClusterServerlessV2ScalingConfigurationOutputReference
ServerlessV2ScalingConfigurationInput() *NeptuneClusterServerlessV2ScalingConfiguration
SkipFinalSnapshot() interface{}
SetSkipFinalSnapshot(val interface{})
SkipFinalSnapshotInput() interface{}
SnapshotIdentifier() *string
SetSnapshotIdentifier(val *string)
SnapshotIdentifierInput() *string
StorageEncrypted() interface{}
SetStorageEncrypted(val interface{})
StorageEncryptedInput() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() NeptuneClusterTimeoutsOutputReference
TimeoutsInput() interface{}
VpcSecurityGroupIds() *[]*string
SetVpcSecurityGroupIds(val *[]*string)
VpcSecurityGroupIdsInput() *[]*string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutServerlessV2ScalingConfiguration(value *NeptuneClusterServerlessV2ScalingConfiguration)
PutTimeouts(value *NeptuneClusterTimeouts)
ResetAllowMajorVersionUpgrade()
ResetApplyImmediately()
ResetAvailabilityZones()
ResetBackupRetentionPeriod()
ResetClusterIdentifier()
ResetClusterIdentifierPrefix()
ResetCopyTagsToSnapshot()
ResetDeletionProtection()
ResetEnableCloudwatchLogsExports()
ResetEngine()
ResetEngineVersion()
ResetFinalSnapshotIdentifier()
ResetGlobalClusterIdentifier()
ResetIamDatabaseAuthenticationEnabled()
ResetIamRoles()
ResetId()
ResetKmsKeyArn()
ResetNeptuneClusterParameterGroupName()
ResetNeptuneInstanceParameterGroupName()
ResetNeptuneSubnetGroupName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPort()
ResetPreferredBackupWindow()
ResetPreferredMaintenanceWindow()
ResetReplicationSourceIdentifier()
ResetServerlessV2ScalingConfiguration()
ResetSkipFinalSnapshot()
ResetSnapshotIdentifier()
ResetStorageEncrypted()
ResetTags()
ResetTagsAll()
ResetTimeouts()
ResetVpcSecurityGroupIds()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster aws_neptune_cluster}.
func NewNeptuneCluster ¶
func NewNeptuneCluster(scope constructs.Construct, id *string, config *NeptuneClusterConfig) NeptuneCluster
Create a new {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster aws_neptune_cluster} Resource.
type NeptuneClusterConfig ¶
type NeptuneClusterConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#allow_major_version_upgrade NeptuneCluster#allow_major_version_upgrade}.
AllowMajorVersionUpgrade interface{} `field:"optional" json:"allowMajorVersionUpgrade" yaml:"allowMajorVersionUpgrade"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#apply_immediately NeptuneCluster#apply_immediately}.
ApplyImmediately interface{} `field:"optional" json:"applyImmediately" yaml:"applyImmediately"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#availability_zones NeptuneCluster#availability_zones}.
AvailabilityZones *[]*string `field:"optional" json:"availabilityZones" yaml:"availabilityZones"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#backup_retention_period NeptuneCluster#backup_retention_period}.
BackupRetentionPeriod *float64 `field:"optional" json:"backupRetentionPeriod" yaml:"backupRetentionPeriod"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#cluster_identifier NeptuneCluster#cluster_identifier}.
ClusterIdentifier *string `field:"optional" json:"clusterIdentifier" yaml:"clusterIdentifier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#cluster_identifier_prefix NeptuneCluster#cluster_identifier_prefix}.
ClusterIdentifierPrefix *string `field:"optional" json:"clusterIdentifierPrefix" yaml:"clusterIdentifierPrefix"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#copy_tags_to_snapshot NeptuneCluster#copy_tags_to_snapshot}.
CopyTagsToSnapshot interface{} `field:"optional" json:"copyTagsToSnapshot" yaml:"copyTagsToSnapshot"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#deletion_protection NeptuneCluster#deletion_protection}.
DeletionProtection interface{} `field:"optional" json:"deletionProtection" yaml:"deletionProtection"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#enable_cloudwatch_logs_exports NeptuneCluster#enable_cloudwatch_logs_exports}.
EnableCloudwatchLogsExports *[]*string `field:"optional" json:"enableCloudwatchLogsExports" yaml:"enableCloudwatchLogsExports"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#engine NeptuneCluster#engine}.
Engine *string `field:"optional" json:"engine" yaml:"engine"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#engine_version NeptuneCluster#engine_version}.
EngineVersion *string `field:"optional" json:"engineVersion" yaml:"engineVersion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#final_snapshot_identifier NeptuneCluster#final_snapshot_identifier}.
FinalSnapshotIdentifier *string `field:"optional" json:"finalSnapshotIdentifier" yaml:"finalSnapshotIdentifier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#global_cluster_identifier NeptuneCluster#global_cluster_identifier}.
GlobalClusterIdentifier *string `field:"optional" json:"globalClusterIdentifier" yaml:"globalClusterIdentifier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#iam_database_authentication_enabled NeptuneCluster#iam_database_authentication_enabled}.
IamDatabaseAuthenticationEnabled interface{} `field:"optional" json:"iamDatabaseAuthenticationEnabled" yaml:"iamDatabaseAuthenticationEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#iam_roles NeptuneCluster#iam_roles}.
IamRoles *[]*string `field:"optional" json:"iamRoles" yaml:"iamRoles"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#id NeptuneCluster#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#kms_key_arn NeptuneCluster#kms_key_arn}.
KmsKeyArn *string `field:"optional" json:"kmsKeyArn" yaml:"kmsKeyArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#neptune_cluster_parameter_group_name NeptuneCluster#neptune_cluster_parameter_group_name}.
NeptuneClusterParameterGroupName *string `field:"optional" json:"neptuneClusterParameterGroupName" yaml:"neptuneClusterParameterGroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#neptune_instance_parameter_group_name NeptuneCluster#neptune_instance_parameter_group_name}.
NeptuneInstanceParameterGroupName *string `field:"optional" json:"neptuneInstanceParameterGroupName" yaml:"neptuneInstanceParameterGroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#neptune_subnet_group_name NeptuneCluster#neptune_subnet_group_name}.
NeptuneSubnetGroupName *string `field:"optional" json:"neptuneSubnetGroupName" yaml:"neptuneSubnetGroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#port NeptuneCluster#port}.
Port *float64 `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#preferred_backup_window NeptuneCluster#preferred_backup_window}.
PreferredBackupWindow *string `field:"optional" json:"preferredBackupWindow" yaml:"preferredBackupWindow"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#preferred_maintenance_window NeptuneCluster#preferred_maintenance_window}.
PreferredMaintenanceWindow *string `field:"optional" json:"preferredMaintenanceWindow" yaml:"preferredMaintenanceWindow"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#replication_source_identifier NeptuneCluster#replication_source_identifier}.
ReplicationSourceIdentifier *string `field:"optional" json:"replicationSourceIdentifier" yaml:"replicationSourceIdentifier"`
// serverless_v2_scaling_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#serverless_v2_scaling_configuration NeptuneCluster#serverless_v2_scaling_configuration}
ServerlessV2ScalingConfiguration *NeptuneClusterServerlessV2ScalingConfiguration `field:"optional" json:"serverlessV2ScalingConfiguration" yaml:"serverlessV2ScalingConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#skip_final_snapshot NeptuneCluster#skip_final_snapshot}.
SkipFinalSnapshot interface{} `field:"optional" json:"skipFinalSnapshot" yaml:"skipFinalSnapshot"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#snapshot_identifier NeptuneCluster#snapshot_identifier}.
SnapshotIdentifier *string `field:"optional" json:"snapshotIdentifier" yaml:"snapshotIdentifier"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#storage_encrypted NeptuneCluster#storage_encrypted}.
StorageEncrypted interface{} `field:"optional" json:"storageEncrypted" yaml:"storageEncrypted"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#tags NeptuneCluster#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#tags_all NeptuneCluster#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#timeouts NeptuneCluster#timeouts}
Timeouts *NeptuneClusterTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#vpc_security_group_ids NeptuneCluster#vpc_security_group_ids}.
VpcSecurityGroupIds *[]*string `field:"optional" json:"vpcSecurityGroupIds" yaml:"vpcSecurityGroupIds"`
}
type NeptuneClusterServerlessV2ScalingConfiguration ¶
type NeptuneClusterServerlessV2ScalingConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#max_capacity NeptuneCluster#max_capacity}.
MaxCapacity *float64 `field:"optional" json:"maxCapacity" yaml:"maxCapacity"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#min_capacity NeptuneCluster#min_capacity}.
MinCapacity *float64 `field:"optional" json:"minCapacity" yaml:"minCapacity"`
}
type NeptuneClusterServerlessV2ScalingConfigurationOutputReference ¶
type NeptuneClusterServerlessV2ScalingConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *NeptuneClusterServerlessV2ScalingConfiguration
SetInternalValue(val *NeptuneClusterServerlessV2ScalingConfiguration)
MaxCapacity() *float64
SetMaxCapacity(val *float64)
MaxCapacityInput() *float64
MinCapacity() *float64
SetMinCapacity(val *float64)
MinCapacityInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetMaxCapacity()
ResetMinCapacity()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNeptuneClusterServerlessV2ScalingConfigurationOutputReference ¶
func NewNeptuneClusterServerlessV2ScalingConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) NeptuneClusterServerlessV2ScalingConfigurationOutputReference
type NeptuneClusterTimeouts ¶
type NeptuneClusterTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#create NeptuneCluster#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#delete NeptuneCluster#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/neptune_cluster#update NeptuneCluster#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type NeptuneClusterTimeoutsOutputReference ¶
type NeptuneClusterTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNeptuneClusterTimeoutsOutputReference ¶
func NewNeptuneClusterTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) NeptuneClusterTimeoutsOutputReference
Source Files
¶
- NeptuneCluster.go
- NeptuneClusterConfig.go
- NeptuneClusterServerlessV2ScalingConfiguration.go
- NeptuneClusterServerlessV2ScalingConfigurationOutputReference.go
- NeptuneClusterServerlessV2ScalingConfigurationOutputReference__checks.go
- NeptuneClusterTimeouts.go
- NeptuneClusterTimeoutsOutputReference.go
- NeptuneClusterTimeoutsOutputReference__checks.go
- NeptuneCluster__checks.go
- main.go