Documentation
¶
Index ¶
- func NetworkfirewallLoggingConfiguration_IsConstruct(x interface{}) *bool
- func NetworkfirewallLoggingConfiguration_IsTerraformElement(x interface{}) *bool
- func NetworkfirewallLoggingConfiguration_IsTerraformResource(x interface{}) *bool
- func NetworkfirewallLoggingConfiguration_TfResourceType() *string
- func NewNetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigList_Override(...)
- func NewNetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigOutputReference_Override(...)
- func NewNetworkfirewallLoggingConfigurationLoggingConfigurationOutputReference_Override(n NetworkfirewallLoggingConfigurationLoggingConfigurationOutputReference, ...)
- func NewNetworkfirewallLoggingConfiguration_Override(n NetworkfirewallLoggingConfiguration, scope constructs.Construct, id *string, ...)
- type NetworkfirewallLoggingConfiguration
- type NetworkfirewallLoggingConfigurationConfig
- type NetworkfirewallLoggingConfigurationLoggingConfiguration
- type NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfig
- type NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigList
- type NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigOutputReference
- type NetworkfirewallLoggingConfigurationLoggingConfigurationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NetworkfirewallLoggingConfiguration_IsConstruct ¶
func NetworkfirewallLoggingConfiguration_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func NetworkfirewallLoggingConfiguration_IsTerraformElement ¶
func NetworkfirewallLoggingConfiguration_IsTerraformElement(x interface{}) *bool
Experimental.
func NetworkfirewallLoggingConfiguration_IsTerraformResource ¶
func NetworkfirewallLoggingConfiguration_IsTerraformResource(x interface{}) *bool
Experimental.
func NetworkfirewallLoggingConfiguration_TfResourceType ¶
func NetworkfirewallLoggingConfiguration_TfResourceType() *string
func NewNetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigList_Override ¶
func NewNetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigList_Override(n NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewNetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigOutputReference_Override ¶
func NewNetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigOutputReference_Override(n NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewNetworkfirewallLoggingConfigurationLoggingConfigurationOutputReference_Override ¶
func NewNetworkfirewallLoggingConfigurationLoggingConfigurationOutputReference_Override(n NetworkfirewallLoggingConfigurationLoggingConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewNetworkfirewallLoggingConfiguration_Override ¶
func NewNetworkfirewallLoggingConfiguration_Override(n NetworkfirewallLoggingConfiguration, scope constructs.Construct, id *string, config *NetworkfirewallLoggingConfigurationConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_logging_configuration aws_networkfirewall_logging_configuration} Resource.
Types ¶
type NetworkfirewallLoggingConfiguration ¶
type NetworkfirewallLoggingConfiguration interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
FirewallArn() *string
SetFirewallArn(val *string)
FirewallArnInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LoggingConfiguration() NetworkfirewallLoggingConfigurationLoggingConfigurationOutputReference
LoggingConfigurationInput() *NetworkfirewallLoggingConfigurationLoggingConfiguration
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutLoggingConfiguration(value *NetworkfirewallLoggingConfigurationLoggingConfiguration)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_logging_configuration aws_networkfirewall_logging_configuration}.
func NewNetworkfirewallLoggingConfiguration ¶
func NewNetworkfirewallLoggingConfiguration(scope constructs.Construct, id *string, config *NetworkfirewallLoggingConfigurationConfig) NetworkfirewallLoggingConfiguration
Create a new {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_logging_configuration aws_networkfirewall_logging_configuration} Resource.
type NetworkfirewallLoggingConfigurationConfig ¶
type NetworkfirewallLoggingConfigurationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_logging_configuration#firewall_arn NetworkfirewallLoggingConfiguration#firewall_arn}.
FirewallArn *string `field:"required" json:"firewallArn" yaml:"firewallArn"`
// logging_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_logging_configuration#logging_configuration NetworkfirewallLoggingConfiguration#logging_configuration}
LoggingConfiguration *NetworkfirewallLoggingConfigurationLoggingConfiguration `field:"required" json:"loggingConfiguration" yaml:"loggingConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_logging_configuration#id NetworkfirewallLoggingConfiguration#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type NetworkfirewallLoggingConfigurationLoggingConfiguration ¶
type NetworkfirewallLoggingConfigurationLoggingConfiguration struct {
// log_destination_config block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_logging_configuration#log_destination_config NetworkfirewallLoggingConfiguration#log_destination_config}
LogDestinationConfig interface{} `field:"required" json:"logDestinationConfig" yaml:"logDestinationConfig"`
}
type NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfig ¶
type NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfig struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_logging_configuration#log_destination NetworkfirewallLoggingConfiguration#log_destination}.
LogDestination *map[string]*string `field:"required" json:"logDestination" yaml:"logDestination"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_logging_configuration#log_destination_type NetworkfirewallLoggingConfiguration#log_destination_type}.
LogDestinationType *string `field:"required" json:"logDestinationType" yaml:"logDestinationType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/networkfirewall_logging_configuration#log_type NetworkfirewallLoggingConfiguration#log_type}.
LogType *string `field:"required" json:"logType" yaml:"logType"`
}
type NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigList ¶
type NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigList ¶
func NewNetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigList
type NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigOutputReference ¶
type NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
LogDestination() *map[string]*string
SetLogDestination(val *map[string]*string)
LogDestinationInput() *map[string]*string
LogDestinationType() *string
SetLogDestinationType(val *string)
LogDestinationTypeInput() *string
LogType() *string
SetLogType(val *string)
LogTypeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigOutputReference ¶
func NewNetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigOutputReference
type NetworkfirewallLoggingConfigurationLoggingConfigurationOutputReference ¶
type NetworkfirewallLoggingConfigurationLoggingConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *NetworkfirewallLoggingConfigurationLoggingConfiguration
SetInternalValue(val *NetworkfirewallLoggingConfigurationLoggingConfiguration)
LogDestinationConfig() NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigList
LogDestinationConfigInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutLogDestinationConfig(value interface{})
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkfirewallLoggingConfigurationLoggingConfigurationOutputReference ¶
func NewNetworkfirewallLoggingConfigurationLoggingConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) NetworkfirewallLoggingConfigurationLoggingConfigurationOutputReference
Source Files
¶
- NetworkfirewallLoggingConfiguration.go
- NetworkfirewallLoggingConfigurationConfig.go
- NetworkfirewallLoggingConfigurationLoggingConfiguration.go
- NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfig.go
- NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigList.go
- NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigList__checks.go
- NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigOutputReference.go
- NetworkfirewallLoggingConfigurationLoggingConfigurationLogDestinationConfigOutputReference__checks.go
- NetworkfirewallLoggingConfigurationLoggingConfigurationOutputReference.go
- NetworkfirewallLoggingConfigurationLoggingConfigurationOutputReference__checks.go
- NetworkfirewallLoggingConfiguration__checks.go
- main.go