Documentation
¶
Index ¶
- func NewOpsworksCustomLayerCloudwatchConfigurationLogStreamsList_Override(o OpsworksCustomLayerCloudwatchConfigurationLogStreamsList, ...)
- func NewOpsworksCustomLayerCloudwatchConfigurationLogStreamsOutputReference_Override(o OpsworksCustomLayerCloudwatchConfigurationLogStreamsOutputReference, ...)
- func NewOpsworksCustomLayerCloudwatchConfigurationOutputReference_Override(o OpsworksCustomLayerCloudwatchConfigurationOutputReference, ...)
- func NewOpsworksCustomLayerEbsVolumeList_Override(o OpsworksCustomLayerEbsVolumeList, ...)
- func NewOpsworksCustomLayerEbsVolumeOutputReference_Override(o OpsworksCustomLayerEbsVolumeOutputReference, ...)
- func NewOpsworksCustomLayerLoadBasedAutoScalingDownscalingOutputReference_Override(o OpsworksCustomLayerLoadBasedAutoScalingDownscalingOutputReference, ...)
- func NewOpsworksCustomLayerLoadBasedAutoScalingOutputReference_Override(o OpsworksCustomLayerLoadBasedAutoScalingOutputReference, ...)
- func NewOpsworksCustomLayerLoadBasedAutoScalingUpscalingOutputReference_Override(o OpsworksCustomLayerLoadBasedAutoScalingUpscalingOutputReference, ...)
- func NewOpsworksCustomLayer_Override(o OpsworksCustomLayer, scope constructs.Construct, id *string, ...)
- func OpsworksCustomLayer_IsConstruct(x interface{}) *bool
- func OpsworksCustomLayer_IsTerraformElement(x interface{}) *bool
- func OpsworksCustomLayer_IsTerraformResource(x interface{}) *bool
- func OpsworksCustomLayer_TfResourceType() *string
- type OpsworksCustomLayer
- type OpsworksCustomLayerCloudwatchConfiguration
- type OpsworksCustomLayerCloudwatchConfigurationLogStreams
- type OpsworksCustomLayerCloudwatchConfigurationLogStreamsList
- type OpsworksCustomLayerCloudwatchConfigurationLogStreamsOutputReference
- type OpsworksCustomLayerCloudwatchConfigurationOutputReference
- type OpsworksCustomLayerConfig
- type OpsworksCustomLayerEbsVolume
- type OpsworksCustomLayerEbsVolumeList
- type OpsworksCustomLayerEbsVolumeOutputReference
- type OpsworksCustomLayerLoadBasedAutoScaling
- type OpsworksCustomLayerLoadBasedAutoScalingDownscaling
- type OpsworksCustomLayerLoadBasedAutoScalingDownscalingOutputReference
- type OpsworksCustomLayerLoadBasedAutoScalingOutputReference
- type OpsworksCustomLayerLoadBasedAutoScalingUpscaling
- type OpsworksCustomLayerLoadBasedAutoScalingUpscalingOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewOpsworksCustomLayerCloudwatchConfigurationLogStreamsList_Override ¶
func NewOpsworksCustomLayerCloudwatchConfigurationLogStreamsList_Override(o OpsworksCustomLayerCloudwatchConfigurationLogStreamsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewOpsworksCustomLayerCloudwatchConfigurationLogStreamsOutputReference_Override ¶
func NewOpsworksCustomLayerCloudwatchConfigurationLogStreamsOutputReference_Override(o OpsworksCustomLayerCloudwatchConfigurationLogStreamsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewOpsworksCustomLayerCloudwatchConfigurationOutputReference_Override ¶
func NewOpsworksCustomLayerCloudwatchConfigurationOutputReference_Override(o OpsworksCustomLayerCloudwatchConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpsworksCustomLayerEbsVolumeList_Override ¶
func NewOpsworksCustomLayerEbsVolumeList_Override(o OpsworksCustomLayerEbsVolumeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewOpsworksCustomLayerEbsVolumeOutputReference_Override ¶
func NewOpsworksCustomLayerEbsVolumeOutputReference_Override(o OpsworksCustomLayerEbsVolumeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewOpsworksCustomLayerLoadBasedAutoScalingDownscalingOutputReference_Override ¶
func NewOpsworksCustomLayerLoadBasedAutoScalingDownscalingOutputReference_Override(o OpsworksCustomLayerLoadBasedAutoScalingDownscalingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpsworksCustomLayerLoadBasedAutoScalingOutputReference_Override ¶
func NewOpsworksCustomLayerLoadBasedAutoScalingOutputReference_Override(o OpsworksCustomLayerLoadBasedAutoScalingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpsworksCustomLayerLoadBasedAutoScalingUpscalingOutputReference_Override ¶
func NewOpsworksCustomLayerLoadBasedAutoScalingUpscalingOutputReference_Override(o OpsworksCustomLayerLoadBasedAutoScalingUpscalingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpsworksCustomLayer_Override ¶
func NewOpsworksCustomLayer_Override(o OpsworksCustomLayer, scope constructs.Construct, id *string, config *OpsworksCustomLayerConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer aws_opsworks_custom_layer} Resource.
func OpsworksCustomLayer_IsConstruct ¶
func OpsworksCustomLayer_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func OpsworksCustomLayer_IsTerraformElement ¶
func OpsworksCustomLayer_IsTerraformElement(x interface{}) *bool
Experimental.
func OpsworksCustomLayer_IsTerraformResource ¶
func OpsworksCustomLayer_IsTerraformResource(x interface{}) *bool
Experimental.
func OpsworksCustomLayer_TfResourceType ¶
func OpsworksCustomLayer_TfResourceType() *string
Types ¶
type OpsworksCustomLayer ¶
type OpsworksCustomLayer interface {
cdktf.TerraformResource
Arn() *string
AutoAssignElasticIps() interface{}
SetAutoAssignElasticIps(val interface{})
AutoAssignElasticIpsInput() interface{}
AutoAssignPublicIps() interface{}
SetAutoAssignPublicIps(val interface{})
AutoAssignPublicIpsInput() interface{}
AutoHealing() interface{}
SetAutoHealing(val interface{})
AutoHealingInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
CloudwatchConfiguration() OpsworksCustomLayerCloudwatchConfigurationOutputReference
CloudwatchConfigurationInput() *OpsworksCustomLayerCloudwatchConfiguration
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CustomConfigureRecipes() *[]*string
SetCustomConfigureRecipes(val *[]*string)
CustomConfigureRecipesInput() *[]*string
CustomDeployRecipes() *[]*string
SetCustomDeployRecipes(val *[]*string)
CustomDeployRecipesInput() *[]*string
CustomInstanceProfileArn() *string
SetCustomInstanceProfileArn(val *string)
CustomInstanceProfileArnInput() *string
CustomJson() *string
SetCustomJson(val *string)
CustomJsonInput() *string
CustomSecurityGroupIds() *[]*string
SetCustomSecurityGroupIds(val *[]*string)
CustomSecurityGroupIdsInput() *[]*string
CustomSetupRecipes() *[]*string
SetCustomSetupRecipes(val *[]*string)
CustomSetupRecipesInput() *[]*string
CustomShutdownRecipes() *[]*string
SetCustomShutdownRecipes(val *[]*string)
CustomShutdownRecipesInput() *[]*string
CustomUndeployRecipes() *[]*string
SetCustomUndeployRecipes(val *[]*string)
CustomUndeployRecipesInput() *[]*string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DrainElbOnShutdown() interface{}
SetDrainElbOnShutdown(val interface{})
DrainElbOnShutdownInput() interface{}
EbsVolume() OpsworksCustomLayerEbsVolumeList
EbsVolumeInput() interface{}
ElasticLoadBalancer() *string
SetElasticLoadBalancer(val *string)
ElasticLoadBalancerInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InstallUpdatesOnBoot() interface{}
SetInstallUpdatesOnBoot(val interface{})
InstallUpdatesOnBootInput() interface{}
InstanceShutdownTimeout() *float64
SetInstanceShutdownTimeout(val *float64)
InstanceShutdownTimeoutInput() *float64
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LoadBasedAutoScaling() OpsworksCustomLayerLoadBasedAutoScalingOutputReference
LoadBasedAutoScalingInput() *OpsworksCustomLayerLoadBasedAutoScaling
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ShortName() *string
SetShortName(val *string)
ShortNameInput() *string
StackId() *string
SetStackId(val *string)
StackIdInput() *string
SystemPackages() *[]*string
SetSystemPackages(val *[]*string)
SystemPackagesInput() *[]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
UseEbsOptimizedInstances() interface{}
SetUseEbsOptimizedInstances(val interface{})
UseEbsOptimizedInstancesInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCloudwatchConfiguration(value *OpsworksCustomLayerCloudwatchConfiguration)
PutEbsVolume(value interface{})
PutLoadBasedAutoScaling(value *OpsworksCustomLayerLoadBasedAutoScaling)
ResetAutoAssignElasticIps()
ResetAutoAssignPublicIps()
ResetAutoHealing()
ResetCloudwatchConfiguration()
ResetCustomConfigureRecipes()
ResetCustomDeployRecipes()
ResetCustomInstanceProfileArn()
ResetCustomJson()
ResetCustomSecurityGroupIds()
ResetCustomSetupRecipes()
ResetCustomShutdownRecipes()
ResetCustomUndeployRecipes()
ResetDrainElbOnShutdown()
ResetEbsVolume()
ResetElasticLoadBalancer()
ResetId()
ResetInstallUpdatesOnBoot()
ResetInstanceShutdownTimeout()
ResetLoadBasedAutoScaling()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSystemPackages()
ResetTags()
ResetTagsAll()
ResetUseEbsOptimizedInstances()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer aws_opsworks_custom_layer}.
func NewOpsworksCustomLayer ¶
func NewOpsworksCustomLayer(scope constructs.Construct, id *string, config *OpsworksCustomLayerConfig) OpsworksCustomLayer
Create a new {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer aws_opsworks_custom_layer} Resource.
type OpsworksCustomLayerCloudwatchConfiguration ¶
type OpsworksCustomLayerCloudwatchConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#enabled OpsworksCustomLayer#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// log_streams block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#log_streams OpsworksCustomLayer#log_streams}
LogStreams interface{} `field:"optional" json:"logStreams" yaml:"logStreams"`
}
type OpsworksCustomLayerCloudwatchConfigurationLogStreams ¶
type OpsworksCustomLayerCloudwatchConfigurationLogStreams struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#file OpsworksCustomLayer#file}.
File *string `field:"required" json:"file" yaml:"file"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#log_group_name OpsworksCustomLayer#log_group_name}.
LogGroupName *string `field:"required" json:"logGroupName" yaml:"logGroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#batch_count OpsworksCustomLayer#batch_count}.
BatchCount *float64 `field:"optional" json:"batchCount" yaml:"batchCount"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#batch_size OpsworksCustomLayer#batch_size}.
BatchSize *float64 `field:"optional" json:"batchSize" yaml:"batchSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#buffer_duration OpsworksCustomLayer#buffer_duration}.
BufferDuration *float64 `field:"optional" json:"bufferDuration" yaml:"bufferDuration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#datetime_format OpsworksCustomLayer#datetime_format}.
DatetimeFormat *string `field:"optional" json:"datetimeFormat" yaml:"datetimeFormat"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#encoding OpsworksCustomLayer#encoding}.
Encoding *string `field:"optional" json:"encoding" yaml:"encoding"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#file_fingerprint_lines OpsworksCustomLayer#file_fingerprint_lines}.
FileFingerprintLines *string `field:"optional" json:"fileFingerprintLines" yaml:"fileFingerprintLines"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#initial_position OpsworksCustomLayer#initial_position}.
InitialPosition *string `field:"optional" json:"initialPosition" yaml:"initialPosition"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#multiline_start_pattern OpsworksCustomLayer#multiline_start_pattern}.
MultilineStartPattern *string `field:"optional" json:"multilineStartPattern" yaml:"multilineStartPattern"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#time_zone OpsworksCustomLayer#time_zone}.
TimeZone *string `field:"optional" json:"timeZone" yaml:"timeZone"`
}
type OpsworksCustomLayerCloudwatchConfigurationLogStreamsList ¶
type OpsworksCustomLayerCloudwatchConfigurationLogStreamsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) OpsworksCustomLayerCloudwatchConfigurationLogStreamsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksCustomLayerCloudwatchConfigurationLogStreamsList ¶
func NewOpsworksCustomLayerCloudwatchConfigurationLogStreamsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) OpsworksCustomLayerCloudwatchConfigurationLogStreamsList
type OpsworksCustomLayerCloudwatchConfigurationLogStreamsOutputReference ¶
type OpsworksCustomLayerCloudwatchConfigurationLogStreamsOutputReference interface {
cdktf.ComplexObject
BatchCount() *float64
SetBatchCount(val *float64)
BatchCountInput() *float64
BatchSize() *float64
SetBatchSize(val *float64)
BatchSizeInput() *float64
BufferDuration() *float64
SetBufferDuration(val *float64)
BufferDurationInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DatetimeFormat() *string
SetDatetimeFormat(val *string)
DatetimeFormatInput() *string
Encoding() *string
SetEncoding(val *string)
EncodingInput() *string
File() *string
SetFile(val *string)
FileFingerprintLines() *string
SetFileFingerprintLines(val *string)
FileFingerprintLinesInput() *string
FileInput() *string
// Experimental.
Fqn() *string
InitialPosition() *string
SetInitialPosition(val *string)
InitialPositionInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
LogGroupName() *string
SetLogGroupName(val *string)
LogGroupNameInput() *string
MultilineStartPattern() *string
SetMultilineStartPattern(val *string)
MultilineStartPatternInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TimeZone() *string
SetTimeZone(val *string)
TimeZoneInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBatchCount()
ResetBatchSize()
ResetBufferDuration()
ResetDatetimeFormat()
ResetEncoding()
ResetFileFingerprintLines()
ResetInitialPosition()
ResetMultilineStartPattern()
ResetTimeZone()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksCustomLayerCloudwatchConfigurationLogStreamsOutputReference ¶
func NewOpsworksCustomLayerCloudwatchConfigurationLogStreamsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) OpsworksCustomLayerCloudwatchConfigurationLogStreamsOutputReference
type OpsworksCustomLayerCloudwatchConfigurationOutputReference ¶
type OpsworksCustomLayerCloudwatchConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *OpsworksCustomLayerCloudwatchConfiguration
SetInternalValue(val *OpsworksCustomLayerCloudwatchConfiguration)
LogStreams() OpsworksCustomLayerCloudwatchConfigurationLogStreamsList
LogStreamsInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutLogStreams(value interface{})
ResetEnabled()
ResetLogStreams()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksCustomLayerCloudwatchConfigurationOutputReference ¶
func NewOpsworksCustomLayerCloudwatchConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpsworksCustomLayerCloudwatchConfigurationOutputReference
type OpsworksCustomLayerConfig ¶
type OpsworksCustomLayerConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#name OpsworksCustomLayer#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#short_name OpsworksCustomLayer#short_name}.
ShortName *string `field:"required" json:"shortName" yaml:"shortName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#stack_id OpsworksCustomLayer#stack_id}.
StackId *string `field:"required" json:"stackId" yaml:"stackId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#auto_assign_elastic_ips OpsworksCustomLayer#auto_assign_elastic_ips}.
AutoAssignElasticIps interface{} `field:"optional" json:"autoAssignElasticIps" yaml:"autoAssignElasticIps"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#auto_assign_public_ips OpsworksCustomLayer#auto_assign_public_ips}.
AutoAssignPublicIps interface{} `field:"optional" json:"autoAssignPublicIps" yaml:"autoAssignPublicIps"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#auto_healing OpsworksCustomLayer#auto_healing}.
AutoHealing interface{} `field:"optional" json:"autoHealing" yaml:"autoHealing"`
// cloudwatch_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#cloudwatch_configuration OpsworksCustomLayer#cloudwatch_configuration}
CloudwatchConfiguration *OpsworksCustomLayerCloudwatchConfiguration `field:"optional" json:"cloudwatchConfiguration" yaml:"cloudwatchConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#custom_configure_recipes OpsworksCustomLayer#custom_configure_recipes}.
CustomConfigureRecipes *[]*string `field:"optional" json:"customConfigureRecipes" yaml:"customConfigureRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#custom_deploy_recipes OpsworksCustomLayer#custom_deploy_recipes}.
CustomDeployRecipes *[]*string `field:"optional" json:"customDeployRecipes" yaml:"customDeployRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#custom_instance_profile_arn OpsworksCustomLayer#custom_instance_profile_arn}.
CustomInstanceProfileArn *string `field:"optional" json:"customInstanceProfileArn" yaml:"customInstanceProfileArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#custom_json OpsworksCustomLayer#custom_json}.
CustomJson *string `field:"optional" json:"customJson" yaml:"customJson"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#custom_security_group_ids OpsworksCustomLayer#custom_security_group_ids}.
CustomSecurityGroupIds *[]*string `field:"optional" json:"customSecurityGroupIds" yaml:"customSecurityGroupIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#custom_setup_recipes OpsworksCustomLayer#custom_setup_recipes}.
CustomSetupRecipes *[]*string `field:"optional" json:"customSetupRecipes" yaml:"customSetupRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#custom_shutdown_recipes OpsworksCustomLayer#custom_shutdown_recipes}.
CustomShutdownRecipes *[]*string `field:"optional" json:"customShutdownRecipes" yaml:"customShutdownRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#custom_undeploy_recipes OpsworksCustomLayer#custom_undeploy_recipes}.
CustomUndeployRecipes *[]*string `field:"optional" json:"customUndeployRecipes" yaml:"customUndeployRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#drain_elb_on_shutdown OpsworksCustomLayer#drain_elb_on_shutdown}.
DrainElbOnShutdown interface{} `field:"optional" json:"drainElbOnShutdown" yaml:"drainElbOnShutdown"`
// ebs_volume block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#ebs_volume OpsworksCustomLayer#ebs_volume}
EbsVolume interface{} `field:"optional" json:"ebsVolume" yaml:"ebsVolume"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#elastic_load_balancer OpsworksCustomLayer#elastic_load_balancer}.
ElasticLoadBalancer *string `field:"optional" json:"elasticLoadBalancer" yaml:"elasticLoadBalancer"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#id OpsworksCustomLayer#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#install_updates_on_boot OpsworksCustomLayer#install_updates_on_boot}.
InstallUpdatesOnBoot interface{} `field:"optional" json:"installUpdatesOnBoot" yaml:"installUpdatesOnBoot"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#instance_shutdown_timeout OpsworksCustomLayer#instance_shutdown_timeout}.
InstanceShutdownTimeout *float64 `field:"optional" json:"instanceShutdownTimeout" yaml:"instanceShutdownTimeout"`
// load_based_auto_scaling block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#load_based_auto_scaling OpsworksCustomLayer#load_based_auto_scaling}
LoadBasedAutoScaling *OpsworksCustomLayerLoadBasedAutoScaling `field:"optional" json:"loadBasedAutoScaling" yaml:"loadBasedAutoScaling"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#system_packages OpsworksCustomLayer#system_packages}.
SystemPackages *[]*string `field:"optional" json:"systemPackages" yaml:"systemPackages"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#tags OpsworksCustomLayer#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#tags_all OpsworksCustomLayer#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#use_ebs_optimized_instances OpsworksCustomLayer#use_ebs_optimized_instances}.
UseEbsOptimizedInstances interface{} `field:"optional" json:"useEbsOptimizedInstances" yaml:"useEbsOptimizedInstances"`
}
type OpsworksCustomLayerEbsVolume ¶
type OpsworksCustomLayerEbsVolume struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#mount_point OpsworksCustomLayer#mount_point}.
MountPoint *string `field:"required" json:"mountPoint" yaml:"mountPoint"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#number_of_disks OpsworksCustomLayer#number_of_disks}.
NumberOfDisks *float64 `field:"required" json:"numberOfDisks" yaml:"numberOfDisks"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#size OpsworksCustomLayer#size}.
Size *float64 `field:"required" json:"size" yaml:"size"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#encrypted OpsworksCustomLayer#encrypted}.
Encrypted interface{} `field:"optional" json:"encrypted" yaml:"encrypted"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#iops OpsworksCustomLayer#iops}.
Iops *float64 `field:"optional" json:"iops" yaml:"iops"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#raid_level OpsworksCustomLayer#raid_level}.
RaidLevel *string `field:"optional" json:"raidLevel" yaml:"raidLevel"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#type OpsworksCustomLayer#type}.
Type *string `field:"optional" json:"type" yaml:"type"`
}
type OpsworksCustomLayerEbsVolumeList ¶
type OpsworksCustomLayerEbsVolumeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) OpsworksCustomLayerEbsVolumeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksCustomLayerEbsVolumeList ¶
func NewOpsworksCustomLayerEbsVolumeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) OpsworksCustomLayerEbsVolumeList
type OpsworksCustomLayerEbsVolumeOutputReference ¶
type OpsworksCustomLayerEbsVolumeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Encrypted() interface{}
SetEncrypted(val interface{})
EncryptedInput() interface{}
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Iops() *float64
SetIops(val *float64)
IopsInput() *float64
MountPoint() *string
SetMountPoint(val *string)
MountPointInput() *string
NumberOfDisks() *float64
SetNumberOfDisks(val *float64)
NumberOfDisksInput() *float64
RaidLevel() *string
SetRaidLevel(val *string)
RaidLevelInput() *string
Size() *float64
SetSize(val *float64)
SizeInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEncrypted()
ResetIops()
ResetRaidLevel()
ResetType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksCustomLayerEbsVolumeOutputReference ¶
func NewOpsworksCustomLayerEbsVolumeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) OpsworksCustomLayerEbsVolumeOutputReference
type OpsworksCustomLayerLoadBasedAutoScaling ¶
type OpsworksCustomLayerLoadBasedAutoScaling struct {
// downscaling block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#downscaling OpsworksCustomLayer#downscaling}
Downscaling *OpsworksCustomLayerLoadBasedAutoScalingDownscaling `field:"optional" json:"downscaling" yaml:"downscaling"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#enable OpsworksCustomLayer#enable}.
Enable interface{} `field:"optional" json:"enable" yaml:"enable"`
// upscaling block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#upscaling OpsworksCustomLayer#upscaling}
Upscaling *OpsworksCustomLayerLoadBasedAutoScalingUpscaling `field:"optional" json:"upscaling" yaml:"upscaling"`
}
type OpsworksCustomLayerLoadBasedAutoScalingDownscaling ¶
type OpsworksCustomLayerLoadBasedAutoScalingDownscaling struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#alarms OpsworksCustomLayer#alarms}.
Alarms *[]*string `field:"optional" json:"alarms" yaml:"alarms"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#cpu_threshold OpsworksCustomLayer#cpu_threshold}.
CpuThreshold *float64 `field:"optional" json:"cpuThreshold" yaml:"cpuThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#ignore_metrics_time OpsworksCustomLayer#ignore_metrics_time}.
IgnoreMetricsTime *float64 `field:"optional" json:"ignoreMetricsTime" yaml:"ignoreMetricsTime"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#instance_count OpsworksCustomLayer#instance_count}.
InstanceCount *float64 `field:"optional" json:"instanceCount" yaml:"instanceCount"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#load_threshold OpsworksCustomLayer#load_threshold}.
LoadThreshold *float64 `field:"optional" json:"loadThreshold" yaml:"loadThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#memory_threshold OpsworksCustomLayer#memory_threshold}.
MemoryThreshold *float64 `field:"optional" json:"memoryThreshold" yaml:"memoryThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#thresholds_wait_time OpsworksCustomLayer#thresholds_wait_time}.
ThresholdsWaitTime *float64 `field:"optional" json:"thresholdsWaitTime" yaml:"thresholdsWaitTime"`
}
type OpsworksCustomLayerLoadBasedAutoScalingDownscalingOutputReference ¶
type OpsworksCustomLayerLoadBasedAutoScalingDownscalingOutputReference interface {
cdktf.ComplexObject
Alarms() *[]*string
SetAlarms(val *[]*string)
AlarmsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CpuThreshold() *float64
SetCpuThreshold(val *float64)
CpuThresholdInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IgnoreMetricsTime() *float64
SetIgnoreMetricsTime(val *float64)
IgnoreMetricsTimeInput() *float64
InstanceCount() *float64
SetInstanceCount(val *float64)
InstanceCountInput() *float64
InternalValue() *OpsworksCustomLayerLoadBasedAutoScalingDownscaling
SetInternalValue(val *OpsworksCustomLayerLoadBasedAutoScalingDownscaling)
LoadThreshold() *float64
SetLoadThreshold(val *float64)
LoadThresholdInput() *float64
MemoryThreshold() *float64
SetMemoryThreshold(val *float64)
MemoryThresholdInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ThresholdsWaitTime() *float64
SetThresholdsWaitTime(val *float64)
ThresholdsWaitTimeInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAlarms()
ResetCpuThreshold()
ResetIgnoreMetricsTime()
ResetInstanceCount()
ResetLoadThreshold()
ResetMemoryThreshold()
ResetThresholdsWaitTime()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksCustomLayerLoadBasedAutoScalingDownscalingOutputReference ¶
func NewOpsworksCustomLayerLoadBasedAutoScalingDownscalingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpsworksCustomLayerLoadBasedAutoScalingDownscalingOutputReference
type OpsworksCustomLayerLoadBasedAutoScalingOutputReference ¶
type OpsworksCustomLayerLoadBasedAutoScalingOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Downscaling() OpsworksCustomLayerLoadBasedAutoScalingDownscalingOutputReference
DownscalingInput() *OpsworksCustomLayerLoadBasedAutoScalingDownscaling
Enable() interface{}
SetEnable(val interface{})
EnableInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *OpsworksCustomLayerLoadBasedAutoScaling
SetInternalValue(val *OpsworksCustomLayerLoadBasedAutoScaling)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Upscaling() OpsworksCustomLayerLoadBasedAutoScalingUpscalingOutputReference
UpscalingInput() *OpsworksCustomLayerLoadBasedAutoScalingUpscaling
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutDownscaling(value *OpsworksCustomLayerLoadBasedAutoScalingDownscaling)
PutUpscaling(value *OpsworksCustomLayerLoadBasedAutoScalingUpscaling)
ResetDownscaling()
ResetEnable()
ResetUpscaling()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksCustomLayerLoadBasedAutoScalingOutputReference ¶
func NewOpsworksCustomLayerLoadBasedAutoScalingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpsworksCustomLayerLoadBasedAutoScalingOutputReference
type OpsworksCustomLayerLoadBasedAutoScalingUpscaling ¶
type OpsworksCustomLayerLoadBasedAutoScalingUpscaling struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#alarms OpsworksCustomLayer#alarms}.
Alarms *[]*string `field:"optional" json:"alarms" yaml:"alarms"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#cpu_threshold OpsworksCustomLayer#cpu_threshold}.
CpuThreshold *float64 `field:"optional" json:"cpuThreshold" yaml:"cpuThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#ignore_metrics_time OpsworksCustomLayer#ignore_metrics_time}.
IgnoreMetricsTime *float64 `field:"optional" json:"ignoreMetricsTime" yaml:"ignoreMetricsTime"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#instance_count OpsworksCustomLayer#instance_count}.
InstanceCount *float64 `field:"optional" json:"instanceCount" yaml:"instanceCount"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#load_threshold OpsworksCustomLayer#load_threshold}.
LoadThreshold *float64 `field:"optional" json:"loadThreshold" yaml:"loadThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#memory_threshold OpsworksCustomLayer#memory_threshold}.
MemoryThreshold *float64 `field:"optional" json:"memoryThreshold" yaml:"memoryThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_custom_layer#thresholds_wait_time OpsworksCustomLayer#thresholds_wait_time}.
ThresholdsWaitTime *float64 `field:"optional" json:"thresholdsWaitTime" yaml:"thresholdsWaitTime"`
}
type OpsworksCustomLayerLoadBasedAutoScalingUpscalingOutputReference ¶
type OpsworksCustomLayerLoadBasedAutoScalingUpscalingOutputReference interface {
cdktf.ComplexObject
Alarms() *[]*string
SetAlarms(val *[]*string)
AlarmsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CpuThreshold() *float64
SetCpuThreshold(val *float64)
CpuThresholdInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IgnoreMetricsTime() *float64
SetIgnoreMetricsTime(val *float64)
IgnoreMetricsTimeInput() *float64
InstanceCount() *float64
SetInstanceCount(val *float64)
InstanceCountInput() *float64
InternalValue() *OpsworksCustomLayerLoadBasedAutoScalingUpscaling
SetInternalValue(val *OpsworksCustomLayerLoadBasedAutoScalingUpscaling)
LoadThreshold() *float64
SetLoadThreshold(val *float64)
LoadThresholdInput() *float64
MemoryThreshold() *float64
SetMemoryThreshold(val *float64)
MemoryThresholdInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ThresholdsWaitTime() *float64
SetThresholdsWaitTime(val *float64)
ThresholdsWaitTimeInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAlarms()
ResetCpuThreshold()
ResetIgnoreMetricsTime()
ResetInstanceCount()
ResetLoadThreshold()
ResetMemoryThreshold()
ResetThresholdsWaitTime()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksCustomLayerLoadBasedAutoScalingUpscalingOutputReference ¶
func NewOpsworksCustomLayerLoadBasedAutoScalingUpscalingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpsworksCustomLayerLoadBasedAutoScalingUpscalingOutputReference
Source Files
¶
- OpsworksCustomLayer.go
- OpsworksCustomLayerCloudwatchConfiguration.go
- OpsworksCustomLayerCloudwatchConfigurationLogStreams.go
- OpsworksCustomLayerCloudwatchConfigurationLogStreamsList.go
- OpsworksCustomLayerCloudwatchConfigurationLogStreamsList__checks.go
- OpsworksCustomLayerCloudwatchConfigurationLogStreamsOutputReference.go
- OpsworksCustomLayerCloudwatchConfigurationLogStreamsOutputReference__checks.go
- OpsworksCustomLayerCloudwatchConfigurationOutputReference.go
- OpsworksCustomLayerCloudwatchConfigurationOutputReference__checks.go
- OpsworksCustomLayerConfig.go
- OpsworksCustomLayerEbsVolume.go
- OpsworksCustomLayerEbsVolumeList.go
- OpsworksCustomLayerEbsVolumeList__checks.go
- OpsworksCustomLayerEbsVolumeOutputReference.go
- OpsworksCustomLayerEbsVolumeOutputReference__checks.go
- OpsworksCustomLayerLoadBasedAutoScaling.go
- OpsworksCustomLayerLoadBasedAutoScalingDownscaling.go
- OpsworksCustomLayerLoadBasedAutoScalingDownscalingOutputReference.go
- OpsworksCustomLayerLoadBasedAutoScalingDownscalingOutputReference__checks.go
- OpsworksCustomLayerLoadBasedAutoScalingOutputReference.go
- OpsworksCustomLayerLoadBasedAutoScalingOutputReference__checks.go
- OpsworksCustomLayerLoadBasedAutoScalingUpscaling.go
- OpsworksCustomLayerLoadBasedAutoScalingUpscalingOutputReference.go
- OpsworksCustomLayerLoadBasedAutoScalingUpscalingOutputReference__checks.go
- OpsworksCustomLayer__checks.go
- main.go