Documentation
¶
Index ¶
- func NewOpsworksHaproxyLayerCloudwatchConfigurationLogStreamsList_Override(o OpsworksHaproxyLayerCloudwatchConfigurationLogStreamsList, ...)
- func NewOpsworksHaproxyLayerCloudwatchConfigurationLogStreamsOutputReference_Override(o OpsworksHaproxyLayerCloudwatchConfigurationLogStreamsOutputReference, ...)
- func NewOpsworksHaproxyLayerCloudwatchConfigurationOutputReference_Override(o OpsworksHaproxyLayerCloudwatchConfigurationOutputReference, ...)
- func NewOpsworksHaproxyLayerEbsVolumeList_Override(o OpsworksHaproxyLayerEbsVolumeList, ...)
- func NewOpsworksHaproxyLayerEbsVolumeOutputReference_Override(o OpsworksHaproxyLayerEbsVolumeOutputReference, ...)
- func NewOpsworksHaproxyLayerLoadBasedAutoScalingDownscalingOutputReference_Override(o OpsworksHaproxyLayerLoadBasedAutoScalingDownscalingOutputReference, ...)
- func NewOpsworksHaproxyLayerLoadBasedAutoScalingOutputReference_Override(o OpsworksHaproxyLayerLoadBasedAutoScalingOutputReference, ...)
- func NewOpsworksHaproxyLayerLoadBasedAutoScalingUpscalingOutputReference_Override(o OpsworksHaproxyLayerLoadBasedAutoScalingUpscalingOutputReference, ...)
- func NewOpsworksHaproxyLayer_Override(o OpsworksHaproxyLayer, scope constructs.Construct, id *string, ...)
- func OpsworksHaproxyLayer_IsConstruct(x interface{}) *bool
- func OpsworksHaproxyLayer_IsTerraformElement(x interface{}) *bool
- func OpsworksHaproxyLayer_IsTerraformResource(x interface{}) *bool
- func OpsworksHaproxyLayer_TfResourceType() *string
- type OpsworksHaproxyLayer
- type OpsworksHaproxyLayerCloudwatchConfiguration
- type OpsworksHaproxyLayerCloudwatchConfigurationLogStreams
- type OpsworksHaproxyLayerCloudwatchConfigurationLogStreamsList
- type OpsworksHaproxyLayerCloudwatchConfigurationLogStreamsOutputReference
- type OpsworksHaproxyLayerCloudwatchConfigurationOutputReference
- type OpsworksHaproxyLayerConfig
- type OpsworksHaproxyLayerEbsVolume
- type OpsworksHaproxyLayerEbsVolumeList
- type OpsworksHaproxyLayerEbsVolumeOutputReference
- type OpsworksHaproxyLayerLoadBasedAutoScaling
- type OpsworksHaproxyLayerLoadBasedAutoScalingDownscaling
- type OpsworksHaproxyLayerLoadBasedAutoScalingDownscalingOutputReference
- type OpsworksHaproxyLayerLoadBasedAutoScalingOutputReference
- type OpsworksHaproxyLayerLoadBasedAutoScalingUpscaling
- type OpsworksHaproxyLayerLoadBasedAutoScalingUpscalingOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewOpsworksHaproxyLayerCloudwatchConfigurationLogStreamsList_Override ¶
func NewOpsworksHaproxyLayerCloudwatchConfigurationLogStreamsList_Override(o OpsworksHaproxyLayerCloudwatchConfigurationLogStreamsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewOpsworksHaproxyLayerCloudwatchConfigurationLogStreamsOutputReference_Override ¶
func NewOpsworksHaproxyLayerCloudwatchConfigurationLogStreamsOutputReference_Override(o OpsworksHaproxyLayerCloudwatchConfigurationLogStreamsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewOpsworksHaproxyLayerCloudwatchConfigurationOutputReference_Override ¶
func NewOpsworksHaproxyLayerCloudwatchConfigurationOutputReference_Override(o OpsworksHaproxyLayerCloudwatchConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpsworksHaproxyLayerEbsVolumeList_Override ¶
func NewOpsworksHaproxyLayerEbsVolumeList_Override(o OpsworksHaproxyLayerEbsVolumeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewOpsworksHaproxyLayerEbsVolumeOutputReference_Override ¶
func NewOpsworksHaproxyLayerEbsVolumeOutputReference_Override(o OpsworksHaproxyLayerEbsVolumeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewOpsworksHaproxyLayerLoadBasedAutoScalingDownscalingOutputReference_Override ¶
func NewOpsworksHaproxyLayerLoadBasedAutoScalingDownscalingOutputReference_Override(o OpsworksHaproxyLayerLoadBasedAutoScalingDownscalingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpsworksHaproxyLayerLoadBasedAutoScalingOutputReference_Override ¶
func NewOpsworksHaproxyLayerLoadBasedAutoScalingOutputReference_Override(o OpsworksHaproxyLayerLoadBasedAutoScalingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpsworksHaproxyLayerLoadBasedAutoScalingUpscalingOutputReference_Override ¶
func NewOpsworksHaproxyLayerLoadBasedAutoScalingUpscalingOutputReference_Override(o OpsworksHaproxyLayerLoadBasedAutoScalingUpscalingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpsworksHaproxyLayer_Override ¶
func NewOpsworksHaproxyLayer_Override(o OpsworksHaproxyLayer, scope constructs.Construct, id *string, config *OpsworksHaproxyLayerConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer aws_opsworks_haproxy_layer} Resource.
func OpsworksHaproxyLayer_IsConstruct ¶
func OpsworksHaproxyLayer_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func OpsworksHaproxyLayer_IsTerraformElement ¶
func OpsworksHaproxyLayer_IsTerraformElement(x interface{}) *bool
Experimental.
func OpsworksHaproxyLayer_IsTerraformResource ¶
func OpsworksHaproxyLayer_IsTerraformResource(x interface{}) *bool
Experimental.
func OpsworksHaproxyLayer_TfResourceType ¶
func OpsworksHaproxyLayer_TfResourceType() *string
Types ¶
type OpsworksHaproxyLayer ¶
type OpsworksHaproxyLayer interface {
cdktf.TerraformResource
Arn() *string
AutoAssignElasticIps() interface{}
SetAutoAssignElasticIps(val interface{})
AutoAssignElasticIpsInput() interface{}
AutoAssignPublicIps() interface{}
SetAutoAssignPublicIps(val interface{})
AutoAssignPublicIpsInput() interface{}
AutoHealing() interface{}
SetAutoHealing(val interface{})
AutoHealingInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
CloudwatchConfiguration() OpsworksHaproxyLayerCloudwatchConfigurationOutputReference
CloudwatchConfigurationInput() *OpsworksHaproxyLayerCloudwatchConfiguration
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CustomConfigureRecipes() *[]*string
SetCustomConfigureRecipes(val *[]*string)
CustomConfigureRecipesInput() *[]*string
CustomDeployRecipes() *[]*string
SetCustomDeployRecipes(val *[]*string)
CustomDeployRecipesInput() *[]*string
CustomInstanceProfileArn() *string
SetCustomInstanceProfileArn(val *string)
CustomInstanceProfileArnInput() *string
CustomJson() *string
SetCustomJson(val *string)
CustomJsonInput() *string
CustomSecurityGroupIds() *[]*string
SetCustomSecurityGroupIds(val *[]*string)
CustomSecurityGroupIdsInput() *[]*string
CustomSetupRecipes() *[]*string
SetCustomSetupRecipes(val *[]*string)
CustomSetupRecipesInput() *[]*string
CustomShutdownRecipes() *[]*string
SetCustomShutdownRecipes(val *[]*string)
CustomShutdownRecipesInput() *[]*string
CustomUndeployRecipes() *[]*string
SetCustomUndeployRecipes(val *[]*string)
CustomUndeployRecipesInput() *[]*string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DrainElbOnShutdown() interface{}
SetDrainElbOnShutdown(val interface{})
DrainElbOnShutdownInput() interface{}
EbsVolume() OpsworksHaproxyLayerEbsVolumeList
EbsVolumeInput() interface{}
ElasticLoadBalancer() *string
SetElasticLoadBalancer(val *string)
ElasticLoadBalancerInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HealthcheckMethod() *string
SetHealthcheckMethod(val *string)
HealthcheckMethodInput() *string
HealthcheckUrl() *string
SetHealthcheckUrl(val *string)
HealthcheckUrlInput() *string
Id() *string
SetId(val *string)
IdInput() *string
InstallUpdatesOnBoot() interface{}
SetInstallUpdatesOnBoot(val interface{})
InstallUpdatesOnBootInput() interface{}
InstanceShutdownTimeout() *float64
SetInstanceShutdownTimeout(val *float64)
InstanceShutdownTimeoutInput() *float64
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LoadBasedAutoScaling() OpsworksHaproxyLayerLoadBasedAutoScalingOutputReference
LoadBasedAutoScalingInput() *OpsworksHaproxyLayerLoadBasedAutoScaling
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
StackId() *string
SetStackId(val *string)
StackIdInput() *string
StatsEnabled() interface{}
SetStatsEnabled(val interface{})
StatsEnabledInput() interface{}
StatsPassword() *string
SetStatsPassword(val *string)
StatsPasswordInput() *string
StatsUrl() *string
SetStatsUrl(val *string)
StatsUrlInput() *string
StatsUser() *string
SetStatsUser(val *string)
StatsUserInput() *string
SystemPackages() *[]*string
SetSystemPackages(val *[]*string)
SystemPackagesInput() *[]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
UseEbsOptimizedInstances() interface{}
SetUseEbsOptimizedInstances(val interface{})
UseEbsOptimizedInstancesInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCloudwatchConfiguration(value *OpsworksHaproxyLayerCloudwatchConfiguration)
PutEbsVolume(value interface{})
PutLoadBasedAutoScaling(value *OpsworksHaproxyLayerLoadBasedAutoScaling)
ResetAutoAssignElasticIps()
ResetAutoAssignPublicIps()
ResetAutoHealing()
ResetCloudwatchConfiguration()
ResetCustomConfigureRecipes()
ResetCustomDeployRecipes()
ResetCustomInstanceProfileArn()
ResetCustomJson()
ResetCustomSecurityGroupIds()
ResetCustomSetupRecipes()
ResetCustomShutdownRecipes()
ResetCustomUndeployRecipes()
ResetDrainElbOnShutdown()
ResetEbsVolume()
ResetElasticLoadBalancer()
ResetHealthcheckMethod()
ResetHealthcheckUrl()
ResetId()
ResetInstallUpdatesOnBoot()
ResetInstanceShutdownTimeout()
ResetLoadBasedAutoScaling()
ResetName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetStatsEnabled()
ResetStatsUrl()
ResetStatsUser()
ResetSystemPackages()
ResetTags()
ResetTagsAll()
ResetUseEbsOptimizedInstances()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer aws_opsworks_haproxy_layer}.
func NewOpsworksHaproxyLayer ¶
func NewOpsworksHaproxyLayer(scope constructs.Construct, id *string, config *OpsworksHaproxyLayerConfig) OpsworksHaproxyLayer
Create a new {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer aws_opsworks_haproxy_layer} Resource.
type OpsworksHaproxyLayerCloudwatchConfiguration ¶
type OpsworksHaproxyLayerCloudwatchConfiguration struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#enabled OpsworksHaproxyLayer#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// log_streams block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#log_streams OpsworksHaproxyLayer#log_streams}
LogStreams interface{} `field:"optional" json:"logStreams" yaml:"logStreams"`
}
type OpsworksHaproxyLayerCloudwatchConfigurationLogStreams ¶
type OpsworksHaproxyLayerCloudwatchConfigurationLogStreams struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#file OpsworksHaproxyLayer#file}.
File *string `field:"required" json:"file" yaml:"file"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#log_group_name OpsworksHaproxyLayer#log_group_name}.
LogGroupName *string `field:"required" json:"logGroupName" yaml:"logGroupName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#batch_count OpsworksHaproxyLayer#batch_count}.
BatchCount *float64 `field:"optional" json:"batchCount" yaml:"batchCount"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#batch_size OpsworksHaproxyLayer#batch_size}.
BatchSize *float64 `field:"optional" json:"batchSize" yaml:"batchSize"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#buffer_duration OpsworksHaproxyLayer#buffer_duration}.
BufferDuration *float64 `field:"optional" json:"bufferDuration" yaml:"bufferDuration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#datetime_format OpsworksHaproxyLayer#datetime_format}.
DatetimeFormat *string `field:"optional" json:"datetimeFormat" yaml:"datetimeFormat"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#encoding OpsworksHaproxyLayer#encoding}.
Encoding *string `field:"optional" json:"encoding" yaml:"encoding"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#file_fingerprint_lines OpsworksHaproxyLayer#file_fingerprint_lines}.
FileFingerprintLines *string `field:"optional" json:"fileFingerprintLines" yaml:"fileFingerprintLines"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#initial_position OpsworksHaproxyLayer#initial_position}.
InitialPosition *string `field:"optional" json:"initialPosition" yaml:"initialPosition"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#multiline_start_pattern OpsworksHaproxyLayer#multiline_start_pattern}.
MultilineStartPattern *string `field:"optional" json:"multilineStartPattern" yaml:"multilineStartPattern"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#time_zone OpsworksHaproxyLayer#time_zone}.
TimeZone *string `field:"optional" json:"timeZone" yaml:"timeZone"`
}
type OpsworksHaproxyLayerCloudwatchConfigurationLogStreamsList ¶
type OpsworksHaproxyLayerCloudwatchConfigurationLogStreamsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) OpsworksHaproxyLayerCloudwatchConfigurationLogStreamsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksHaproxyLayerCloudwatchConfigurationLogStreamsList ¶
func NewOpsworksHaproxyLayerCloudwatchConfigurationLogStreamsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) OpsworksHaproxyLayerCloudwatchConfigurationLogStreamsList
type OpsworksHaproxyLayerCloudwatchConfigurationLogStreamsOutputReference ¶
type OpsworksHaproxyLayerCloudwatchConfigurationLogStreamsOutputReference interface {
cdktf.ComplexObject
BatchCount() *float64
SetBatchCount(val *float64)
BatchCountInput() *float64
BatchSize() *float64
SetBatchSize(val *float64)
BatchSizeInput() *float64
BufferDuration() *float64
SetBufferDuration(val *float64)
BufferDurationInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DatetimeFormat() *string
SetDatetimeFormat(val *string)
DatetimeFormatInput() *string
Encoding() *string
SetEncoding(val *string)
EncodingInput() *string
File() *string
SetFile(val *string)
FileFingerprintLines() *string
SetFileFingerprintLines(val *string)
FileFingerprintLinesInput() *string
FileInput() *string
// Experimental.
Fqn() *string
InitialPosition() *string
SetInitialPosition(val *string)
InitialPositionInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
LogGroupName() *string
SetLogGroupName(val *string)
LogGroupNameInput() *string
MultilineStartPattern() *string
SetMultilineStartPattern(val *string)
MultilineStartPatternInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TimeZone() *string
SetTimeZone(val *string)
TimeZoneInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBatchCount()
ResetBatchSize()
ResetBufferDuration()
ResetDatetimeFormat()
ResetEncoding()
ResetFileFingerprintLines()
ResetInitialPosition()
ResetMultilineStartPattern()
ResetTimeZone()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksHaproxyLayerCloudwatchConfigurationLogStreamsOutputReference ¶
func NewOpsworksHaproxyLayerCloudwatchConfigurationLogStreamsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) OpsworksHaproxyLayerCloudwatchConfigurationLogStreamsOutputReference
type OpsworksHaproxyLayerCloudwatchConfigurationOutputReference ¶
type OpsworksHaproxyLayerCloudwatchConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *OpsworksHaproxyLayerCloudwatchConfiguration
SetInternalValue(val *OpsworksHaproxyLayerCloudwatchConfiguration)
LogStreams() OpsworksHaproxyLayerCloudwatchConfigurationLogStreamsList
LogStreamsInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutLogStreams(value interface{})
ResetEnabled()
ResetLogStreams()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksHaproxyLayerCloudwatchConfigurationOutputReference ¶
func NewOpsworksHaproxyLayerCloudwatchConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpsworksHaproxyLayerCloudwatchConfigurationOutputReference
type OpsworksHaproxyLayerConfig ¶
type OpsworksHaproxyLayerConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#stack_id OpsworksHaproxyLayer#stack_id}.
StackId *string `field:"required" json:"stackId" yaml:"stackId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#stats_password OpsworksHaproxyLayer#stats_password}.
StatsPassword *string `field:"required" json:"statsPassword" yaml:"statsPassword"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#auto_assign_elastic_ips OpsworksHaproxyLayer#auto_assign_elastic_ips}.
AutoAssignElasticIps interface{} `field:"optional" json:"autoAssignElasticIps" yaml:"autoAssignElasticIps"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#auto_assign_public_ips OpsworksHaproxyLayer#auto_assign_public_ips}.
AutoAssignPublicIps interface{} `field:"optional" json:"autoAssignPublicIps" yaml:"autoAssignPublicIps"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#auto_healing OpsworksHaproxyLayer#auto_healing}.
AutoHealing interface{} `field:"optional" json:"autoHealing" yaml:"autoHealing"`
// cloudwatch_configuration block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#cloudwatch_configuration OpsworksHaproxyLayer#cloudwatch_configuration}
CloudwatchConfiguration *OpsworksHaproxyLayerCloudwatchConfiguration `field:"optional" json:"cloudwatchConfiguration" yaml:"cloudwatchConfiguration"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#custom_configure_recipes OpsworksHaproxyLayer#custom_configure_recipes}.
CustomConfigureRecipes *[]*string `field:"optional" json:"customConfigureRecipes" yaml:"customConfigureRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#custom_deploy_recipes OpsworksHaproxyLayer#custom_deploy_recipes}.
CustomDeployRecipes *[]*string `field:"optional" json:"customDeployRecipes" yaml:"customDeployRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#custom_instance_profile_arn OpsworksHaproxyLayer#custom_instance_profile_arn}.
CustomInstanceProfileArn *string `field:"optional" json:"customInstanceProfileArn" yaml:"customInstanceProfileArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#custom_json OpsworksHaproxyLayer#custom_json}.
CustomJson *string `field:"optional" json:"customJson" yaml:"customJson"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#custom_security_group_ids OpsworksHaproxyLayer#custom_security_group_ids}.
CustomSecurityGroupIds *[]*string `field:"optional" json:"customSecurityGroupIds" yaml:"customSecurityGroupIds"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#custom_setup_recipes OpsworksHaproxyLayer#custom_setup_recipes}.
CustomSetupRecipes *[]*string `field:"optional" json:"customSetupRecipes" yaml:"customSetupRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#custom_shutdown_recipes OpsworksHaproxyLayer#custom_shutdown_recipes}.
CustomShutdownRecipes *[]*string `field:"optional" json:"customShutdownRecipes" yaml:"customShutdownRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#custom_undeploy_recipes OpsworksHaproxyLayer#custom_undeploy_recipes}.
CustomUndeployRecipes *[]*string `field:"optional" json:"customUndeployRecipes" yaml:"customUndeployRecipes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#drain_elb_on_shutdown OpsworksHaproxyLayer#drain_elb_on_shutdown}.
DrainElbOnShutdown interface{} `field:"optional" json:"drainElbOnShutdown" yaml:"drainElbOnShutdown"`
// ebs_volume block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#ebs_volume OpsworksHaproxyLayer#ebs_volume}
EbsVolume interface{} `field:"optional" json:"ebsVolume" yaml:"ebsVolume"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#elastic_load_balancer OpsworksHaproxyLayer#elastic_load_balancer}.
ElasticLoadBalancer *string `field:"optional" json:"elasticLoadBalancer" yaml:"elasticLoadBalancer"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#healthcheck_method OpsworksHaproxyLayer#healthcheck_method}.
HealthcheckMethod *string `field:"optional" json:"healthcheckMethod" yaml:"healthcheckMethod"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#healthcheck_url OpsworksHaproxyLayer#healthcheck_url}.
HealthcheckUrl *string `field:"optional" json:"healthcheckUrl" yaml:"healthcheckUrl"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#id OpsworksHaproxyLayer#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#install_updates_on_boot OpsworksHaproxyLayer#install_updates_on_boot}.
InstallUpdatesOnBoot interface{} `field:"optional" json:"installUpdatesOnBoot" yaml:"installUpdatesOnBoot"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#instance_shutdown_timeout OpsworksHaproxyLayer#instance_shutdown_timeout}.
InstanceShutdownTimeout *float64 `field:"optional" json:"instanceShutdownTimeout" yaml:"instanceShutdownTimeout"`
// load_based_auto_scaling block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#load_based_auto_scaling OpsworksHaproxyLayer#load_based_auto_scaling}
LoadBasedAutoScaling *OpsworksHaproxyLayerLoadBasedAutoScaling `field:"optional" json:"loadBasedAutoScaling" yaml:"loadBasedAutoScaling"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#name OpsworksHaproxyLayer#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#stats_enabled OpsworksHaproxyLayer#stats_enabled}.
StatsEnabled interface{} `field:"optional" json:"statsEnabled" yaml:"statsEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#stats_url OpsworksHaproxyLayer#stats_url}.
StatsUrl *string `field:"optional" json:"statsUrl" yaml:"statsUrl"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#stats_user OpsworksHaproxyLayer#stats_user}.
StatsUser *string `field:"optional" json:"statsUser" yaml:"statsUser"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#system_packages OpsworksHaproxyLayer#system_packages}.
SystemPackages *[]*string `field:"optional" json:"systemPackages" yaml:"systemPackages"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#tags OpsworksHaproxyLayer#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#tags_all OpsworksHaproxyLayer#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#use_ebs_optimized_instances OpsworksHaproxyLayer#use_ebs_optimized_instances}.
UseEbsOptimizedInstances interface{} `field:"optional" json:"useEbsOptimizedInstances" yaml:"useEbsOptimizedInstances"`
}
type OpsworksHaproxyLayerEbsVolume ¶
type OpsworksHaproxyLayerEbsVolume struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#mount_point OpsworksHaproxyLayer#mount_point}.
MountPoint *string `field:"required" json:"mountPoint" yaml:"mountPoint"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#number_of_disks OpsworksHaproxyLayer#number_of_disks}.
NumberOfDisks *float64 `field:"required" json:"numberOfDisks" yaml:"numberOfDisks"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#size OpsworksHaproxyLayer#size}.
Size *float64 `field:"required" json:"size" yaml:"size"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#encrypted OpsworksHaproxyLayer#encrypted}.
Encrypted interface{} `field:"optional" json:"encrypted" yaml:"encrypted"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#iops OpsworksHaproxyLayer#iops}.
Iops *float64 `field:"optional" json:"iops" yaml:"iops"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#raid_level OpsworksHaproxyLayer#raid_level}.
RaidLevel *string `field:"optional" json:"raidLevel" yaml:"raidLevel"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#type OpsworksHaproxyLayer#type}.
Type *string `field:"optional" json:"type" yaml:"type"`
}
type OpsworksHaproxyLayerEbsVolumeList ¶
type OpsworksHaproxyLayerEbsVolumeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) OpsworksHaproxyLayerEbsVolumeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksHaproxyLayerEbsVolumeList ¶
func NewOpsworksHaproxyLayerEbsVolumeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) OpsworksHaproxyLayerEbsVolumeList
type OpsworksHaproxyLayerEbsVolumeOutputReference ¶
type OpsworksHaproxyLayerEbsVolumeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Encrypted() interface{}
SetEncrypted(val interface{})
EncryptedInput() interface{}
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Iops() *float64
SetIops(val *float64)
IopsInput() *float64
MountPoint() *string
SetMountPoint(val *string)
MountPointInput() *string
NumberOfDisks() *float64
SetNumberOfDisks(val *float64)
NumberOfDisksInput() *float64
RaidLevel() *string
SetRaidLevel(val *string)
RaidLevelInput() *string
Size() *float64
SetSize(val *float64)
SizeInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEncrypted()
ResetIops()
ResetRaidLevel()
ResetType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksHaproxyLayerEbsVolumeOutputReference ¶
func NewOpsworksHaproxyLayerEbsVolumeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) OpsworksHaproxyLayerEbsVolumeOutputReference
type OpsworksHaproxyLayerLoadBasedAutoScaling ¶
type OpsworksHaproxyLayerLoadBasedAutoScaling struct {
// downscaling block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#downscaling OpsworksHaproxyLayer#downscaling}
Downscaling *OpsworksHaproxyLayerLoadBasedAutoScalingDownscaling `field:"optional" json:"downscaling" yaml:"downscaling"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#enable OpsworksHaproxyLayer#enable}.
Enable interface{} `field:"optional" json:"enable" yaml:"enable"`
// upscaling block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#upscaling OpsworksHaproxyLayer#upscaling}
Upscaling *OpsworksHaproxyLayerLoadBasedAutoScalingUpscaling `field:"optional" json:"upscaling" yaml:"upscaling"`
}
type OpsworksHaproxyLayerLoadBasedAutoScalingDownscaling ¶
type OpsworksHaproxyLayerLoadBasedAutoScalingDownscaling struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#alarms OpsworksHaproxyLayer#alarms}.
Alarms *[]*string `field:"optional" json:"alarms" yaml:"alarms"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#cpu_threshold OpsworksHaproxyLayer#cpu_threshold}.
CpuThreshold *float64 `field:"optional" json:"cpuThreshold" yaml:"cpuThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#ignore_metrics_time OpsworksHaproxyLayer#ignore_metrics_time}.
IgnoreMetricsTime *float64 `field:"optional" json:"ignoreMetricsTime" yaml:"ignoreMetricsTime"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#instance_count OpsworksHaproxyLayer#instance_count}.
InstanceCount *float64 `field:"optional" json:"instanceCount" yaml:"instanceCount"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#load_threshold OpsworksHaproxyLayer#load_threshold}.
LoadThreshold *float64 `field:"optional" json:"loadThreshold" yaml:"loadThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#memory_threshold OpsworksHaproxyLayer#memory_threshold}.
MemoryThreshold *float64 `field:"optional" json:"memoryThreshold" yaml:"memoryThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#thresholds_wait_time OpsworksHaproxyLayer#thresholds_wait_time}.
ThresholdsWaitTime *float64 `field:"optional" json:"thresholdsWaitTime" yaml:"thresholdsWaitTime"`
}
type OpsworksHaproxyLayerLoadBasedAutoScalingDownscalingOutputReference ¶
type OpsworksHaproxyLayerLoadBasedAutoScalingDownscalingOutputReference interface {
cdktf.ComplexObject
Alarms() *[]*string
SetAlarms(val *[]*string)
AlarmsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CpuThreshold() *float64
SetCpuThreshold(val *float64)
CpuThresholdInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IgnoreMetricsTime() *float64
SetIgnoreMetricsTime(val *float64)
IgnoreMetricsTimeInput() *float64
InstanceCount() *float64
SetInstanceCount(val *float64)
InstanceCountInput() *float64
InternalValue() *OpsworksHaproxyLayerLoadBasedAutoScalingDownscaling
SetInternalValue(val *OpsworksHaproxyLayerLoadBasedAutoScalingDownscaling)
LoadThreshold() *float64
SetLoadThreshold(val *float64)
LoadThresholdInput() *float64
MemoryThreshold() *float64
SetMemoryThreshold(val *float64)
MemoryThresholdInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ThresholdsWaitTime() *float64
SetThresholdsWaitTime(val *float64)
ThresholdsWaitTimeInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAlarms()
ResetCpuThreshold()
ResetIgnoreMetricsTime()
ResetInstanceCount()
ResetLoadThreshold()
ResetMemoryThreshold()
ResetThresholdsWaitTime()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksHaproxyLayerLoadBasedAutoScalingDownscalingOutputReference ¶
func NewOpsworksHaproxyLayerLoadBasedAutoScalingDownscalingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpsworksHaproxyLayerLoadBasedAutoScalingDownscalingOutputReference
type OpsworksHaproxyLayerLoadBasedAutoScalingOutputReference ¶
type OpsworksHaproxyLayerLoadBasedAutoScalingOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Downscaling() OpsworksHaproxyLayerLoadBasedAutoScalingDownscalingOutputReference
DownscalingInput() *OpsworksHaproxyLayerLoadBasedAutoScalingDownscaling
Enable() interface{}
SetEnable(val interface{})
EnableInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *OpsworksHaproxyLayerLoadBasedAutoScaling
SetInternalValue(val *OpsworksHaproxyLayerLoadBasedAutoScaling)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Upscaling() OpsworksHaproxyLayerLoadBasedAutoScalingUpscalingOutputReference
UpscalingInput() *OpsworksHaproxyLayerLoadBasedAutoScalingUpscaling
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutDownscaling(value *OpsworksHaproxyLayerLoadBasedAutoScalingDownscaling)
PutUpscaling(value *OpsworksHaproxyLayerLoadBasedAutoScalingUpscaling)
ResetDownscaling()
ResetEnable()
ResetUpscaling()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksHaproxyLayerLoadBasedAutoScalingOutputReference ¶
func NewOpsworksHaproxyLayerLoadBasedAutoScalingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpsworksHaproxyLayerLoadBasedAutoScalingOutputReference
type OpsworksHaproxyLayerLoadBasedAutoScalingUpscaling ¶
type OpsworksHaproxyLayerLoadBasedAutoScalingUpscaling struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#alarms OpsworksHaproxyLayer#alarms}.
Alarms *[]*string `field:"optional" json:"alarms" yaml:"alarms"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#cpu_threshold OpsworksHaproxyLayer#cpu_threshold}.
CpuThreshold *float64 `field:"optional" json:"cpuThreshold" yaml:"cpuThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#ignore_metrics_time OpsworksHaproxyLayer#ignore_metrics_time}.
IgnoreMetricsTime *float64 `field:"optional" json:"ignoreMetricsTime" yaml:"ignoreMetricsTime"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#instance_count OpsworksHaproxyLayer#instance_count}.
InstanceCount *float64 `field:"optional" json:"instanceCount" yaml:"instanceCount"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#load_threshold OpsworksHaproxyLayer#load_threshold}.
LoadThreshold *float64 `field:"optional" json:"loadThreshold" yaml:"loadThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#memory_threshold OpsworksHaproxyLayer#memory_threshold}.
MemoryThreshold *float64 `field:"optional" json:"memoryThreshold" yaml:"memoryThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/opsworks_haproxy_layer#thresholds_wait_time OpsworksHaproxyLayer#thresholds_wait_time}.
ThresholdsWaitTime *float64 `field:"optional" json:"thresholdsWaitTime" yaml:"thresholdsWaitTime"`
}
type OpsworksHaproxyLayerLoadBasedAutoScalingUpscalingOutputReference ¶
type OpsworksHaproxyLayerLoadBasedAutoScalingUpscalingOutputReference interface {
cdktf.ComplexObject
Alarms() *[]*string
SetAlarms(val *[]*string)
AlarmsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CpuThreshold() *float64
SetCpuThreshold(val *float64)
CpuThresholdInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IgnoreMetricsTime() *float64
SetIgnoreMetricsTime(val *float64)
IgnoreMetricsTimeInput() *float64
InstanceCount() *float64
SetInstanceCount(val *float64)
InstanceCountInput() *float64
InternalValue() *OpsworksHaproxyLayerLoadBasedAutoScalingUpscaling
SetInternalValue(val *OpsworksHaproxyLayerLoadBasedAutoScalingUpscaling)
LoadThreshold() *float64
SetLoadThreshold(val *float64)
LoadThresholdInput() *float64
MemoryThreshold() *float64
SetMemoryThreshold(val *float64)
MemoryThresholdInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ThresholdsWaitTime() *float64
SetThresholdsWaitTime(val *float64)
ThresholdsWaitTimeInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAlarms()
ResetCpuThreshold()
ResetIgnoreMetricsTime()
ResetInstanceCount()
ResetLoadThreshold()
ResetMemoryThreshold()
ResetThresholdsWaitTime()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpsworksHaproxyLayerLoadBasedAutoScalingUpscalingOutputReference ¶
func NewOpsworksHaproxyLayerLoadBasedAutoScalingUpscalingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpsworksHaproxyLayerLoadBasedAutoScalingUpscalingOutputReference
Source Files
¶
- OpsworksHaproxyLayer.go
- OpsworksHaproxyLayerCloudwatchConfiguration.go
- OpsworksHaproxyLayerCloudwatchConfigurationLogStreams.go
- OpsworksHaproxyLayerCloudwatchConfigurationLogStreamsList.go
- OpsworksHaproxyLayerCloudwatchConfigurationLogStreamsList__checks.go
- OpsworksHaproxyLayerCloudwatchConfigurationLogStreamsOutputReference.go
- OpsworksHaproxyLayerCloudwatchConfigurationLogStreamsOutputReference__checks.go
- OpsworksHaproxyLayerCloudwatchConfigurationOutputReference.go
- OpsworksHaproxyLayerCloudwatchConfigurationOutputReference__checks.go
- OpsworksHaproxyLayerConfig.go
- OpsworksHaproxyLayerEbsVolume.go
- OpsworksHaproxyLayerEbsVolumeList.go
- OpsworksHaproxyLayerEbsVolumeList__checks.go
- OpsworksHaproxyLayerEbsVolumeOutputReference.go
- OpsworksHaproxyLayerEbsVolumeOutputReference__checks.go
- OpsworksHaproxyLayerLoadBasedAutoScaling.go
- OpsworksHaproxyLayerLoadBasedAutoScalingDownscaling.go
- OpsworksHaproxyLayerLoadBasedAutoScalingDownscalingOutputReference.go
- OpsworksHaproxyLayerLoadBasedAutoScalingDownscalingOutputReference__checks.go
- OpsworksHaproxyLayerLoadBasedAutoScalingOutputReference.go
- OpsworksHaproxyLayerLoadBasedAutoScalingOutputReference__checks.go
- OpsworksHaproxyLayerLoadBasedAutoScalingUpscaling.go
- OpsworksHaproxyLayerLoadBasedAutoScalingUpscalingOutputReference.go
- OpsworksHaproxyLayerLoadBasedAutoScalingUpscalingOutputReference__checks.go
- OpsworksHaproxyLayer__checks.go
- main.go