Documentation
¶
Index ¶
- func NewPipesPipeSourceParametersFilterCriteriaFilterList_Override(p PipesPipeSourceParametersFilterCriteriaFilterList, ...)
- func NewPipesPipeSourceParametersFilterCriteriaFilterOutputReference_Override(p PipesPipeSourceParametersFilterCriteriaFilterOutputReference, ...)
- func NewPipesPipeSourceParametersFilterCriteriaOutputReference_Override(p PipesPipeSourceParametersFilterCriteriaOutputReference, ...)
- func NewPipesPipeSourceParametersOutputReference_Override(p PipesPipeSourceParametersOutputReference, ...)
- func NewPipesPipeTargetParametersOutputReference_Override(p PipesPipeTargetParametersOutputReference, ...)
- func NewPipesPipeTimeoutsOutputReference_Override(p PipesPipeTimeoutsOutputReference, ...)
- func NewPipesPipe_Override(p PipesPipe, scope constructs.Construct, id *string, config *PipesPipeConfig)
- func PipesPipe_IsConstruct(x interface{}) *bool
- func PipesPipe_IsTerraformElement(x interface{}) *bool
- func PipesPipe_IsTerraformResource(x interface{}) *bool
- func PipesPipe_TfResourceType() *string
- type PipesPipe
- type PipesPipeConfig
- type PipesPipeSourceParameters
- type PipesPipeSourceParametersFilterCriteria
- type PipesPipeSourceParametersFilterCriteriaFilter
- type PipesPipeSourceParametersFilterCriteriaFilterList
- type PipesPipeSourceParametersFilterCriteriaFilterOutputReference
- type PipesPipeSourceParametersFilterCriteriaOutputReference
- type PipesPipeSourceParametersOutputReference
- type PipesPipeTargetParameters
- type PipesPipeTargetParametersOutputReference
- type PipesPipeTimeouts
- type PipesPipeTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewPipesPipeSourceParametersFilterCriteriaFilterList_Override ¶
func NewPipesPipeSourceParametersFilterCriteriaFilterList_Override(p PipesPipeSourceParametersFilterCriteriaFilterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewPipesPipeSourceParametersFilterCriteriaFilterOutputReference_Override ¶
func NewPipesPipeSourceParametersFilterCriteriaFilterOutputReference_Override(p PipesPipeSourceParametersFilterCriteriaFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewPipesPipeSourceParametersFilterCriteriaOutputReference_Override ¶
func NewPipesPipeSourceParametersFilterCriteriaOutputReference_Override(p PipesPipeSourceParametersFilterCriteriaOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewPipesPipeSourceParametersOutputReference_Override ¶
func NewPipesPipeSourceParametersOutputReference_Override(p PipesPipeSourceParametersOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewPipesPipeTargetParametersOutputReference_Override ¶
func NewPipesPipeTargetParametersOutputReference_Override(p PipesPipeTargetParametersOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewPipesPipeTimeoutsOutputReference_Override ¶
func NewPipesPipeTimeoutsOutputReference_Override(p PipesPipeTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewPipesPipe_Override ¶
func NewPipesPipe_Override(p PipesPipe, scope constructs.Construct, id *string, config *PipesPipeConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe aws_pipes_pipe} Resource.
func PipesPipe_IsConstruct ¶
func PipesPipe_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func PipesPipe_IsTerraformElement ¶
func PipesPipe_IsTerraformElement(x interface{}) *bool
Experimental.
func PipesPipe_IsTerraformResource ¶
func PipesPipe_IsTerraformResource(x interface{}) *bool
Experimental.
func PipesPipe_TfResourceType ¶
func PipesPipe_TfResourceType() *string
Types ¶
type PipesPipe ¶
type PipesPipe interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DesiredState() *string
SetDesiredState(val *string)
DesiredStateInput() *string
Enrichment() *string
SetEnrichment(val *string)
EnrichmentInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
NamePrefix() *string
SetNamePrefix(val *string)
NamePrefixInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
Source() *string
SetSource(val *string)
SourceInput() *string
SourceParameters() PipesPipeSourceParametersOutputReference
SourceParametersInput() *PipesPipeSourceParameters
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
Target() *string
SetTarget(val *string)
TargetInput() *string
TargetParameters() PipesPipeTargetParametersOutputReference
TargetParametersInput() *PipesPipeTargetParameters
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() PipesPipeTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutSourceParameters(value *PipesPipeSourceParameters)
PutTargetParameters(value *PipesPipeTargetParameters)
PutTimeouts(value *PipesPipeTimeouts)
ResetDescription()
ResetDesiredState()
ResetEnrichment()
ResetId()
ResetName()
ResetNamePrefix()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe aws_pipes_pipe}.
func NewPipesPipe ¶
func NewPipesPipe(scope constructs.Construct, id *string, config *PipesPipeConfig) PipesPipe
Create a new {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe aws_pipes_pipe} Resource.
type PipesPipeConfig ¶
type PipesPipeConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#role_arn PipesPipe#role_arn}.
RoleArn *string `field:"required" json:"roleArn" yaml:"roleArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#source PipesPipe#source}.
Source *string `field:"required" json:"source" yaml:"source"`
// source_parameters block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#source_parameters PipesPipe#source_parameters}
SourceParameters *PipesPipeSourceParameters `field:"required" json:"sourceParameters" yaml:"sourceParameters"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#target PipesPipe#target}.
Target *string `field:"required" json:"target" yaml:"target"`
// target_parameters block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#target_parameters PipesPipe#target_parameters}
TargetParameters *PipesPipeTargetParameters `field:"required" json:"targetParameters" yaml:"targetParameters"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#description PipesPipe#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#desired_state PipesPipe#desired_state}.
DesiredState *string `field:"optional" json:"desiredState" yaml:"desiredState"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#enrichment PipesPipe#enrichment}.
Enrichment *string `field:"optional" json:"enrichment" yaml:"enrichment"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#id PipesPipe#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#name PipesPipe#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#name_prefix PipesPipe#name_prefix}.
NamePrefix *string `field:"optional" json:"namePrefix" yaml:"namePrefix"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#tags PipesPipe#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#tags_all PipesPipe#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#timeouts PipesPipe#timeouts}
Timeouts *PipesPipeTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type PipesPipeSourceParameters ¶
type PipesPipeSourceParameters struct {
// filter_criteria block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#filter_criteria PipesPipe#filter_criteria}
FilterCriteria *PipesPipeSourceParametersFilterCriteria `field:"optional" json:"filterCriteria" yaml:"filterCriteria"`
}
type PipesPipeSourceParametersFilterCriteria ¶
type PipesPipeSourceParametersFilterCriteria struct {
// filter block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#filter PipesPipe#filter}
Filter interface{} `field:"optional" json:"filter" yaml:"filter"`
}
type PipesPipeSourceParametersFilterCriteriaFilter ¶
type PipesPipeSourceParametersFilterCriteriaFilter struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#pattern PipesPipe#pattern}.
Pattern *string `field:"required" json:"pattern" yaml:"pattern"`
}
type PipesPipeSourceParametersFilterCriteriaFilterList ¶
type PipesPipeSourceParametersFilterCriteriaFilterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) PipesPipeSourceParametersFilterCriteriaFilterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewPipesPipeSourceParametersFilterCriteriaFilterList ¶
func NewPipesPipeSourceParametersFilterCriteriaFilterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) PipesPipeSourceParametersFilterCriteriaFilterList
type PipesPipeSourceParametersFilterCriteriaFilterOutputReference ¶
type PipesPipeSourceParametersFilterCriteriaFilterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Pattern() *string
SetPattern(val *string)
PatternInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewPipesPipeSourceParametersFilterCriteriaFilterOutputReference ¶
func NewPipesPipeSourceParametersFilterCriteriaFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) PipesPipeSourceParametersFilterCriteriaFilterOutputReference
type PipesPipeSourceParametersFilterCriteriaOutputReference ¶
type PipesPipeSourceParametersFilterCriteriaOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Filter() PipesPipeSourceParametersFilterCriteriaFilterList
FilterInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *PipesPipeSourceParametersFilterCriteria
SetInternalValue(val *PipesPipeSourceParametersFilterCriteria)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutFilter(value interface{})
ResetFilter()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewPipesPipeSourceParametersFilterCriteriaOutputReference ¶
func NewPipesPipeSourceParametersFilterCriteriaOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) PipesPipeSourceParametersFilterCriteriaOutputReference
type PipesPipeSourceParametersOutputReference ¶
type PipesPipeSourceParametersOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FilterCriteria() PipesPipeSourceParametersFilterCriteriaOutputReference
FilterCriteriaInput() *PipesPipeSourceParametersFilterCriteria
// Experimental.
Fqn() *string
InternalValue() *PipesPipeSourceParameters
SetInternalValue(val *PipesPipeSourceParameters)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutFilterCriteria(value *PipesPipeSourceParametersFilterCriteria)
ResetFilterCriteria()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewPipesPipeSourceParametersOutputReference ¶
func NewPipesPipeSourceParametersOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) PipesPipeSourceParametersOutputReference
type PipesPipeTargetParameters ¶
type PipesPipeTargetParameters struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#input_template PipesPipe#input_template}.
InputTemplate *string `field:"optional" json:"inputTemplate" yaml:"inputTemplate"`
}
type PipesPipeTargetParametersOutputReference ¶
type PipesPipeTargetParametersOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InputTemplate() *string
SetInputTemplate(val *string)
InputTemplateInput() *string
InternalValue() *PipesPipeTargetParameters
SetInternalValue(val *PipesPipeTargetParameters)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetInputTemplate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewPipesPipeTargetParametersOutputReference ¶
func NewPipesPipeTargetParametersOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) PipesPipeTargetParametersOutputReference
type PipesPipeTimeouts ¶
type PipesPipeTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#create PipesPipe#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#delete PipesPipe#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/pipes_pipe#update PipesPipe#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type PipesPipeTimeoutsOutputReference ¶
type PipesPipeTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewPipesPipeTimeoutsOutputReference ¶
func NewPipesPipeTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) PipesPipeTimeoutsOutputReference
Source Files
¶
- PipesPipe.go
- PipesPipeConfig.go
- PipesPipeSourceParameters.go
- PipesPipeSourceParametersFilterCriteria.go
- PipesPipeSourceParametersFilterCriteriaFilter.go
- PipesPipeSourceParametersFilterCriteriaFilterList.go
- PipesPipeSourceParametersFilterCriteriaFilterList__checks.go
- PipesPipeSourceParametersFilterCriteriaFilterOutputReference.go
- PipesPipeSourceParametersFilterCriteriaFilterOutputReference__checks.go
- PipesPipeSourceParametersFilterCriteriaOutputReference.go
- PipesPipeSourceParametersFilterCriteriaOutputReference__checks.go
- PipesPipeSourceParametersOutputReference.go
- PipesPipeSourceParametersOutputReference__checks.go
- PipesPipeTargetParameters.go
- PipesPipeTargetParametersOutputReference.go
- PipesPipeTargetParametersOutputReference__checks.go
- PipesPipeTimeouts.go
- PipesPipeTimeoutsOutputReference.go
- PipesPipeTimeoutsOutputReference__checks.go
- PipesPipe__checks.go
- main.go