Documentation
¶
Index ¶
- func NewRoute53HealthCheck_Override(r Route53HealthCheck, scope constructs.Construct, id *string, ...)
- func Route53HealthCheck_IsConstruct(x interface{}) *bool
- func Route53HealthCheck_IsTerraformElement(x interface{}) *bool
- func Route53HealthCheck_IsTerraformResource(x interface{}) *bool
- func Route53HealthCheck_TfResourceType() *string
- type Route53HealthCheck
- type Route53HealthCheckConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRoute53HealthCheck_Override ¶
func NewRoute53HealthCheck_Override(r Route53HealthCheck, scope constructs.Construct, id *string, config *Route53HealthCheckConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check aws_route53_health_check} Resource.
func Route53HealthCheck_IsConstruct ¶
func Route53HealthCheck_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func Route53HealthCheck_IsTerraformElement ¶
func Route53HealthCheck_IsTerraformElement(x interface{}) *bool
Experimental.
func Route53HealthCheck_IsTerraformResource ¶
func Route53HealthCheck_IsTerraformResource(x interface{}) *bool
Experimental.
func Route53HealthCheck_TfResourceType ¶
func Route53HealthCheck_TfResourceType() *string
Types ¶
type Route53HealthCheck ¶
type Route53HealthCheck interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ChildHealthchecks() *[]*string
SetChildHealthchecks(val *[]*string)
ChildHealthchecksInput() *[]*string
ChildHealthThreshold() *float64
SetChildHealthThreshold(val *float64)
ChildHealthThresholdInput() *float64
CloudwatchAlarmName() *string
SetCloudwatchAlarmName(val *string)
CloudwatchAlarmNameInput() *string
CloudwatchAlarmRegion() *string
SetCloudwatchAlarmRegion(val *string)
CloudwatchAlarmRegionInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Disabled() interface{}
SetDisabled(val interface{})
DisabledInput() interface{}
EnableSni() interface{}
SetEnableSni(val interface{})
EnableSniInput() interface{}
FailureThreshold() *float64
SetFailureThreshold(val *float64)
FailureThresholdInput() *float64
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
Fqdn() *string
SetFqdn(val *string)
FqdnInput() *string
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InsufficientDataHealthStatus() *string
SetInsufficientDataHealthStatus(val *string)
InsufficientDataHealthStatusInput() *string
InvertHealthcheck() interface{}
SetInvertHealthcheck(val interface{})
InvertHealthcheckInput() interface{}
IpAddress() *string
SetIpAddress(val *string)
IpAddressInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MeasureLatency() interface{}
SetMeasureLatency(val interface{})
MeasureLatencyInput() interface{}
// The tree node.
Node() constructs.Node
Port() *float64
SetPort(val *float64)
PortInput() *float64
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ReferenceName() *string
SetReferenceName(val *string)
ReferenceNameInput() *string
Regions() *[]*string
SetRegions(val *[]*string)
RegionsInput() *[]*string
RequestInterval() *float64
SetRequestInterval(val *float64)
RequestIntervalInput() *float64
ResourcePath() *string
SetResourcePath(val *string)
ResourcePathInput() *string
RoutingControlArn() *string
SetRoutingControlArn(val *string)
RoutingControlArnInput() *string
SearchString() *string
SetSearchString(val *string)
SearchStringInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetChildHealthchecks()
ResetChildHealthThreshold()
ResetCloudwatchAlarmName()
ResetCloudwatchAlarmRegion()
ResetDisabled()
ResetEnableSni()
ResetFailureThreshold()
ResetFqdn()
ResetId()
ResetInsufficientDataHealthStatus()
ResetInvertHealthcheck()
ResetIpAddress()
ResetMeasureLatency()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPort()
ResetReferenceName()
ResetRegions()
ResetRequestInterval()
ResetResourcePath()
ResetRoutingControlArn()
ResetSearchString()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check aws_route53_health_check}.
func NewRoute53HealthCheck ¶
func NewRoute53HealthCheck(scope constructs.Construct, id *string, config *Route53HealthCheckConfig) Route53HealthCheck
Create a new {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check aws_route53_health_check} Resource.
type Route53HealthCheckConfig ¶
type Route53HealthCheckConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#type Route53HealthCheck#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#child_healthchecks Route53HealthCheck#child_healthchecks}.
ChildHealthchecks *[]*string `field:"optional" json:"childHealthchecks" yaml:"childHealthchecks"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#child_health_threshold Route53HealthCheck#child_health_threshold}.
ChildHealthThreshold *float64 `field:"optional" json:"childHealthThreshold" yaml:"childHealthThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#cloudwatch_alarm_name Route53HealthCheck#cloudwatch_alarm_name}.
CloudwatchAlarmName *string `field:"optional" json:"cloudwatchAlarmName" yaml:"cloudwatchAlarmName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#cloudwatch_alarm_region Route53HealthCheck#cloudwatch_alarm_region}.
CloudwatchAlarmRegion *string `field:"optional" json:"cloudwatchAlarmRegion" yaml:"cloudwatchAlarmRegion"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#disabled Route53HealthCheck#disabled}.
Disabled interface{} `field:"optional" json:"disabled" yaml:"disabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#enable_sni Route53HealthCheck#enable_sni}.
EnableSni interface{} `field:"optional" json:"enableSni" yaml:"enableSni"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#failure_threshold Route53HealthCheck#failure_threshold}.
FailureThreshold *float64 `field:"optional" json:"failureThreshold" yaml:"failureThreshold"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#fqdn Route53HealthCheck#fqdn}.
Fqdn *string `field:"optional" json:"fqdn" yaml:"fqdn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#id Route53HealthCheck#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#insufficient_data_health_status Route53HealthCheck#insufficient_data_health_status}.
InsufficientDataHealthStatus *string `field:"optional" json:"insufficientDataHealthStatus" yaml:"insufficientDataHealthStatus"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#invert_healthcheck Route53HealthCheck#invert_healthcheck}.
InvertHealthcheck interface{} `field:"optional" json:"invertHealthcheck" yaml:"invertHealthcheck"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#ip_address Route53HealthCheck#ip_address}.
IpAddress *string `field:"optional" json:"ipAddress" yaml:"ipAddress"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#measure_latency Route53HealthCheck#measure_latency}.
MeasureLatency interface{} `field:"optional" json:"measureLatency" yaml:"measureLatency"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#port Route53HealthCheck#port}.
Port *float64 `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#reference_name Route53HealthCheck#reference_name}.
ReferenceName *string `field:"optional" json:"referenceName" yaml:"referenceName"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#regions Route53HealthCheck#regions}.
Regions *[]*string `field:"optional" json:"regions" yaml:"regions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#request_interval Route53HealthCheck#request_interval}.
RequestInterval *float64 `field:"optional" json:"requestInterval" yaml:"requestInterval"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#resource_path Route53HealthCheck#resource_path}.
ResourcePath *string `field:"optional" json:"resourcePath" yaml:"resourcePath"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#routing_control_arn Route53HealthCheck#routing_control_arn}.
RoutingControlArn *string `field:"optional" json:"routingControlArn" yaml:"routingControlArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#search_string Route53HealthCheck#search_string}.
SearchString *string `field:"optional" json:"searchString" yaml:"searchString"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#tags Route53HealthCheck#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route53_health_check#tags_all Route53HealthCheck#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}