Documentation
¶
Index ¶
- func NewS3BucketInventoryDestinationBucketEncryptionOutputReference_Override(s S3BucketInventoryDestinationBucketEncryptionOutputReference, ...)
- func NewS3BucketInventoryDestinationBucketEncryptionSseKmsOutputReference_Override(s S3BucketInventoryDestinationBucketEncryptionSseKmsOutputReference, ...)
- func NewS3BucketInventoryDestinationBucketEncryptionSseS3OutputReference_Override(s S3BucketInventoryDestinationBucketEncryptionSseS3OutputReference, ...)
- func NewS3BucketInventoryDestinationBucketOutputReference_Override(s S3BucketInventoryDestinationBucketOutputReference, ...)
- func NewS3BucketInventoryDestinationOutputReference_Override(s S3BucketInventoryDestinationOutputReference, ...)
- func NewS3BucketInventoryFilterOutputReference_Override(s S3BucketInventoryFilterOutputReference, ...)
- func NewS3BucketInventoryScheduleOutputReference_Override(s S3BucketInventoryScheduleOutputReference, ...)
- func NewS3BucketInventory_Override(s S3BucketInventory, scope constructs.Construct, id *string, ...)
- func S3BucketInventory_IsConstruct(x interface{}) *bool
- func S3BucketInventory_IsTerraformElement(x interface{}) *bool
- func S3BucketInventory_IsTerraformResource(x interface{}) *bool
- func S3BucketInventory_TfResourceType() *string
- type S3BucketInventory
- type S3BucketInventoryConfig
- type S3BucketInventoryDestination
- type S3BucketInventoryDestinationBucket
- type S3BucketInventoryDestinationBucketEncryption
- type S3BucketInventoryDestinationBucketEncryptionOutputReference
- type S3BucketInventoryDestinationBucketEncryptionSseKms
- type S3BucketInventoryDestinationBucketEncryptionSseKmsOutputReference
- type S3BucketInventoryDestinationBucketEncryptionSseS3
- type S3BucketInventoryDestinationBucketEncryptionSseS3OutputReference
- type S3BucketInventoryDestinationBucketOutputReference
- type S3BucketInventoryDestinationOutputReference
- type S3BucketInventoryFilter
- type S3BucketInventoryFilterOutputReference
- type S3BucketInventorySchedule
- type S3BucketInventoryScheduleOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewS3BucketInventoryDestinationBucketEncryptionOutputReference_Override ¶
func NewS3BucketInventoryDestinationBucketEncryptionOutputReference_Override(s S3BucketInventoryDestinationBucketEncryptionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketInventoryDestinationBucketEncryptionSseKmsOutputReference_Override ¶
func NewS3BucketInventoryDestinationBucketEncryptionSseKmsOutputReference_Override(s S3BucketInventoryDestinationBucketEncryptionSseKmsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketInventoryDestinationBucketEncryptionSseS3OutputReference_Override ¶
func NewS3BucketInventoryDestinationBucketEncryptionSseS3OutputReference_Override(s S3BucketInventoryDestinationBucketEncryptionSseS3OutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketInventoryDestinationBucketOutputReference_Override ¶
func NewS3BucketInventoryDestinationBucketOutputReference_Override(s S3BucketInventoryDestinationBucketOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketInventoryDestinationOutputReference_Override ¶
func NewS3BucketInventoryDestinationOutputReference_Override(s S3BucketInventoryDestinationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketInventoryFilterOutputReference_Override ¶
func NewS3BucketInventoryFilterOutputReference_Override(s S3BucketInventoryFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketInventoryScheduleOutputReference_Override ¶
func NewS3BucketInventoryScheduleOutputReference_Override(s S3BucketInventoryScheduleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewS3BucketInventory_Override ¶
func NewS3BucketInventory_Override(s S3BucketInventory, scope constructs.Construct, id *string, config *S3BucketInventoryConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory aws_s3_bucket_inventory} Resource.
func S3BucketInventory_IsConstruct ¶
func S3BucketInventory_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func S3BucketInventory_IsTerraformElement ¶
func S3BucketInventory_IsTerraformElement(x interface{}) *bool
Experimental.
func S3BucketInventory_IsTerraformResource ¶
func S3BucketInventory_IsTerraformResource(x interface{}) *bool
Experimental.
func S3BucketInventory_TfResourceType ¶
func S3BucketInventory_TfResourceType() *string
Types ¶
type S3BucketInventory ¶
type S3BucketInventory interface {
cdktf.TerraformResource
Bucket() *string
SetBucket(val *string)
BucketInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Destination() S3BucketInventoryDestinationOutputReference
DestinationInput() *S3BucketInventoryDestination
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
Filter() S3BucketInventoryFilterOutputReference
FilterInput() *S3BucketInventoryFilter
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IncludedObjectVersions() *string
SetIncludedObjectVersions(val *string)
IncludedObjectVersionsInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
OptionalFields() *[]*string
SetOptionalFields(val *[]*string)
OptionalFieldsInput() *[]*string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Schedule() S3BucketInventoryScheduleOutputReference
ScheduleInput() *S3BucketInventorySchedule
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDestination(value *S3BucketInventoryDestination)
PutFilter(value *S3BucketInventoryFilter)
PutSchedule(value *S3BucketInventorySchedule)
ResetEnabled()
ResetFilter()
ResetId()
ResetOptionalFields()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory aws_s3_bucket_inventory}.
func NewS3BucketInventory ¶
func NewS3BucketInventory(scope constructs.Construct, id *string, config *S3BucketInventoryConfig) S3BucketInventory
Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory aws_s3_bucket_inventory} Resource.
type S3BucketInventoryConfig ¶
type S3BucketInventoryConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#bucket S3BucketInventory#bucket}.
Bucket *string `field:"required" json:"bucket" yaml:"bucket"`
// destination block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#destination S3BucketInventory#destination}
Destination *S3BucketInventoryDestination `field:"required" json:"destination" yaml:"destination"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#included_object_versions S3BucketInventory#included_object_versions}.
IncludedObjectVersions *string `field:"required" json:"includedObjectVersions" yaml:"includedObjectVersions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#name S3BucketInventory#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// schedule block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#schedule S3BucketInventory#schedule}
Schedule *S3BucketInventorySchedule `field:"required" json:"schedule" yaml:"schedule"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#enabled S3BucketInventory#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// filter block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#filter S3BucketInventory#filter}
Filter *S3BucketInventoryFilter `field:"optional" json:"filter" yaml:"filter"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#id S3BucketInventory#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#optional_fields S3BucketInventory#optional_fields}.
OptionalFields *[]*string `field:"optional" json:"optionalFields" yaml:"optionalFields"`
}
type S3BucketInventoryDestination ¶
type S3BucketInventoryDestination struct {
// bucket block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#bucket S3BucketInventory#bucket}
Bucket *S3BucketInventoryDestinationBucket `field:"required" json:"bucket" yaml:"bucket"`
}
type S3BucketInventoryDestinationBucket ¶
type S3BucketInventoryDestinationBucket struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#bucket_arn S3BucketInventory#bucket_arn}.
BucketArn *string `field:"required" json:"bucketArn" yaml:"bucketArn"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#format S3BucketInventory#format}.
Format *string `field:"required" json:"format" yaml:"format"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#account_id S3BucketInventory#account_id}.
AccountId *string `field:"optional" json:"accountId" yaml:"accountId"`
// encryption block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#encryption S3BucketInventory#encryption}
Encryption *S3BucketInventoryDestinationBucketEncryption `field:"optional" json:"encryption" yaml:"encryption"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#prefix S3BucketInventory#prefix}.
Prefix *string `field:"optional" json:"prefix" yaml:"prefix"`
}
type S3BucketInventoryDestinationBucketEncryption ¶
type S3BucketInventoryDestinationBucketEncryption struct {
// sse_kms block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#sse_kms S3BucketInventory#sse_kms}
SseKms *S3BucketInventoryDestinationBucketEncryptionSseKms `field:"optional" json:"sseKms" yaml:"sseKms"`
// sse_s3 block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#sse_s3 S3BucketInventory#sse_s3}
SseS3 *S3BucketInventoryDestinationBucketEncryptionSseS3 `field:"optional" json:"sseS3" yaml:"sseS3"`
}
type S3BucketInventoryDestinationBucketEncryptionOutputReference ¶
type S3BucketInventoryDestinationBucketEncryptionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *S3BucketInventoryDestinationBucketEncryption
SetInternalValue(val *S3BucketInventoryDestinationBucketEncryption)
SseKms() S3BucketInventoryDestinationBucketEncryptionSseKmsOutputReference
SseKmsInput() *S3BucketInventoryDestinationBucketEncryptionSseKms
SseS3() S3BucketInventoryDestinationBucketEncryptionSseS3OutputReference
SseS3Input() *S3BucketInventoryDestinationBucketEncryptionSseS3
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutSseKms(value *S3BucketInventoryDestinationBucketEncryptionSseKms)
PutSseS3(value *S3BucketInventoryDestinationBucketEncryptionSseS3)
ResetSseKms()
ResetSseS3()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketInventoryDestinationBucketEncryptionOutputReference ¶
func NewS3BucketInventoryDestinationBucketEncryptionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketInventoryDestinationBucketEncryptionOutputReference
type S3BucketInventoryDestinationBucketEncryptionSseKms ¶
type S3BucketInventoryDestinationBucketEncryptionSseKms struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#key_id S3BucketInventory#key_id}.
KeyId *string `field:"required" json:"keyId" yaml:"keyId"`
}
type S3BucketInventoryDestinationBucketEncryptionSseKmsOutputReference ¶
type S3BucketInventoryDestinationBucketEncryptionSseKmsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *S3BucketInventoryDestinationBucketEncryptionSseKms
SetInternalValue(val *S3BucketInventoryDestinationBucketEncryptionSseKms)
KeyId() *string
SetKeyId(val *string)
KeyIdInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketInventoryDestinationBucketEncryptionSseKmsOutputReference ¶
func NewS3BucketInventoryDestinationBucketEncryptionSseKmsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketInventoryDestinationBucketEncryptionSseKmsOutputReference
type S3BucketInventoryDestinationBucketEncryptionSseS3 ¶
type S3BucketInventoryDestinationBucketEncryptionSseS3 struct {
}
type S3BucketInventoryDestinationBucketEncryptionSseS3OutputReference ¶
type S3BucketInventoryDestinationBucketEncryptionSseS3OutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *S3BucketInventoryDestinationBucketEncryptionSseS3
SetInternalValue(val *S3BucketInventoryDestinationBucketEncryptionSseS3)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketInventoryDestinationBucketEncryptionSseS3OutputReference ¶
func NewS3BucketInventoryDestinationBucketEncryptionSseS3OutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketInventoryDestinationBucketEncryptionSseS3OutputReference
type S3BucketInventoryDestinationBucketOutputReference ¶
type S3BucketInventoryDestinationBucketOutputReference interface {
cdktf.ComplexObject
AccountId() *string
SetAccountId(val *string)
AccountIdInput() *string
BucketArn() *string
SetBucketArn(val *string)
BucketArnInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Encryption() S3BucketInventoryDestinationBucketEncryptionOutputReference
EncryptionInput() *S3BucketInventoryDestinationBucketEncryption
Format() *string
SetFormat(val *string)
FormatInput() *string
// Experimental.
Fqn() *string
InternalValue() *S3BucketInventoryDestinationBucket
SetInternalValue(val *S3BucketInventoryDestinationBucket)
Prefix() *string
SetPrefix(val *string)
PrefixInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutEncryption(value *S3BucketInventoryDestinationBucketEncryption)
ResetAccountId()
ResetEncryption()
ResetPrefix()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketInventoryDestinationBucketOutputReference ¶
func NewS3BucketInventoryDestinationBucketOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketInventoryDestinationBucketOutputReference
type S3BucketInventoryDestinationOutputReference ¶
type S3BucketInventoryDestinationOutputReference interface {
cdktf.ComplexObject
Bucket() S3BucketInventoryDestinationBucketOutputReference
BucketInput() *S3BucketInventoryDestinationBucket
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *S3BucketInventoryDestination
SetInternalValue(val *S3BucketInventoryDestination)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutBucket(value *S3BucketInventoryDestinationBucket)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketInventoryDestinationOutputReference ¶
func NewS3BucketInventoryDestinationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketInventoryDestinationOutputReference
type S3BucketInventoryFilter ¶
type S3BucketInventoryFilter struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#prefix S3BucketInventory#prefix}.
Prefix *string `field:"optional" json:"prefix" yaml:"prefix"`
}
type S3BucketInventoryFilterOutputReference ¶
type S3BucketInventoryFilterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *S3BucketInventoryFilter
SetInternalValue(val *S3BucketInventoryFilter)
Prefix() *string
SetPrefix(val *string)
PrefixInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetPrefix()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketInventoryFilterOutputReference ¶
func NewS3BucketInventoryFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketInventoryFilterOutputReference
type S3BucketInventorySchedule ¶
type S3BucketInventorySchedule struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory#frequency S3BucketInventory#frequency}.
Frequency *string `field:"required" json:"frequency" yaml:"frequency"`
}
type S3BucketInventoryScheduleOutputReference ¶
type S3BucketInventoryScheduleOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Frequency() *string
SetFrequency(val *string)
FrequencyInput() *string
InternalValue() *S3BucketInventorySchedule
SetInternalValue(val *S3BucketInventorySchedule)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3BucketInventoryScheduleOutputReference ¶
func NewS3BucketInventoryScheduleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) S3BucketInventoryScheduleOutputReference
Source Files
¶
- S3BucketInventory.go
- S3BucketInventoryConfig.go
- S3BucketInventoryDestination.go
- S3BucketInventoryDestinationBucket.go
- S3BucketInventoryDestinationBucketEncryption.go
- S3BucketInventoryDestinationBucketEncryptionOutputReference.go
- S3BucketInventoryDestinationBucketEncryptionOutputReference__checks.go
- S3BucketInventoryDestinationBucketEncryptionSseKms.go
- S3BucketInventoryDestinationBucketEncryptionSseKmsOutputReference.go
- S3BucketInventoryDestinationBucketEncryptionSseKmsOutputReference__checks.go
- S3BucketInventoryDestinationBucketEncryptionSseS3.go
- S3BucketInventoryDestinationBucketEncryptionSseS3OutputReference.go
- S3BucketInventoryDestinationBucketEncryptionSseS3OutputReference__checks.go
- S3BucketInventoryDestinationBucketOutputReference.go
- S3BucketInventoryDestinationBucketOutputReference__checks.go
- S3BucketInventoryDestinationOutputReference.go
- S3BucketInventoryDestinationOutputReference__checks.go
- S3BucketInventoryFilter.go
- S3BucketInventoryFilterOutputReference.go
- S3BucketInventoryFilterOutputReference__checks.go
- S3BucketInventorySchedule.go
- S3BucketInventoryScheduleOutputReference.go
- S3BucketInventoryScheduleOutputReference__checks.go
- S3BucketInventory__checks.go
- main.go