Documentation
¶
Index ¶
- func NewS3Object_Override(s S3Object, scope constructs.Construct, id *string, config *S3ObjectConfig)
- func S3Object_IsConstruct(x interface{}) *bool
- func S3Object_IsTerraformElement(x interface{}) *bool
- func S3Object_IsTerraformResource(x interface{}) *bool
- func S3Object_TfResourceType() *string
- type S3Object
- type S3ObjectConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewS3Object_Override ¶
func NewS3Object_Override(s S3Object, scope constructs.Construct, id *string, config *S3ObjectConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_object aws_s3_object} Resource.
func S3Object_IsConstruct ¶
func S3Object_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func S3Object_IsTerraformElement ¶
func S3Object_IsTerraformElement(x interface{}) *bool
Experimental.
func S3Object_IsTerraformResource ¶
func S3Object_IsTerraformResource(x interface{}) *bool
Experimental.
func S3Object_TfResourceType ¶
func S3Object_TfResourceType() *string
Types ¶
type S3Object ¶
type S3Object interface {
cdktf.TerraformResource
Acl() *string
SetAcl(val *string)
AclInput() *string
Bucket() *string
SetBucket(val *string)
BucketInput() *string
BucketKeyEnabled() interface{}
SetBucketKeyEnabled(val interface{})
BucketKeyEnabledInput() interface{}
CacheControl() *string
SetCacheControl(val *string)
CacheControlInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
Content() *string
SetContent(val *string)
ContentBase64() *string
SetContentBase64(val *string)
ContentBase64Input() *string
ContentDisposition() *string
SetContentDisposition(val *string)
ContentDispositionInput() *string
ContentEncoding() *string
SetContentEncoding(val *string)
ContentEncodingInput() *string
ContentInput() *string
ContentLanguage() *string
SetContentLanguage(val *string)
ContentLanguageInput() *string
ContentType() *string
SetContentType(val *string)
ContentTypeInput() *string
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Etag() *string
SetEtag(val *string)
EtagInput() *string
ForceDestroy() interface{}
SetForceDestroy(val interface{})
ForceDestroyInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Key() *string
SetKey(val *string)
KeyInput() *string
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Metadata() *map[string]*string
SetMetadata(val *map[string]*string)
MetadataInput() *map[string]*string
// The tree node.
Node() constructs.Node
ObjectLockLegalHoldStatus() *string
SetObjectLockLegalHoldStatus(val *string)
ObjectLockLegalHoldStatusInput() *string
ObjectLockMode() *string
SetObjectLockMode(val *string)
ObjectLockModeInput() *string
ObjectLockRetainUntilDate() *string
SetObjectLockRetainUntilDate(val *string)
ObjectLockRetainUntilDateInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ServerSideEncryption() *string
SetServerSideEncryption(val *string)
ServerSideEncryptionInput() *string
Source() *string
SetSource(val *string)
SourceHash() *string
SetSourceHash(val *string)
SourceHashInput() *string
SourceInput() *string
StorageClass() *string
SetStorageClass(val *string)
StorageClassInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
VersionId() *string
WebsiteRedirect() *string
SetWebsiteRedirect(val *string)
WebsiteRedirectInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetAcl()
ResetBucketKeyEnabled()
ResetCacheControl()
ResetContent()
ResetContentBase64()
ResetContentDisposition()
ResetContentEncoding()
ResetContentLanguage()
ResetContentType()
ResetEtag()
ResetForceDestroy()
ResetId()
ResetKmsKeyId()
ResetMetadata()
ResetObjectLockLegalHoldStatus()
ResetObjectLockMode()
ResetObjectLockRetainUntilDate()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetServerSideEncryption()
ResetSource()
ResetSourceHash()
ResetStorageClass()
ResetTags()
ResetTagsAll()
ResetWebsiteRedirect()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_object aws_s3_object}.
func NewS3Object ¶
func NewS3Object(scope constructs.Construct, id *string, config *S3ObjectConfig) S3Object
Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_object aws_s3_object} Resource.
type S3ObjectConfig ¶
type S3ObjectConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#bucket S3Object#bucket}.
Bucket *string `field:"required" json:"bucket" yaml:"bucket"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#key S3Object#key}.
Key *string `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#acl S3Object#acl}.
Acl *string `field:"optional" json:"acl" yaml:"acl"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#bucket_key_enabled S3Object#bucket_key_enabled}.
BucketKeyEnabled interface{} `field:"optional" json:"bucketKeyEnabled" yaml:"bucketKeyEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#cache_control S3Object#cache_control}.
CacheControl *string `field:"optional" json:"cacheControl" yaml:"cacheControl"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#content S3Object#content}.
Content *string `field:"optional" json:"content" yaml:"content"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#content_base64 S3Object#content_base64}.
ContentBase64 *string `field:"optional" json:"contentBase64" yaml:"contentBase64"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#content_disposition S3Object#content_disposition}.
ContentDisposition *string `field:"optional" json:"contentDisposition" yaml:"contentDisposition"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#content_encoding S3Object#content_encoding}.
ContentEncoding *string `field:"optional" json:"contentEncoding" yaml:"contentEncoding"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#content_language S3Object#content_language}.
ContentLanguage *string `field:"optional" json:"contentLanguage" yaml:"contentLanguage"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#content_type S3Object#content_type}.
ContentType *string `field:"optional" json:"contentType" yaml:"contentType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#etag S3Object#etag}.
Etag *string `field:"optional" json:"etag" yaml:"etag"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#force_destroy S3Object#force_destroy}.
ForceDestroy interface{} `field:"optional" json:"forceDestroy" yaml:"forceDestroy"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#id S3Object#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#kms_key_id S3Object#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#metadata S3Object#metadata}.
Metadata *map[string]*string `field:"optional" json:"metadata" yaml:"metadata"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#object_lock_legal_hold_status S3Object#object_lock_legal_hold_status}.
ObjectLockLegalHoldStatus *string `field:"optional" json:"objectLockLegalHoldStatus" yaml:"objectLockLegalHoldStatus"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#object_lock_mode S3Object#object_lock_mode}.
ObjectLockMode *string `field:"optional" json:"objectLockMode" yaml:"objectLockMode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#object_lock_retain_until_date S3Object#object_lock_retain_until_date}.
ObjectLockRetainUntilDate *string `field:"optional" json:"objectLockRetainUntilDate" yaml:"objectLockRetainUntilDate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#server_side_encryption S3Object#server_side_encryption}.
ServerSideEncryption *string `field:"optional" json:"serverSideEncryption" yaml:"serverSideEncryption"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#source S3Object#source}.
Source *string `field:"optional" json:"source" yaml:"source"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#source_hash S3Object#source_hash}.
SourceHash *string `field:"optional" json:"sourceHash" yaml:"sourceHash"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#storage_class S3Object#storage_class}.
StorageClass *string `field:"optional" json:"storageClass" yaml:"storageClass"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#tags S3Object#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#tags_all S3Object#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object#website_redirect S3Object#website_redirect}.
WebsiteRedirect *string `field:"optional" json:"websiteRedirect" yaml:"websiteRedirect"`
}