Documentation
¶
Index ¶
- func NewS3ObjectCopyGrantList_Override(s S3ObjectCopyGrantList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewS3ObjectCopyGrantOutputReference_Override(s S3ObjectCopyGrantOutputReference, ...)
- func NewS3ObjectCopy_Override(s S3ObjectCopy, scope constructs.Construct, id *string, ...)
- func S3ObjectCopy_IsConstruct(x interface{}) *bool
- func S3ObjectCopy_IsTerraformElement(x interface{}) *bool
- func S3ObjectCopy_IsTerraformResource(x interface{}) *bool
- func S3ObjectCopy_TfResourceType() *string
- type S3ObjectCopy
- type S3ObjectCopyConfig
- type S3ObjectCopyGrant
- type S3ObjectCopyGrantList
- type S3ObjectCopyGrantOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewS3ObjectCopyGrantList_Override ¶
func NewS3ObjectCopyGrantList_Override(s S3ObjectCopyGrantList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewS3ObjectCopyGrantOutputReference_Override ¶
func NewS3ObjectCopyGrantOutputReference_Override(s S3ObjectCopyGrantOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewS3ObjectCopy_Override ¶
func NewS3ObjectCopy_Override(s S3ObjectCopy, scope constructs.Construct, id *string, config *S3ObjectCopyConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy aws_s3_object_copy} Resource.
func S3ObjectCopy_IsConstruct ¶
func S3ObjectCopy_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func S3ObjectCopy_IsTerraformElement ¶
func S3ObjectCopy_IsTerraformElement(x interface{}) *bool
Experimental.
func S3ObjectCopy_IsTerraformResource ¶
func S3ObjectCopy_IsTerraformResource(x interface{}) *bool
Experimental.
func S3ObjectCopy_TfResourceType ¶
func S3ObjectCopy_TfResourceType() *string
Types ¶
type S3ObjectCopy ¶
type S3ObjectCopy interface {
cdktf.TerraformResource
Acl() *string
SetAcl(val *string)
AclInput() *string
Bucket() *string
SetBucket(val *string)
BucketInput() *string
BucketKeyEnabled() interface{}
SetBucketKeyEnabled(val interface{})
BucketKeyEnabledInput() interface{}
CacheControl() *string
SetCacheControl(val *string)
CacheControlInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ContentDisposition() *string
SetContentDisposition(val *string)
ContentDispositionInput() *string
ContentEncoding() *string
SetContentEncoding(val *string)
ContentEncodingInput() *string
ContentLanguage() *string
SetContentLanguage(val *string)
ContentLanguageInput() *string
ContentType() *string
SetContentType(val *string)
ContentTypeInput() *string
CopyIfMatch() *string
SetCopyIfMatch(val *string)
CopyIfMatchInput() *string
CopyIfModifiedSince() *string
SetCopyIfModifiedSince(val *string)
CopyIfModifiedSinceInput() *string
CopyIfNoneMatch() *string
SetCopyIfNoneMatch(val *string)
CopyIfNoneMatchInput() *string
CopyIfUnmodifiedSince() *string
SetCopyIfUnmodifiedSince(val *string)
CopyIfUnmodifiedSinceInput() *string
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
CustomerAlgorithm() *string
SetCustomerAlgorithm(val *string)
CustomerAlgorithmInput() *string
CustomerKey() *string
SetCustomerKey(val *string)
CustomerKeyInput() *string
CustomerKeyMd5() *string
SetCustomerKeyMd5(val *string)
CustomerKeyMd5Input() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Etag() *string
ExpectedBucketOwner() *string
SetExpectedBucketOwner(val *string)
ExpectedBucketOwnerInput() *string
ExpectedSourceBucketOwner() *string
SetExpectedSourceBucketOwner(val *string)
ExpectedSourceBucketOwnerInput() *string
Expiration() *string
Expires() *string
SetExpires(val *string)
ExpiresInput() *string
ForceDestroy() interface{}
SetForceDestroy(val interface{})
ForceDestroyInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Grant() S3ObjectCopyGrantList
GrantInput() interface{}
Id() *string
SetId(val *string)
IdInput() *string
Key() *string
SetKey(val *string)
KeyInput() *string
KmsEncryptionContext() *string
SetKmsEncryptionContext(val *string)
KmsEncryptionContextInput() *string
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
LastModified() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Metadata() *map[string]*string
SetMetadata(val *map[string]*string)
MetadataDirective() *string
SetMetadataDirective(val *string)
MetadataDirectiveInput() *string
MetadataInput() *map[string]*string
// The tree node.
Node() constructs.Node
ObjectLockLegalHoldStatus() *string
SetObjectLockLegalHoldStatus(val *string)
ObjectLockLegalHoldStatusInput() *string
ObjectLockMode() *string
SetObjectLockMode(val *string)
ObjectLockModeInput() *string
ObjectLockRetainUntilDate() *string
SetObjectLockRetainUntilDate(val *string)
ObjectLockRetainUntilDateInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RequestCharged() cdktf.IResolvable
RequestPayer() *string
SetRequestPayer(val *string)
RequestPayerInput() *string
ServerSideEncryption() *string
SetServerSideEncryption(val *string)
ServerSideEncryptionInput() *string
Source() *string
SetSource(val *string)
SourceCustomerAlgorithm() *string
SetSourceCustomerAlgorithm(val *string)
SourceCustomerAlgorithmInput() *string
SourceCustomerKey() *string
SetSourceCustomerKey(val *string)
SourceCustomerKeyInput() *string
SourceCustomerKeyMd5() *string
SetSourceCustomerKeyMd5(val *string)
SourceCustomerKeyMd5Input() *string
SourceInput() *string
SourceVersionId() *string
StorageClass() *string
SetStorageClass(val *string)
StorageClassInput() *string
TaggingDirective() *string
SetTaggingDirective(val *string)
TaggingDirectiveInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
VersionId() *string
WebsiteRedirect() *string
SetWebsiteRedirect(val *string)
WebsiteRedirectInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutGrant(value interface{})
ResetAcl()
ResetBucketKeyEnabled()
ResetCacheControl()
ResetContentDisposition()
ResetContentEncoding()
ResetContentLanguage()
ResetContentType()
ResetCopyIfMatch()
ResetCopyIfModifiedSince()
ResetCopyIfNoneMatch()
ResetCopyIfUnmodifiedSince()
ResetCustomerAlgorithm()
ResetCustomerKey()
ResetCustomerKeyMd5()
ResetExpectedBucketOwner()
ResetExpectedSourceBucketOwner()
ResetExpires()
ResetForceDestroy()
ResetGrant()
ResetId()
ResetKmsEncryptionContext()
ResetKmsKeyId()
ResetMetadata()
ResetMetadataDirective()
ResetObjectLockLegalHoldStatus()
ResetObjectLockMode()
ResetObjectLockRetainUntilDate()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRequestPayer()
ResetServerSideEncryption()
ResetSourceCustomerAlgorithm()
ResetSourceCustomerKey()
ResetSourceCustomerKeyMd5()
ResetStorageClass()
ResetTaggingDirective()
ResetTags()
ResetTagsAll()
ResetWebsiteRedirect()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy aws_s3_object_copy}.
func NewS3ObjectCopy ¶
func NewS3ObjectCopy(scope constructs.Construct, id *string, config *S3ObjectCopyConfig) S3ObjectCopy
Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy aws_s3_object_copy} Resource.
type S3ObjectCopyConfig ¶
type S3ObjectCopyConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#bucket S3ObjectCopy#bucket}.
Bucket *string `field:"required" json:"bucket" yaml:"bucket"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#key S3ObjectCopy#key}.
Key *string `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#source S3ObjectCopy#source}.
Source *string `field:"required" json:"source" yaml:"source"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#acl S3ObjectCopy#acl}.
Acl *string `field:"optional" json:"acl" yaml:"acl"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#bucket_key_enabled S3ObjectCopy#bucket_key_enabled}.
BucketKeyEnabled interface{} `field:"optional" json:"bucketKeyEnabled" yaml:"bucketKeyEnabled"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#cache_control S3ObjectCopy#cache_control}.
CacheControl *string `field:"optional" json:"cacheControl" yaml:"cacheControl"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#content_disposition S3ObjectCopy#content_disposition}.
ContentDisposition *string `field:"optional" json:"contentDisposition" yaml:"contentDisposition"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#content_encoding S3ObjectCopy#content_encoding}.
ContentEncoding *string `field:"optional" json:"contentEncoding" yaml:"contentEncoding"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#content_language S3ObjectCopy#content_language}.
ContentLanguage *string `field:"optional" json:"contentLanguage" yaml:"contentLanguage"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#content_type S3ObjectCopy#content_type}.
ContentType *string `field:"optional" json:"contentType" yaml:"contentType"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#copy_if_match S3ObjectCopy#copy_if_match}.
CopyIfMatch *string `field:"optional" json:"copyIfMatch" yaml:"copyIfMatch"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#copy_if_modified_since S3ObjectCopy#copy_if_modified_since}.
CopyIfModifiedSince *string `field:"optional" json:"copyIfModifiedSince" yaml:"copyIfModifiedSince"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#copy_if_none_match S3ObjectCopy#copy_if_none_match}.
CopyIfNoneMatch *string `field:"optional" json:"copyIfNoneMatch" yaml:"copyIfNoneMatch"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#copy_if_unmodified_since S3ObjectCopy#copy_if_unmodified_since}.
CopyIfUnmodifiedSince *string `field:"optional" json:"copyIfUnmodifiedSince" yaml:"copyIfUnmodifiedSince"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#customer_algorithm S3ObjectCopy#customer_algorithm}.
CustomerAlgorithm *string `field:"optional" json:"customerAlgorithm" yaml:"customerAlgorithm"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#customer_key S3ObjectCopy#customer_key}.
CustomerKey *string `field:"optional" json:"customerKey" yaml:"customerKey"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#customer_key_md5 S3ObjectCopy#customer_key_md5}.
CustomerKeyMd5 *string `field:"optional" json:"customerKeyMd5" yaml:"customerKeyMd5"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#expected_bucket_owner S3ObjectCopy#expected_bucket_owner}.
ExpectedBucketOwner *string `field:"optional" json:"expectedBucketOwner" yaml:"expectedBucketOwner"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#expected_source_bucket_owner S3ObjectCopy#expected_source_bucket_owner}.
ExpectedSourceBucketOwner *string `field:"optional" json:"expectedSourceBucketOwner" yaml:"expectedSourceBucketOwner"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#expires S3ObjectCopy#expires}.
Expires *string `field:"optional" json:"expires" yaml:"expires"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#force_destroy S3ObjectCopy#force_destroy}.
ForceDestroy interface{} `field:"optional" json:"forceDestroy" yaml:"forceDestroy"`
// grant block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#grant S3ObjectCopy#grant}
Grant interface{} `field:"optional" json:"grant" yaml:"grant"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#id S3ObjectCopy#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#kms_encryption_context S3ObjectCopy#kms_encryption_context}.
KmsEncryptionContext *string `field:"optional" json:"kmsEncryptionContext" yaml:"kmsEncryptionContext"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#kms_key_id S3ObjectCopy#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#metadata S3ObjectCopy#metadata}.
Metadata *map[string]*string `field:"optional" json:"metadata" yaml:"metadata"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#metadata_directive S3ObjectCopy#metadata_directive}.
MetadataDirective *string `field:"optional" json:"metadataDirective" yaml:"metadataDirective"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#object_lock_legal_hold_status S3ObjectCopy#object_lock_legal_hold_status}.
ObjectLockLegalHoldStatus *string `field:"optional" json:"objectLockLegalHoldStatus" yaml:"objectLockLegalHoldStatus"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#object_lock_mode S3ObjectCopy#object_lock_mode}.
ObjectLockMode *string `field:"optional" json:"objectLockMode" yaml:"objectLockMode"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#object_lock_retain_until_date S3ObjectCopy#object_lock_retain_until_date}.
ObjectLockRetainUntilDate *string `field:"optional" json:"objectLockRetainUntilDate" yaml:"objectLockRetainUntilDate"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#request_payer S3ObjectCopy#request_payer}.
RequestPayer *string `field:"optional" json:"requestPayer" yaml:"requestPayer"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#server_side_encryption S3ObjectCopy#server_side_encryption}.
ServerSideEncryption *string `field:"optional" json:"serverSideEncryption" yaml:"serverSideEncryption"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#source_customer_algorithm S3ObjectCopy#source_customer_algorithm}.
SourceCustomerAlgorithm *string `field:"optional" json:"sourceCustomerAlgorithm" yaml:"sourceCustomerAlgorithm"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#source_customer_key S3ObjectCopy#source_customer_key}.
SourceCustomerKey *string `field:"optional" json:"sourceCustomerKey" yaml:"sourceCustomerKey"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#source_customer_key_md5 S3ObjectCopy#source_customer_key_md5}.
SourceCustomerKeyMd5 *string `field:"optional" json:"sourceCustomerKeyMd5" yaml:"sourceCustomerKeyMd5"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#storage_class S3ObjectCopy#storage_class}.
StorageClass *string `field:"optional" json:"storageClass" yaml:"storageClass"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#tagging_directive S3ObjectCopy#tagging_directive}.
TaggingDirective *string `field:"optional" json:"taggingDirective" yaml:"taggingDirective"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#tags S3ObjectCopy#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#tags_all S3ObjectCopy#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#website_redirect S3ObjectCopy#website_redirect}.
WebsiteRedirect *string `field:"optional" json:"websiteRedirect" yaml:"websiteRedirect"`
}
type S3ObjectCopyGrant ¶
type S3ObjectCopyGrant struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#permissions S3ObjectCopy#permissions}.
Permissions *[]*string `field:"required" json:"permissions" yaml:"permissions"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#type S3ObjectCopy#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#email S3ObjectCopy#email}.
Email *string `field:"optional" json:"email" yaml:"email"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#id S3ObjectCopy#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy#uri S3ObjectCopy#uri}.
Uri *string `field:"optional" json:"uri" yaml:"uri"`
}
type S3ObjectCopyGrantList ¶
type S3ObjectCopyGrantList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) S3ObjectCopyGrantOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3ObjectCopyGrantList ¶
func NewS3ObjectCopyGrantList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) S3ObjectCopyGrantList
type S3ObjectCopyGrantOutputReference ¶
type S3ObjectCopyGrantOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Email() *string
SetEmail(val *string)
EmailInput() *string
// Experimental.
Fqn() *string
Id() *string
SetId(val *string)
IdInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Permissions() *[]*string
SetPermissions(val *[]*string)
PermissionsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
Uri() *string
SetUri(val *string)
UriInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEmail()
ResetId()
ResetUri()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewS3ObjectCopyGrantOutputReference ¶
func NewS3ObjectCopyGrantOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) S3ObjectCopyGrantOutputReference