Documentation
¶
Index ¶
- func NewStoragegatewaySmbFileShareCacheAttributesOutputReference_Override(s StoragegatewaySmbFileShareCacheAttributesOutputReference, ...)
- func NewStoragegatewaySmbFileShareTimeoutsOutputReference_Override(s StoragegatewaySmbFileShareTimeoutsOutputReference, ...)
- func NewStoragegatewaySmbFileShare_Override(s StoragegatewaySmbFileShare, scope constructs.Construct, id *string, ...)
- func StoragegatewaySmbFileShare_IsConstruct(x interface{}) *bool
- func StoragegatewaySmbFileShare_IsTerraformElement(x interface{}) *bool
- func StoragegatewaySmbFileShare_IsTerraformResource(x interface{}) *bool
- func StoragegatewaySmbFileShare_TfResourceType() *string
- type StoragegatewaySmbFileShare
- type StoragegatewaySmbFileShareCacheAttributes
- type StoragegatewaySmbFileShareCacheAttributesOutputReference
- type StoragegatewaySmbFileShareConfig
- type StoragegatewaySmbFileShareTimeouts
- type StoragegatewaySmbFileShareTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewStoragegatewaySmbFileShareCacheAttributesOutputReference_Override ¶
func NewStoragegatewaySmbFileShareCacheAttributesOutputReference_Override(s StoragegatewaySmbFileShareCacheAttributesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewStoragegatewaySmbFileShareTimeoutsOutputReference_Override ¶
func NewStoragegatewaySmbFileShareTimeoutsOutputReference_Override(s StoragegatewaySmbFileShareTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewStoragegatewaySmbFileShare_Override ¶
func NewStoragegatewaySmbFileShare_Override(s StoragegatewaySmbFileShare, scope constructs.Construct, id *string, config *StoragegatewaySmbFileShareConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share aws_storagegateway_smb_file_share} Resource.
func StoragegatewaySmbFileShare_IsConstruct ¶
func StoragegatewaySmbFileShare_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func StoragegatewaySmbFileShare_IsTerraformElement ¶
func StoragegatewaySmbFileShare_IsTerraformElement(x interface{}) *bool
Experimental.
func StoragegatewaySmbFileShare_IsTerraformResource ¶
func StoragegatewaySmbFileShare_IsTerraformResource(x interface{}) *bool
Experimental.
func StoragegatewaySmbFileShare_TfResourceType ¶
func StoragegatewaySmbFileShare_TfResourceType() *string
Types ¶
type StoragegatewaySmbFileShare ¶
type StoragegatewaySmbFileShare interface {
cdktf.TerraformResource
CdktfStack() cdktf.TerraformStack
Connection() interface{}
SetConnection(val interface{})
ConstructNodeMetadata() *map[string]interface{}
Count() *float64
// Experimental.
DependsOn() *[]*string
// Experimental.
ForEach() cdktf.ITerraformIterator
SetForEach(val cdktf.ITerraformIterator)
Fqn() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
// The tree node.
Provider() cdktf.TerraformProvider
SetProvider(val cdktf.TerraformProvider)
Provisioners() *[]interface{}
SetProvisioners(val *[]interface{})
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformMetaArguments() *map[string]interface{}
// Experimental.
AddOverride(path *string, value interface{})
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ToMetadata() interface{}
ToString() *string
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share aws_storagegateway_smb_file_share}.
func NewStoragegatewaySmbFileShare ¶
func NewStoragegatewaySmbFileShare(scope constructs.Construct, id *string, config *StoragegatewaySmbFileShareConfig) StoragegatewaySmbFileShare
Create a new {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share aws_storagegateway_smb_file_share} Resource.
type StoragegatewaySmbFileShareCacheAttributes ¶
type StoragegatewaySmbFileShareCacheAttributes struct {
CacheStaleTimeoutInSeconds *float64 `field:"optional" json:"cacheStaleTimeoutInSeconds" yaml:"cacheStaleTimeoutInSeconds"`
}
type StoragegatewaySmbFileShareCacheAttributesOutputReference ¶
type StoragegatewaySmbFileShareCacheAttributesOutputReference interface {
cdktf.ComplexObject
// Experimental.
ComplexObjectIndex() interface{}
SetComplexObjectIndex(val interface{})
// Experimental.
ComplexObjectIsFromSet() *bool
SetComplexObjectIsFromSet(val *bool)
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
ComputeFqn() *string
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationAsList() cdktf.IResolvable
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewStoragegatewaySmbFileShareCacheAttributesOutputReference ¶
func NewStoragegatewaySmbFileShareCacheAttributesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) StoragegatewaySmbFileShareCacheAttributesOutputReference
type StoragegatewaySmbFileShareConfig ¶
type StoragegatewaySmbFileShareConfig struct {
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
Count *float64 `field:"optional" json:"count" yaml:"count"`
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
GatewayArn *string `field:"required" json:"gatewayArn" yaml:"gatewayArn"`
LocationArn *string `field:"required" json:"locationArn" yaml:"locationArn"`
RoleArn *string `field:"required" json:"roleArn" yaml:"roleArn"`
AccessBasedEnumeration interface{} `field:"optional" json:"accessBasedEnumeration" yaml:"accessBasedEnumeration"`
AdminUserList *[]*string `field:"optional" json:"adminUserList" yaml:"adminUserList"`
AuditDestinationArn *string `field:"optional" json:"auditDestinationArn" yaml:"auditDestinationArn"`
Authentication *string `field:"optional" json:"authentication" yaml:"authentication"`
BucketRegion *string `field:"optional" json:"bucketRegion" yaml:"bucketRegion"`
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share#cache_attributes StoragegatewaySmbFileShare#cache_attributes}
CacheAttributes *StoragegatewaySmbFileShareCacheAttributes `field:"optional" json:"cacheAttributes" yaml:"cacheAttributes"`
CaseSensitivity *string `field:"optional" json:"caseSensitivity" yaml:"caseSensitivity"`
DefaultStorageClass *string `field:"optional" json:"defaultStorageClass" yaml:"defaultStorageClass"`
FileShareName *string `field:"optional" json:"fileShareName" yaml:"fileShareName"`
GuessMimeTypeEnabled interface{} `field:"optional" json:"guessMimeTypeEnabled" yaml:"guessMimeTypeEnabled"`
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
InvalidUserList *[]*string `field:"optional" json:"invalidUserList" yaml:"invalidUserList"`
KmsEncrypted interface{} `field:"optional" json:"kmsEncrypted" yaml:"kmsEncrypted"`
KmsKeyArn *string `field:"optional" json:"kmsKeyArn" yaml:"kmsKeyArn"`
NotificationPolicy *string `field:"optional" json:"notificationPolicy" yaml:"notificationPolicy"`
ObjectAcl *string `field:"optional" json:"objectAcl" yaml:"objectAcl"`
OplocksEnabled interface{} `field:"optional" json:"oplocksEnabled" yaml:"oplocksEnabled"`
ReadOnly interface{} `field:"optional" json:"readOnly" yaml:"readOnly"`
RequesterPays interface{} `field:"optional" json:"requesterPays" yaml:"requesterPays"`
SmbAclEnabled interface{} `field:"optional" json:"smbAclEnabled" yaml:"smbAclEnabled"`
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share#timeouts StoragegatewaySmbFileShare#timeouts}
Timeouts *StoragegatewaySmbFileShareTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
ValidUserList *[]*string `field:"optional" json:"validUserList" yaml:"validUserList"`
VpcEndpointDnsName *string `field:"optional" json:"vpcEndpointDnsName" yaml:"vpcEndpointDnsName"`
}
type StoragegatewaySmbFileShareTimeoutsOutputReference ¶
type StoragegatewaySmbFileShareTimeoutsOutputReference interface {
cdktf.ComplexObject
// Experimental.
ComplexObjectIndex() interface{}
SetComplexObjectIndex(val interface{})
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
// Experimental.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
ComputeFqn() *string
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationAsList() cdktf.IResolvable
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewStoragegatewaySmbFileShareTimeoutsOutputReference ¶
func NewStoragegatewaySmbFileShareTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) StoragegatewaySmbFileShareTimeoutsOutputReference
Source Files
¶
- StoragegatewaySmbFileShare.go
- StoragegatewaySmbFileShareCacheAttributes.go
- StoragegatewaySmbFileShareCacheAttributesOutputReference.go
- StoragegatewaySmbFileShareCacheAttributesOutputReference__checks.go
- StoragegatewaySmbFileShareConfig.go
- StoragegatewaySmbFileShareTimeouts.go
- StoragegatewaySmbFileShareTimeoutsOutputReference.go
- StoragegatewaySmbFileShareTimeoutsOutputReference__checks.go
- StoragegatewaySmbFileShare__checks.go
- main.go