Documentation
¶
Index ¶
- func NewWafregionalByteMatchSetByteMatchTuplesFieldToMatchOutputReference_Override(w WafregionalByteMatchSetByteMatchTuplesFieldToMatchOutputReference, ...)
- func NewWafregionalByteMatchSetByteMatchTuplesList_Override(w WafregionalByteMatchSetByteMatchTuplesList, ...)
- func NewWafregionalByteMatchSetByteMatchTuplesOutputReference_Override(w WafregionalByteMatchSetByteMatchTuplesOutputReference, ...)
- func NewWafregionalByteMatchSet_Override(w WafregionalByteMatchSet, scope constructs.Construct, id *string, ...)
- func WafregionalByteMatchSet_IsConstruct(x interface{}) *bool
- func WafregionalByteMatchSet_IsTerraformElement(x interface{}) *bool
- func WafregionalByteMatchSet_IsTerraformResource(x interface{}) *bool
- func WafregionalByteMatchSet_TfResourceType() *string
- type WafregionalByteMatchSet
- type WafregionalByteMatchSetByteMatchTuples
- type WafregionalByteMatchSetByteMatchTuplesFieldToMatch
- type WafregionalByteMatchSetByteMatchTuplesFieldToMatchOutputReference
- type WafregionalByteMatchSetByteMatchTuplesList
- type WafregionalByteMatchSetByteMatchTuplesOutputReference
- type WafregionalByteMatchSetConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewWafregionalByteMatchSetByteMatchTuplesFieldToMatchOutputReference_Override ¶
func NewWafregionalByteMatchSetByteMatchTuplesFieldToMatchOutputReference_Override(w WafregionalByteMatchSetByteMatchTuplesFieldToMatchOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewWafregionalByteMatchSetByteMatchTuplesList_Override ¶
func NewWafregionalByteMatchSetByteMatchTuplesList_Override(w WafregionalByteMatchSetByteMatchTuplesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewWafregionalByteMatchSetByteMatchTuplesOutputReference_Override ¶
func NewWafregionalByteMatchSetByteMatchTuplesOutputReference_Override(w WafregionalByteMatchSetByteMatchTuplesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewWafregionalByteMatchSet_Override ¶
func NewWafregionalByteMatchSet_Override(w WafregionalByteMatchSet, scope constructs.Construct, id *string, config *WafregionalByteMatchSetConfig)
Create a new {@link https://www.terraform.io/docs/providers/aws/r/wafregional_byte_match_set aws_wafregional_byte_match_set} Resource.
func WafregionalByteMatchSet_IsConstruct ¶
func WafregionalByteMatchSet_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func WafregionalByteMatchSet_IsTerraformElement ¶
func WafregionalByteMatchSet_IsTerraformElement(x interface{}) *bool
Experimental.
func WafregionalByteMatchSet_IsTerraformResource ¶
func WafregionalByteMatchSet_IsTerraformResource(x interface{}) *bool
Experimental.
func WafregionalByteMatchSet_TfResourceType ¶
func WafregionalByteMatchSet_TfResourceType() *string
Types ¶
type WafregionalByteMatchSet ¶
type WafregionalByteMatchSet interface {
cdktf.TerraformResource
ByteMatchTuples() WafregionalByteMatchSetByteMatchTuplesList
ByteMatchTuplesInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutByteMatchTuples(value interface{})
ResetByteMatchTuples()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/aws/r/wafregional_byte_match_set aws_wafregional_byte_match_set}.
func NewWafregionalByteMatchSet ¶
func NewWafregionalByteMatchSet(scope constructs.Construct, id *string, config *WafregionalByteMatchSetConfig) WafregionalByteMatchSet
Create a new {@link https://www.terraform.io/docs/providers/aws/r/wafregional_byte_match_set aws_wafregional_byte_match_set} Resource.
type WafregionalByteMatchSetByteMatchTuples ¶
type WafregionalByteMatchSetByteMatchTuples struct {
// field_to_match block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafregional_byte_match_set#field_to_match WafregionalByteMatchSet#field_to_match}
FieldToMatch *WafregionalByteMatchSetByteMatchTuplesFieldToMatch `field:"required" json:"fieldToMatch" yaml:"fieldToMatch"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafregional_byte_match_set#positional_constraint WafregionalByteMatchSet#positional_constraint}.
PositionalConstraint *string `field:"required" json:"positionalConstraint" yaml:"positionalConstraint"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafregional_byte_match_set#text_transformation WafregionalByteMatchSet#text_transformation}.
TextTransformation *string `field:"required" json:"textTransformation" yaml:"textTransformation"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafregional_byte_match_set#target_string WafregionalByteMatchSet#target_string}.
TargetString *string `field:"optional" json:"targetString" yaml:"targetString"`
}
type WafregionalByteMatchSetByteMatchTuplesFieldToMatch ¶
type WafregionalByteMatchSetByteMatchTuplesFieldToMatch struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafregional_byte_match_set#type WafregionalByteMatchSet#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafregional_byte_match_set#data WafregionalByteMatchSet#data}.
Data *string `field:"optional" json:"data" yaml:"data"`
}
type WafregionalByteMatchSetByteMatchTuplesFieldToMatchOutputReference ¶
type WafregionalByteMatchSetByteMatchTuplesFieldToMatchOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Data() *string
SetData(val *string)
DataInput() *string
// Experimental.
Fqn() *string
InternalValue() *WafregionalByteMatchSetByteMatchTuplesFieldToMatch
SetInternalValue(val *WafregionalByteMatchSetByteMatchTuplesFieldToMatch)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetData()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewWafregionalByteMatchSetByteMatchTuplesFieldToMatchOutputReference ¶
func NewWafregionalByteMatchSetByteMatchTuplesFieldToMatchOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) WafregionalByteMatchSetByteMatchTuplesFieldToMatchOutputReference
type WafregionalByteMatchSetByteMatchTuplesList ¶
type WafregionalByteMatchSetByteMatchTuplesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) WafregionalByteMatchSetByteMatchTuplesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewWafregionalByteMatchSetByteMatchTuplesList ¶
func NewWafregionalByteMatchSetByteMatchTuplesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) WafregionalByteMatchSetByteMatchTuplesList
type WafregionalByteMatchSetByteMatchTuplesOutputReference ¶
type WafregionalByteMatchSetByteMatchTuplesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FieldToMatch() WafregionalByteMatchSetByteMatchTuplesFieldToMatchOutputReference
FieldToMatchInput() *WafregionalByteMatchSetByteMatchTuplesFieldToMatch
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
PositionalConstraint() *string
SetPositionalConstraint(val *string)
PositionalConstraintInput() *string
TargetString() *string
SetTargetString(val *string)
TargetStringInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TextTransformation() *string
SetTextTransformation(val *string)
TextTransformationInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutFieldToMatch(value *WafregionalByteMatchSetByteMatchTuplesFieldToMatch)
ResetTargetString()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewWafregionalByteMatchSetByteMatchTuplesOutputReference ¶
func NewWafregionalByteMatchSetByteMatchTuplesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) WafregionalByteMatchSetByteMatchTuplesOutputReference
type WafregionalByteMatchSetConfig ¶
type WafregionalByteMatchSetConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafregional_byte_match_set#name WafregionalByteMatchSet#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// byte_match_tuples block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafregional_byte_match_set#byte_match_tuples WafregionalByteMatchSet#byte_match_tuples}
ByteMatchTuples interface{} `field:"optional" json:"byteMatchTuples" yaml:"byteMatchTuples"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/wafregional_byte_match_set#id WafregionalByteMatchSet#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
Source Files
¶
- WafregionalByteMatchSet.go
- WafregionalByteMatchSetByteMatchTuples.go
- WafregionalByteMatchSetByteMatchTuplesFieldToMatch.go
- WafregionalByteMatchSetByteMatchTuplesFieldToMatchOutputReference.go
- WafregionalByteMatchSetByteMatchTuplesFieldToMatchOutputReference__checks.go
- WafregionalByteMatchSetByteMatchTuplesList.go
- WafregionalByteMatchSetByteMatchTuplesList__checks.go
- WafregionalByteMatchSetByteMatchTuplesOutputReference.go
- WafregionalByteMatchSetByteMatchTuplesOutputReference__checks.go
- WafregionalByteMatchSetConfig.go
- WafregionalByteMatchSet__checks.go
- main.go