Documentation
¶
Index ¶
- func AppautoscalingScheduledAction_IsConstruct(x interface{}) *bool
- func AppautoscalingScheduledAction_IsTerraformElement(x interface{}) *bool
- func AppautoscalingScheduledAction_IsTerraformResource(x interface{}) *bool
- func AppautoscalingScheduledAction_TfResourceType() *string
- func NewAppautoscalingScheduledActionScalableTargetActionOutputReference_Override(a AppautoscalingScheduledActionScalableTargetActionOutputReference, ...)
- func NewAppautoscalingScheduledAction_Override(a AppautoscalingScheduledAction, scope constructs.Construct, id *string, ...)
- type AppautoscalingScheduledAction
- type AppautoscalingScheduledActionConfig
- type AppautoscalingScheduledActionScalableTargetAction
- type AppautoscalingScheduledActionScalableTargetActionOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AppautoscalingScheduledAction_IsConstruct ¶
func AppautoscalingScheduledAction_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AppautoscalingScheduledAction_IsTerraformElement ¶
func AppautoscalingScheduledAction_IsTerraformElement(x interface{}) *bool
Experimental.
func AppautoscalingScheduledAction_IsTerraformResource ¶
func AppautoscalingScheduledAction_IsTerraformResource(x interface{}) *bool
Experimental.
func AppautoscalingScheduledAction_TfResourceType ¶
func AppautoscalingScheduledAction_TfResourceType() *string
func NewAppautoscalingScheduledActionScalableTargetActionOutputReference_Override ¶
func NewAppautoscalingScheduledActionScalableTargetActionOutputReference_Override(a AppautoscalingScheduledActionScalableTargetActionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppautoscalingScheduledAction_Override ¶
func NewAppautoscalingScheduledAction_Override(a AppautoscalingScheduledAction, scope constructs.Construct, id *string, config *AppautoscalingScheduledActionConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_scheduled_action aws_appautoscaling_scheduled_action} Resource.
Types ¶
type AppautoscalingScheduledAction ¶
type AppautoscalingScheduledAction interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EndTime() *string
SetEndTime(val *string)
EndTimeInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ResourceId() *string
SetResourceId(val *string)
ResourceIdInput() *string
ScalableDimension() *string
SetScalableDimension(val *string)
ScalableDimensionInput() *string
ScalableTargetAction() AppautoscalingScheduledActionScalableTargetActionOutputReference
ScalableTargetActionInput() *AppautoscalingScheduledActionScalableTargetAction
Schedule() *string
SetSchedule(val *string)
ScheduleInput() *string
ServiceNamespace() *string
SetServiceNamespace(val *string)
ServiceNamespaceInput() *string
StartTime() *string
SetStartTime(val *string)
StartTimeInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timezone() *string
SetTimezone(val *string)
TimezoneInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutScalableTargetAction(value *AppautoscalingScheduledActionScalableTargetAction)
ResetEndTime()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetStartTime()
ResetTimezone()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_scheduled_action aws_appautoscaling_scheduled_action}.
func NewAppautoscalingScheduledAction ¶
func NewAppautoscalingScheduledAction(scope constructs.Construct, id *string, config *AppautoscalingScheduledActionConfig) AppautoscalingScheduledAction
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_scheduled_action aws_appautoscaling_scheduled_action} Resource.
type AppautoscalingScheduledActionConfig ¶
type AppautoscalingScheduledActionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_scheduled_action#name AppautoscalingScheduledAction#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_scheduled_action#resource_id AppautoscalingScheduledAction#resource_id}.
ResourceId *string `field:"required" json:"resourceId" yaml:"resourceId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_scheduled_action#scalable_dimension AppautoscalingScheduledAction#scalable_dimension}.
ScalableDimension *string `field:"required" json:"scalableDimension" yaml:"scalableDimension"`
// scalable_target_action block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_scheduled_action#scalable_target_action AppautoscalingScheduledAction#scalable_target_action}
ScalableTargetAction *AppautoscalingScheduledActionScalableTargetAction `field:"required" json:"scalableTargetAction" yaml:"scalableTargetAction"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_scheduled_action#schedule AppautoscalingScheduledAction#schedule}.
Schedule *string `field:"required" json:"schedule" yaml:"schedule"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_scheduled_action#service_namespace AppautoscalingScheduledAction#service_namespace}.
ServiceNamespace *string `field:"required" json:"serviceNamespace" yaml:"serviceNamespace"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_scheduled_action#end_time AppautoscalingScheduledAction#end_time}.
EndTime *string `field:"optional" json:"endTime" yaml:"endTime"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_scheduled_action#id AppautoscalingScheduledAction#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_scheduled_action#start_time AppautoscalingScheduledAction#start_time}.
StartTime *string `field:"optional" json:"startTime" yaml:"startTime"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_scheduled_action#timezone AppautoscalingScheduledAction#timezone}.
Timezone *string `field:"optional" json:"timezone" yaml:"timezone"`
}
type AppautoscalingScheduledActionScalableTargetAction ¶
type AppautoscalingScheduledActionScalableTargetAction struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_scheduled_action#max_capacity AppautoscalingScheduledAction#max_capacity}.
MaxCapacity *string `field:"optional" json:"maxCapacity" yaml:"maxCapacity"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_scheduled_action#min_capacity AppautoscalingScheduledAction#min_capacity}.
MinCapacity *string `field:"optional" json:"minCapacity" yaml:"minCapacity"`
}
type AppautoscalingScheduledActionScalableTargetActionOutputReference ¶
type AppautoscalingScheduledActionScalableTargetActionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AppautoscalingScheduledActionScalableTargetAction
SetInternalValue(val *AppautoscalingScheduledActionScalableTargetAction)
MaxCapacity() *string
SetMaxCapacity(val *string)
MaxCapacityInput() *string
MinCapacity() *string
SetMinCapacity(val *string)
MinCapacityInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetMaxCapacity()
ResetMinCapacity()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppautoscalingScheduledActionScalableTargetActionOutputReference ¶
func NewAppautoscalingScheduledActionScalableTargetActionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppautoscalingScheduledActionScalableTargetActionOutputReference
Source Files
¶
- AppautoscalingScheduledAction.go
- AppautoscalingScheduledActionConfig.go
- AppautoscalingScheduledActionScalableTargetAction.go
- AppautoscalingScheduledActionScalableTargetActionOutputReference.go
- AppautoscalingScheduledActionScalableTargetActionOutputReference__checks.go
- AppautoscalingScheduledAction__checks.go
- main.go