Documentation
¶
Index ¶
- func AppautoscalingTarget_IsConstruct(x interface{}) *bool
- func AppautoscalingTarget_IsTerraformElement(x interface{}) *bool
- func AppautoscalingTarget_IsTerraformResource(x interface{}) *bool
- func AppautoscalingTarget_TfResourceType() *string
- func NewAppautoscalingTarget_Override(a AppautoscalingTarget, scope constructs.Construct, id *string, ...)
- type AppautoscalingTarget
- type AppautoscalingTargetConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AppautoscalingTarget_IsConstruct ¶
func AppautoscalingTarget_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AppautoscalingTarget_IsTerraformElement ¶
func AppautoscalingTarget_IsTerraformElement(x interface{}) *bool
Experimental.
func AppautoscalingTarget_IsTerraformResource ¶
func AppautoscalingTarget_IsTerraformResource(x interface{}) *bool
Experimental.
func AppautoscalingTarget_TfResourceType ¶
func AppautoscalingTarget_TfResourceType() *string
func NewAppautoscalingTarget_Override ¶
func NewAppautoscalingTarget_Override(a AppautoscalingTarget, scope constructs.Construct, id *string, config *AppautoscalingTargetConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_target aws_appautoscaling_target} Resource.
Types ¶
type AppautoscalingTarget ¶
type AppautoscalingTarget interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaxCapacity() *float64
SetMaxCapacity(val *float64)
MaxCapacityInput() *float64
MinCapacity() *float64
SetMinCapacity(val *float64)
MinCapacityInput() *float64
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ResourceId() *string
SetResourceId(val *string)
ResourceIdInput() *string
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
ScalableDimension() *string
SetScalableDimension(val *string)
ScalableDimensionInput() *string
ServiceNamespace() *string
SetServiceNamespace(val *string)
ServiceNamespaceInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRoleArn()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_target aws_appautoscaling_target}.
func NewAppautoscalingTarget ¶
func NewAppautoscalingTarget(scope constructs.Construct, id *string, config *AppautoscalingTargetConfig) AppautoscalingTarget
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_target aws_appautoscaling_target} Resource.
type AppautoscalingTargetConfig ¶
type AppautoscalingTargetConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_target#max_capacity AppautoscalingTarget#max_capacity}.
MaxCapacity *float64 `field:"required" json:"maxCapacity" yaml:"maxCapacity"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_target#min_capacity AppautoscalingTarget#min_capacity}.
MinCapacity *float64 `field:"required" json:"minCapacity" yaml:"minCapacity"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_target#resource_id AppautoscalingTarget#resource_id}.
ResourceId *string `field:"required" json:"resourceId" yaml:"resourceId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_target#scalable_dimension AppautoscalingTarget#scalable_dimension}.
ScalableDimension *string `field:"required" json:"scalableDimension" yaml:"scalableDimension"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_target#service_namespace AppautoscalingTarget#service_namespace}.
ServiceNamespace *string `field:"required" json:"serviceNamespace" yaml:"serviceNamespace"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_target#id AppautoscalingTarget#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_target#role_arn AppautoscalingTarget#role_arn}.
RoleArn *string `field:"optional" json:"roleArn" yaml:"roleArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_target#tags AppautoscalingTarget#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appautoscaling_target#tags_all AppautoscalingTarget#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}