Documentation
¶
Index ¶
- func AppmeshVirtualRouter_IsConstruct(x interface{}) *bool
- func AppmeshVirtualRouter_IsTerraformElement(x interface{}) *bool
- func AppmeshVirtualRouter_IsTerraformResource(x interface{}) *bool
- func AppmeshVirtualRouter_TfResourceType() *string
- func NewAppmeshVirtualRouterSpecListenerList_Override(a AppmeshVirtualRouterSpecListenerList, ...)
- func NewAppmeshVirtualRouterSpecListenerOutputReference_Override(a AppmeshVirtualRouterSpecListenerOutputReference, ...)
- func NewAppmeshVirtualRouterSpecListenerPortMappingOutputReference_Override(a AppmeshVirtualRouterSpecListenerPortMappingOutputReference, ...)
- func NewAppmeshVirtualRouterSpecOutputReference_Override(a AppmeshVirtualRouterSpecOutputReference, ...)
- func NewAppmeshVirtualRouter_Override(a AppmeshVirtualRouter, scope constructs.Construct, id *string, ...)
- type AppmeshVirtualRouter
- type AppmeshVirtualRouterConfig
- type AppmeshVirtualRouterSpec
- type AppmeshVirtualRouterSpecListener
- type AppmeshVirtualRouterSpecListenerList
- type AppmeshVirtualRouterSpecListenerOutputReference
- type AppmeshVirtualRouterSpecListenerPortMapping
- type AppmeshVirtualRouterSpecListenerPortMappingOutputReference
- type AppmeshVirtualRouterSpecOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AppmeshVirtualRouter_IsConstruct ¶
func AppmeshVirtualRouter_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AppmeshVirtualRouter_IsTerraformElement ¶
func AppmeshVirtualRouter_IsTerraformElement(x interface{}) *bool
Experimental.
func AppmeshVirtualRouter_IsTerraformResource ¶
func AppmeshVirtualRouter_IsTerraformResource(x interface{}) *bool
Experimental.
func AppmeshVirtualRouter_TfResourceType ¶
func AppmeshVirtualRouter_TfResourceType() *string
func NewAppmeshVirtualRouterSpecListenerList_Override ¶
func NewAppmeshVirtualRouterSpecListenerList_Override(a AppmeshVirtualRouterSpecListenerList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAppmeshVirtualRouterSpecListenerOutputReference_Override ¶
func NewAppmeshVirtualRouterSpecListenerOutputReference_Override(a AppmeshVirtualRouterSpecListenerOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAppmeshVirtualRouterSpecListenerPortMappingOutputReference_Override ¶
func NewAppmeshVirtualRouterSpecListenerPortMappingOutputReference_Override(a AppmeshVirtualRouterSpecListenerPortMappingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppmeshVirtualRouterSpecOutputReference_Override ¶
func NewAppmeshVirtualRouterSpecOutputReference_Override(a AppmeshVirtualRouterSpecOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppmeshVirtualRouter_Override ¶
func NewAppmeshVirtualRouter_Override(a AppmeshVirtualRouter, scope constructs.Construct, id *string, config *AppmeshVirtualRouterConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_router aws_appmesh_virtual_router} Resource.
Types ¶
type AppmeshVirtualRouter ¶
type AppmeshVirtualRouter interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreatedDate() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
LastUpdatedDate() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MeshName() *string
SetMeshName(val *string)
MeshNameInput() *string
MeshOwner() *string
SetMeshOwner(val *string)
MeshOwnerInput() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ResourceOwner() *string
Spec() AppmeshVirtualRouterSpecOutputReference
SpecInput() *AppmeshVirtualRouterSpec
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutSpec(value *AppmeshVirtualRouterSpec)
ResetId()
ResetMeshOwner()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_router aws_appmesh_virtual_router}.
func NewAppmeshVirtualRouter ¶
func NewAppmeshVirtualRouter(scope constructs.Construct, id *string, config *AppmeshVirtualRouterConfig) AppmeshVirtualRouter
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_router aws_appmesh_virtual_router} Resource.
type AppmeshVirtualRouterConfig ¶
type AppmeshVirtualRouterConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_router#mesh_name AppmeshVirtualRouter#mesh_name}.
MeshName *string `field:"required" json:"meshName" yaml:"meshName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_router#name AppmeshVirtualRouter#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// spec block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_router#spec AppmeshVirtualRouter#spec}
Spec *AppmeshVirtualRouterSpec `field:"required" json:"spec" yaml:"spec"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_router#id AppmeshVirtualRouter#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_router#mesh_owner AppmeshVirtualRouter#mesh_owner}.
MeshOwner *string `field:"optional" json:"meshOwner" yaml:"meshOwner"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_router#tags AppmeshVirtualRouter#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_router#tags_all AppmeshVirtualRouter#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type AppmeshVirtualRouterSpec ¶
type AppmeshVirtualRouterSpec struct {
// listener block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_router#listener AppmeshVirtualRouter#listener}
Listener interface{} `field:"optional" json:"listener" yaml:"listener"`
}
type AppmeshVirtualRouterSpecListener ¶
type AppmeshVirtualRouterSpecListener struct {
// port_mapping block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_router#port_mapping AppmeshVirtualRouter#port_mapping}
PortMapping *AppmeshVirtualRouterSpecListenerPortMapping `field:"required" json:"portMapping" yaml:"portMapping"`
}
type AppmeshVirtualRouterSpecListenerList ¶
type AppmeshVirtualRouterSpecListenerList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) AppmeshVirtualRouterSpecListenerOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppmeshVirtualRouterSpecListenerList ¶
func NewAppmeshVirtualRouterSpecListenerList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AppmeshVirtualRouterSpecListenerList
type AppmeshVirtualRouterSpecListenerOutputReference ¶
type AppmeshVirtualRouterSpecListenerOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
PortMapping() AppmeshVirtualRouterSpecListenerPortMappingOutputReference
PortMappingInput() *AppmeshVirtualRouterSpecListenerPortMapping
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutPortMapping(value *AppmeshVirtualRouterSpecListenerPortMapping)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppmeshVirtualRouterSpecListenerOutputReference ¶
func NewAppmeshVirtualRouterSpecListenerOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AppmeshVirtualRouterSpecListenerOutputReference
type AppmeshVirtualRouterSpecListenerPortMapping ¶
type AppmeshVirtualRouterSpecListenerPortMapping struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_router#port AppmeshVirtualRouter#port}.
Port *float64 `field:"required" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_router#protocol AppmeshVirtualRouter#protocol}.
Protocol *string `field:"required" json:"protocol" yaml:"protocol"`
}
type AppmeshVirtualRouterSpecListenerPortMappingOutputReference ¶
type AppmeshVirtualRouterSpecListenerPortMappingOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AppmeshVirtualRouterSpecListenerPortMapping
SetInternalValue(val *AppmeshVirtualRouterSpecListenerPortMapping)
Port() *float64
SetPort(val *float64)
PortInput() *float64
Protocol() *string
SetProtocol(val *string)
ProtocolInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppmeshVirtualRouterSpecListenerPortMappingOutputReference ¶
func NewAppmeshVirtualRouterSpecListenerPortMappingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppmeshVirtualRouterSpecListenerPortMappingOutputReference
type AppmeshVirtualRouterSpecOutputReference ¶
type AppmeshVirtualRouterSpecOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AppmeshVirtualRouterSpec
SetInternalValue(val *AppmeshVirtualRouterSpec)
Listener() AppmeshVirtualRouterSpecListenerList
ListenerInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutListener(value interface{})
ResetListener()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppmeshVirtualRouterSpecOutputReference ¶
func NewAppmeshVirtualRouterSpecOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppmeshVirtualRouterSpecOutputReference
Source Files
¶
- AppmeshVirtualRouter.go
- AppmeshVirtualRouterConfig.go
- AppmeshVirtualRouterSpec.go
- AppmeshVirtualRouterSpecListener.go
- AppmeshVirtualRouterSpecListenerList.go
- AppmeshVirtualRouterSpecListenerList__checks.go
- AppmeshVirtualRouterSpecListenerOutputReference.go
- AppmeshVirtualRouterSpecListenerOutputReference__checks.go
- AppmeshVirtualRouterSpecListenerPortMapping.go
- AppmeshVirtualRouterSpecListenerPortMappingOutputReference.go
- AppmeshVirtualRouterSpecListenerPortMappingOutputReference__checks.go
- AppmeshVirtualRouterSpecOutputReference.go
- AppmeshVirtualRouterSpecOutputReference__checks.go
- AppmeshVirtualRouter__checks.go
- main.go