Documentation
¶
Index ¶
- func AppmeshVirtualService_IsConstruct(x interface{}) *bool
- func AppmeshVirtualService_IsTerraformElement(x interface{}) *bool
- func AppmeshVirtualService_IsTerraformResource(x interface{}) *bool
- func AppmeshVirtualService_TfResourceType() *string
- func NewAppmeshVirtualServiceSpecOutputReference_Override(a AppmeshVirtualServiceSpecOutputReference, ...)
- func NewAppmeshVirtualServiceSpecProviderOutputReference_Override(a AppmeshVirtualServiceSpecProviderOutputReference, ...)
- func NewAppmeshVirtualServiceSpecProviderVirtualNodeOutputReference_Override(a AppmeshVirtualServiceSpecProviderVirtualNodeOutputReference, ...)
- func NewAppmeshVirtualServiceSpecProviderVirtualRouterOutputReference_Override(a AppmeshVirtualServiceSpecProviderVirtualRouterOutputReference, ...)
- func NewAppmeshVirtualService_Override(a AppmeshVirtualService, scope constructs.Construct, id *string, ...)
- type AppmeshVirtualService
- type AppmeshVirtualServiceConfig
- type AppmeshVirtualServiceSpec
- type AppmeshVirtualServiceSpecOutputReference
- type AppmeshVirtualServiceSpecProvider
- type AppmeshVirtualServiceSpecProviderOutputReference
- type AppmeshVirtualServiceSpecProviderVirtualNode
- type AppmeshVirtualServiceSpecProviderVirtualNodeOutputReference
- type AppmeshVirtualServiceSpecProviderVirtualRouter
- type AppmeshVirtualServiceSpecProviderVirtualRouterOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AppmeshVirtualService_IsConstruct ¶
func AppmeshVirtualService_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AppmeshVirtualService_IsTerraformElement ¶
func AppmeshVirtualService_IsTerraformElement(x interface{}) *bool
Experimental.
func AppmeshVirtualService_IsTerraformResource ¶
func AppmeshVirtualService_IsTerraformResource(x interface{}) *bool
Experimental.
func AppmeshVirtualService_TfResourceType ¶
func AppmeshVirtualService_TfResourceType() *string
func NewAppmeshVirtualServiceSpecOutputReference_Override ¶
func NewAppmeshVirtualServiceSpecOutputReference_Override(a AppmeshVirtualServiceSpecOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppmeshVirtualServiceSpecProviderOutputReference_Override ¶
func NewAppmeshVirtualServiceSpecProviderOutputReference_Override(a AppmeshVirtualServiceSpecProviderOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppmeshVirtualServiceSpecProviderVirtualNodeOutputReference_Override ¶
func NewAppmeshVirtualServiceSpecProviderVirtualNodeOutputReference_Override(a AppmeshVirtualServiceSpecProviderVirtualNodeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppmeshVirtualServiceSpecProviderVirtualRouterOutputReference_Override ¶
func NewAppmeshVirtualServiceSpecProviderVirtualRouterOutputReference_Override(a AppmeshVirtualServiceSpecProviderVirtualRouterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAppmeshVirtualService_Override ¶
func NewAppmeshVirtualService_Override(a AppmeshVirtualService, scope constructs.Construct, id *string, config *AppmeshVirtualServiceConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_service aws_appmesh_virtual_service} Resource.
Types ¶
type AppmeshVirtualService ¶
type AppmeshVirtualService interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreatedDate() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
LastUpdatedDate() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MeshName() *string
SetMeshName(val *string)
MeshNameInput() *string
MeshOwner() *string
SetMeshOwner(val *string)
MeshOwnerInput() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ResourceOwner() *string
Spec() AppmeshVirtualServiceSpecOutputReference
SpecInput() *AppmeshVirtualServiceSpec
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutSpec(value *AppmeshVirtualServiceSpec)
ResetId()
ResetMeshOwner()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_service aws_appmesh_virtual_service}.
func NewAppmeshVirtualService ¶
func NewAppmeshVirtualService(scope constructs.Construct, id *string, config *AppmeshVirtualServiceConfig) AppmeshVirtualService
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_service aws_appmesh_virtual_service} Resource.
type AppmeshVirtualServiceConfig ¶
type AppmeshVirtualServiceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_service#mesh_name AppmeshVirtualService#mesh_name}.
MeshName *string `field:"required" json:"meshName" yaml:"meshName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_service#name AppmeshVirtualService#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// spec block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_service#spec AppmeshVirtualService#spec}
Spec *AppmeshVirtualServiceSpec `field:"required" json:"spec" yaml:"spec"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_service#id AppmeshVirtualService#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_service#mesh_owner AppmeshVirtualService#mesh_owner}.
MeshOwner *string `field:"optional" json:"meshOwner" yaml:"meshOwner"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_service#tags AppmeshVirtualService#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_service#tags_all AppmeshVirtualService#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type AppmeshVirtualServiceSpec ¶
type AppmeshVirtualServiceSpec struct {
// provider block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_service#provider AppmeshVirtualService#provider}
Provider *AppmeshVirtualServiceSpecProvider `field:"optional" json:"provider" yaml:"provider"`
}
type AppmeshVirtualServiceSpecOutputReference ¶
type AppmeshVirtualServiceSpecOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AppmeshVirtualServiceSpec
SetInternalValue(val *AppmeshVirtualServiceSpec)
Provider() AppmeshVirtualServiceSpecProviderOutputReference
ProviderInput() *AppmeshVirtualServiceSpecProvider
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutProvider(value *AppmeshVirtualServiceSpecProvider)
ResetProvider()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppmeshVirtualServiceSpecOutputReference ¶
func NewAppmeshVirtualServiceSpecOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppmeshVirtualServiceSpecOutputReference
type AppmeshVirtualServiceSpecProvider ¶
type AppmeshVirtualServiceSpecProvider struct {
// virtual_node block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_service#virtual_node AppmeshVirtualService#virtual_node}
VirtualNode *AppmeshVirtualServiceSpecProviderVirtualNode `field:"optional" json:"virtualNode" yaml:"virtualNode"`
// virtual_router block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_service#virtual_router AppmeshVirtualService#virtual_router}
VirtualRouter *AppmeshVirtualServiceSpecProviderVirtualRouter `field:"optional" json:"virtualRouter" yaml:"virtualRouter"`
}
type AppmeshVirtualServiceSpecProviderOutputReference ¶
type AppmeshVirtualServiceSpecProviderOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AppmeshVirtualServiceSpecProvider
SetInternalValue(val *AppmeshVirtualServiceSpecProvider)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VirtualNode() AppmeshVirtualServiceSpecProviderVirtualNodeOutputReference
VirtualNodeInput() *AppmeshVirtualServiceSpecProviderVirtualNode
VirtualRouter() AppmeshVirtualServiceSpecProviderVirtualRouterOutputReference
VirtualRouterInput() *AppmeshVirtualServiceSpecProviderVirtualRouter
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutVirtualNode(value *AppmeshVirtualServiceSpecProviderVirtualNode)
PutVirtualRouter(value *AppmeshVirtualServiceSpecProviderVirtualRouter)
ResetVirtualNode()
ResetVirtualRouter()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppmeshVirtualServiceSpecProviderOutputReference ¶
func NewAppmeshVirtualServiceSpecProviderOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppmeshVirtualServiceSpecProviderOutputReference
type AppmeshVirtualServiceSpecProviderVirtualNode ¶
type AppmeshVirtualServiceSpecProviderVirtualNode struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_service#virtual_node_name AppmeshVirtualService#virtual_node_name}.
VirtualNodeName *string `field:"required" json:"virtualNodeName" yaml:"virtualNodeName"`
}
type AppmeshVirtualServiceSpecProviderVirtualNodeOutputReference ¶
type AppmeshVirtualServiceSpecProviderVirtualNodeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AppmeshVirtualServiceSpecProviderVirtualNode
SetInternalValue(val *AppmeshVirtualServiceSpecProviderVirtualNode)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VirtualNodeName() *string
SetVirtualNodeName(val *string)
VirtualNodeNameInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppmeshVirtualServiceSpecProviderVirtualNodeOutputReference ¶
func NewAppmeshVirtualServiceSpecProviderVirtualNodeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppmeshVirtualServiceSpecProviderVirtualNodeOutputReference
type AppmeshVirtualServiceSpecProviderVirtualRouter ¶
type AppmeshVirtualServiceSpecProviderVirtualRouter struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/appmesh_virtual_service#virtual_router_name AppmeshVirtualService#virtual_router_name}.
VirtualRouterName *string `field:"required" json:"virtualRouterName" yaml:"virtualRouterName"`
}
type AppmeshVirtualServiceSpecProviderVirtualRouterOutputReference ¶
type AppmeshVirtualServiceSpecProviderVirtualRouterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AppmeshVirtualServiceSpecProviderVirtualRouter
SetInternalValue(val *AppmeshVirtualServiceSpecProviderVirtualRouter)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VirtualRouterName() *string
SetVirtualRouterName(val *string)
VirtualRouterNameInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAppmeshVirtualServiceSpecProviderVirtualRouterOutputReference ¶
func NewAppmeshVirtualServiceSpecProviderVirtualRouterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AppmeshVirtualServiceSpecProviderVirtualRouterOutputReference
Source Files
¶
- AppmeshVirtualService.go
- AppmeshVirtualServiceConfig.go
- AppmeshVirtualServiceSpec.go
- AppmeshVirtualServiceSpecOutputReference.go
- AppmeshVirtualServiceSpecOutputReference__checks.go
- AppmeshVirtualServiceSpecProvider.go
- AppmeshVirtualServiceSpecProviderOutputReference.go
- AppmeshVirtualServiceSpecProviderOutputReference__checks.go
- AppmeshVirtualServiceSpecProviderVirtualNode.go
- AppmeshVirtualServiceSpecProviderVirtualNodeOutputReference.go
- AppmeshVirtualServiceSpecProviderVirtualNodeOutputReference__checks.go
- AppmeshVirtualServiceSpecProviderVirtualRouter.go
- AppmeshVirtualServiceSpecProviderVirtualRouterOutputReference.go
- AppmeshVirtualServiceSpecProviderVirtualRouterOutputReference__checks.go
- AppmeshVirtualService__checks.go
- main.go