Documentation
¶
Index ¶
- func AthenaWorkgroup_IsConstruct(x interface{}) *bool
- func AthenaWorkgroup_IsTerraformElement(x interface{}) *bool
- func AthenaWorkgroup_IsTerraformResource(x interface{}) *bool
- func AthenaWorkgroup_TfResourceType() *string
- func NewAthenaWorkgroupConfigurationEngineVersionOutputReference_Override(a AthenaWorkgroupConfigurationEngineVersionOutputReference, ...)
- func NewAthenaWorkgroupConfigurationOutputReference_Override(a AthenaWorkgroupConfigurationOutputReference, ...)
- func NewAthenaWorkgroupConfigurationResultConfigurationAclConfigurationOutputReference_Override(...)
- func NewAthenaWorkgroupConfigurationResultConfigurationEncryptionConfigurationOutputReference_Override(...)
- func NewAthenaWorkgroupConfigurationResultConfigurationOutputReference_Override(a AthenaWorkgroupConfigurationResultConfigurationOutputReference, ...)
- func NewAthenaWorkgroup_Override(a AthenaWorkgroup, scope constructs.Construct, id *string, ...)
- type AthenaWorkgroup
- type AthenaWorkgroupConfig
- type AthenaWorkgroupConfiguration
- type AthenaWorkgroupConfigurationEngineVersion
- type AthenaWorkgroupConfigurationEngineVersionOutputReference
- type AthenaWorkgroupConfigurationOutputReference
- type AthenaWorkgroupConfigurationResultConfiguration
- type AthenaWorkgroupConfigurationResultConfigurationAclConfiguration
- type AthenaWorkgroupConfigurationResultConfigurationAclConfigurationOutputReference
- type AthenaWorkgroupConfigurationResultConfigurationEncryptionConfiguration
- type AthenaWorkgroupConfigurationResultConfigurationEncryptionConfigurationOutputReference
- type AthenaWorkgroupConfigurationResultConfigurationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AthenaWorkgroup_IsConstruct ¶
func AthenaWorkgroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AthenaWorkgroup_IsTerraformElement ¶
func AthenaWorkgroup_IsTerraformElement(x interface{}) *bool
Experimental.
func AthenaWorkgroup_IsTerraformResource ¶
func AthenaWorkgroup_IsTerraformResource(x interface{}) *bool
Experimental.
func AthenaWorkgroup_TfResourceType ¶
func AthenaWorkgroup_TfResourceType() *string
func NewAthenaWorkgroupConfigurationEngineVersionOutputReference_Override ¶
func NewAthenaWorkgroupConfigurationEngineVersionOutputReference_Override(a AthenaWorkgroupConfigurationEngineVersionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAthenaWorkgroupConfigurationOutputReference_Override ¶
func NewAthenaWorkgroupConfigurationOutputReference_Override(a AthenaWorkgroupConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAthenaWorkgroupConfigurationResultConfigurationAclConfigurationOutputReference_Override ¶
func NewAthenaWorkgroupConfigurationResultConfigurationAclConfigurationOutputReference_Override(a AthenaWorkgroupConfigurationResultConfigurationAclConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAthenaWorkgroupConfigurationResultConfigurationEncryptionConfigurationOutputReference_Override ¶
func NewAthenaWorkgroupConfigurationResultConfigurationEncryptionConfigurationOutputReference_Override(a AthenaWorkgroupConfigurationResultConfigurationEncryptionConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAthenaWorkgroupConfigurationResultConfigurationOutputReference_Override ¶
func NewAthenaWorkgroupConfigurationResultConfigurationOutputReference_Override(a AthenaWorkgroupConfigurationResultConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAthenaWorkgroup_Override ¶
func NewAthenaWorkgroup_Override(a AthenaWorkgroup, scope constructs.Construct, id *string, config *AthenaWorkgroupConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup aws_athena_workgroup} Resource.
Types ¶
type AthenaWorkgroup ¶
type AthenaWorkgroup interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
Configuration() AthenaWorkgroupConfigurationOutputReference
ConfigurationInput() *AthenaWorkgroupConfiguration
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
ForceDestroy() interface{}
SetForceDestroy(val interface{})
ForceDestroyInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
State() *string
SetState(val *string)
StateInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutConfiguration(value *AthenaWorkgroupConfiguration)
ResetConfiguration()
ResetDescription()
ResetForceDestroy()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetState()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup aws_athena_workgroup}.
func NewAthenaWorkgroup ¶
func NewAthenaWorkgroup(scope constructs.Construct, id *string, config *AthenaWorkgroupConfig) AthenaWorkgroup
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup aws_athena_workgroup} Resource.
type AthenaWorkgroupConfig ¶
type AthenaWorkgroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#name AthenaWorkgroup#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#configuration AthenaWorkgroup#configuration}
Configuration *AthenaWorkgroupConfiguration `field:"optional" json:"configuration" yaml:"configuration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#description AthenaWorkgroup#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#force_destroy AthenaWorkgroup#force_destroy}.
ForceDestroy interface{} `field:"optional" json:"forceDestroy" yaml:"forceDestroy"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#id AthenaWorkgroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#state AthenaWorkgroup#state}.
State *string `field:"optional" json:"state" yaml:"state"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#tags AthenaWorkgroup#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#tags_all AthenaWorkgroup#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type AthenaWorkgroupConfiguration ¶
type AthenaWorkgroupConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#bytes_scanned_cutoff_per_query AthenaWorkgroup#bytes_scanned_cutoff_per_query}.
BytesScannedCutoffPerQuery *float64 `field:"optional" json:"bytesScannedCutoffPerQuery" yaml:"bytesScannedCutoffPerQuery"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#enforce_workgroup_configuration AthenaWorkgroup#enforce_workgroup_configuration}.
EnforceWorkgroupConfiguration interface{} `field:"optional" json:"enforceWorkgroupConfiguration" yaml:"enforceWorkgroupConfiguration"`
// engine_version block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#engine_version AthenaWorkgroup#engine_version}
EngineVersion *AthenaWorkgroupConfigurationEngineVersion `field:"optional" json:"engineVersion" yaml:"engineVersion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#execution_role AthenaWorkgroup#execution_role}.
ExecutionRole *string `field:"optional" json:"executionRole" yaml:"executionRole"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#publish_cloudwatch_metrics_enabled AthenaWorkgroup#publish_cloudwatch_metrics_enabled}.
PublishCloudwatchMetricsEnabled interface{} `field:"optional" json:"publishCloudwatchMetricsEnabled" yaml:"publishCloudwatchMetricsEnabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#requester_pays_enabled AthenaWorkgroup#requester_pays_enabled}.
RequesterPaysEnabled interface{} `field:"optional" json:"requesterPaysEnabled" yaml:"requesterPaysEnabled"`
// result_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#result_configuration AthenaWorkgroup#result_configuration}
ResultConfiguration *AthenaWorkgroupConfigurationResultConfiguration `field:"optional" json:"resultConfiguration" yaml:"resultConfiguration"`
}
type AthenaWorkgroupConfigurationEngineVersion ¶
type AthenaWorkgroupConfigurationEngineVersion struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#selected_engine_version AthenaWorkgroup#selected_engine_version}.
SelectedEngineVersion *string `field:"optional" json:"selectedEngineVersion" yaml:"selectedEngineVersion"`
}
type AthenaWorkgroupConfigurationEngineVersionOutputReference ¶
type AthenaWorkgroupConfigurationEngineVersionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EffectiveEngineVersion() *string
// Experimental.
Fqn() *string
InternalValue() *AthenaWorkgroupConfigurationEngineVersion
SetInternalValue(val *AthenaWorkgroupConfigurationEngineVersion)
SelectedEngineVersion() *string
SetSelectedEngineVersion(val *string)
SelectedEngineVersionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetSelectedEngineVersion()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAthenaWorkgroupConfigurationEngineVersionOutputReference ¶
func NewAthenaWorkgroupConfigurationEngineVersionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AthenaWorkgroupConfigurationEngineVersionOutputReference
type AthenaWorkgroupConfigurationOutputReference ¶
type AthenaWorkgroupConfigurationOutputReference interface {
cdktf.ComplexObject
BytesScannedCutoffPerQuery() *float64
SetBytesScannedCutoffPerQuery(val *float64)
BytesScannedCutoffPerQueryInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EnforceWorkgroupConfiguration() interface{}
SetEnforceWorkgroupConfiguration(val interface{})
EnforceWorkgroupConfigurationInput() interface{}
EngineVersion() AthenaWorkgroupConfigurationEngineVersionOutputReference
EngineVersionInput() *AthenaWorkgroupConfigurationEngineVersion
ExecutionRole() *string
SetExecutionRole(val *string)
ExecutionRoleInput() *string
// Experimental.
Fqn() *string
InternalValue() *AthenaWorkgroupConfiguration
SetInternalValue(val *AthenaWorkgroupConfiguration)
PublishCloudwatchMetricsEnabled() interface{}
SetPublishCloudwatchMetricsEnabled(val interface{})
PublishCloudwatchMetricsEnabledInput() interface{}
RequesterPaysEnabled() interface{}
SetRequesterPaysEnabled(val interface{})
RequesterPaysEnabledInput() interface{}
ResultConfiguration() AthenaWorkgroupConfigurationResultConfigurationOutputReference
ResultConfigurationInput() *AthenaWorkgroupConfigurationResultConfiguration
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutEngineVersion(value *AthenaWorkgroupConfigurationEngineVersion)
PutResultConfiguration(value *AthenaWorkgroupConfigurationResultConfiguration)
ResetBytesScannedCutoffPerQuery()
ResetEnforceWorkgroupConfiguration()
ResetEngineVersion()
ResetExecutionRole()
ResetPublishCloudwatchMetricsEnabled()
ResetRequesterPaysEnabled()
ResetResultConfiguration()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAthenaWorkgroupConfigurationOutputReference ¶
func NewAthenaWorkgroupConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AthenaWorkgroupConfigurationOutputReference
type AthenaWorkgroupConfigurationResultConfiguration ¶
type AthenaWorkgroupConfigurationResultConfiguration struct {
// acl_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#acl_configuration AthenaWorkgroup#acl_configuration}
AclConfiguration *AthenaWorkgroupConfigurationResultConfigurationAclConfiguration `field:"optional" json:"aclConfiguration" yaml:"aclConfiguration"`
// encryption_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#encryption_configuration AthenaWorkgroup#encryption_configuration}
EncryptionConfiguration *AthenaWorkgroupConfigurationResultConfigurationEncryptionConfiguration `field:"optional" json:"encryptionConfiguration" yaml:"encryptionConfiguration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#expected_bucket_owner AthenaWorkgroup#expected_bucket_owner}.
ExpectedBucketOwner *string `field:"optional" json:"expectedBucketOwner" yaml:"expectedBucketOwner"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#output_location AthenaWorkgroup#output_location}.
OutputLocation *string `field:"optional" json:"outputLocation" yaml:"outputLocation"`
}
type AthenaWorkgroupConfigurationResultConfigurationAclConfiguration ¶
type AthenaWorkgroupConfigurationResultConfigurationAclConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#s3_acl_option AthenaWorkgroup#s3_acl_option}.
S3AclOption *string `field:"required" json:"s3AclOption" yaml:"s3AclOption"`
}
type AthenaWorkgroupConfigurationResultConfigurationAclConfigurationOutputReference ¶
type AthenaWorkgroupConfigurationResultConfigurationAclConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AthenaWorkgroupConfigurationResultConfigurationAclConfiguration
SetInternalValue(val *AthenaWorkgroupConfigurationResultConfigurationAclConfiguration)
S3AclOption() *string
SetS3AclOption(val *string)
S3AclOptionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAthenaWorkgroupConfigurationResultConfigurationAclConfigurationOutputReference ¶
func NewAthenaWorkgroupConfigurationResultConfigurationAclConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AthenaWorkgroupConfigurationResultConfigurationAclConfigurationOutputReference
type AthenaWorkgroupConfigurationResultConfigurationEncryptionConfiguration ¶
type AthenaWorkgroupConfigurationResultConfigurationEncryptionConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#encryption_option AthenaWorkgroup#encryption_option}.
EncryptionOption *string `field:"optional" json:"encryptionOption" yaml:"encryptionOption"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/athena_workgroup#kms_key_arn AthenaWorkgroup#kms_key_arn}.
KmsKeyArn *string `field:"optional" json:"kmsKeyArn" yaml:"kmsKeyArn"`
}
type AthenaWorkgroupConfigurationResultConfigurationEncryptionConfigurationOutputReference ¶
type AthenaWorkgroupConfigurationResultConfigurationEncryptionConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EncryptionOption() *string
SetEncryptionOption(val *string)
EncryptionOptionInput() *string
// Experimental.
Fqn() *string
InternalValue() *AthenaWorkgroupConfigurationResultConfigurationEncryptionConfiguration
SetInternalValue(val *AthenaWorkgroupConfigurationResultConfigurationEncryptionConfiguration)
KmsKeyArn() *string
SetKmsKeyArn(val *string)
KmsKeyArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEncryptionOption()
ResetKmsKeyArn()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAthenaWorkgroupConfigurationResultConfigurationEncryptionConfigurationOutputReference ¶
func NewAthenaWorkgroupConfigurationResultConfigurationEncryptionConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AthenaWorkgroupConfigurationResultConfigurationEncryptionConfigurationOutputReference
type AthenaWorkgroupConfigurationResultConfigurationOutputReference ¶
type AthenaWorkgroupConfigurationResultConfigurationOutputReference interface {
cdktf.ComplexObject
AclConfiguration() AthenaWorkgroupConfigurationResultConfigurationAclConfigurationOutputReference
AclConfigurationInput() *AthenaWorkgroupConfigurationResultConfigurationAclConfiguration
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EncryptionConfiguration() AthenaWorkgroupConfigurationResultConfigurationEncryptionConfigurationOutputReference
EncryptionConfigurationInput() *AthenaWorkgroupConfigurationResultConfigurationEncryptionConfiguration
ExpectedBucketOwner() *string
SetExpectedBucketOwner(val *string)
ExpectedBucketOwnerInput() *string
// Experimental.
Fqn() *string
InternalValue() *AthenaWorkgroupConfigurationResultConfiguration
SetInternalValue(val *AthenaWorkgroupConfigurationResultConfiguration)
OutputLocation() *string
SetOutputLocation(val *string)
OutputLocationInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAclConfiguration(value *AthenaWorkgroupConfigurationResultConfigurationAclConfiguration)
PutEncryptionConfiguration(value *AthenaWorkgroupConfigurationResultConfigurationEncryptionConfiguration)
ResetAclConfiguration()
ResetEncryptionConfiguration()
ResetExpectedBucketOwner()
ResetOutputLocation()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAthenaWorkgroupConfigurationResultConfigurationOutputReference ¶
func NewAthenaWorkgroupConfigurationResultConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AthenaWorkgroupConfigurationResultConfigurationOutputReference
Source Files
¶
- AthenaWorkgroup.go
- AthenaWorkgroupConfig.go
- AthenaWorkgroupConfiguration.go
- AthenaWorkgroupConfigurationEngineVersion.go
- AthenaWorkgroupConfigurationEngineVersionOutputReference.go
- AthenaWorkgroupConfigurationEngineVersionOutputReference__checks.go
- AthenaWorkgroupConfigurationOutputReference.go
- AthenaWorkgroupConfigurationOutputReference__checks.go
- AthenaWorkgroupConfigurationResultConfiguration.go
- AthenaWorkgroupConfigurationResultConfigurationAclConfiguration.go
- AthenaWorkgroupConfigurationResultConfigurationAclConfigurationOutputReference.go
- AthenaWorkgroupConfigurationResultConfigurationAclConfigurationOutputReference__checks.go
- AthenaWorkgroupConfigurationResultConfigurationEncryptionConfiguration.go
- AthenaWorkgroupConfigurationResultConfigurationEncryptionConfigurationOutputReference.go
- AthenaWorkgroupConfigurationResultConfigurationEncryptionConfigurationOutputReference__checks.go
- AthenaWorkgroupConfigurationResultConfigurationOutputReference.go
- AthenaWorkgroupConfigurationResultConfigurationOutputReference__checks.go
- AthenaWorkgroup__checks.go
- main.go