Documentation
¶
Index ¶
- func AuditmanagerControl_IsConstruct(x interface{}) *bool
- func AuditmanagerControl_IsTerraformElement(x interface{}) *bool
- func AuditmanagerControl_IsTerraformResource(x interface{}) *bool
- func AuditmanagerControl_TfResourceType() *string
- func NewAuditmanagerControlControlMappingSourcesList_Override(a AuditmanagerControlControlMappingSourcesList, ...)
- func NewAuditmanagerControlControlMappingSourcesOutputReference_Override(a AuditmanagerControlControlMappingSourcesOutputReference, ...)
- func NewAuditmanagerControlControlMappingSourcesSourceKeywordList_Override(a AuditmanagerControlControlMappingSourcesSourceKeywordList, ...)
- func NewAuditmanagerControlControlMappingSourcesSourceKeywordOutputReference_Override(a AuditmanagerControlControlMappingSourcesSourceKeywordOutputReference, ...)
- func NewAuditmanagerControl_Override(a AuditmanagerControl, scope constructs.Construct, id *string, ...)
- type AuditmanagerControl
- type AuditmanagerControlConfig
- type AuditmanagerControlControlMappingSources
- type AuditmanagerControlControlMappingSourcesList
- type AuditmanagerControlControlMappingSourcesOutputReference
- type AuditmanagerControlControlMappingSourcesSourceKeyword
- type AuditmanagerControlControlMappingSourcesSourceKeywordList
- type AuditmanagerControlControlMappingSourcesSourceKeywordOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AuditmanagerControl_IsConstruct ¶
func AuditmanagerControl_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AuditmanagerControl_IsTerraformElement ¶
func AuditmanagerControl_IsTerraformElement(x interface{}) *bool
Experimental.
func AuditmanagerControl_IsTerraformResource ¶
func AuditmanagerControl_IsTerraformResource(x interface{}) *bool
Experimental.
func AuditmanagerControl_TfResourceType ¶
func AuditmanagerControl_TfResourceType() *string
func NewAuditmanagerControlControlMappingSourcesList_Override ¶
func NewAuditmanagerControlControlMappingSourcesList_Override(a AuditmanagerControlControlMappingSourcesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAuditmanagerControlControlMappingSourcesOutputReference_Override ¶
func NewAuditmanagerControlControlMappingSourcesOutputReference_Override(a AuditmanagerControlControlMappingSourcesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAuditmanagerControlControlMappingSourcesSourceKeywordList_Override ¶
func NewAuditmanagerControlControlMappingSourcesSourceKeywordList_Override(a AuditmanagerControlControlMappingSourcesSourceKeywordList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAuditmanagerControlControlMappingSourcesSourceKeywordOutputReference_Override ¶
func NewAuditmanagerControlControlMappingSourcesSourceKeywordOutputReference_Override(a AuditmanagerControlControlMappingSourcesSourceKeywordOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAuditmanagerControl_Override ¶
func NewAuditmanagerControl_Override(a AuditmanagerControl, scope constructs.Construct, id *string, config *AuditmanagerControlConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/auditmanager_control aws_auditmanager_control} Resource.
Types ¶
type AuditmanagerControl ¶
type AuditmanagerControl interface {
cdktf.TerraformResource
ActionPlanInstructions() *string
SetActionPlanInstructions(val *string)
ActionPlanInstructionsInput() *string
ActionPlanTitle() *string
SetActionPlanTitle(val *string)
ActionPlanTitleInput() *string
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ControlMappingSources() AuditmanagerControlControlMappingSourcesList
ControlMappingSourcesInput() interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() cdktf.StringMap
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
TestingInformation() *string
SetTestingInformation(val *string)
TestingInformationInput() *string
Type() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutControlMappingSources(value interface{})
ResetActionPlanInstructions()
ResetActionPlanTitle()
ResetControlMappingSources()
ResetDescription()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTestingInformation()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/auditmanager_control aws_auditmanager_control}.
func NewAuditmanagerControl ¶
func NewAuditmanagerControl(scope constructs.Construct, id *string, config *AuditmanagerControlConfig) AuditmanagerControl
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/auditmanager_control aws_auditmanager_control} Resource.
type AuditmanagerControlConfig ¶
type AuditmanagerControlConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/auditmanager_control#name AuditmanagerControl#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/auditmanager_control#action_plan_instructions AuditmanagerControl#action_plan_instructions}.
ActionPlanInstructions *string `field:"optional" json:"actionPlanInstructions" yaml:"actionPlanInstructions"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/auditmanager_control#action_plan_title AuditmanagerControl#action_plan_title}.
ActionPlanTitle *string `field:"optional" json:"actionPlanTitle" yaml:"actionPlanTitle"`
// control_mapping_sources block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/auditmanager_control#control_mapping_sources AuditmanagerControl#control_mapping_sources}
ControlMappingSources interface{} `field:"optional" json:"controlMappingSources" yaml:"controlMappingSources"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/auditmanager_control#description AuditmanagerControl#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/auditmanager_control#tags AuditmanagerControl#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/auditmanager_control#testing_information AuditmanagerControl#testing_information}.
TestingInformation *string `field:"optional" json:"testingInformation" yaml:"testingInformation"`
}
type AuditmanagerControlControlMappingSources ¶
type AuditmanagerControlControlMappingSources struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/auditmanager_control#source_name AuditmanagerControl#source_name}.
SourceName *string `field:"required" json:"sourceName" yaml:"sourceName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/auditmanager_control#source_set_up_option AuditmanagerControl#source_set_up_option}.
SourceSetUpOption *string `field:"required" json:"sourceSetUpOption" yaml:"sourceSetUpOption"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/auditmanager_control#source_type AuditmanagerControl#source_type}.
SourceType *string `field:"required" json:"sourceType" yaml:"sourceType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/auditmanager_control#source_description AuditmanagerControl#source_description}.
SourceDescription *string `field:"optional" json:"sourceDescription" yaml:"sourceDescription"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/auditmanager_control#source_frequency AuditmanagerControl#source_frequency}.
SourceFrequency *string `field:"optional" json:"sourceFrequency" yaml:"sourceFrequency"`
// source_keyword block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/auditmanager_control#source_keyword AuditmanagerControl#source_keyword}
SourceKeyword interface{} `field:"optional" json:"sourceKeyword" yaml:"sourceKeyword"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/auditmanager_control#troubleshooting_text AuditmanagerControl#troubleshooting_text}.
TroubleshootingText *string `field:"optional" json:"troubleshootingText" yaml:"troubleshootingText"`
}
type AuditmanagerControlControlMappingSourcesList ¶
type AuditmanagerControlControlMappingSourcesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) AuditmanagerControlControlMappingSourcesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAuditmanagerControlControlMappingSourcesList ¶
func NewAuditmanagerControlControlMappingSourcesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AuditmanagerControlControlMappingSourcesList
type AuditmanagerControlControlMappingSourcesOutputReference ¶
type AuditmanagerControlControlMappingSourcesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
SourceDescription() *string
SetSourceDescription(val *string)
SourceDescriptionInput() *string
SourceFrequency() *string
SetSourceFrequency(val *string)
SourceFrequencyInput() *string
SourceId() *string
SourceKeyword() AuditmanagerControlControlMappingSourcesSourceKeywordList
SourceKeywordInput() interface{}
SourceName() *string
SetSourceName(val *string)
SourceNameInput() *string
SourceSetUpOption() *string
SetSourceSetUpOption(val *string)
SourceSetUpOptionInput() *string
SourceType() *string
SetSourceType(val *string)
SourceTypeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TroubleshootingText() *string
SetTroubleshootingText(val *string)
TroubleshootingTextInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutSourceKeyword(value interface{})
ResetSourceDescription()
ResetSourceFrequency()
ResetSourceKeyword()
ResetTroubleshootingText()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAuditmanagerControlControlMappingSourcesOutputReference ¶
func NewAuditmanagerControlControlMappingSourcesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AuditmanagerControlControlMappingSourcesOutputReference
type AuditmanagerControlControlMappingSourcesSourceKeyword ¶
type AuditmanagerControlControlMappingSourcesSourceKeyword struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/auditmanager_control#keyword_input_type AuditmanagerControl#keyword_input_type}.
KeywordInputType *string `field:"required" json:"keywordInputType" yaml:"keywordInputType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/auditmanager_control#keyword_value AuditmanagerControl#keyword_value}.
KeywordValue *string `field:"required" json:"keywordValue" yaml:"keywordValue"`
}
type AuditmanagerControlControlMappingSourcesSourceKeywordList ¶
type AuditmanagerControlControlMappingSourcesSourceKeywordList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) AuditmanagerControlControlMappingSourcesSourceKeywordOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAuditmanagerControlControlMappingSourcesSourceKeywordList ¶
func NewAuditmanagerControlControlMappingSourcesSourceKeywordList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AuditmanagerControlControlMappingSourcesSourceKeywordList
type AuditmanagerControlControlMappingSourcesSourceKeywordOutputReference ¶
type AuditmanagerControlControlMappingSourcesSourceKeywordOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
KeywordInputType() *string
SetKeywordInputType(val *string)
KeywordInputTypeInput() *string
KeywordValue() *string
SetKeywordValue(val *string)
KeywordValueInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAuditmanagerControlControlMappingSourcesSourceKeywordOutputReference ¶
func NewAuditmanagerControlControlMappingSourcesSourceKeywordOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AuditmanagerControlControlMappingSourcesSourceKeywordOutputReference
Source Files
¶
- AuditmanagerControl.go
- AuditmanagerControlConfig.go
- AuditmanagerControlControlMappingSources.go
- AuditmanagerControlControlMappingSourcesList.go
- AuditmanagerControlControlMappingSourcesList__checks.go
- AuditmanagerControlControlMappingSourcesOutputReference.go
- AuditmanagerControlControlMappingSourcesOutputReference__checks.go
- AuditmanagerControlControlMappingSourcesSourceKeyword.go
- AuditmanagerControlControlMappingSourcesSourceKeywordList.go
- AuditmanagerControlControlMappingSourcesSourceKeywordList__checks.go
- AuditmanagerControlControlMappingSourcesSourceKeywordOutputReference.go
- AuditmanagerControlControlMappingSourcesSourceKeywordOutputReference__checks.go
- AuditmanagerControl__checks.go
- main.go