Documentation
¶
Index ¶
- func BackupSelection_IsConstruct(x interface{}) *bool
- func BackupSelection_IsTerraformElement(x interface{}) *bool
- func BackupSelection_IsTerraformResource(x interface{}) *bool
- func BackupSelection_TfResourceType() *string
- func NewBackupSelectionConditionList_Override(b BackupSelectionConditionList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewBackupSelectionConditionOutputReference_Override(b BackupSelectionConditionOutputReference, ...)
- func NewBackupSelectionConditionStringEqualsList_Override(b BackupSelectionConditionStringEqualsList, ...)
- func NewBackupSelectionConditionStringEqualsOutputReference_Override(b BackupSelectionConditionStringEqualsOutputReference, ...)
- func NewBackupSelectionConditionStringLikeList_Override(b BackupSelectionConditionStringLikeList, ...)
- func NewBackupSelectionConditionStringLikeOutputReference_Override(b BackupSelectionConditionStringLikeOutputReference, ...)
- func NewBackupSelectionConditionStringNotEqualsList_Override(b BackupSelectionConditionStringNotEqualsList, ...)
- func NewBackupSelectionConditionStringNotEqualsOutputReference_Override(b BackupSelectionConditionStringNotEqualsOutputReference, ...)
- func NewBackupSelectionConditionStringNotLikeList_Override(b BackupSelectionConditionStringNotLikeList, ...)
- func NewBackupSelectionConditionStringNotLikeOutputReference_Override(b BackupSelectionConditionStringNotLikeOutputReference, ...)
- func NewBackupSelectionSelectionTagList_Override(b BackupSelectionSelectionTagList, ...)
- func NewBackupSelectionSelectionTagOutputReference_Override(b BackupSelectionSelectionTagOutputReference, ...)
- func NewBackupSelection_Override(b BackupSelection, scope constructs.Construct, id *string, ...)
- type BackupSelection
- type BackupSelectionCondition
- type BackupSelectionConditionList
- type BackupSelectionConditionOutputReference
- type BackupSelectionConditionStringEquals
- type BackupSelectionConditionStringEqualsList
- type BackupSelectionConditionStringEqualsOutputReference
- type BackupSelectionConditionStringLike
- type BackupSelectionConditionStringLikeList
- type BackupSelectionConditionStringLikeOutputReference
- type BackupSelectionConditionStringNotEquals
- type BackupSelectionConditionStringNotEqualsList
- type BackupSelectionConditionStringNotEqualsOutputReference
- type BackupSelectionConditionStringNotLike
- type BackupSelectionConditionStringNotLikeList
- type BackupSelectionConditionStringNotLikeOutputReference
- type BackupSelectionConfig
- type BackupSelectionSelectionTag
- type BackupSelectionSelectionTagList
- type BackupSelectionSelectionTagOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BackupSelection_IsConstruct ¶
func BackupSelection_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func BackupSelection_IsTerraformElement ¶
func BackupSelection_IsTerraformElement(x interface{}) *bool
Experimental.
func BackupSelection_IsTerraformResource ¶
func BackupSelection_IsTerraformResource(x interface{}) *bool
Experimental.
func BackupSelection_TfResourceType ¶
func BackupSelection_TfResourceType() *string
func NewBackupSelectionConditionList_Override ¶
func NewBackupSelectionConditionList_Override(b BackupSelectionConditionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewBackupSelectionConditionOutputReference_Override ¶
func NewBackupSelectionConditionOutputReference_Override(b BackupSelectionConditionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewBackupSelectionConditionStringEqualsList_Override ¶
func NewBackupSelectionConditionStringEqualsList_Override(b BackupSelectionConditionStringEqualsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewBackupSelectionConditionStringEqualsOutputReference_Override ¶
func NewBackupSelectionConditionStringEqualsOutputReference_Override(b BackupSelectionConditionStringEqualsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewBackupSelectionConditionStringLikeList_Override ¶
func NewBackupSelectionConditionStringLikeList_Override(b BackupSelectionConditionStringLikeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewBackupSelectionConditionStringLikeOutputReference_Override ¶
func NewBackupSelectionConditionStringLikeOutputReference_Override(b BackupSelectionConditionStringLikeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewBackupSelectionConditionStringNotEqualsList_Override ¶
func NewBackupSelectionConditionStringNotEqualsList_Override(b BackupSelectionConditionStringNotEqualsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewBackupSelectionConditionStringNotEqualsOutputReference_Override ¶
func NewBackupSelectionConditionStringNotEqualsOutputReference_Override(b BackupSelectionConditionStringNotEqualsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewBackupSelectionConditionStringNotLikeList_Override ¶
func NewBackupSelectionConditionStringNotLikeList_Override(b BackupSelectionConditionStringNotLikeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewBackupSelectionConditionStringNotLikeOutputReference_Override ¶
func NewBackupSelectionConditionStringNotLikeOutputReference_Override(b BackupSelectionConditionStringNotLikeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewBackupSelectionSelectionTagList_Override ¶
func NewBackupSelectionSelectionTagList_Override(b BackupSelectionSelectionTagList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewBackupSelectionSelectionTagOutputReference_Override ¶
func NewBackupSelectionSelectionTagOutputReference_Override(b BackupSelectionSelectionTagOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewBackupSelection_Override ¶
func NewBackupSelection_Override(b BackupSelection, scope constructs.Construct, id *string, config *BackupSelectionConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection aws_backup_selection} Resource.
Types ¶
type BackupSelection ¶
type BackupSelection interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
Condition() BackupSelectionConditionList
ConditionInput() interface{}
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
IamRoleArn() *string
SetIamRoleArn(val *string)
IamRoleArnInput() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
NotResources() *[]*string
SetNotResources(val *[]*string)
NotResourcesInput() *[]*string
PlanId() *string
SetPlanId(val *string)
PlanIdInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Resources() *[]*string
SetResources(val *[]*string)
ResourcesInput() *[]*string
SelectionTag() BackupSelectionSelectionTagList
SelectionTagInput() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCondition(value interface{})
PutSelectionTag(value interface{})
ResetCondition()
ResetId()
ResetNotResources()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetResources()
ResetSelectionTag()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection aws_backup_selection}.
func NewBackupSelection ¶
func NewBackupSelection(scope constructs.Construct, id *string, config *BackupSelectionConfig) BackupSelection
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection aws_backup_selection} Resource.
type BackupSelectionCondition ¶
type BackupSelectionCondition struct {
// string_equals block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#string_equals BackupSelection#string_equals}
StringEquals interface{} `field:"optional" json:"stringEquals" yaml:"stringEquals"`
// string_like block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#string_like BackupSelection#string_like}
StringLike interface{} `field:"optional" json:"stringLike" yaml:"stringLike"`
// string_not_equals block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#string_not_equals BackupSelection#string_not_equals}
StringNotEquals interface{} `field:"optional" json:"stringNotEquals" yaml:"stringNotEquals"`
// string_not_like block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#string_not_like BackupSelection#string_not_like}
StringNotLike interface{} `field:"optional" json:"stringNotLike" yaml:"stringNotLike"`
}
type BackupSelectionConditionList ¶
type BackupSelectionConditionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) BackupSelectionConditionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupSelectionConditionList ¶
func NewBackupSelectionConditionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) BackupSelectionConditionList
type BackupSelectionConditionOutputReference ¶
type BackupSelectionConditionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
StringEquals() BackupSelectionConditionStringEqualsList
StringEqualsInput() interface{}
StringLike() BackupSelectionConditionStringLikeList
StringLikeInput() interface{}
StringNotEquals() BackupSelectionConditionStringNotEqualsList
StringNotEqualsInput() interface{}
StringNotLike() BackupSelectionConditionStringNotLikeList
StringNotLikeInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutStringEquals(value interface{})
PutStringLike(value interface{})
PutStringNotEquals(value interface{})
PutStringNotLike(value interface{})
ResetStringEquals()
ResetStringLike()
ResetStringNotEquals()
ResetStringNotLike()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupSelectionConditionOutputReference ¶
func NewBackupSelectionConditionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) BackupSelectionConditionOutputReference
type BackupSelectionConditionStringEquals ¶
type BackupSelectionConditionStringEquals struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#key BackupSelection#key}.
Key *string `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#value BackupSelection#value}.
Value *string `field:"required" json:"value" yaml:"value"`
}
type BackupSelectionConditionStringEqualsList ¶
type BackupSelectionConditionStringEqualsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) BackupSelectionConditionStringEqualsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupSelectionConditionStringEqualsList ¶
func NewBackupSelectionConditionStringEqualsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) BackupSelectionConditionStringEqualsList
type BackupSelectionConditionStringEqualsOutputReference ¶
type BackupSelectionConditionStringEqualsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupSelectionConditionStringEqualsOutputReference ¶
func NewBackupSelectionConditionStringEqualsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) BackupSelectionConditionStringEqualsOutputReference
type BackupSelectionConditionStringLike ¶
type BackupSelectionConditionStringLike struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#key BackupSelection#key}.
Key *string `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#value BackupSelection#value}.
Value *string `field:"required" json:"value" yaml:"value"`
}
type BackupSelectionConditionStringLikeList ¶
type BackupSelectionConditionStringLikeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) BackupSelectionConditionStringLikeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupSelectionConditionStringLikeList ¶
func NewBackupSelectionConditionStringLikeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) BackupSelectionConditionStringLikeList
type BackupSelectionConditionStringLikeOutputReference ¶
type BackupSelectionConditionStringLikeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupSelectionConditionStringLikeOutputReference ¶
func NewBackupSelectionConditionStringLikeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) BackupSelectionConditionStringLikeOutputReference
type BackupSelectionConditionStringNotEquals ¶
type BackupSelectionConditionStringNotEquals struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#key BackupSelection#key}.
Key *string `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#value BackupSelection#value}.
Value *string `field:"required" json:"value" yaml:"value"`
}
type BackupSelectionConditionStringNotEqualsList ¶
type BackupSelectionConditionStringNotEqualsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) BackupSelectionConditionStringNotEqualsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupSelectionConditionStringNotEqualsList ¶
func NewBackupSelectionConditionStringNotEqualsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) BackupSelectionConditionStringNotEqualsList
type BackupSelectionConditionStringNotEqualsOutputReference ¶
type BackupSelectionConditionStringNotEqualsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupSelectionConditionStringNotEqualsOutputReference ¶
func NewBackupSelectionConditionStringNotEqualsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) BackupSelectionConditionStringNotEqualsOutputReference
type BackupSelectionConditionStringNotLike ¶
type BackupSelectionConditionStringNotLike struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#key BackupSelection#key}.
Key *string `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#value BackupSelection#value}.
Value *string `field:"required" json:"value" yaml:"value"`
}
type BackupSelectionConditionStringNotLikeList ¶
type BackupSelectionConditionStringNotLikeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) BackupSelectionConditionStringNotLikeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupSelectionConditionStringNotLikeList ¶
func NewBackupSelectionConditionStringNotLikeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) BackupSelectionConditionStringNotLikeList
type BackupSelectionConditionStringNotLikeOutputReference ¶
type BackupSelectionConditionStringNotLikeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupSelectionConditionStringNotLikeOutputReference ¶
func NewBackupSelectionConditionStringNotLikeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) BackupSelectionConditionStringNotLikeOutputReference
type BackupSelectionConfig ¶
type BackupSelectionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#iam_role_arn BackupSelection#iam_role_arn}.
IamRoleArn *string `field:"required" json:"iamRoleArn" yaml:"iamRoleArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#name BackupSelection#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#plan_id BackupSelection#plan_id}.
PlanId *string `field:"required" json:"planId" yaml:"planId"`
// condition block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#condition BackupSelection#condition}
Condition interface{} `field:"optional" json:"condition" yaml:"condition"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#id BackupSelection#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#not_resources BackupSelection#not_resources}.
NotResources *[]*string `field:"optional" json:"notResources" yaml:"notResources"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#resources BackupSelection#resources}.
Resources *[]*string `field:"optional" json:"resources" yaml:"resources"`
// selection_tag block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#selection_tag BackupSelection#selection_tag}
SelectionTag interface{} `field:"optional" json:"selectionTag" yaml:"selectionTag"`
}
type BackupSelectionSelectionTag ¶
type BackupSelectionSelectionTag struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#key BackupSelection#key}.
Key *string `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#type BackupSelection#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/backup_selection#value BackupSelection#value}.
Value *string `field:"required" json:"value" yaml:"value"`
}
type BackupSelectionSelectionTagList ¶
type BackupSelectionSelectionTagList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) BackupSelectionSelectionTagOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupSelectionSelectionTagList ¶
func NewBackupSelectionSelectionTagList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) BackupSelectionSelectionTagList
type BackupSelectionSelectionTagOutputReference ¶
type BackupSelectionSelectionTagOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupSelectionSelectionTagOutputReference ¶
func NewBackupSelectionSelectionTagOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) BackupSelectionSelectionTagOutputReference
Source Files
¶
- BackupSelection.go
- BackupSelectionCondition.go
- BackupSelectionConditionList.go
- BackupSelectionConditionList__checks.go
- BackupSelectionConditionOutputReference.go
- BackupSelectionConditionOutputReference__checks.go
- BackupSelectionConditionStringEquals.go
- BackupSelectionConditionStringEqualsList.go
- BackupSelectionConditionStringEqualsList__checks.go
- BackupSelectionConditionStringEqualsOutputReference.go
- BackupSelectionConditionStringEqualsOutputReference__checks.go
- BackupSelectionConditionStringLike.go
- BackupSelectionConditionStringLikeList.go
- BackupSelectionConditionStringLikeList__checks.go
- BackupSelectionConditionStringLikeOutputReference.go
- BackupSelectionConditionStringLikeOutputReference__checks.go
- BackupSelectionConditionStringNotEquals.go
- BackupSelectionConditionStringNotEqualsList.go
- BackupSelectionConditionStringNotEqualsList__checks.go
- BackupSelectionConditionStringNotEqualsOutputReference.go
- BackupSelectionConditionStringNotEqualsOutputReference__checks.go
- BackupSelectionConditionStringNotLike.go
- BackupSelectionConditionStringNotLikeList.go
- BackupSelectionConditionStringNotLikeList__checks.go
- BackupSelectionConditionStringNotLikeOutputReference.go
- BackupSelectionConditionStringNotLikeOutputReference__checks.go
- BackupSelectionConfig.go
- BackupSelectionSelectionTag.go
- BackupSelectionSelectionTagList.go
- BackupSelectionSelectionTagList__checks.go
- BackupSelectionSelectionTagOutputReference.go
- BackupSelectionSelectionTagOutputReference__checks.go
- BackupSelection__checks.go
- main.go