Documentation
¶
Index ¶
- func BudgetsBudgetAction_IsConstruct(x interface{}) *bool
- func BudgetsBudgetAction_IsTerraformElement(x interface{}) *bool
- func BudgetsBudgetAction_IsTerraformResource(x interface{}) *bool
- func BudgetsBudgetAction_TfResourceType() *string
- func NewBudgetsBudgetActionActionThresholdOutputReference_Override(b BudgetsBudgetActionActionThresholdOutputReference, ...)
- func NewBudgetsBudgetActionDefinitionIamActionDefinitionOutputReference_Override(b BudgetsBudgetActionDefinitionIamActionDefinitionOutputReference, ...)
- func NewBudgetsBudgetActionDefinitionOutputReference_Override(b BudgetsBudgetActionDefinitionOutputReference, ...)
- func NewBudgetsBudgetActionDefinitionScpActionDefinitionOutputReference_Override(b BudgetsBudgetActionDefinitionScpActionDefinitionOutputReference, ...)
- func NewBudgetsBudgetActionDefinitionSsmActionDefinitionOutputReference_Override(b BudgetsBudgetActionDefinitionSsmActionDefinitionOutputReference, ...)
- func NewBudgetsBudgetActionSubscriberList_Override(b BudgetsBudgetActionSubscriberList, ...)
- func NewBudgetsBudgetActionSubscriberOutputReference_Override(b BudgetsBudgetActionSubscriberOutputReference, ...)
- func NewBudgetsBudgetActionTimeoutsOutputReference_Override(b BudgetsBudgetActionTimeoutsOutputReference, ...)
- func NewBudgetsBudgetAction_Override(b BudgetsBudgetAction, scope constructs.Construct, id *string, ...)
- type BudgetsBudgetAction
- type BudgetsBudgetActionActionThreshold
- type BudgetsBudgetActionActionThresholdOutputReference
- type BudgetsBudgetActionConfig
- type BudgetsBudgetActionDefinition
- type BudgetsBudgetActionDefinitionIamActionDefinition
- type BudgetsBudgetActionDefinitionIamActionDefinitionOutputReference
- type BudgetsBudgetActionDefinitionOutputReference
- type BudgetsBudgetActionDefinitionScpActionDefinition
- type BudgetsBudgetActionDefinitionScpActionDefinitionOutputReference
- type BudgetsBudgetActionDefinitionSsmActionDefinition
- type BudgetsBudgetActionDefinitionSsmActionDefinitionOutputReference
- type BudgetsBudgetActionSubscriber
- type BudgetsBudgetActionSubscriberList
- type BudgetsBudgetActionSubscriberOutputReference
- type BudgetsBudgetActionTimeouts
- type BudgetsBudgetActionTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BudgetsBudgetAction_IsConstruct ¶
func BudgetsBudgetAction_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func BudgetsBudgetAction_IsTerraformElement ¶
func BudgetsBudgetAction_IsTerraformElement(x interface{}) *bool
Experimental.
func BudgetsBudgetAction_IsTerraformResource ¶
func BudgetsBudgetAction_IsTerraformResource(x interface{}) *bool
Experimental.
func BudgetsBudgetAction_TfResourceType ¶
func BudgetsBudgetAction_TfResourceType() *string
func NewBudgetsBudgetActionActionThresholdOutputReference_Override ¶
func NewBudgetsBudgetActionActionThresholdOutputReference_Override(b BudgetsBudgetActionActionThresholdOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBudgetsBudgetActionDefinitionIamActionDefinitionOutputReference_Override ¶
func NewBudgetsBudgetActionDefinitionIamActionDefinitionOutputReference_Override(b BudgetsBudgetActionDefinitionIamActionDefinitionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBudgetsBudgetActionDefinitionOutputReference_Override ¶
func NewBudgetsBudgetActionDefinitionOutputReference_Override(b BudgetsBudgetActionDefinitionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBudgetsBudgetActionDefinitionScpActionDefinitionOutputReference_Override ¶
func NewBudgetsBudgetActionDefinitionScpActionDefinitionOutputReference_Override(b BudgetsBudgetActionDefinitionScpActionDefinitionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBudgetsBudgetActionDefinitionSsmActionDefinitionOutputReference_Override ¶
func NewBudgetsBudgetActionDefinitionSsmActionDefinitionOutputReference_Override(b BudgetsBudgetActionDefinitionSsmActionDefinitionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBudgetsBudgetActionSubscriberList_Override ¶
func NewBudgetsBudgetActionSubscriberList_Override(b BudgetsBudgetActionSubscriberList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewBudgetsBudgetActionSubscriberOutputReference_Override ¶
func NewBudgetsBudgetActionSubscriberOutputReference_Override(b BudgetsBudgetActionSubscriberOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewBudgetsBudgetActionTimeoutsOutputReference_Override ¶
func NewBudgetsBudgetActionTimeoutsOutputReference_Override(b BudgetsBudgetActionTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBudgetsBudgetAction_Override ¶
func NewBudgetsBudgetAction_Override(b BudgetsBudgetAction, scope constructs.Construct, id *string, config *BudgetsBudgetActionConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action aws_budgets_budget_action} Resource.
Types ¶
type BudgetsBudgetAction ¶
type BudgetsBudgetAction interface {
cdktf.TerraformResource
AccountId() *string
SetAccountId(val *string)
AccountIdInput() *string
ActionId() *string
ActionThreshold() BudgetsBudgetActionActionThresholdOutputReference
ActionThresholdInput() *BudgetsBudgetActionActionThreshold
ActionType() *string
SetActionType(val *string)
ActionTypeInput() *string
ApprovalModel() *string
SetApprovalModel(val *string)
ApprovalModelInput() *string
Arn() *string
BudgetName() *string
SetBudgetName(val *string)
BudgetNameInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
Definition() BudgetsBudgetActionDefinitionOutputReference
DefinitionInput() *BudgetsBudgetActionDefinition
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
ExecutionRoleArn() *string
SetExecutionRoleArn(val *string)
ExecutionRoleArnInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
NotificationType() *string
SetNotificationType(val *string)
NotificationTypeInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Status() *string
Subscriber() BudgetsBudgetActionSubscriberList
SubscriberInput() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() BudgetsBudgetActionTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutActionThreshold(value *BudgetsBudgetActionActionThreshold)
PutDefinition(value *BudgetsBudgetActionDefinition)
PutSubscriber(value interface{})
PutTimeouts(value *BudgetsBudgetActionTimeouts)
ResetAccountId()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action aws_budgets_budget_action}.
func NewBudgetsBudgetAction ¶
func NewBudgetsBudgetAction(scope constructs.Construct, id *string, config *BudgetsBudgetActionConfig) BudgetsBudgetAction
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action aws_budgets_budget_action} Resource.
type BudgetsBudgetActionActionThreshold ¶
type BudgetsBudgetActionActionThreshold struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#action_threshold_type BudgetsBudgetAction#action_threshold_type}.
ActionThresholdType *string `field:"required" json:"actionThresholdType" yaml:"actionThresholdType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#action_threshold_value BudgetsBudgetAction#action_threshold_value}.
ActionThresholdValue *float64 `field:"required" json:"actionThresholdValue" yaml:"actionThresholdValue"`
}
type BudgetsBudgetActionActionThresholdOutputReference ¶
type BudgetsBudgetActionActionThresholdOutputReference interface {
cdktf.ComplexObject
ActionThresholdType() *string
SetActionThresholdType(val *string)
ActionThresholdTypeInput() *string
ActionThresholdValue() *float64
SetActionThresholdValue(val *float64)
ActionThresholdValueInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *BudgetsBudgetActionActionThreshold
SetInternalValue(val *BudgetsBudgetActionActionThreshold)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBudgetsBudgetActionActionThresholdOutputReference ¶
func NewBudgetsBudgetActionActionThresholdOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BudgetsBudgetActionActionThresholdOutputReference
type BudgetsBudgetActionConfig ¶
type BudgetsBudgetActionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// action_threshold block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#action_threshold BudgetsBudgetAction#action_threshold}
ActionThreshold *BudgetsBudgetActionActionThreshold `field:"required" json:"actionThreshold" yaml:"actionThreshold"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#action_type BudgetsBudgetAction#action_type}.
ActionType *string `field:"required" json:"actionType" yaml:"actionType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#approval_model BudgetsBudgetAction#approval_model}.
ApprovalModel *string `field:"required" json:"approvalModel" yaml:"approvalModel"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#budget_name BudgetsBudgetAction#budget_name}.
BudgetName *string `field:"required" json:"budgetName" yaml:"budgetName"`
// definition block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#definition BudgetsBudgetAction#definition}
Definition *BudgetsBudgetActionDefinition `field:"required" json:"definition" yaml:"definition"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#execution_role_arn BudgetsBudgetAction#execution_role_arn}.
ExecutionRoleArn *string `field:"required" json:"executionRoleArn" yaml:"executionRoleArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#notification_type BudgetsBudgetAction#notification_type}.
NotificationType *string `field:"required" json:"notificationType" yaml:"notificationType"`
// subscriber block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#subscriber BudgetsBudgetAction#subscriber}
Subscriber interface{} `field:"required" json:"subscriber" yaml:"subscriber"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#account_id BudgetsBudgetAction#account_id}.
AccountId *string `field:"optional" json:"accountId" yaml:"accountId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#id BudgetsBudgetAction#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#timeouts BudgetsBudgetAction#timeouts}
Timeouts *BudgetsBudgetActionTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type BudgetsBudgetActionDefinition ¶
type BudgetsBudgetActionDefinition struct {
// iam_action_definition block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#iam_action_definition BudgetsBudgetAction#iam_action_definition}
IamActionDefinition *BudgetsBudgetActionDefinitionIamActionDefinition `field:"optional" json:"iamActionDefinition" yaml:"iamActionDefinition"`
// scp_action_definition block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#scp_action_definition BudgetsBudgetAction#scp_action_definition}
ScpActionDefinition *BudgetsBudgetActionDefinitionScpActionDefinition `field:"optional" json:"scpActionDefinition" yaml:"scpActionDefinition"`
// ssm_action_definition block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#ssm_action_definition BudgetsBudgetAction#ssm_action_definition}
SsmActionDefinition *BudgetsBudgetActionDefinitionSsmActionDefinition `field:"optional" json:"ssmActionDefinition" yaml:"ssmActionDefinition"`
}
type BudgetsBudgetActionDefinitionIamActionDefinition ¶
type BudgetsBudgetActionDefinitionIamActionDefinition struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#policy_arn BudgetsBudgetAction#policy_arn}.
PolicyArn *string `field:"required" json:"policyArn" yaml:"policyArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#groups BudgetsBudgetAction#groups}.
Groups *[]*string `field:"optional" json:"groups" yaml:"groups"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#roles BudgetsBudgetAction#roles}.
Roles *[]*string `field:"optional" json:"roles" yaml:"roles"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#users BudgetsBudgetAction#users}.
Users *[]*string `field:"optional" json:"users" yaml:"users"`
}
type BudgetsBudgetActionDefinitionIamActionDefinitionOutputReference ¶
type BudgetsBudgetActionDefinitionIamActionDefinitionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Groups() *[]*string
SetGroups(val *[]*string)
GroupsInput() *[]*string
InternalValue() *BudgetsBudgetActionDefinitionIamActionDefinition
SetInternalValue(val *BudgetsBudgetActionDefinitionIamActionDefinition)
PolicyArn() *string
SetPolicyArn(val *string)
PolicyArnInput() *string
Roles() *[]*string
SetRoles(val *[]*string)
RolesInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Users() *[]*string
SetUsers(val *[]*string)
UsersInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetGroups()
ResetRoles()
ResetUsers()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBudgetsBudgetActionDefinitionIamActionDefinitionOutputReference ¶
func NewBudgetsBudgetActionDefinitionIamActionDefinitionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BudgetsBudgetActionDefinitionIamActionDefinitionOutputReference
type BudgetsBudgetActionDefinitionOutputReference ¶
type BudgetsBudgetActionDefinitionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IamActionDefinition() BudgetsBudgetActionDefinitionIamActionDefinitionOutputReference
IamActionDefinitionInput() *BudgetsBudgetActionDefinitionIamActionDefinition
InternalValue() *BudgetsBudgetActionDefinition
SetInternalValue(val *BudgetsBudgetActionDefinition)
ScpActionDefinition() BudgetsBudgetActionDefinitionScpActionDefinitionOutputReference
ScpActionDefinitionInput() *BudgetsBudgetActionDefinitionScpActionDefinition
SsmActionDefinition() BudgetsBudgetActionDefinitionSsmActionDefinitionOutputReference
SsmActionDefinitionInput() *BudgetsBudgetActionDefinitionSsmActionDefinition
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutIamActionDefinition(value *BudgetsBudgetActionDefinitionIamActionDefinition)
PutScpActionDefinition(value *BudgetsBudgetActionDefinitionScpActionDefinition)
PutSsmActionDefinition(value *BudgetsBudgetActionDefinitionSsmActionDefinition)
ResetIamActionDefinition()
ResetScpActionDefinition()
ResetSsmActionDefinition()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBudgetsBudgetActionDefinitionOutputReference ¶
func NewBudgetsBudgetActionDefinitionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BudgetsBudgetActionDefinitionOutputReference
type BudgetsBudgetActionDefinitionScpActionDefinition ¶
type BudgetsBudgetActionDefinitionScpActionDefinition struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#policy_id BudgetsBudgetAction#policy_id}.
PolicyId *string `field:"required" json:"policyId" yaml:"policyId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#target_ids BudgetsBudgetAction#target_ids}.
TargetIds *[]*string `field:"required" json:"targetIds" yaml:"targetIds"`
}
type BudgetsBudgetActionDefinitionScpActionDefinitionOutputReference ¶
type BudgetsBudgetActionDefinitionScpActionDefinitionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *BudgetsBudgetActionDefinitionScpActionDefinition
SetInternalValue(val *BudgetsBudgetActionDefinitionScpActionDefinition)
PolicyId() *string
SetPolicyId(val *string)
PolicyIdInput() *string
TargetIds() *[]*string
SetTargetIds(val *[]*string)
TargetIdsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBudgetsBudgetActionDefinitionScpActionDefinitionOutputReference ¶
func NewBudgetsBudgetActionDefinitionScpActionDefinitionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BudgetsBudgetActionDefinitionScpActionDefinitionOutputReference
type BudgetsBudgetActionDefinitionSsmActionDefinition ¶
type BudgetsBudgetActionDefinitionSsmActionDefinition struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#action_sub_type BudgetsBudgetAction#action_sub_type}.
ActionSubType *string `field:"required" json:"actionSubType" yaml:"actionSubType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#instance_ids BudgetsBudgetAction#instance_ids}.
InstanceIds *[]*string `field:"required" json:"instanceIds" yaml:"instanceIds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#region BudgetsBudgetAction#region}.
Region *string `field:"required" json:"region" yaml:"region"`
}
type BudgetsBudgetActionDefinitionSsmActionDefinitionOutputReference ¶
type BudgetsBudgetActionDefinitionSsmActionDefinitionOutputReference interface {
cdktf.ComplexObject
ActionSubType() *string
SetActionSubType(val *string)
ActionSubTypeInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InstanceIds() *[]*string
SetInstanceIds(val *[]*string)
InstanceIdsInput() *[]*string
InternalValue() *BudgetsBudgetActionDefinitionSsmActionDefinition
SetInternalValue(val *BudgetsBudgetActionDefinitionSsmActionDefinition)
Region() *string
SetRegion(val *string)
RegionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBudgetsBudgetActionDefinitionSsmActionDefinitionOutputReference ¶
func NewBudgetsBudgetActionDefinitionSsmActionDefinitionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BudgetsBudgetActionDefinitionSsmActionDefinitionOutputReference
type BudgetsBudgetActionSubscriber ¶
type BudgetsBudgetActionSubscriber struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#address BudgetsBudgetAction#address}.
Address *string `field:"required" json:"address" yaml:"address"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#subscription_type BudgetsBudgetAction#subscription_type}.
SubscriptionType *string `field:"required" json:"subscriptionType" yaml:"subscriptionType"`
}
type BudgetsBudgetActionSubscriberList ¶
type BudgetsBudgetActionSubscriberList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) BudgetsBudgetActionSubscriberOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBudgetsBudgetActionSubscriberList ¶
func NewBudgetsBudgetActionSubscriberList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) BudgetsBudgetActionSubscriberList
type BudgetsBudgetActionSubscriberOutputReference ¶
type BudgetsBudgetActionSubscriberOutputReference interface {
cdktf.ComplexObject
Address() *string
SetAddress(val *string)
AddressInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
SubscriptionType() *string
SetSubscriptionType(val *string)
SubscriptionTypeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBudgetsBudgetActionSubscriberOutputReference ¶
func NewBudgetsBudgetActionSubscriberOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) BudgetsBudgetActionSubscriberOutputReference
type BudgetsBudgetActionTimeouts ¶
type BudgetsBudgetActionTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#create BudgetsBudgetAction#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/budgets_budget_action#update BudgetsBudgetAction#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type BudgetsBudgetActionTimeoutsOutputReference ¶
type BudgetsBudgetActionTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBudgetsBudgetActionTimeoutsOutputReference ¶
func NewBudgetsBudgetActionTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BudgetsBudgetActionTimeoutsOutputReference
Source Files
¶
- BudgetsBudgetAction.go
- BudgetsBudgetActionActionThreshold.go
- BudgetsBudgetActionActionThresholdOutputReference.go
- BudgetsBudgetActionActionThresholdOutputReference__checks.go
- BudgetsBudgetActionConfig.go
- BudgetsBudgetActionDefinition.go
- BudgetsBudgetActionDefinitionIamActionDefinition.go
- BudgetsBudgetActionDefinitionIamActionDefinitionOutputReference.go
- BudgetsBudgetActionDefinitionIamActionDefinitionOutputReference__checks.go
- BudgetsBudgetActionDefinitionOutputReference.go
- BudgetsBudgetActionDefinitionOutputReference__checks.go
- BudgetsBudgetActionDefinitionScpActionDefinition.go
- BudgetsBudgetActionDefinitionScpActionDefinitionOutputReference.go
- BudgetsBudgetActionDefinitionScpActionDefinitionOutputReference__checks.go
- BudgetsBudgetActionDefinitionSsmActionDefinition.go
- BudgetsBudgetActionDefinitionSsmActionDefinitionOutputReference.go
- BudgetsBudgetActionDefinitionSsmActionDefinitionOutputReference__checks.go
- BudgetsBudgetActionSubscriber.go
- BudgetsBudgetActionSubscriberList.go
- BudgetsBudgetActionSubscriberList__checks.go
- BudgetsBudgetActionSubscriberOutputReference.go
- BudgetsBudgetActionSubscriberOutputReference__checks.go
- BudgetsBudgetActionTimeouts.go
- BudgetsBudgetActionTimeoutsOutputReference.go
- BudgetsBudgetActionTimeoutsOutputReference__checks.go
- BudgetsBudgetAction__checks.go
- main.go