Documentation
¶
Index ¶
- func ChimeVoiceConnectorGroup_IsConstruct(x interface{}) *bool
- func ChimeVoiceConnectorGroup_IsTerraformElement(x interface{}) *bool
- func ChimeVoiceConnectorGroup_IsTerraformResource(x interface{}) *bool
- func ChimeVoiceConnectorGroup_TfResourceType() *string
- func NewChimeVoiceConnectorGroupConnectorList_Override(c ChimeVoiceConnectorGroupConnectorList, ...)
- func NewChimeVoiceConnectorGroupConnectorOutputReference_Override(c ChimeVoiceConnectorGroupConnectorOutputReference, ...)
- func NewChimeVoiceConnectorGroup_Override(c ChimeVoiceConnectorGroup, scope constructs.Construct, id *string, ...)
- type ChimeVoiceConnectorGroup
- type ChimeVoiceConnectorGroupConfig
- type ChimeVoiceConnectorGroupConnector
- type ChimeVoiceConnectorGroupConnectorList
- type ChimeVoiceConnectorGroupConnectorOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ChimeVoiceConnectorGroup_IsConstruct ¶
func ChimeVoiceConnectorGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ChimeVoiceConnectorGroup_IsTerraformElement ¶
func ChimeVoiceConnectorGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func ChimeVoiceConnectorGroup_IsTerraformResource ¶
func ChimeVoiceConnectorGroup_IsTerraformResource(x interface{}) *bool
Experimental.
func ChimeVoiceConnectorGroup_TfResourceType ¶
func ChimeVoiceConnectorGroup_TfResourceType() *string
func NewChimeVoiceConnectorGroupConnectorList_Override ¶
func NewChimeVoiceConnectorGroupConnectorList_Override(c ChimeVoiceConnectorGroupConnectorList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewChimeVoiceConnectorGroupConnectorOutputReference_Override ¶
func NewChimeVoiceConnectorGroupConnectorOutputReference_Override(c ChimeVoiceConnectorGroupConnectorOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewChimeVoiceConnectorGroup_Override ¶
func NewChimeVoiceConnectorGroup_Override(c ChimeVoiceConnectorGroup, scope constructs.Construct, id *string, config *ChimeVoiceConnectorGroupConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_group aws_chime_voice_connector_group} Resource.
Types ¶
type ChimeVoiceConnectorGroup ¶
type ChimeVoiceConnectorGroup interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
Connector() ChimeVoiceConnectorGroupConnectorList
ConnectorInput() interface{}
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutConnector(value interface{})
ResetConnector()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_group aws_chime_voice_connector_group}.
func NewChimeVoiceConnectorGroup ¶
func NewChimeVoiceConnectorGroup(scope constructs.Construct, id *string, config *ChimeVoiceConnectorGroupConfig) ChimeVoiceConnectorGroup
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_group aws_chime_voice_connector_group} Resource.
type ChimeVoiceConnectorGroupConfig ¶
type ChimeVoiceConnectorGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_group#name ChimeVoiceConnectorGroup#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// connector block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_group#connector ChimeVoiceConnectorGroup#connector}
Connector interface{} `field:"optional" json:"connector" yaml:"connector"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_group#id ChimeVoiceConnectorGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type ChimeVoiceConnectorGroupConnector ¶
type ChimeVoiceConnectorGroupConnector struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_group#priority ChimeVoiceConnectorGroup#priority}.
Priority *float64 `field:"required" json:"priority" yaml:"priority"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_group#voice_connector_id ChimeVoiceConnectorGroup#voice_connector_id}.
VoiceConnectorId *string `field:"required" json:"voiceConnectorId" yaml:"voiceConnectorId"`
}
type ChimeVoiceConnectorGroupConnectorList ¶
type ChimeVoiceConnectorGroupConnectorList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ChimeVoiceConnectorGroupConnectorOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewChimeVoiceConnectorGroupConnectorList ¶
func NewChimeVoiceConnectorGroupConnectorList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ChimeVoiceConnectorGroupConnectorList
type ChimeVoiceConnectorGroupConnectorOutputReference ¶
type ChimeVoiceConnectorGroupConnectorOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Priority() *float64
SetPriority(val *float64)
PriorityInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VoiceConnectorId() *string
SetVoiceConnectorId(val *string)
VoiceConnectorIdInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewChimeVoiceConnectorGroupConnectorOutputReference ¶
func NewChimeVoiceConnectorGroupConnectorOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ChimeVoiceConnectorGroupConnectorOutputReference
Source Files
¶
- ChimeVoiceConnectorGroup.go
- ChimeVoiceConnectorGroupConfig.go
- ChimeVoiceConnectorGroupConnector.go
- ChimeVoiceConnectorGroupConnectorList.go
- ChimeVoiceConnectorGroupConnectorList__checks.go
- ChimeVoiceConnectorGroupConnectorOutputReference.go
- ChimeVoiceConnectorGroupConnectorOutputReference__checks.go
- ChimeVoiceConnectorGroup__checks.go
- main.go