Documentation
¶
Index ¶
- func ChimeVoiceConnectorOrigination_IsConstruct(x interface{}) *bool
- func ChimeVoiceConnectorOrigination_IsTerraformElement(x interface{}) *bool
- func ChimeVoiceConnectorOrigination_IsTerraformResource(x interface{}) *bool
- func ChimeVoiceConnectorOrigination_TfResourceType() *string
- func NewChimeVoiceConnectorOriginationRouteList_Override(c ChimeVoiceConnectorOriginationRouteList, ...)
- func NewChimeVoiceConnectorOriginationRouteOutputReference_Override(c ChimeVoiceConnectorOriginationRouteOutputReference, ...)
- func NewChimeVoiceConnectorOrigination_Override(c ChimeVoiceConnectorOrigination, scope constructs.Construct, id *string, ...)
- type ChimeVoiceConnectorOrigination
- type ChimeVoiceConnectorOriginationConfig
- type ChimeVoiceConnectorOriginationRoute
- type ChimeVoiceConnectorOriginationRouteList
- type ChimeVoiceConnectorOriginationRouteOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ChimeVoiceConnectorOrigination_IsConstruct ¶
func ChimeVoiceConnectorOrigination_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ChimeVoiceConnectorOrigination_IsTerraformElement ¶
func ChimeVoiceConnectorOrigination_IsTerraformElement(x interface{}) *bool
Experimental.
func ChimeVoiceConnectorOrigination_IsTerraformResource ¶
func ChimeVoiceConnectorOrigination_IsTerraformResource(x interface{}) *bool
Experimental.
func ChimeVoiceConnectorOrigination_TfResourceType ¶
func ChimeVoiceConnectorOrigination_TfResourceType() *string
func NewChimeVoiceConnectorOriginationRouteList_Override ¶
func NewChimeVoiceConnectorOriginationRouteList_Override(c ChimeVoiceConnectorOriginationRouteList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewChimeVoiceConnectorOriginationRouteOutputReference_Override ¶
func NewChimeVoiceConnectorOriginationRouteOutputReference_Override(c ChimeVoiceConnectorOriginationRouteOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewChimeVoiceConnectorOrigination_Override ¶
func NewChimeVoiceConnectorOrigination_Override(c ChimeVoiceConnectorOrigination, scope constructs.Construct, id *string, config *ChimeVoiceConnectorOriginationConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_origination aws_chime_voice_connector_origination} Resource.
Types ¶
type ChimeVoiceConnectorOrigination ¶
type ChimeVoiceConnectorOrigination interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Disabled() interface{}
SetDisabled(val interface{})
DisabledInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Route() ChimeVoiceConnectorOriginationRouteList
RouteInput() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
VoiceConnectorId() *string
SetVoiceConnectorId(val *string)
VoiceConnectorIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutRoute(value interface{})
ResetDisabled()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_origination aws_chime_voice_connector_origination}.
func NewChimeVoiceConnectorOrigination ¶
func NewChimeVoiceConnectorOrigination(scope constructs.Construct, id *string, config *ChimeVoiceConnectorOriginationConfig) ChimeVoiceConnectorOrigination
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_origination aws_chime_voice_connector_origination} Resource.
type ChimeVoiceConnectorOriginationConfig ¶
type ChimeVoiceConnectorOriginationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// route block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_origination#route ChimeVoiceConnectorOrigination#route}
Route interface{} `field:"required" json:"route" yaml:"route"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_origination#voice_connector_id ChimeVoiceConnectorOrigination#voice_connector_id}.
VoiceConnectorId *string `field:"required" json:"voiceConnectorId" yaml:"voiceConnectorId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_origination#disabled ChimeVoiceConnectorOrigination#disabled}.
Disabled interface{} `field:"optional" json:"disabled" yaml:"disabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_origination#id ChimeVoiceConnectorOrigination#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type ChimeVoiceConnectorOriginationRoute ¶
type ChimeVoiceConnectorOriginationRoute struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_origination#host ChimeVoiceConnectorOrigination#host}.
Host *string `field:"required" json:"host" yaml:"host"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_origination#priority ChimeVoiceConnectorOrigination#priority}.
Priority *float64 `field:"required" json:"priority" yaml:"priority"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_origination#protocol ChimeVoiceConnectorOrigination#protocol}.
Protocol *string `field:"required" json:"protocol" yaml:"protocol"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_origination#weight ChimeVoiceConnectorOrigination#weight}.
Weight *float64 `field:"required" json:"weight" yaml:"weight"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/chime_voice_connector_origination#port ChimeVoiceConnectorOrigination#port}.
Port *float64 `field:"optional" json:"port" yaml:"port"`
}
type ChimeVoiceConnectorOriginationRouteList ¶
type ChimeVoiceConnectorOriginationRouteList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ChimeVoiceConnectorOriginationRouteOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewChimeVoiceConnectorOriginationRouteList ¶
func NewChimeVoiceConnectorOriginationRouteList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ChimeVoiceConnectorOriginationRouteList
type ChimeVoiceConnectorOriginationRouteOutputReference ¶
type ChimeVoiceConnectorOriginationRouteOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Host() *string
SetHost(val *string)
HostInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Port() *float64
SetPort(val *float64)
PortInput() *float64
Priority() *float64
SetPriority(val *float64)
PriorityInput() *float64
Protocol() *string
SetProtocol(val *string)
ProtocolInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Weight() *float64
SetWeight(val *float64)
WeightInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetPort()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewChimeVoiceConnectorOriginationRouteOutputReference ¶
func NewChimeVoiceConnectorOriginationRouteOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ChimeVoiceConnectorOriginationRouteOutputReference
Source Files
¶
- ChimeVoiceConnectorOrigination.go
- ChimeVoiceConnectorOriginationConfig.go
- ChimeVoiceConnectorOriginationRoute.go
- ChimeVoiceConnectorOriginationRouteList.go
- ChimeVoiceConnectorOriginationRouteList__checks.go
- ChimeVoiceConnectorOriginationRouteOutputReference.go
- ChimeVoiceConnectorOriginationRouteOutputReference__checks.go
- ChimeVoiceConnectorOrigination__checks.go
- main.go