Documentation
¶
Index ¶
- func CloudwatchMetricStream_IsConstruct(x interface{}) *bool
- func CloudwatchMetricStream_IsTerraformElement(x interface{}) *bool
- func CloudwatchMetricStream_IsTerraformResource(x interface{}) *bool
- func CloudwatchMetricStream_TfResourceType() *string
- func NewCloudwatchMetricStreamExcludeFilterList_Override(c CloudwatchMetricStreamExcludeFilterList, ...)
- func NewCloudwatchMetricStreamExcludeFilterOutputReference_Override(c CloudwatchMetricStreamExcludeFilterOutputReference, ...)
- func NewCloudwatchMetricStreamIncludeFilterList_Override(c CloudwatchMetricStreamIncludeFilterList, ...)
- func NewCloudwatchMetricStreamIncludeFilterOutputReference_Override(c CloudwatchMetricStreamIncludeFilterOutputReference, ...)
- func NewCloudwatchMetricStreamStatisticsConfigurationIncludeMetricList_Override(c CloudwatchMetricStreamStatisticsConfigurationIncludeMetricList, ...)
- func NewCloudwatchMetricStreamStatisticsConfigurationIncludeMetricOutputReference_Override(c CloudwatchMetricStreamStatisticsConfigurationIncludeMetricOutputReference, ...)
- func NewCloudwatchMetricStreamStatisticsConfigurationList_Override(c CloudwatchMetricStreamStatisticsConfigurationList, ...)
- func NewCloudwatchMetricStreamStatisticsConfigurationOutputReference_Override(c CloudwatchMetricStreamStatisticsConfigurationOutputReference, ...)
- func NewCloudwatchMetricStreamTimeoutsOutputReference_Override(c CloudwatchMetricStreamTimeoutsOutputReference, ...)
- func NewCloudwatchMetricStream_Override(c CloudwatchMetricStream, scope constructs.Construct, id *string, ...)
- type CloudwatchMetricStream
- type CloudwatchMetricStreamConfig
- type CloudwatchMetricStreamExcludeFilter
- type CloudwatchMetricStreamExcludeFilterList
- type CloudwatchMetricStreamExcludeFilterOutputReference
- type CloudwatchMetricStreamIncludeFilter
- type CloudwatchMetricStreamIncludeFilterList
- type CloudwatchMetricStreamIncludeFilterOutputReference
- type CloudwatchMetricStreamStatisticsConfiguration
- type CloudwatchMetricStreamStatisticsConfigurationIncludeMetric
- type CloudwatchMetricStreamStatisticsConfigurationIncludeMetricList
- type CloudwatchMetricStreamStatisticsConfigurationIncludeMetricOutputReference
- type CloudwatchMetricStreamStatisticsConfigurationList
- type CloudwatchMetricStreamStatisticsConfigurationOutputReference
- type CloudwatchMetricStreamTimeouts
- type CloudwatchMetricStreamTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CloudwatchMetricStream_IsConstruct ¶
func CloudwatchMetricStream_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func CloudwatchMetricStream_IsTerraformElement ¶
func CloudwatchMetricStream_IsTerraformElement(x interface{}) *bool
Experimental.
func CloudwatchMetricStream_IsTerraformResource ¶
func CloudwatchMetricStream_IsTerraformResource(x interface{}) *bool
Experimental.
func CloudwatchMetricStream_TfResourceType ¶
func CloudwatchMetricStream_TfResourceType() *string
func NewCloudwatchMetricStreamExcludeFilterList_Override ¶
func NewCloudwatchMetricStreamExcludeFilterList_Override(c CloudwatchMetricStreamExcludeFilterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCloudwatchMetricStreamExcludeFilterOutputReference_Override ¶
func NewCloudwatchMetricStreamExcludeFilterOutputReference_Override(c CloudwatchMetricStreamExcludeFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCloudwatchMetricStreamIncludeFilterList_Override ¶
func NewCloudwatchMetricStreamIncludeFilterList_Override(c CloudwatchMetricStreamIncludeFilterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCloudwatchMetricStreamIncludeFilterOutputReference_Override ¶
func NewCloudwatchMetricStreamIncludeFilterOutputReference_Override(c CloudwatchMetricStreamIncludeFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCloudwatchMetricStreamStatisticsConfigurationIncludeMetricList_Override ¶
func NewCloudwatchMetricStreamStatisticsConfigurationIncludeMetricList_Override(c CloudwatchMetricStreamStatisticsConfigurationIncludeMetricList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCloudwatchMetricStreamStatisticsConfigurationIncludeMetricOutputReference_Override ¶
func NewCloudwatchMetricStreamStatisticsConfigurationIncludeMetricOutputReference_Override(c CloudwatchMetricStreamStatisticsConfigurationIncludeMetricOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCloudwatchMetricStreamStatisticsConfigurationList_Override ¶
func NewCloudwatchMetricStreamStatisticsConfigurationList_Override(c CloudwatchMetricStreamStatisticsConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCloudwatchMetricStreamStatisticsConfigurationOutputReference_Override ¶
func NewCloudwatchMetricStreamStatisticsConfigurationOutputReference_Override(c CloudwatchMetricStreamStatisticsConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCloudwatchMetricStreamTimeoutsOutputReference_Override ¶
func NewCloudwatchMetricStreamTimeoutsOutputReference_Override(c CloudwatchMetricStreamTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCloudwatchMetricStream_Override ¶
func NewCloudwatchMetricStream_Override(c CloudwatchMetricStream, scope constructs.Construct, id *string, config *CloudwatchMetricStreamConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream aws_cloudwatch_metric_stream} Resource.
Types ¶
type CloudwatchMetricStream ¶
type CloudwatchMetricStream interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreationDate() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
ExcludeFilter() CloudwatchMetricStreamExcludeFilterList
ExcludeFilterInput() interface{}
FirehoseArn() *string
SetFirehoseArn(val *string)
FirehoseArnInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IncludeFilter() CloudwatchMetricStreamIncludeFilterList
IncludeFilterInput() interface{}
IncludeLinkedAccountsMetrics() interface{}
SetIncludeLinkedAccountsMetrics(val interface{})
IncludeLinkedAccountsMetricsInput() interface{}
LastUpdateDate() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
NamePrefix() *string
SetNamePrefix(val *string)
NamePrefixInput() *string
// The tree node.
Node() constructs.Node
OutputFormat() *string
SetOutputFormat(val *string)
OutputFormatInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
State() *string
StatisticsConfiguration() CloudwatchMetricStreamStatisticsConfigurationList
StatisticsConfigurationInput() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() CloudwatchMetricStreamTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutExcludeFilter(value interface{})
PutIncludeFilter(value interface{})
PutStatisticsConfiguration(value interface{})
PutTimeouts(value *CloudwatchMetricStreamTimeouts)
ResetExcludeFilter()
ResetId()
ResetIncludeFilter()
ResetIncludeLinkedAccountsMetrics()
ResetName()
ResetNamePrefix()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetStatisticsConfiguration()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream aws_cloudwatch_metric_stream}.
func NewCloudwatchMetricStream ¶
func NewCloudwatchMetricStream(scope constructs.Construct, id *string, config *CloudwatchMetricStreamConfig) CloudwatchMetricStream
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream aws_cloudwatch_metric_stream} Resource.
type CloudwatchMetricStreamConfig ¶
type CloudwatchMetricStreamConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#firehose_arn CloudwatchMetricStream#firehose_arn}.
FirehoseArn *string `field:"required" json:"firehoseArn" yaml:"firehoseArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#output_format CloudwatchMetricStream#output_format}.
OutputFormat *string `field:"required" json:"outputFormat" yaml:"outputFormat"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#role_arn CloudwatchMetricStream#role_arn}.
RoleArn *string `field:"required" json:"roleArn" yaml:"roleArn"`
// exclude_filter block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#exclude_filter CloudwatchMetricStream#exclude_filter}
ExcludeFilter interface{} `field:"optional" json:"excludeFilter" yaml:"excludeFilter"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#id CloudwatchMetricStream#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// include_filter block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#include_filter CloudwatchMetricStream#include_filter}
IncludeFilter interface{} `field:"optional" json:"includeFilter" yaml:"includeFilter"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#include_linked_accounts_metrics CloudwatchMetricStream#include_linked_accounts_metrics}.
IncludeLinkedAccountsMetrics interface{} `field:"optional" json:"includeLinkedAccountsMetrics" yaml:"includeLinkedAccountsMetrics"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#name CloudwatchMetricStream#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#name_prefix CloudwatchMetricStream#name_prefix}.
NamePrefix *string `field:"optional" json:"namePrefix" yaml:"namePrefix"`
// statistics_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#statistics_configuration CloudwatchMetricStream#statistics_configuration}
StatisticsConfiguration interface{} `field:"optional" json:"statisticsConfiguration" yaml:"statisticsConfiguration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#tags CloudwatchMetricStream#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#tags_all CloudwatchMetricStream#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#timeouts CloudwatchMetricStream#timeouts}
Timeouts *CloudwatchMetricStreamTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type CloudwatchMetricStreamExcludeFilter ¶
type CloudwatchMetricStreamExcludeFilter struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#namespace CloudwatchMetricStream#namespace}.
Namespace *string `field:"required" json:"namespace" yaml:"namespace"`
}
type CloudwatchMetricStreamExcludeFilterList ¶
type CloudwatchMetricStreamExcludeFilterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CloudwatchMetricStreamExcludeFilterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudwatchMetricStreamExcludeFilterList ¶
func NewCloudwatchMetricStreamExcludeFilterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CloudwatchMetricStreamExcludeFilterList
type CloudwatchMetricStreamExcludeFilterOutputReference ¶
type CloudwatchMetricStreamExcludeFilterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Namespace() *string
SetNamespace(val *string)
NamespaceInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudwatchMetricStreamExcludeFilterOutputReference ¶
func NewCloudwatchMetricStreamExcludeFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CloudwatchMetricStreamExcludeFilterOutputReference
type CloudwatchMetricStreamIncludeFilter ¶
type CloudwatchMetricStreamIncludeFilter struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#namespace CloudwatchMetricStream#namespace}.
Namespace *string `field:"required" json:"namespace" yaml:"namespace"`
}
type CloudwatchMetricStreamIncludeFilterList ¶
type CloudwatchMetricStreamIncludeFilterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CloudwatchMetricStreamIncludeFilterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudwatchMetricStreamIncludeFilterList ¶
func NewCloudwatchMetricStreamIncludeFilterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CloudwatchMetricStreamIncludeFilterList
type CloudwatchMetricStreamIncludeFilterOutputReference ¶
type CloudwatchMetricStreamIncludeFilterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Namespace() *string
SetNamespace(val *string)
NamespaceInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudwatchMetricStreamIncludeFilterOutputReference ¶
func NewCloudwatchMetricStreamIncludeFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CloudwatchMetricStreamIncludeFilterOutputReference
type CloudwatchMetricStreamStatisticsConfiguration ¶
type CloudwatchMetricStreamStatisticsConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#additional_statistics CloudwatchMetricStream#additional_statistics}.
AdditionalStatistics *[]*string `field:"required" json:"additionalStatistics" yaml:"additionalStatistics"`
// include_metric block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#include_metric CloudwatchMetricStream#include_metric}
IncludeMetric interface{} `field:"required" json:"includeMetric" yaml:"includeMetric"`
}
type CloudwatchMetricStreamStatisticsConfigurationIncludeMetric ¶
type CloudwatchMetricStreamStatisticsConfigurationIncludeMetric struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#metric_name CloudwatchMetricStream#metric_name}.
MetricName *string `field:"required" json:"metricName" yaml:"metricName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#namespace CloudwatchMetricStream#namespace}.
Namespace *string `field:"required" json:"namespace" yaml:"namespace"`
}
type CloudwatchMetricStreamStatisticsConfigurationIncludeMetricList ¶
type CloudwatchMetricStreamStatisticsConfigurationIncludeMetricList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CloudwatchMetricStreamStatisticsConfigurationIncludeMetricOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudwatchMetricStreamStatisticsConfigurationIncludeMetricList ¶
func NewCloudwatchMetricStreamStatisticsConfigurationIncludeMetricList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CloudwatchMetricStreamStatisticsConfigurationIncludeMetricList
type CloudwatchMetricStreamStatisticsConfigurationIncludeMetricOutputReference ¶
type CloudwatchMetricStreamStatisticsConfigurationIncludeMetricOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
MetricName() *string
SetMetricName(val *string)
MetricNameInput() *string
Namespace() *string
SetNamespace(val *string)
NamespaceInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudwatchMetricStreamStatisticsConfigurationIncludeMetricOutputReference ¶
func NewCloudwatchMetricStreamStatisticsConfigurationIncludeMetricOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CloudwatchMetricStreamStatisticsConfigurationIncludeMetricOutputReference
type CloudwatchMetricStreamStatisticsConfigurationList ¶
type CloudwatchMetricStreamStatisticsConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CloudwatchMetricStreamStatisticsConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudwatchMetricStreamStatisticsConfigurationList ¶
func NewCloudwatchMetricStreamStatisticsConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CloudwatchMetricStreamStatisticsConfigurationList
type CloudwatchMetricStreamStatisticsConfigurationOutputReference ¶
type CloudwatchMetricStreamStatisticsConfigurationOutputReference interface {
cdktf.ComplexObject
AdditionalStatistics() *[]*string
SetAdditionalStatistics(val *[]*string)
AdditionalStatisticsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IncludeMetric() CloudwatchMetricStreamStatisticsConfigurationIncludeMetricList
IncludeMetricInput() interface{}
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutIncludeMetric(value interface{})
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudwatchMetricStreamStatisticsConfigurationOutputReference ¶
func NewCloudwatchMetricStreamStatisticsConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CloudwatchMetricStreamStatisticsConfigurationOutputReference
type CloudwatchMetricStreamTimeouts ¶
type CloudwatchMetricStreamTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#create CloudwatchMetricStream#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#delete CloudwatchMetricStream#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cloudwatch_metric_stream#update CloudwatchMetricStream#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type CloudwatchMetricStreamTimeoutsOutputReference ¶
type CloudwatchMetricStreamTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudwatchMetricStreamTimeoutsOutputReference ¶
func NewCloudwatchMetricStreamTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CloudwatchMetricStreamTimeoutsOutputReference
Source Files
¶
- CloudwatchMetricStream.go
- CloudwatchMetricStreamConfig.go
- CloudwatchMetricStreamExcludeFilter.go
- CloudwatchMetricStreamExcludeFilterList.go
- CloudwatchMetricStreamExcludeFilterList__checks.go
- CloudwatchMetricStreamExcludeFilterOutputReference.go
- CloudwatchMetricStreamExcludeFilterOutputReference__checks.go
- CloudwatchMetricStreamIncludeFilter.go
- CloudwatchMetricStreamIncludeFilterList.go
- CloudwatchMetricStreamIncludeFilterList__checks.go
- CloudwatchMetricStreamIncludeFilterOutputReference.go
- CloudwatchMetricStreamIncludeFilterOutputReference__checks.go
- CloudwatchMetricStreamStatisticsConfiguration.go
- CloudwatchMetricStreamStatisticsConfigurationIncludeMetric.go
- CloudwatchMetricStreamStatisticsConfigurationIncludeMetricList.go
- CloudwatchMetricStreamStatisticsConfigurationIncludeMetricList__checks.go
- CloudwatchMetricStreamStatisticsConfigurationIncludeMetricOutputReference.go
- CloudwatchMetricStreamStatisticsConfigurationIncludeMetricOutputReference__checks.go
- CloudwatchMetricStreamStatisticsConfigurationList.go
- CloudwatchMetricStreamStatisticsConfigurationList__checks.go
- CloudwatchMetricStreamStatisticsConfigurationOutputReference.go
- CloudwatchMetricStreamStatisticsConfigurationOutputReference__checks.go
- CloudwatchMetricStreamTimeouts.go
- CloudwatchMetricStreamTimeoutsOutputReference.go
- CloudwatchMetricStreamTimeoutsOutputReference__checks.go
- CloudwatchMetricStream__checks.go
- main.go