Documentation
¶
Index ¶
- func Codepipeline_IsConstruct(x interface{}) *bool
- func Codepipeline_IsTerraformElement(x interface{}) *bool
- func Codepipeline_IsTerraformResource(x interface{}) *bool
- func Codepipeline_TfResourceType() *string
- func NewCodepipelineArtifactStoreEncryptionKeyOutputReference_Override(c CodepipelineArtifactStoreEncryptionKeyOutputReference, ...)
- func NewCodepipelineArtifactStoreList_Override(c CodepipelineArtifactStoreList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewCodepipelineArtifactStoreOutputReference_Override(c CodepipelineArtifactStoreOutputReference, ...)
- func NewCodepipelineStageActionList_Override(c CodepipelineStageActionList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewCodepipelineStageActionOutputReference_Override(c CodepipelineStageActionOutputReference, ...)
- func NewCodepipelineStageList_Override(c CodepipelineStageList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewCodepipelineStageOutputReference_Override(c CodepipelineStageOutputReference, ...)
- func NewCodepipeline_Override(c Codepipeline, scope constructs.Construct, id *string, ...)
- type Codepipeline
- type CodepipelineArtifactStore
- type CodepipelineArtifactStoreEncryptionKey
- type CodepipelineArtifactStoreEncryptionKeyOutputReference
- type CodepipelineArtifactStoreList
- type CodepipelineArtifactStoreOutputReference
- type CodepipelineConfig
- type CodepipelineStage
- type CodepipelineStageAction
- type CodepipelineStageActionList
- type CodepipelineStageActionOutputReference
- type CodepipelineStageList
- type CodepipelineStageOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Codepipeline_IsConstruct ¶
func Codepipeline_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func Codepipeline_IsTerraformElement ¶
func Codepipeline_IsTerraformElement(x interface{}) *bool
Experimental.
func Codepipeline_IsTerraformResource ¶
func Codepipeline_IsTerraformResource(x interface{}) *bool
Experimental.
func Codepipeline_TfResourceType ¶
func Codepipeline_TfResourceType() *string
func NewCodepipelineArtifactStoreEncryptionKeyOutputReference_Override ¶
func NewCodepipelineArtifactStoreEncryptionKeyOutputReference_Override(c CodepipelineArtifactStoreEncryptionKeyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCodepipelineArtifactStoreList_Override ¶
func NewCodepipelineArtifactStoreList_Override(c CodepipelineArtifactStoreList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCodepipelineArtifactStoreOutputReference_Override ¶
func NewCodepipelineArtifactStoreOutputReference_Override(c CodepipelineArtifactStoreOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCodepipelineStageActionList_Override ¶
func NewCodepipelineStageActionList_Override(c CodepipelineStageActionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCodepipelineStageActionOutputReference_Override ¶
func NewCodepipelineStageActionOutputReference_Override(c CodepipelineStageActionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCodepipelineStageList_Override ¶
func NewCodepipelineStageList_Override(c CodepipelineStageList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCodepipelineStageOutputReference_Override ¶
func NewCodepipelineStageOutputReference_Override(c CodepipelineStageOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCodepipeline_Override ¶
func NewCodepipeline_Override(c Codepipeline, scope constructs.Construct, id *string, config *CodepipelineConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline aws_codepipeline} Resource.
Types ¶
type Codepipeline ¶
type Codepipeline interface {
cdktf.TerraformResource
Arn() *string
ArtifactStore() CodepipelineArtifactStoreList
ArtifactStoreInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
Stage() CodepipelineStageList
StageInput() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutArtifactStore(value interface{})
PutStage(value interface{})
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline aws_codepipeline}.
func NewCodepipeline ¶
func NewCodepipeline(scope constructs.Construct, id *string, config *CodepipelineConfig) Codepipeline
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline aws_codepipeline} Resource.
type CodepipelineArtifactStore ¶
type CodepipelineArtifactStore struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#location Codepipeline#location}.
Location *string `field:"required" json:"location" yaml:"location"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#type Codepipeline#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// encryption_key block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#encryption_key Codepipeline#encryption_key}
EncryptionKey *CodepipelineArtifactStoreEncryptionKey `field:"optional" json:"encryptionKey" yaml:"encryptionKey"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#region Codepipeline#region}.
Region *string `field:"optional" json:"region" yaml:"region"`
}
type CodepipelineArtifactStoreEncryptionKey ¶
type CodepipelineArtifactStoreEncryptionKey struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#id Codepipeline#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"required" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#type Codepipeline#type}.
Type *string `field:"required" json:"type" yaml:"type"`
}
type CodepipelineArtifactStoreEncryptionKeyOutputReference ¶
type CodepipelineArtifactStoreEncryptionKeyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
SetId(val *string)
IdInput() *string
InternalValue() *CodepipelineArtifactStoreEncryptionKey
SetInternalValue(val *CodepipelineArtifactStoreEncryptionKey)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCodepipelineArtifactStoreEncryptionKeyOutputReference ¶
func NewCodepipelineArtifactStoreEncryptionKeyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CodepipelineArtifactStoreEncryptionKeyOutputReference
type CodepipelineArtifactStoreList ¶
type CodepipelineArtifactStoreList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CodepipelineArtifactStoreOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCodepipelineArtifactStoreList ¶
func NewCodepipelineArtifactStoreList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CodepipelineArtifactStoreList
type CodepipelineArtifactStoreOutputReference ¶
type CodepipelineArtifactStoreOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EncryptionKey() CodepipelineArtifactStoreEncryptionKeyOutputReference
EncryptionKeyInput() *CodepipelineArtifactStoreEncryptionKey
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Location() *string
SetLocation(val *string)
LocationInput() *string
Region() *string
SetRegion(val *string)
RegionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutEncryptionKey(value *CodepipelineArtifactStoreEncryptionKey)
ResetEncryptionKey()
ResetRegion()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCodepipelineArtifactStoreOutputReference ¶
func NewCodepipelineArtifactStoreOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CodepipelineArtifactStoreOutputReference
type CodepipelineConfig ¶
type CodepipelineConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// artifact_store block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#artifact_store Codepipeline#artifact_store}
ArtifactStore interface{} `field:"required" json:"artifactStore" yaml:"artifactStore"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#name Codepipeline#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#role_arn Codepipeline#role_arn}.
RoleArn *string `field:"required" json:"roleArn" yaml:"roleArn"`
// stage block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#stage Codepipeline#stage}
Stage interface{} `field:"required" json:"stage" yaml:"stage"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#id Codepipeline#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#tags Codepipeline#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#tags_all Codepipeline#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type CodepipelineStage ¶
type CodepipelineStage struct {
// action block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#action Codepipeline#action}
Action interface{} `field:"required" json:"action" yaml:"action"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#name Codepipeline#name}.
Name *string `field:"required" json:"name" yaml:"name"`
}
type CodepipelineStageAction ¶
type CodepipelineStageAction struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#category Codepipeline#category}.
Category *string `field:"required" json:"category" yaml:"category"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#name Codepipeline#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#owner Codepipeline#owner}.
Owner *string `field:"required" json:"owner" yaml:"owner"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#provider Codepipeline#provider}.
Provider *string `field:"required" json:"provider" yaml:"provider"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#version Codepipeline#version}.
Version *string `field:"required" json:"version" yaml:"version"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#configuration Codepipeline#configuration}.
Configuration *map[string]*string `field:"optional" json:"configuration" yaml:"configuration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#input_artifacts Codepipeline#input_artifacts}.
InputArtifacts *[]*string `field:"optional" json:"inputArtifacts" yaml:"inputArtifacts"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#namespace Codepipeline#namespace}.
Namespace *string `field:"optional" json:"namespace" yaml:"namespace"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#output_artifacts Codepipeline#output_artifacts}.
OutputArtifacts *[]*string `field:"optional" json:"outputArtifacts" yaml:"outputArtifacts"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#region Codepipeline#region}.
Region *string `field:"optional" json:"region" yaml:"region"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#role_arn Codepipeline#role_arn}.
RoleArn *string `field:"optional" json:"roleArn" yaml:"roleArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/codepipeline#run_order Codepipeline#run_order}.
RunOrder *float64 `field:"optional" json:"runOrder" yaml:"runOrder"`
}
type CodepipelineStageActionList ¶
type CodepipelineStageActionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CodepipelineStageActionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCodepipelineStageActionList ¶
func NewCodepipelineStageActionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CodepipelineStageActionList
type CodepipelineStageActionOutputReference ¶
type CodepipelineStageActionOutputReference interface {
cdktf.ComplexObject
Category() *string
SetCategory(val *string)
CategoryInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Configuration() *map[string]*string
SetConfiguration(val *map[string]*string)
ConfigurationInput() *map[string]*string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InputArtifacts() *[]*string
SetInputArtifacts(val *[]*string)
InputArtifactsInput() *[]*string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
Namespace() *string
SetNamespace(val *string)
NamespaceInput() *string
OutputArtifacts() *[]*string
SetOutputArtifacts(val *[]*string)
OutputArtifactsInput() *[]*string
Owner() *string
SetOwner(val *string)
OwnerInput() *string
Provider() *string
SetProvider(val *string)
ProviderInput() *string
Region() *string
SetRegion(val *string)
RegionInput() *string
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
RunOrder() *float64
SetRunOrder(val *float64)
RunOrderInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Version() *string
SetVersion(val *string)
VersionInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetConfiguration()
ResetInputArtifacts()
ResetNamespace()
ResetOutputArtifacts()
ResetRegion()
ResetRoleArn()
ResetRunOrder()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCodepipelineStageActionOutputReference ¶
func NewCodepipelineStageActionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CodepipelineStageActionOutputReference
type CodepipelineStageList ¶
type CodepipelineStageList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CodepipelineStageOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCodepipelineStageList ¶
func NewCodepipelineStageList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CodepipelineStageList
type CodepipelineStageOutputReference ¶
type CodepipelineStageOutputReference interface {
cdktf.ComplexObject
Action() CodepipelineStageActionList
ActionInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAction(value interface{})
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCodepipelineStageOutputReference ¶
func NewCodepipelineStageOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CodepipelineStageOutputReference
Source Files
¶
- Codepipeline.go
- CodepipelineArtifactStore.go
- CodepipelineArtifactStoreEncryptionKey.go
- CodepipelineArtifactStoreEncryptionKeyOutputReference.go
- CodepipelineArtifactStoreEncryptionKeyOutputReference__checks.go
- CodepipelineArtifactStoreList.go
- CodepipelineArtifactStoreList__checks.go
- CodepipelineArtifactStoreOutputReference.go
- CodepipelineArtifactStoreOutputReference__checks.go
- CodepipelineConfig.go
- CodepipelineStage.go
- CodepipelineStageAction.go
- CodepipelineStageActionList.go
- CodepipelineStageActionList__checks.go
- CodepipelineStageActionOutputReference.go
- CodepipelineStageActionOutputReference__checks.go
- CodepipelineStageList.go
- CodepipelineStageList__checks.go
- CodepipelineStageOutputReference.go
- CodepipelineStageOutputReference__checks.go
- Codepipeline__checks.go
- main.go