Documentation
¶
Index ¶
- func CognitoIdentityPool_IsConstruct(x interface{}) *bool
- func CognitoIdentityPool_IsTerraformElement(x interface{}) *bool
- func CognitoIdentityPool_IsTerraformResource(x interface{}) *bool
- func CognitoIdentityPool_TfResourceType() *string
- func NewCognitoIdentityPoolCognitoIdentityProvidersList_Override(c CognitoIdentityPoolCognitoIdentityProvidersList, ...)
- func NewCognitoIdentityPoolCognitoIdentityProvidersOutputReference_Override(c CognitoIdentityPoolCognitoIdentityProvidersOutputReference, ...)
- func NewCognitoIdentityPool_Override(c CognitoIdentityPool, scope constructs.Construct, id *string, ...)
- type CognitoIdentityPool
- type CognitoIdentityPoolCognitoIdentityProviders
- type CognitoIdentityPoolCognitoIdentityProvidersList
- type CognitoIdentityPoolCognitoIdentityProvidersOutputReference
- type CognitoIdentityPoolConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CognitoIdentityPool_IsConstruct ¶
func CognitoIdentityPool_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func CognitoIdentityPool_IsTerraformElement ¶
func CognitoIdentityPool_IsTerraformElement(x interface{}) *bool
Experimental.
func CognitoIdentityPool_IsTerraformResource ¶
func CognitoIdentityPool_IsTerraformResource(x interface{}) *bool
Experimental.
func CognitoIdentityPool_TfResourceType ¶
func CognitoIdentityPool_TfResourceType() *string
func NewCognitoIdentityPoolCognitoIdentityProvidersList_Override ¶
func NewCognitoIdentityPoolCognitoIdentityProvidersList_Override(c CognitoIdentityPoolCognitoIdentityProvidersList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCognitoIdentityPoolCognitoIdentityProvidersOutputReference_Override ¶
func NewCognitoIdentityPoolCognitoIdentityProvidersOutputReference_Override(c CognitoIdentityPoolCognitoIdentityProvidersOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCognitoIdentityPool_Override ¶
func NewCognitoIdentityPool_Override(c CognitoIdentityPool, scope constructs.Construct, id *string, config *CognitoIdentityPoolConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool aws_cognito_identity_pool} Resource.
Types ¶
type CognitoIdentityPool ¶
type CognitoIdentityPool interface {
cdktf.TerraformResource
AllowClassicFlow() interface{}
SetAllowClassicFlow(val interface{})
AllowClassicFlowInput() interface{}
AllowUnauthenticatedIdentities() interface{}
SetAllowUnauthenticatedIdentities(val interface{})
AllowUnauthenticatedIdentitiesInput() interface{}
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CognitoIdentityProviders() CognitoIdentityPoolCognitoIdentityProvidersList
CognitoIdentityProvidersInput() interface{}
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeveloperProviderName() *string
SetDeveloperProviderName(val *string)
DeveloperProviderNameInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdentityPoolName() *string
SetIdentityPoolName(val *string)
IdentityPoolNameInput() *string
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
OpenidConnectProviderArns() *[]*string
SetOpenidConnectProviderArns(val *[]*string)
OpenidConnectProviderArnsInput() *[]*string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SamlProviderArns() *[]*string
SetSamlProviderArns(val *[]*string)
SamlProviderArnsInput() *[]*string
SupportedLoginProviders() *map[string]*string
SetSupportedLoginProviders(val *map[string]*string)
SupportedLoginProvidersInput() *map[string]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCognitoIdentityProviders(value interface{})
ResetAllowClassicFlow()
ResetAllowUnauthenticatedIdentities()
ResetCognitoIdentityProviders()
ResetDeveloperProviderName()
ResetId()
ResetOpenidConnectProviderArns()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSamlProviderArns()
ResetSupportedLoginProviders()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool aws_cognito_identity_pool}.
func NewCognitoIdentityPool ¶
func NewCognitoIdentityPool(scope constructs.Construct, id *string, config *CognitoIdentityPoolConfig) CognitoIdentityPool
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool aws_cognito_identity_pool} Resource.
type CognitoIdentityPoolCognitoIdentityProviders ¶
type CognitoIdentityPoolCognitoIdentityProviders struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool#client_id CognitoIdentityPool#client_id}.
ClientId *string `field:"optional" json:"clientId" yaml:"clientId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool#provider_name CognitoIdentityPool#provider_name}.
ProviderName *string `field:"optional" json:"providerName" yaml:"providerName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool#server_side_token_check CognitoIdentityPool#server_side_token_check}.
ServerSideTokenCheck interface{} `field:"optional" json:"serverSideTokenCheck" yaml:"serverSideTokenCheck"`
}
type CognitoIdentityPoolCognitoIdentityProvidersList ¶
type CognitoIdentityPoolCognitoIdentityProvidersList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CognitoIdentityPoolCognitoIdentityProvidersOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCognitoIdentityPoolCognitoIdentityProvidersList ¶
func NewCognitoIdentityPoolCognitoIdentityProvidersList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CognitoIdentityPoolCognitoIdentityProvidersList
type CognitoIdentityPoolCognitoIdentityProvidersOutputReference ¶
type CognitoIdentityPoolCognitoIdentityProvidersOutputReference interface {
cdktf.ComplexObject
ClientId() *string
SetClientId(val *string)
ClientIdInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
ProviderName() *string
SetProviderName(val *string)
ProviderNameInput() *string
ServerSideTokenCheck() interface{}
SetServerSideTokenCheck(val interface{})
ServerSideTokenCheckInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetClientId()
ResetProviderName()
ResetServerSideTokenCheck()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCognitoIdentityPoolCognitoIdentityProvidersOutputReference ¶
func NewCognitoIdentityPoolCognitoIdentityProvidersOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CognitoIdentityPoolCognitoIdentityProvidersOutputReference
type CognitoIdentityPoolConfig ¶
type CognitoIdentityPoolConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool#identity_pool_name CognitoIdentityPool#identity_pool_name}.
IdentityPoolName *string `field:"required" json:"identityPoolName" yaml:"identityPoolName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool#allow_classic_flow CognitoIdentityPool#allow_classic_flow}.
AllowClassicFlow interface{} `field:"optional" json:"allowClassicFlow" yaml:"allowClassicFlow"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool#allow_unauthenticated_identities CognitoIdentityPool#allow_unauthenticated_identities}.
AllowUnauthenticatedIdentities interface{} `field:"optional" json:"allowUnauthenticatedIdentities" yaml:"allowUnauthenticatedIdentities"`
// cognito_identity_providers block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool#cognito_identity_providers CognitoIdentityPool#cognito_identity_providers}
CognitoIdentityProviders interface{} `field:"optional" json:"cognitoIdentityProviders" yaml:"cognitoIdentityProviders"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool#developer_provider_name CognitoIdentityPool#developer_provider_name}.
DeveloperProviderName *string `field:"optional" json:"developerProviderName" yaml:"developerProviderName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool#id CognitoIdentityPool#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool#openid_connect_provider_arns CognitoIdentityPool#openid_connect_provider_arns}.
OpenidConnectProviderArns *[]*string `field:"optional" json:"openidConnectProviderArns" yaml:"openidConnectProviderArns"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool#saml_provider_arns CognitoIdentityPool#saml_provider_arns}.
SamlProviderArns *[]*string `field:"optional" json:"samlProviderArns" yaml:"samlProviderArns"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool#supported_login_providers CognitoIdentityPool#supported_login_providers}.
SupportedLoginProviders *map[string]*string `field:"optional" json:"supportedLoginProviders" yaml:"supportedLoginProviders"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool#tags CognitoIdentityPool#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool#tags_all CognitoIdentityPool#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
Source Files
¶
- CognitoIdentityPool.go
- CognitoIdentityPoolCognitoIdentityProviders.go
- CognitoIdentityPoolCognitoIdentityProvidersList.go
- CognitoIdentityPoolCognitoIdentityProvidersList__checks.go
- CognitoIdentityPoolCognitoIdentityProvidersOutputReference.go
- CognitoIdentityPoolCognitoIdentityProvidersOutputReference__checks.go
- CognitoIdentityPoolConfig.go
- CognitoIdentityPool__checks.go
- main.go