Documentation
¶
Index ¶
- func CognitoIdentityPoolRolesAttachment_IsConstruct(x interface{}) *bool
- func CognitoIdentityPoolRolesAttachment_IsTerraformElement(x interface{}) *bool
- func CognitoIdentityPoolRolesAttachment_IsTerraformResource(x interface{}) *bool
- func CognitoIdentityPoolRolesAttachment_TfResourceType() *string
- func NewCognitoIdentityPoolRolesAttachmentRoleMappingList_Override(c CognitoIdentityPoolRolesAttachmentRoleMappingList, ...)
- func NewCognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleList_Override(c CognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleList, ...)
- func NewCognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleOutputReference_Override(c CognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleOutputReference, ...)
- func NewCognitoIdentityPoolRolesAttachmentRoleMappingOutputReference_Override(c CognitoIdentityPoolRolesAttachmentRoleMappingOutputReference, ...)
- func NewCognitoIdentityPoolRolesAttachment_Override(c CognitoIdentityPoolRolesAttachment, scope constructs.Construct, id *string, ...)
- type CognitoIdentityPoolRolesAttachment
- type CognitoIdentityPoolRolesAttachmentConfig
- type CognitoIdentityPoolRolesAttachmentRoleMapping
- type CognitoIdentityPoolRolesAttachmentRoleMappingList
- type CognitoIdentityPoolRolesAttachmentRoleMappingMappingRule
- type CognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleList
- type CognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleOutputReference
- type CognitoIdentityPoolRolesAttachmentRoleMappingOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CognitoIdentityPoolRolesAttachment_IsConstruct ¶
func CognitoIdentityPoolRolesAttachment_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func CognitoIdentityPoolRolesAttachment_IsTerraformElement ¶
func CognitoIdentityPoolRolesAttachment_IsTerraformElement(x interface{}) *bool
Experimental.
func CognitoIdentityPoolRolesAttachment_IsTerraformResource ¶
func CognitoIdentityPoolRolesAttachment_IsTerraformResource(x interface{}) *bool
Experimental.
func CognitoIdentityPoolRolesAttachment_TfResourceType ¶
func CognitoIdentityPoolRolesAttachment_TfResourceType() *string
func NewCognitoIdentityPoolRolesAttachmentRoleMappingList_Override ¶
func NewCognitoIdentityPoolRolesAttachmentRoleMappingList_Override(c CognitoIdentityPoolRolesAttachmentRoleMappingList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleList_Override ¶
func NewCognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleList_Override(c CognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewCognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleOutputReference_Override ¶
func NewCognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleOutputReference_Override(c CognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCognitoIdentityPoolRolesAttachmentRoleMappingOutputReference_Override ¶
func NewCognitoIdentityPoolRolesAttachmentRoleMappingOutputReference_Override(c CognitoIdentityPoolRolesAttachmentRoleMappingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewCognitoIdentityPoolRolesAttachment_Override ¶
func NewCognitoIdentityPoolRolesAttachment_Override(c CognitoIdentityPoolRolesAttachment, scope constructs.Construct, id *string, config *CognitoIdentityPoolRolesAttachmentConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool_roles_attachment aws_cognito_identity_pool_roles_attachment} Resource.
Types ¶
type CognitoIdentityPoolRolesAttachment ¶
type CognitoIdentityPoolRolesAttachment interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdentityPoolId() *string
SetIdentityPoolId(val *string)
IdentityPoolIdInput() *string
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RoleMapping() CognitoIdentityPoolRolesAttachmentRoleMappingList
RoleMappingInput() interface{}
Roles() *map[string]*string
SetRoles(val *map[string]*string)
RolesInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutRoleMapping(value interface{})
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRoleMapping()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool_roles_attachment aws_cognito_identity_pool_roles_attachment}.
func NewCognitoIdentityPoolRolesAttachment ¶
func NewCognitoIdentityPoolRolesAttachment(scope constructs.Construct, id *string, config *CognitoIdentityPoolRolesAttachmentConfig) CognitoIdentityPoolRolesAttachment
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool_roles_attachment aws_cognito_identity_pool_roles_attachment} Resource.
type CognitoIdentityPoolRolesAttachmentConfig ¶
type CognitoIdentityPoolRolesAttachmentConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool_roles_attachment#identity_pool_id CognitoIdentityPoolRolesAttachment#identity_pool_id}.
IdentityPoolId *string `field:"required" json:"identityPoolId" yaml:"identityPoolId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool_roles_attachment#roles CognitoIdentityPoolRolesAttachment#roles}.
Roles *map[string]*string `field:"required" json:"roles" yaml:"roles"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool_roles_attachment#id CognitoIdentityPoolRolesAttachment#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// role_mapping block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool_roles_attachment#role_mapping CognitoIdentityPoolRolesAttachment#role_mapping}
RoleMapping interface{} `field:"optional" json:"roleMapping" yaml:"roleMapping"`
}
type CognitoIdentityPoolRolesAttachmentRoleMapping ¶
type CognitoIdentityPoolRolesAttachmentRoleMapping struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool_roles_attachment#identity_provider CognitoIdentityPoolRolesAttachment#identity_provider}.
IdentityProvider *string `field:"required" json:"identityProvider" yaml:"identityProvider"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool_roles_attachment#type CognitoIdentityPoolRolesAttachment#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool_roles_attachment#ambiguous_role_resolution CognitoIdentityPoolRolesAttachment#ambiguous_role_resolution}.
AmbiguousRoleResolution *string `field:"optional" json:"ambiguousRoleResolution" yaml:"ambiguousRoleResolution"`
// mapping_rule block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool_roles_attachment#mapping_rule CognitoIdentityPoolRolesAttachment#mapping_rule}
MappingRule interface{} `field:"optional" json:"mappingRule" yaml:"mappingRule"`
}
type CognitoIdentityPoolRolesAttachmentRoleMappingList ¶
type CognitoIdentityPoolRolesAttachmentRoleMappingList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CognitoIdentityPoolRolesAttachmentRoleMappingOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCognitoIdentityPoolRolesAttachmentRoleMappingList ¶
func NewCognitoIdentityPoolRolesAttachmentRoleMappingList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CognitoIdentityPoolRolesAttachmentRoleMappingList
type CognitoIdentityPoolRolesAttachmentRoleMappingMappingRule ¶
type CognitoIdentityPoolRolesAttachmentRoleMappingMappingRule struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool_roles_attachment#claim CognitoIdentityPoolRolesAttachment#claim}.
Claim *string `field:"required" json:"claim" yaml:"claim"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool_roles_attachment#match_type CognitoIdentityPoolRolesAttachment#match_type}.
MatchType *string `field:"required" json:"matchType" yaml:"matchType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool_roles_attachment#role_arn CognitoIdentityPoolRolesAttachment#role_arn}.
RoleArn *string `field:"required" json:"roleArn" yaml:"roleArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/cognito_identity_pool_roles_attachment#value CognitoIdentityPoolRolesAttachment#value}.
Value *string `field:"required" json:"value" yaml:"value"`
}
type CognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleList ¶
type CognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) CognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleList ¶
func NewCognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) CognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleList
type CognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleOutputReference ¶
type CognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleOutputReference interface {
cdktf.ComplexObject
Claim() *string
SetClaim(val *string)
ClaimInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
MatchType() *string
SetMatchType(val *string)
MatchTypeInput() *string
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleOutputReference ¶
func NewCognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleOutputReference
type CognitoIdentityPoolRolesAttachmentRoleMappingOutputReference ¶
type CognitoIdentityPoolRolesAttachmentRoleMappingOutputReference interface {
cdktf.ComplexObject
AmbiguousRoleResolution() *string
SetAmbiguousRoleResolution(val *string)
AmbiguousRoleResolutionInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IdentityProvider() *string
SetIdentityProvider(val *string)
IdentityProviderInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
MappingRule() CognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleList
MappingRuleInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutMappingRule(value interface{})
ResetAmbiguousRoleResolution()
ResetMappingRule()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCognitoIdentityPoolRolesAttachmentRoleMappingOutputReference ¶
func NewCognitoIdentityPoolRolesAttachmentRoleMappingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) CognitoIdentityPoolRolesAttachmentRoleMappingOutputReference
Source Files
¶
- CognitoIdentityPoolRolesAttachment.go
- CognitoIdentityPoolRolesAttachmentConfig.go
- CognitoIdentityPoolRolesAttachmentRoleMapping.go
- CognitoIdentityPoolRolesAttachmentRoleMappingList.go
- CognitoIdentityPoolRolesAttachmentRoleMappingList__checks.go
- CognitoIdentityPoolRolesAttachmentRoleMappingMappingRule.go
- CognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleList.go
- CognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleList__checks.go
- CognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleOutputReference.go
- CognitoIdentityPoolRolesAttachmentRoleMappingMappingRuleOutputReference__checks.go
- CognitoIdentityPoolRolesAttachmentRoleMappingOutputReference.go
- CognitoIdentityPoolRolesAttachmentRoleMappingOutputReference__checks.go
- CognitoIdentityPoolRolesAttachment__checks.go
- main.go