Documentation
¶
Index ¶
- func ComprehendEntityRecognizer_IsConstruct(x interface{}) *bool
- func ComprehendEntityRecognizer_IsTerraformElement(x interface{}) *bool
- func ComprehendEntityRecognizer_IsTerraformResource(x interface{}) *bool
- func ComprehendEntityRecognizer_TfResourceType() *string
- func NewComprehendEntityRecognizerInputDataConfigAnnotationsOutputReference_Override(c ComprehendEntityRecognizerInputDataConfigAnnotationsOutputReference, ...)
- func NewComprehendEntityRecognizerInputDataConfigAugmentedManifestsList_Override(c ComprehendEntityRecognizerInputDataConfigAugmentedManifestsList, ...)
- func NewComprehendEntityRecognizerInputDataConfigAugmentedManifestsOutputReference_Override(c ComprehendEntityRecognizerInputDataConfigAugmentedManifestsOutputReference, ...)
- func NewComprehendEntityRecognizerInputDataConfigDocumentsOutputReference_Override(c ComprehendEntityRecognizerInputDataConfigDocumentsOutputReference, ...)
- func NewComprehendEntityRecognizerInputDataConfigEntityListOutputReference_Override(c ComprehendEntityRecognizerInputDataConfigEntityListOutputReference, ...)
- func NewComprehendEntityRecognizerInputDataConfigEntityTypesList_Override(c ComprehendEntityRecognizerInputDataConfigEntityTypesList, ...)
- func NewComprehendEntityRecognizerInputDataConfigEntityTypesOutputReference_Override(c ComprehendEntityRecognizerInputDataConfigEntityTypesOutputReference, ...)
- func NewComprehendEntityRecognizerInputDataConfigOutputReference_Override(c ComprehendEntityRecognizerInputDataConfigOutputReference, ...)
- func NewComprehendEntityRecognizerTimeoutsOutputReference_Override(c ComprehendEntityRecognizerTimeoutsOutputReference, ...)
- func NewComprehendEntityRecognizerVpcConfigOutputReference_Override(c ComprehendEntityRecognizerVpcConfigOutputReference, ...)
- func NewComprehendEntityRecognizer_Override(c ComprehendEntityRecognizer, scope constructs.Construct, id *string, ...)
- type ComprehendEntityRecognizer
- type ComprehendEntityRecognizerConfig
- type ComprehendEntityRecognizerInputDataConfig
- type ComprehendEntityRecognizerInputDataConfigAnnotations
- type ComprehendEntityRecognizerInputDataConfigAnnotationsOutputReference
- type ComprehendEntityRecognizerInputDataConfigAugmentedManifests
- type ComprehendEntityRecognizerInputDataConfigAugmentedManifestsList
- type ComprehendEntityRecognizerInputDataConfigAugmentedManifestsOutputReference
- type ComprehendEntityRecognizerInputDataConfigDocuments
- type ComprehendEntityRecognizerInputDataConfigDocumentsOutputReference
- type ComprehendEntityRecognizerInputDataConfigEntityList
- type ComprehendEntityRecognizerInputDataConfigEntityListOutputReference
- type ComprehendEntityRecognizerInputDataConfigEntityTypes
- type ComprehendEntityRecognizerInputDataConfigEntityTypesList
- type ComprehendEntityRecognizerInputDataConfigEntityTypesOutputReference
- type ComprehendEntityRecognizerInputDataConfigOutputReference
- type ComprehendEntityRecognizerTimeouts
- type ComprehendEntityRecognizerTimeoutsOutputReference
- type ComprehendEntityRecognizerVpcConfig
- type ComprehendEntityRecognizerVpcConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ComprehendEntityRecognizer_IsConstruct ¶
func ComprehendEntityRecognizer_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ComprehendEntityRecognizer_IsTerraformElement ¶
func ComprehendEntityRecognizer_IsTerraformElement(x interface{}) *bool
Experimental.
func ComprehendEntityRecognizer_IsTerraformResource ¶
func ComprehendEntityRecognizer_IsTerraformResource(x interface{}) *bool
Experimental.
func ComprehendEntityRecognizer_TfResourceType ¶
func ComprehendEntityRecognizer_TfResourceType() *string
func NewComprehendEntityRecognizerInputDataConfigAnnotationsOutputReference_Override ¶
func NewComprehendEntityRecognizerInputDataConfigAnnotationsOutputReference_Override(c ComprehendEntityRecognizerInputDataConfigAnnotationsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComprehendEntityRecognizerInputDataConfigAugmentedManifestsList_Override ¶
func NewComprehendEntityRecognizerInputDataConfigAugmentedManifestsList_Override(c ComprehendEntityRecognizerInputDataConfigAugmentedManifestsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewComprehendEntityRecognizerInputDataConfigAugmentedManifestsOutputReference_Override ¶
func NewComprehendEntityRecognizerInputDataConfigAugmentedManifestsOutputReference_Override(c ComprehendEntityRecognizerInputDataConfigAugmentedManifestsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewComprehendEntityRecognizerInputDataConfigDocumentsOutputReference_Override ¶
func NewComprehendEntityRecognizerInputDataConfigDocumentsOutputReference_Override(c ComprehendEntityRecognizerInputDataConfigDocumentsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComprehendEntityRecognizerInputDataConfigEntityListOutputReference_Override ¶
func NewComprehendEntityRecognizerInputDataConfigEntityListOutputReference_Override(c ComprehendEntityRecognizerInputDataConfigEntityListOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComprehendEntityRecognizerInputDataConfigEntityTypesList_Override ¶
func NewComprehendEntityRecognizerInputDataConfigEntityTypesList_Override(c ComprehendEntityRecognizerInputDataConfigEntityTypesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewComprehendEntityRecognizerInputDataConfigEntityTypesOutputReference_Override ¶
func NewComprehendEntityRecognizerInputDataConfigEntityTypesOutputReference_Override(c ComprehendEntityRecognizerInputDataConfigEntityTypesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewComprehendEntityRecognizerInputDataConfigOutputReference_Override ¶
func NewComprehendEntityRecognizerInputDataConfigOutputReference_Override(c ComprehendEntityRecognizerInputDataConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComprehendEntityRecognizerTimeoutsOutputReference_Override ¶
func NewComprehendEntityRecognizerTimeoutsOutputReference_Override(c ComprehendEntityRecognizerTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComprehendEntityRecognizerVpcConfigOutputReference_Override ¶
func NewComprehendEntityRecognizerVpcConfigOutputReference_Override(c ComprehendEntityRecognizerVpcConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComprehendEntityRecognizer_Override ¶
func NewComprehendEntityRecognizer_Override(c ComprehendEntityRecognizer, scope constructs.Construct, id *string, config *ComprehendEntityRecognizerConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer aws_comprehend_entity_recognizer} Resource.
Types ¶
type ComprehendEntityRecognizer ¶
type ComprehendEntityRecognizer interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DataAccessRoleArn() *string
SetDataAccessRoleArn(val *string)
DataAccessRoleArnInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InputDataConfig() ComprehendEntityRecognizerInputDataConfigOutputReference
InputDataConfigInput() *ComprehendEntityRecognizerInputDataConfig
LanguageCode() *string
SetLanguageCode(val *string)
LanguageCodeInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
ModelKmsKeyId() *string
SetModelKmsKeyId(val *string)
ModelKmsKeyIdInput() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() ComprehendEntityRecognizerTimeoutsOutputReference
TimeoutsInput() interface{}
VersionName() *string
SetVersionName(val *string)
VersionNameInput() *string
VersionNamePrefix() *string
SetVersionNamePrefix(val *string)
VersionNamePrefixInput() *string
VolumeKmsKeyId() *string
SetVolumeKmsKeyId(val *string)
VolumeKmsKeyIdInput() *string
VpcConfig() ComprehendEntityRecognizerVpcConfigOutputReference
VpcConfigInput() *ComprehendEntityRecognizerVpcConfig
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutInputDataConfig(value *ComprehendEntityRecognizerInputDataConfig)
PutTimeouts(value *ComprehendEntityRecognizerTimeouts)
PutVpcConfig(value *ComprehendEntityRecognizerVpcConfig)
ResetId()
ResetModelKmsKeyId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
ResetTimeouts()
ResetVersionName()
ResetVersionNamePrefix()
ResetVolumeKmsKeyId()
ResetVpcConfig()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer aws_comprehend_entity_recognizer}.
func NewComprehendEntityRecognizer ¶
func NewComprehendEntityRecognizer(scope constructs.Construct, id *string, config *ComprehendEntityRecognizerConfig) ComprehendEntityRecognizer
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer aws_comprehend_entity_recognizer} Resource.
type ComprehendEntityRecognizerConfig ¶
type ComprehendEntityRecognizerConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#data_access_role_arn ComprehendEntityRecognizer#data_access_role_arn}.
DataAccessRoleArn *string `field:"required" json:"dataAccessRoleArn" yaml:"dataAccessRoleArn"`
// input_data_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#input_data_config ComprehendEntityRecognizer#input_data_config}
InputDataConfig *ComprehendEntityRecognizerInputDataConfig `field:"required" json:"inputDataConfig" yaml:"inputDataConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#language_code ComprehendEntityRecognizer#language_code}.
LanguageCode *string `field:"required" json:"languageCode" yaml:"languageCode"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#name ComprehendEntityRecognizer#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#id ComprehendEntityRecognizer#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#model_kms_key_id ComprehendEntityRecognizer#model_kms_key_id}.
ModelKmsKeyId *string `field:"optional" json:"modelKmsKeyId" yaml:"modelKmsKeyId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#tags ComprehendEntityRecognizer#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#tags_all ComprehendEntityRecognizer#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#timeouts ComprehendEntityRecognizer#timeouts}
Timeouts *ComprehendEntityRecognizerTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#version_name ComprehendEntityRecognizer#version_name}.
VersionName *string `field:"optional" json:"versionName" yaml:"versionName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#version_name_prefix ComprehendEntityRecognizer#version_name_prefix}.
VersionNamePrefix *string `field:"optional" json:"versionNamePrefix" yaml:"versionNamePrefix"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#volume_kms_key_id ComprehendEntityRecognizer#volume_kms_key_id}.
VolumeKmsKeyId *string `field:"optional" json:"volumeKmsKeyId" yaml:"volumeKmsKeyId"`
// vpc_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#vpc_config ComprehendEntityRecognizer#vpc_config}
VpcConfig *ComprehendEntityRecognizerVpcConfig `field:"optional" json:"vpcConfig" yaml:"vpcConfig"`
}
type ComprehendEntityRecognizerInputDataConfig ¶
type ComprehendEntityRecognizerInputDataConfig struct {
// entity_types block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#entity_types ComprehendEntityRecognizer#entity_types}
EntityTypes interface{} `field:"required" json:"entityTypes" yaml:"entityTypes"`
// annotations block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#annotations ComprehendEntityRecognizer#annotations}
Annotations *ComprehendEntityRecognizerInputDataConfigAnnotations `field:"optional" json:"annotations" yaml:"annotations"`
// augmented_manifests block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#augmented_manifests ComprehendEntityRecognizer#augmented_manifests}
AugmentedManifests interface{} `field:"optional" json:"augmentedManifests" yaml:"augmentedManifests"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#data_format ComprehendEntityRecognizer#data_format}.
DataFormat *string `field:"optional" json:"dataFormat" yaml:"dataFormat"`
// documents block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#documents ComprehendEntityRecognizer#documents}
Documents *ComprehendEntityRecognizerInputDataConfigDocuments `field:"optional" json:"documents" yaml:"documents"`
// entity_list block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#entity_list ComprehendEntityRecognizer#entity_list}
EntityList *ComprehendEntityRecognizerInputDataConfigEntityList `field:"optional" json:"entityList" yaml:"entityList"`
}
type ComprehendEntityRecognizerInputDataConfigAnnotations ¶
type ComprehendEntityRecognizerInputDataConfigAnnotations struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#s3_uri ComprehendEntityRecognizer#s3_uri}.
S3Uri *string `field:"required" json:"s3Uri" yaml:"s3Uri"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#test_s3_uri ComprehendEntityRecognizer#test_s3_uri}.
TestS3Uri *string `field:"optional" json:"testS3Uri" yaml:"testS3Uri"`
}
type ComprehendEntityRecognizerInputDataConfigAnnotationsOutputReference ¶
type ComprehendEntityRecognizerInputDataConfigAnnotationsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ComprehendEntityRecognizerInputDataConfigAnnotations
SetInternalValue(val *ComprehendEntityRecognizerInputDataConfigAnnotations)
S3Uri() *string
SetS3Uri(val *string)
S3UriInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TestS3Uri() *string
SetTestS3Uri(val *string)
TestS3UriInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetTestS3Uri()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComprehendEntityRecognizerInputDataConfigAnnotationsOutputReference ¶
func NewComprehendEntityRecognizerInputDataConfigAnnotationsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComprehendEntityRecognizerInputDataConfigAnnotationsOutputReference
type ComprehendEntityRecognizerInputDataConfigAugmentedManifests ¶
type ComprehendEntityRecognizerInputDataConfigAugmentedManifests struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#attribute_names ComprehendEntityRecognizer#attribute_names}.
AttributeNames *[]*string `field:"required" json:"attributeNames" yaml:"attributeNames"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#s3_uri ComprehendEntityRecognizer#s3_uri}.
S3Uri *string `field:"required" json:"s3Uri" yaml:"s3Uri"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#annotation_data_s3_uri ComprehendEntityRecognizer#annotation_data_s3_uri}.
AnnotationDataS3Uri *string `field:"optional" json:"annotationDataS3Uri" yaml:"annotationDataS3Uri"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#document_type ComprehendEntityRecognizer#document_type}.
DocumentType *string `field:"optional" json:"documentType" yaml:"documentType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#source_documents_s3_uri ComprehendEntityRecognizer#source_documents_s3_uri}.
SourceDocumentsS3Uri *string `field:"optional" json:"sourceDocumentsS3Uri" yaml:"sourceDocumentsS3Uri"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#split ComprehendEntityRecognizer#split}.
Split *string `field:"optional" json:"split" yaml:"split"`
}
type ComprehendEntityRecognizerInputDataConfigAugmentedManifestsList ¶
type ComprehendEntityRecognizerInputDataConfigAugmentedManifestsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ComprehendEntityRecognizerInputDataConfigAugmentedManifestsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComprehendEntityRecognizerInputDataConfigAugmentedManifestsList ¶
func NewComprehendEntityRecognizerInputDataConfigAugmentedManifestsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ComprehendEntityRecognizerInputDataConfigAugmentedManifestsList
type ComprehendEntityRecognizerInputDataConfigAugmentedManifestsOutputReference ¶
type ComprehendEntityRecognizerInputDataConfigAugmentedManifestsOutputReference interface {
cdktf.ComplexObject
AnnotationDataS3Uri() *string
SetAnnotationDataS3Uri(val *string)
AnnotationDataS3UriInput() *string
AttributeNames() *[]*string
SetAttributeNames(val *[]*string)
AttributeNamesInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DocumentType() *string
SetDocumentType(val *string)
DocumentTypeInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
S3Uri() *string
SetS3Uri(val *string)
S3UriInput() *string
SourceDocumentsS3Uri() *string
SetSourceDocumentsS3Uri(val *string)
SourceDocumentsS3UriInput() *string
Split() *string
SetSplit(val *string)
SplitInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAnnotationDataS3Uri()
ResetDocumentType()
ResetSourceDocumentsS3Uri()
ResetSplit()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComprehendEntityRecognizerInputDataConfigAugmentedManifestsOutputReference ¶
func NewComprehendEntityRecognizerInputDataConfigAugmentedManifestsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ComprehendEntityRecognizerInputDataConfigAugmentedManifestsOutputReference
type ComprehendEntityRecognizerInputDataConfigDocuments ¶
type ComprehendEntityRecognizerInputDataConfigDocuments struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#s3_uri ComprehendEntityRecognizer#s3_uri}.
S3Uri *string `field:"required" json:"s3Uri" yaml:"s3Uri"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#input_format ComprehendEntityRecognizer#input_format}.
InputFormat *string `field:"optional" json:"inputFormat" yaml:"inputFormat"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#test_s3_uri ComprehendEntityRecognizer#test_s3_uri}.
TestS3Uri *string `field:"optional" json:"testS3Uri" yaml:"testS3Uri"`
}
type ComprehendEntityRecognizerInputDataConfigDocumentsOutputReference ¶
type ComprehendEntityRecognizerInputDataConfigDocumentsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InputFormat() *string
SetInputFormat(val *string)
InputFormatInput() *string
InternalValue() *ComprehendEntityRecognizerInputDataConfigDocuments
SetInternalValue(val *ComprehendEntityRecognizerInputDataConfigDocuments)
S3Uri() *string
SetS3Uri(val *string)
S3UriInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TestS3Uri() *string
SetTestS3Uri(val *string)
TestS3UriInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetInputFormat()
ResetTestS3Uri()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComprehendEntityRecognizerInputDataConfigDocumentsOutputReference ¶
func NewComprehendEntityRecognizerInputDataConfigDocumentsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComprehendEntityRecognizerInputDataConfigDocumentsOutputReference
type ComprehendEntityRecognizerInputDataConfigEntityList ¶
type ComprehendEntityRecognizerInputDataConfigEntityList struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#s3_uri ComprehendEntityRecognizer#s3_uri}.
S3Uri *string `field:"required" json:"s3Uri" yaml:"s3Uri"`
}
type ComprehendEntityRecognizerInputDataConfigEntityListOutputReference ¶
type ComprehendEntityRecognizerInputDataConfigEntityListOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ComprehendEntityRecognizerInputDataConfigEntityList
SetInternalValue(val *ComprehendEntityRecognizerInputDataConfigEntityList)
S3Uri() *string
SetS3Uri(val *string)
S3UriInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComprehendEntityRecognizerInputDataConfigEntityListOutputReference ¶
func NewComprehendEntityRecognizerInputDataConfigEntityListOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComprehendEntityRecognizerInputDataConfigEntityListOutputReference
type ComprehendEntityRecognizerInputDataConfigEntityTypes ¶
type ComprehendEntityRecognizerInputDataConfigEntityTypes struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#type ComprehendEntityRecognizer#type}.
Type *string `field:"required" json:"type" yaml:"type"`
}
type ComprehendEntityRecognizerInputDataConfigEntityTypesList ¶
type ComprehendEntityRecognizerInputDataConfigEntityTypesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ComprehendEntityRecognizerInputDataConfigEntityTypesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComprehendEntityRecognizerInputDataConfigEntityTypesList ¶
func NewComprehendEntityRecognizerInputDataConfigEntityTypesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ComprehendEntityRecognizerInputDataConfigEntityTypesList
type ComprehendEntityRecognizerInputDataConfigEntityTypesOutputReference ¶
type ComprehendEntityRecognizerInputDataConfigEntityTypesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComprehendEntityRecognizerInputDataConfigEntityTypesOutputReference ¶
func NewComprehendEntityRecognizerInputDataConfigEntityTypesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ComprehendEntityRecognizerInputDataConfigEntityTypesOutputReference
type ComprehendEntityRecognizerInputDataConfigOutputReference ¶
type ComprehendEntityRecognizerInputDataConfigOutputReference interface {
cdktf.ComplexObject
Annotations() ComprehendEntityRecognizerInputDataConfigAnnotationsOutputReference
AnnotationsInput() *ComprehendEntityRecognizerInputDataConfigAnnotations
AugmentedManifests() ComprehendEntityRecognizerInputDataConfigAugmentedManifestsList
AugmentedManifestsInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DataFormat() *string
SetDataFormat(val *string)
DataFormatInput() *string
Documents() ComprehendEntityRecognizerInputDataConfigDocumentsOutputReference
DocumentsInput() *ComprehendEntityRecognizerInputDataConfigDocuments
EntityList() ComprehendEntityRecognizerInputDataConfigEntityListOutputReference
EntityListInput() *ComprehendEntityRecognizerInputDataConfigEntityList
EntityTypes() ComprehendEntityRecognizerInputDataConfigEntityTypesList
EntityTypesInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *ComprehendEntityRecognizerInputDataConfig
SetInternalValue(val *ComprehendEntityRecognizerInputDataConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAnnotations(value *ComprehendEntityRecognizerInputDataConfigAnnotations)
PutAugmentedManifests(value interface{})
PutDocuments(value *ComprehendEntityRecognizerInputDataConfigDocuments)
PutEntityList(value *ComprehendEntityRecognizerInputDataConfigEntityList)
PutEntityTypes(value interface{})
ResetAnnotations()
ResetAugmentedManifests()
ResetDataFormat()
ResetDocuments()
ResetEntityList()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComprehendEntityRecognizerInputDataConfigOutputReference ¶
func NewComprehendEntityRecognizerInputDataConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComprehendEntityRecognizerInputDataConfigOutputReference
type ComprehendEntityRecognizerTimeouts ¶
type ComprehendEntityRecognizerTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#create ComprehendEntityRecognizer#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#delete ComprehendEntityRecognizer#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#update ComprehendEntityRecognizer#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type ComprehendEntityRecognizerTimeoutsOutputReference ¶
type ComprehendEntityRecognizerTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComprehendEntityRecognizerTimeoutsOutputReference ¶
func NewComprehendEntityRecognizerTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComprehendEntityRecognizerTimeoutsOutputReference
type ComprehendEntityRecognizerVpcConfig ¶
type ComprehendEntityRecognizerVpcConfig struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#security_group_ids ComprehendEntityRecognizer#security_group_ids}.
SecurityGroupIds *[]*string `field:"required" json:"securityGroupIds" yaml:"securityGroupIds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/comprehend_entity_recognizer#subnets ComprehendEntityRecognizer#subnets}.
Subnets *[]*string `field:"required" json:"subnets" yaml:"subnets"`
}
type ComprehendEntityRecognizerVpcConfigOutputReference ¶
type ComprehendEntityRecognizerVpcConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ComprehendEntityRecognizerVpcConfig
SetInternalValue(val *ComprehendEntityRecognizerVpcConfig)
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
Subnets() *[]*string
SetSubnets(val *[]*string)
SubnetsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComprehendEntityRecognizerVpcConfigOutputReference ¶
func NewComprehendEntityRecognizerVpcConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComprehendEntityRecognizerVpcConfigOutputReference
Source Files
¶
- ComprehendEntityRecognizer.go
- ComprehendEntityRecognizerConfig.go
- ComprehendEntityRecognizerInputDataConfig.go
- ComprehendEntityRecognizerInputDataConfigAnnotations.go
- ComprehendEntityRecognizerInputDataConfigAnnotationsOutputReference.go
- ComprehendEntityRecognizerInputDataConfigAnnotationsOutputReference__checks.go
- ComprehendEntityRecognizerInputDataConfigAugmentedManifests.go
- ComprehendEntityRecognizerInputDataConfigAugmentedManifestsList.go
- ComprehendEntityRecognizerInputDataConfigAugmentedManifestsList__checks.go
- ComprehendEntityRecognizerInputDataConfigAugmentedManifestsOutputReference.go
- ComprehendEntityRecognizerInputDataConfigAugmentedManifestsOutputReference__checks.go
- ComprehendEntityRecognizerInputDataConfigDocuments.go
- ComprehendEntityRecognizerInputDataConfigDocumentsOutputReference.go
- ComprehendEntityRecognizerInputDataConfigDocumentsOutputReference__checks.go
- ComprehendEntityRecognizerInputDataConfigEntityList.go
- ComprehendEntityRecognizerInputDataConfigEntityListOutputReference.go
- ComprehendEntityRecognizerInputDataConfigEntityListOutputReference__checks.go
- ComprehendEntityRecognizerInputDataConfigEntityTypes.go
- ComprehendEntityRecognizerInputDataConfigEntityTypesList.go
- ComprehendEntityRecognizerInputDataConfigEntityTypesList__checks.go
- ComprehendEntityRecognizerInputDataConfigEntityTypesOutputReference.go
- ComprehendEntityRecognizerInputDataConfigEntityTypesOutputReference__checks.go
- ComprehendEntityRecognizerInputDataConfigOutputReference.go
- ComprehendEntityRecognizerInputDataConfigOutputReference__checks.go
- ComprehendEntityRecognizerTimeouts.go
- ComprehendEntityRecognizerTimeoutsOutputReference.go
- ComprehendEntityRecognizerTimeoutsOutputReference__checks.go
- ComprehendEntityRecognizerVpcConfig.go
- ComprehendEntityRecognizerVpcConfigOutputReference.go
- ComprehendEntityRecognizerVpcConfigOutputReference__checks.go
- ComprehendEntityRecognizer__checks.go
- main.go