Documentation
¶
Index ¶
- func ConfigConfigRule_IsConstruct(x interface{}) *bool
- func ConfigConfigRule_IsTerraformElement(x interface{}) *bool
- func ConfigConfigRule_IsTerraformResource(x interface{}) *bool
- func ConfigConfigRule_TfResourceType() *string
- func NewConfigConfigRuleScopeOutputReference_Override(c ConfigConfigRuleScopeOutputReference, ...)
- func NewConfigConfigRuleSourceCustomPolicyDetailsOutputReference_Override(c ConfigConfigRuleSourceCustomPolicyDetailsOutputReference, ...)
- func NewConfigConfigRuleSourceOutputReference_Override(c ConfigConfigRuleSourceOutputReference, ...)
- func NewConfigConfigRuleSourceSourceDetailList_Override(c ConfigConfigRuleSourceSourceDetailList, ...)
- func NewConfigConfigRuleSourceSourceDetailOutputReference_Override(c ConfigConfigRuleSourceSourceDetailOutputReference, ...)
- func NewConfigConfigRule_Override(c ConfigConfigRule, scope constructs.Construct, id *string, ...)
- type ConfigConfigRule
- type ConfigConfigRuleConfig
- type ConfigConfigRuleScope
- type ConfigConfigRuleScopeOutputReference
- type ConfigConfigRuleSource
- type ConfigConfigRuleSourceCustomPolicyDetails
- type ConfigConfigRuleSourceCustomPolicyDetailsOutputReference
- type ConfigConfigRuleSourceOutputReference
- type ConfigConfigRuleSourceSourceDetail
- type ConfigConfigRuleSourceSourceDetailList
- type ConfigConfigRuleSourceSourceDetailOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConfigConfigRule_IsConstruct ¶
func ConfigConfigRule_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ConfigConfigRule_IsTerraformElement ¶
func ConfigConfigRule_IsTerraformElement(x interface{}) *bool
Experimental.
func ConfigConfigRule_IsTerraformResource ¶
func ConfigConfigRule_IsTerraformResource(x interface{}) *bool
Experimental.
func ConfigConfigRule_TfResourceType ¶
func ConfigConfigRule_TfResourceType() *string
func NewConfigConfigRuleScopeOutputReference_Override ¶
func NewConfigConfigRuleScopeOutputReference_Override(c ConfigConfigRuleScopeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewConfigConfigRuleSourceCustomPolicyDetailsOutputReference_Override ¶
func NewConfigConfigRuleSourceCustomPolicyDetailsOutputReference_Override(c ConfigConfigRuleSourceCustomPolicyDetailsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewConfigConfigRuleSourceOutputReference_Override ¶
func NewConfigConfigRuleSourceOutputReference_Override(c ConfigConfigRuleSourceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewConfigConfigRuleSourceSourceDetailList_Override ¶
func NewConfigConfigRuleSourceSourceDetailList_Override(c ConfigConfigRuleSourceSourceDetailList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewConfigConfigRuleSourceSourceDetailOutputReference_Override ¶
func NewConfigConfigRuleSourceSourceDetailOutputReference_Override(c ConfigConfigRuleSourceSourceDetailOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewConfigConfigRule_Override ¶
func NewConfigConfigRule_Override(c ConfigConfigRule, scope constructs.Construct, id *string, config *ConfigConfigRuleConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule aws_config_config_rule} Resource.
Types ¶
type ConfigConfigRule ¶
type ConfigConfigRule interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InputParameters() *string
SetInputParameters(val *string)
InputParametersInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaximumExecutionFrequency() *string
SetMaximumExecutionFrequency(val *string)
MaximumExecutionFrequencyInput() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RuleId() *string
Scope() ConfigConfigRuleScopeOutputReference
ScopeInput() *ConfigConfigRuleScope
Source() ConfigConfigRuleSourceOutputReference
SourceInput() *ConfigConfigRuleSource
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutScope(value *ConfigConfigRuleScope)
PutSource(value *ConfigConfigRuleSource)
ResetDescription()
ResetId()
ResetInputParameters()
ResetMaximumExecutionFrequency()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetScope()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule aws_config_config_rule}.
func NewConfigConfigRule ¶
func NewConfigConfigRule(scope constructs.Construct, id *string, config *ConfigConfigRuleConfig) ConfigConfigRule
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule aws_config_config_rule} Resource.
type ConfigConfigRuleConfig ¶
type ConfigConfigRuleConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#name ConfigConfigRule#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// source block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#source ConfigConfigRule#source}
Source *ConfigConfigRuleSource `field:"required" json:"source" yaml:"source"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#description ConfigConfigRule#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#id ConfigConfigRule#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#input_parameters ConfigConfigRule#input_parameters}.
InputParameters *string `field:"optional" json:"inputParameters" yaml:"inputParameters"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#maximum_execution_frequency ConfigConfigRule#maximum_execution_frequency}.
MaximumExecutionFrequency *string `field:"optional" json:"maximumExecutionFrequency" yaml:"maximumExecutionFrequency"`
// scope block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#scope ConfigConfigRule#scope}
Scope *ConfigConfigRuleScope `field:"optional" json:"scope" yaml:"scope"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#tags ConfigConfigRule#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#tags_all ConfigConfigRule#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type ConfigConfigRuleScope ¶
type ConfigConfigRuleScope struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#compliance_resource_id ConfigConfigRule#compliance_resource_id}.
ComplianceResourceId *string `field:"optional" json:"complianceResourceId" yaml:"complianceResourceId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#compliance_resource_types ConfigConfigRule#compliance_resource_types}.
ComplianceResourceTypes *[]*string `field:"optional" json:"complianceResourceTypes" yaml:"complianceResourceTypes"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#tag_key ConfigConfigRule#tag_key}.
TagKey *string `field:"optional" json:"tagKey" yaml:"tagKey"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#tag_value ConfigConfigRule#tag_value}.
TagValue *string `field:"optional" json:"tagValue" yaml:"tagValue"`
}
type ConfigConfigRuleScopeOutputReference ¶
type ConfigConfigRuleScopeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ComplianceResourceId() *string
SetComplianceResourceId(val *string)
ComplianceResourceIdInput() *string
ComplianceResourceTypes() *[]*string
SetComplianceResourceTypes(val *[]*string)
ComplianceResourceTypesInput() *[]*string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ConfigConfigRuleScope
SetInternalValue(val *ConfigConfigRuleScope)
TagKey() *string
SetTagKey(val *string)
TagKeyInput() *string
TagValue() *string
SetTagValue(val *string)
TagValueInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetComplianceResourceId()
ResetComplianceResourceTypes()
ResetTagKey()
ResetTagValue()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConfigConfigRuleScopeOutputReference ¶
func NewConfigConfigRuleScopeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ConfigConfigRuleScopeOutputReference
type ConfigConfigRuleSource ¶
type ConfigConfigRuleSource struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#owner ConfigConfigRule#owner}.
Owner *string `field:"required" json:"owner" yaml:"owner"`
// custom_policy_details block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#custom_policy_details ConfigConfigRule#custom_policy_details}
CustomPolicyDetails *ConfigConfigRuleSourceCustomPolicyDetails `field:"optional" json:"customPolicyDetails" yaml:"customPolicyDetails"`
// source_detail block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#source_detail ConfigConfigRule#source_detail}
SourceDetail interface{} `field:"optional" json:"sourceDetail" yaml:"sourceDetail"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#source_identifier ConfigConfigRule#source_identifier}.
SourceIdentifier *string `field:"optional" json:"sourceIdentifier" yaml:"sourceIdentifier"`
}
type ConfigConfigRuleSourceCustomPolicyDetails ¶
type ConfigConfigRuleSourceCustomPolicyDetails struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#policy_runtime ConfigConfigRule#policy_runtime}.
PolicyRuntime *string `field:"required" json:"policyRuntime" yaml:"policyRuntime"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#policy_text ConfigConfigRule#policy_text}.
PolicyText *string `field:"required" json:"policyText" yaml:"policyText"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#enable_debug_log_delivery ConfigConfigRule#enable_debug_log_delivery}.
EnableDebugLogDelivery interface{} `field:"optional" json:"enableDebugLogDelivery" yaml:"enableDebugLogDelivery"`
}
type ConfigConfigRuleSourceCustomPolicyDetailsOutputReference ¶
type ConfigConfigRuleSourceCustomPolicyDetailsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EnableDebugLogDelivery() interface{}
SetEnableDebugLogDelivery(val interface{})
EnableDebugLogDeliveryInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *ConfigConfigRuleSourceCustomPolicyDetails
SetInternalValue(val *ConfigConfigRuleSourceCustomPolicyDetails)
PolicyRuntime() *string
SetPolicyRuntime(val *string)
PolicyRuntimeInput() *string
PolicyText() *string
SetPolicyText(val *string)
PolicyTextInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnableDebugLogDelivery()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConfigConfigRuleSourceCustomPolicyDetailsOutputReference ¶
func NewConfigConfigRuleSourceCustomPolicyDetailsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ConfigConfigRuleSourceCustomPolicyDetailsOutputReference
type ConfigConfigRuleSourceOutputReference ¶
type ConfigConfigRuleSourceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
CustomPolicyDetails() ConfigConfigRuleSourceCustomPolicyDetailsOutputReference
CustomPolicyDetailsInput() *ConfigConfigRuleSourceCustomPolicyDetails
// Experimental.
Fqn() *string
InternalValue() *ConfigConfigRuleSource
SetInternalValue(val *ConfigConfigRuleSource)
Owner() *string
SetOwner(val *string)
OwnerInput() *string
SourceDetail() ConfigConfigRuleSourceSourceDetailList
SourceDetailInput() interface{}
SourceIdentifier() *string
SetSourceIdentifier(val *string)
SourceIdentifierInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutCustomPolicyDetails(value *ConfigConfigRuleSourceCustomPolicyDetails)
PutSourceDetail(value interface{})
ResetCustomPolicyDetails()
ResetSourceDetail()
ResetSourceIdentifier()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConfigConfigRuleSourceOutputReference ¶
func NewConfigConfigRuleSourceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ConfigConfigRuleSourceOutputReference
type ConfigConfigRuleSourceSourceDetail ¶
type ConfigConfigRuleSourceSourceDetail struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#event_source ConfigConfigRule#event_source}.
EventSource *string `field:"optional" json:"eventSource" yaml:"eventSource"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#maximum_execution_frequency ConfigConfigRule#maximum_execution_frequency}.
MaximumExecutionFrequency *string `field:"optional" json:"maximumExecutionFrequency" yaml:"maximumExecutionFrequency"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/config_config_rule#message_type ConfigConfigRule#message_type}.
MessageType *string `field:"optional" json:"messageType" yaml:"messageType"`
}
type ConfigConfigRuleSourceSourceDetailList ¶
type ConfigConfigRuleSourceSourceDetailList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ConfigConfigRuleSourceSourceDetailOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConfigConfigRuleSourceSourceDetailList ¶
func NewConfigConfigRuleSourceSourceDetailList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ConfigConfigRuleSourceSourceDetailList
type ConfigConfigRuleSourceSourceDetailOutputReference ¶
type ConfigConfigRuleSourceSourceDetailOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EventSource() *string
SetEventSource(val *string)
EventSourceInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
MaximumExecutionFrequency() *string
SetMaximumExecutionFrequency(val *string)
MaximumExecutionFrequencyInput() *string
MessageType() *string
SetMessageType(val *string)
MessageTypeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEventSource()
ResetMaximumExecutionFrequency()
ResetMessageType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConfigConfigRuleSourceSourceDetailOutputReference ¶
func NewConfigConfigRuleSourceSourceDetailOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ConfigConfigRuleSourceSourceDetailOutputReference
Source Files
¶
- ConfigConfigRule.go
- ConfigConfigRuleConfig.go
- ConfigConfigRuleScope.go
- ConfigConfigRuleScopeOutputReference.go
- ConfigConfigRuleScopeOutputReference__checks.go
- ConfigConfigRuleSource.go
- ConfigConfigRuleSourceCustomPolicyDetails.go
- ConfigConfigRuleSourceCustomPolicyDetailsOutputReference.go
- ConfigConfigRuleSourceCustomPolicyDetailsOutputReference__checks.go
- ConfigConfigRuleSourceOutputReference.go
- ConfigConfigRuleSourceOutputReference__checks.go
- ConfigConfigRuleSourceSourceDetail.go
- ConfigConfigRuleSourceSourceDetailList.go
- ConfigConfigRuleSourceSourceDetailList__checks.go
- ConfigConfigRuleSourceSourceDetailOutputReference.go
- ConfigConfigRuleSourceSourceDetailOutputReference__checks.go
- ConfigConfigRule__checks.go
- main.go