Documentation
¶
Index ¶
- func ConnectRoutingProfile_IsConstruct(x interface{}) *bool
- func ConnectRoutingProfile_IsTerraformElement(x interface{}) *bool
- func ConnectRoutingProfile_IsTerraformResource(x interface{}) *bool
- func ConnectRoutingProfile_TfResourceType() *string
- func NewConnectRoutingProfileMediaConcurrenciesList_Override(c ConnectRoutingProfileMediaConcurrenciesList, ...)
- func NewConnectRoutingProfileMediaConcurrenciesOutputReference_Override(c ConnectRoutingProfileMediaConcurrenciesOutputReference, ...)
- func NewConnectRoutingProfileQueueConfigsAssociatedList_Override(c ConnectRoutingProfileQueueConfigsAssociatedList, ...)
- func NewConnectRoutingProfileQueueConfigsAssociatedOutputReference_Override(c ConnectRoutingProfileQueueConfigsAssociatedOutputReference, ...)
- func NewConnectRoutingProfileQueueConfigsList_Override(c ConnectRoutingProfileQueueConfigsList, ...)
- func NewConnectRoutingProfileQueueConfigsOutputReference_Override(c ConnectRoutingProfileQueueConfigsOutputReference, ...)
- func NewConnectRoutingProfile_Override(c ConnectRoutingProfile, scope constructs.Construct, id *string, ...)
- type ConnectRoutingProfile
- type ConnectRoutingProfileConfig
- type ConnectRoutingProfileMediaConcurrencies
- type ConnectRoutingProfileMediaConcurrenciesList
- type ConnectRoutingProfileMediaConcurrenciesOutputReference
- type ConnectRoutingProfileQueueConfigs
- type ConnectRoutingProfileQueueConfigsAssociated
- type ConnectRoutingProfileQueueConfigsAssociatedList
- type ConnectRoutingProfileQueueConfigsAssociatedOutputReference
- type ConnectRoutingProfileQueueConfigsList
- type ConnectRoutingProfileQueueConfigsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConnectRoutingProfile_IsConstruct ¶
func ConnectRoutingProfile_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ConnectRoutingProfile_IsTerraformElement ¶
func ConnectRoutingProfile_IsTerraformElement(x interface{}) *bool
Experimental.
func ConnectRoutingProfile_IsTerraformResource ¶
func ConnectRoutingProfile_IsTerraformResource(x interface{}) *bool
Experimental.
func ConnectRoutingProfile_TfResourceType ¶
func ConnectRoutingProfile_TfResourceType() *string
func NewConnectRoutingProfileMediaConcurrenciesList_Override ¶
func NewConnectRoutingProfileMediaConcurrenciesList_Override(c ConnectRoutingProfileMediaConcurrenciesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewConnectRoutingProfileMediaConcurrenciesOutputReference_Override ¶
func NewConnectRoutingProfileMediaConcurrenciesOutputReference_Override(c ConnectRoutingProfileMediaConcurrenciesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewConnectRoutingProfileQueueConfigsAssociatedList_Override ¶
func NewConnectRoutingProfileQueueConfigsAssociatedList_Override(c ConnectRoutingProfileQueueConfigsAssociatedList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewConnectRoutingProfileQueueConfigsAssociatedOutputReference_Override ¶
func NewConnectRoutingProfileQueueConfigsAssociatedOutputReference_Override(c ConnectRoutingProfileQueueConfigsAssociatedOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewConnectRoutingProfileQueueConfigsList_Override ¶
func NewConnectRoutingProfileQueueConfigsList_Override(c ConnectRoutingProfileQueueConfigsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewConnectRoutingProfileQueueConfigsOutputReference_Override ¶
func NewConnectRoutingProfileQueueConfigsOutputReference_Override(c ConnectRoutingProfileQueueConfigsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewConnectRoutingProfile_Override ¶
func NewConnectRoutingProfile_Override(c ConnectRoutingProfile, scope constructs.Construct, id *string, config *ConnectRoutingProfileConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/connect_routing_profile aws_connect_routing_profile} Resource.
Types ¶
type ConnectRoutingProfile ¶
type ConnectRoutingProfile interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DefaultOutboundQueueId() *string
SetDefaultOutboundQueueId(val *string)
DefaultOutboundQueueIdInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InstanceId() *string
SetInstanceId(val *string)
InstanceIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MediaConcurrencies() ConnectRoutingProfileMediaConcurrenciesList
MediaConcurrenciesInput() interface{}
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
QueueConfigs() ConnectRoutingProfileQueueConfigsList
QueueConfigsAssociated() ConnectRoutingProfileQueueConfigsAssociatedList
QueueConfigsInput() interface{}
// Experimental.
RawOverrides() interface{}
RoutingProfileId() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutMediaConcurrencies(value interface{})
PutQueueConfigs(value interface{})
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetQueueConfigs()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/connect_routing_profile aws_connect_routing_profile}.
func NewConnectRoutingProfile ¶
func NewConnectRoutingProfile(scope constructs.Construct, id *string, config *ConnectRoutingProfileConfig) ConnectRoutingProfile
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/connect_routing_profile aws_connect_routing_profile} Resource.
type ConnectRoutingProfileConfig ¶
type ConnectRoutingProfileConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/connect_routing_profile#default_outbound_queue_id ConnectRoutingProfile#default_outbound_queue_id}.
DefaultOutboundQueueId *string `field:"required" json:"defaultOutboundQueueId" yaml:"defaultOutboundQueueId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/connect_routing_profile#description ConnectRoutingProfile#description}.
Description *string `field:"required" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/connect_routing_profile#instance_id ConnectRoutingProfile#instance_id}.
InstanceId *string `field:"required" json:"instanceId" yaml:"instanceId"`
// media_concurrencies block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/connect_routing_profile#media_concurrencies ConnectRoutingProfile#media_concurrencies}
MediaConcurrencies interface{} `field:"required" json:"mediaConcurrencies" yaml:"mediaConcurrencies"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/connect_routing_profile#name ConnectRoutingProfile#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/connect_routing_profile#id ConnectRoutingProfile#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// queue_configs block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/connect_routing_profile#queue_configs ConnectRoutingProfile#queue_configs}
QueueConfigs interface{} `field:"optional" json:"queueConfigs" yaml:"queueConfigs"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/connect_routing_profile#tags ConnectRoutingProfile#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/connect_routing_profile#tags_all ConnectRoutingProfile#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type ConnectRoutingProfileMediaConcurrencies ¶
type ConnectRoutingProfileMediaConcurrencies struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/connect_routing_profile#channel ConnectRoutingProfile#channel}.
Channel *string `field:"required" json:"channel" yaml:"channel"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/connect_routing_profile#concurrency ConnectRoutingProfile#concurrency}.
Concurrency *float64 `field:"required" json:"concurrency" yaml:"concurrency"`
}
type ConnectRoutingProfileMediaConcurrenciesList ¶
type ConnectRoutingProfileMediaConcurrenciesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ConnectRoutingProfileMediaConcurrenciesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectRoutingProfileMediaConcurrenciesList ¶
func NewConnectRoutingProfileMediaConcurrenciesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ConnectRoutingProfileMediaConcurrenciesList
type ConnectRoutingProfileMediaConcurrenciesOutputReference ¶
type ConnectRoutingProfileMediaConcurrenciesOutputReference interface {
cdktf.ComplexObject
Channel() *string
SetChannel(val *string)
ChannelInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Concurrency() *float64
SetConcurrency(val *float64)
ConcurrencyInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectRoutingProfileMediaConcurrenciesOutputReference ¶
func NewConnectRoutingProfileMediaConcurrenciesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ConnectRoutingProfileMediaConcurrenciesOutputReference
type ConnectRoutingProfileQueueConfigs ¶
type ConnectRoutingProfileQueueConfigs struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/connect_routing_profile#channel ConnectRoutingProfile#channel}.
Channel *string `field:"required" json:"channel" yaml:"channel"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/connect_routing_profile#delay ConnectRoutingProfile#delay}.
Delay *float64 `field:"required" json:"delay" yaml:"delay"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/connect_routing_profile#priority ConnectRoutingProfile#priority}.
Priority *float64 `field:"required" json:"priority" yaml:"priority"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/connect_routing_profile#queue_id ConnectRoutingProfile#queue_id}.
QueueId *string `field:"required" json:"queueId" yaml:"queueId"`
}
type ConnectRoutingProfileQueueConfigsAssociated ¶
type ConnectRoutingProfileQueueConfigsAssociated struct {
}
type ConnectRoutingProfileQueueConfigsAssociatedList ¶
type ConnectRoutingProfileQueueConfigsAssociatedList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ConnectRoutingProfileQueueConfigsAssociatedOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectRoutingProfileQueueConfigsAssociatedList ¶
func NewConnectRoutingProfileQueueConfigsAssociatedList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ConnectRoutingProfileQueueConfigsAssociatedList
type ConnectRoutingProfileQueueConfigsAssociatedOutputReference ¶
type ConnectRoutingProfileQueueConfigsAssociatedOutputReference interface {
cdktf.ComplexObject
Channel() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delay() *float64
// Experimental.
Fqn() *string
InternalValue() *ConnectRoutingProfileQueueConfigsAssociated
SetInternalValue(val *ConnectRoutingProfileQueueConfigsAssociated)
Priority() *float64
QueueArn() *string
QueueId() *string
QueueName() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectRoutingProfileQueueConfigsAssociatedOutputReference ¶
func NewConnectRoutingProfileQueueConfigsAssociatedOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ConnectRoutingProfileQueueConfigsAssociatedOutputReference
type ConnectRoutingProfileQueueConfigsList ¶
type ConnectRoutingProfileQueueConfigsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ConnectRoutingProfileQueueConfigsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectRoutingProfileQueueConfigsList ¶
func NewConnectRoutingProfileQueueConfigsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ConnectRoutingProfileQueueConfigsList
type ConnectRoutingProfileQueueConfigsOutputReference ¶
type ConnectRoutingProfileQueueConfigsOutputReference interface {
cdktf.ComplexObject
Channel() *string
SetChannel(val *string)
ChannelInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delay() *float64
SetDelay(val *float64)
DelayInput() *float64
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Priority() *float64
SetPriority(val *float64)
PriorityInput() *float64
QueueArn() *string
QueueId() *string
SetQueueId(val *string)
QueueIdInput() *string
QueueName() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewConnectRoutingProfileQueueConfigsOutputReference ¶
func NewConnectRoutingProfileQueueConfigsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ConnectRoutingProfileQueueConfigsOutputReference
Source Files
¶
- ConnectRoutingProfile.go
- ConnectRoutingProfileConfig.go
- ConnectRoutingProfileMediaConcurrencies.go
- ConnectRoutingProfileMediaConcurrenciesList.go
- ConnectRoutingProfileMediaConcurrenciesList__checks.go
- ConnectRoutingProfileMediaConcurrenciesOutputReference.go
- ConnectRoutingProfileMediaConcurrenciesOutputReference__checks.go
- ConnectRoutingProfileQueueConfigs.go
- ConnectRoutingProfileQueueConfigsAssociated.go
- ConnectRoutingProfileQueueConfigsAssociatedList.go
- ConnectRoutingProfileQueueConfigsAssociatedList__checks.go
- ConnectRoutingProfileQueueConfigsAssociatedOutputReference.go
- ConnectRoutingProfileQueueConfigsAssociatedOutputReference__checks.go
- ConnectRoutingProfileQueueConfigsList.go
- ConnectRoutingProfileQueueConfigsList__checks.go
- ConnectRoutingProfileQueueConfigsOutputReference.go
- ConnectRoutingProfileQueueConfigsOutputReference__checks.go
- ConnectRoutingProfile__checks.go
- main.go