Documentation
¶
Index ¶
- func DataAwsAlbListener_IsConstruct(x interface{}) *bool
- func DataAwsAlbListener_IsTerraformDataSource(x interface{}) *bool
- func DataAwsAlbListener_IsTerraformElement(x interface{}) *bool
- func DataAwsAlbListener_TfResourceType() *string
- func NewDataAwsAlbListenerDefaultActionAuthenticateCognitoList_Override(d DataAwsAlbListenerDefaultActionAuthenticateCognitoList, ...)
- func NewDataAwsAlbListenerDefaultActionAuthenticateCognitoOutputReference_Override(d DataAwsAlbListenerDefaultActionAuthenticateCognitoOutputReference, ...)
- func NewDataAwsAlbListenerDefaultActionAuthenticateOidcList_Override(d DataAwsAlbListenerDefaultActionAuthenticateOidcList, ...)
- func NewDataAwsAlbListenerDefaultActionAuthenticateOidcOutputReference_Override(d DataAwsAlbListenerDefaultActionAuthenticateOidcOutputReference, ...)
- func NewDataAwsAlbListenerDefaultActionFixedResponseList_Override(d DataAwsAlbListenerDefaultActionFixedResponseList, ...)
- func NewDataAwsAlbListenerDefaultActionFixedResponseOutputReference_Override(d DataAwsAlbListenerDefaultActionFixedResponseOutputReference, ...)
- func NewDataAwsAlbListenerDefaultActionForwardList_Override(d DataAwsAlbListenerDefaultActionForwardList, ...)
- func NewDataAwsAlbListenerDefaultActionForwardOutputReference_Override(d DataAwsAlbListenerDefaultActionForwardOutputReference, ...)
- func NewDataAwsAlbListenerDefaultActionForwardStickinessList_Override(d DataAwsAlbListenerDefaultActionForwardStickinessList, ...)
- func NewDataAwsAlbListenerDefaultActionForwardStickinessOutputReference_Override(d DataAwsAlbListenerDefaultActionForwardStickinessOutputReference, ...)
- func NewDataAwsAlbListenerDefaultActionForwardTargetGroupList_Override(d DataAwsAlbListenerDefaultActionForwardTargetGroupList, ...)
- func NewDataAwsAlbListenerDefaultActionForwardTargetGroupOutputReference_Override(d DataAwsAlbListenerDefaultActionForwardTargetGroupOutputReference, ...)
- func NewDataAwsAlbListenerDefaultActionList_Override(d DataAwsAlbListenerDefaultActionList, ...)
- func NewDataAwsAlbListenerDefaultActionOutputReference_Override(d DataAwsAlbListenerDefaultActionOutputReference, ...)
- func NewDataAwsAlbListenerDefaultActionRedirectList_Override(d DataAwsAlbListenerDefaultActionRedirectList, ...)
- func NewDataAwsAlbListenerDefaultActionRedirectOutputReference_Override(d DataAwsAlbListenerDefaultActionRedirectOutputReference, ...)
- func NewDataAwsAlbListenerTimeoutsOutputReference_Override(d DataAwsAlbListenerTimeoutsOutputReference, ...)
- func NewDataAwsAlbListener_Override(d DataAwsAlbListener, scope constructs.Construct, id *string, ...)
- type DataAwsAlbListener
- type DataAwsAlbListenerConfig
- type DataAwsAlbListenerDefaultAction
- type DataAwsAlbListenerDefaultActionAuthenticateCognito
- type DataAwsAlbListenerDefaultActionAuthenticateCognitoList
- type DataAwsAlbListenerDefaultActionAuthenticateCognitoOutputReference
- type DataAwsAlbListenerDefaultActionAuthenticateOidc
- type DataAwsAlbListenerDefaultActionAuthenticateOidcList
- type DataAwsAlbListenerDefaultActionAuthenticateOidcOutputReference
- type DataAwsAlbListenerDefaultActionFixedResponse
- type DataAwsAlbListenerDefaultActionFixedResponseList
- type DataAwsAlbListenerDefaultActionFixedResponseOutputReference
- type DataAwsAlbListenerDefaultActionForward
- type DataAwsAlbListenerDefaultActionForwardList
- type DataAwsAlbListenerDefaultActionForwardOutputReference
- type DataAwsAlbListenerDefaultActionForwardStickiness
- type DataAwsAlbListenerDefaultActionForwardStickinessList
- type DataAwsAlbListenerDefaultActionForwardStickinessOutputReference
- type DataAwsAlbListenerDefaultActionForwardTargetGroup
- type DataAwsAlbListenerDefaultActionForwardTargetGroupList
- type DataAwsAlbListenerDefaultActionForwardTargetGroupOutputReference
- type DataAwsAlbListenerDefaultActionList
- type DataAwsAlbListenerDefaultActionOutputReference
- type DataAwsAlbListenerDefaultActionRedirect
- type DataAwsAlbListenerDefaultActionRedirectList
- type DataAwsAlbListenerDefaultActionRedirectOutputReference
- type DataAwsAlbListenerTimeouts
- type DataAwsAlbListenerTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsAlbListener_IsConstruct ¶
func DataAwsAlbListener_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsAlbListener_IsTerraformDataSource ¶
func DataAwsAlbListener_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsAlbListener_IsTerraformElement ¶
func DataAwsAlbListener_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsAlbListener_TfResourceType ¶
func DataAwsAlbListener_TfResourceType() *string
func NewDataAwsAlbListenerDefaultActionAuthenticateCognitoList_Override ¶
func NewDataAwsAlbListenerDefaultActionAuthenticateCognitoList_Override(d DataAwsAlbListenerDefaultActionAuthenticateCognitoList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsAlbListenerDefaultActionAuthenticateCognitoOutputReference_Override ¶
func NewDataAwsAlbListenerDefaultActionAuthenticateCognitoOutputReference_Override(d DataAwsAlbListenerDefaultActionAuthenticateCognitoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsAlbListenerDefaultActionAuthenticateOidcList_Override ¶
func NewDataAwsAlbListenerDefaultActionAuthenticateOidcList_Override(d DataAwsAlbListenerDefaultActionAuthenticateOidcList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsAlbListenerDefaultActionAuthenticateOidcOutputReference_Override ¶
func NewDataAwsAlbListenerDefaultActionAuthenticateOidcOutputReference_Override(d DataAwsAlbListenerDefaultActionAuthenticateOidcOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsAlbListenerDefaultActionFixedResponseList_Override ¶
func NewDataAwsAlbListenerDefaultActionFixedResponseList_Override(d DataAwsAlbListenerDefaultActionFixedResponseList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsAlbListenerDefaultActionFixedResponseOutputReference_Override ¶
func NewDataAwsAlbListenerDefaultActionFixedResponseOutputReference_Override(d DataAwsAlbListenerDefaultActionFixedResponseOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsAlbListenerDefaultActionForwardList_Override ¶
func NewDataAwsAlbListenerDefaultActionForwardList_Override(d DataAwsAlbListenerDefaultActionForwardList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsAlbListenerDefaultActionForwardOutputReference_Override ¶
func NewDataAwsAlbListenerDefaultActionForwardOutputReference_Override(d DataAwsAlbListenerDefaultActionForwardOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsAlbListenerDefaultActionForwardStickinessList_Override ¶
func NewDataAwsAlbListenerDefaultActionForwardStickinessList_Override(d DataAwsAlbListenerDefaultActionForwardStickinessList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsAlbListenerDefaultActionForwardStickinessOutputReference_Override ¶
func NewDataAwsAlbListenerDefaultActionForwardStickinessOutputReference_Override(d DataAwsAlbListenerDefaultActionForwardStickinessOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsAlbListenerDefaultActionForwardTargetGroupList_Override ¶
func NewDataAwsAlbListenerDefaultActionForwardTargetGroupList_Override(d DataAwsAlbListenerDefaultActionForwardTargetGroupList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsAlbListenerDefaultActionForwardTargetGroupOutputReference_Override ¶
func NewDataAwsAlbListenerDefaultActionForwardTargetGroupOutputReference_Override(d DataAwsAlbListenerDefaultActionForwardTargetGroupOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsAlbListenerDefaultActionList_Override ¶
func NewDataAwsAlbListenerDefaultActionList_Override(d DataAwsAlbListenerDefaultActionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsAlbListenerDefaultActionOutputReference_Override ¶
func NewDataAwsAlbListenerDefaultActionOutputReference_Override(d DataAwsAlbListenerDefaultActionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsAlbListenerDefaultActionRedirectList_Override ¶
func NewDataAwsAlbListenerDefaultActionRedirectList_Override(d DataAwsAlbListenerDefaultActionRedirectList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsAlbListenerDefaultActionRedirectOutputReference_Override ¶
func NewDataAwsAlbListenerDefaultActionRedirectOutputReference_Override(d DataAwsAlbListenerDefaultActionRedirectOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsAlbListenerTimeoutsOutputReference_Override ¶
func NewDataAwsAlbListenerTimeoutsOutputReference_Override(d DataAwsAlbListenerTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsAlbListener_Override ¶
func NewDataAwsAlbListener_Override(d DataAwsAlbListener, scope constructs.Construct, id *string, config *DataAwsAlbListenerConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/alb_listener aws_alb_listener} Data Source.
Types ¶
type DataAwsAlbListener ¶
type DataAwsAlbListener interface {
cdktf.TerraformDataSource
AlpnPolicy() *string
Arn() *string
SetArn(val *string)
ArnInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CertificateArn() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DefaultAction() DataAwsAlbListenerDefaultActionList
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LoadBalancerArn() *string
SetLoadBalancerArn(val *string)
LoadBalancerArnInput() *string
// The tree node.
Node() constructs.Node
Port() *float64
SetPort(val *float64)
PortInput() *float64
Protocol() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
SslPolicy() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DataAwsAlbListenerTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *DataAwsAlbListenerTimeouts)
ResetArn()
ResetId()
ResetLoadBalancerArn()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPort()
ResetTags()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/alb_listener aws_alb_listener}.
func NewDataAwsAlbListener ¶
func NewDataAwsAlbListener(scope constructs.Construct, id *string, config *DataAwsAlbListenerConfig) DataAwsAlbListener
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/alb_listener aws_alb_listener} Data Source.
type DataAwsAlbListenerConfig ¶
type DataAwsAlbListenerConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/alb_listener#arn DataAwsAlbListener#arn}.
Arn *string `field:"optional" json:"arn" yaml:"arn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/alb_listener#id DataAwsAlbListener#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/alb_listener#load_balancer_arn DataAwsAlbListener#load_balancer_arn}.
LoadBalancerArn *string `field:"optional" json:"loadBalancerArn" yaml:"loadBalancerArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/alb_listener#port DataAwsAlbListener#port}.
Port *float64 `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/alb_listener#tags DataAwsAlbListener#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/alb_listener#timeouts DataAwsAlbListener#timeouts}
Timeouts *DataAwsAlbListenerTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type DataAwsAlbListenerDefaultAction ¶
type DataAwsAlbListenerDefaultAction struct {
}
type DataAwsAlbListenerDefaultActionAuthenticateCognito ¶
type DataAwsAlbListenerDefaultActionAuthenticateCognito struct {
}
type DataAwsAlbListenerDefaultActionAuthenticateCognitoList ¶
type DataAwsAlbListenerDefaultActionAuthenticateCognitoList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsAlbListenerDefaultActionAuthenticateCognitoOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbListenerDefaultActionAuthenticateCognitoList ¶
func NewDataAwsAlbListenerDefaultActionAuthenticateCognitoList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsAlbListenerDefaultActionAuthenticateCognitoList
type DataAwsAlbListenerDefaultActionAuthenticateCognitoOutputReference ¶
type DataAwsAlbListenerDefaultActionAuthenticateCognitoOutputReference interface {
cdktf.ComplexObject
AuthenticationRequestExtraParams() cdktf.StringMap
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsAlbListenerDefaultActionAuthenticateCognito
SetInternalValue(val *DataAwsAlbListenerDefaultActionAuthenticateCognito)
OnUnauthenticatedRequest() *string
Scope() *string
SessionCookieName() *string
SessionTimeout() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UserPoolArn() *string
UserPoolClientId() *string
UserPoolDomain() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbListenerDefaultActionAuthenticateCognitoOutputReference ¶
func NewDataAwsAlbListenerDefaultActionAuthenticateCognitoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsAlbListenerDefaultActionAuthenticateCognitoOutputReference
type DataAwsAlbListenerDefaultActionAuthenticateOidc ¶
type DataAwsAlbListenerDefaultActionAuthenticateOidc struct {
}
type DataAwsAlbListenerDefaultActionAuthenticateOidcList ¶
type DataAwsAlbListenerDefaultActionAuthenticateOidcList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsAlbListenerDefaultActionAuthenticateOidcOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbListenerDefaultActionAuthenticateOidcList ¶
func NewDataAwsAlbListenerDefaultActionAuthenticateOidcList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsAlbListenerDefaultActionAuthenticateOidcList
type DataAwsAlbListenerDefaultActionAuthenticateOidcOutputReference ¶
type DataAwsAlbListenerDefaultActionAuthenticateOidcOutputReference interface {
cdktf.ComplexObject
AuthenticationRequestExtraParams() cdktf.StringMap
AuthorizationEndpoint() *string
ClientId() *string
ClientSecret() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsAlbListenerDefaultActionAuthenticateOidc
SetInternalValue(val *DataAwsAlbListenerDefaultActionAuthenticateOidc)
Issuer() *string
OnUnauthenticatedRequest() *string
Scope() *string
SessionCookieName() *string
SessionTimeout() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TokenEndpoint() *string
UserInfoEndpoint() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbListenerDefaultActionAuthenticateOidcOutputReference ¶
func NewDataAwsAlbListenerDefaultActionAuthenticateOidcOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsAlbListenerDefaultActionAuthenticateOidcOutputReference
type DataAwsAlbListenerDefaultActionFixedResponse ¶
type DataAwsAlbListenerDefaultActionFixedResponse struct {
}
type DataAwsAlbListenerDefaultActionFixedResponseList ¶
type DataAwsAlbListenerDefaultActionFixedResponseList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsAlbListenerDefaultActionFixedResponseOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbListenerDefaultActionFixedResponseList ¶
func NewDataAwsAlbListenerDefaultActionFixedResponseList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsAlbListenerDefaultActionFixedResponseList
type DataAwsAlbListenerDefaultActionFixedResponseOutputReference ¶
type DataAwsAlbListenerDefaultActionFixedResponseOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ContentType() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsAlbListenerDefaultActionFixedResponse
SetInternalValue(val *DataAwsAlbListenerDefaultActionFixedResponse)
MessageBody() *string
StatusCode() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbListenerDefaultActionFixedResponseOutputReference ¶
func NewDataAwsAlbListenerDefaultActionFixedResponseOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsAlbListenerDefaultActionFixedResponseOutputReference
type DataAwsAlbListenerDefaultActionForward ¶
type DataAwsAlbListenerDefaultActionForward struct {
}
type DataAwsAlbListenerDefaultActionForwardList ¶
type DataAwsAlbListenerDefaultActionForwardList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsAlbListenerDefaultActionForwardOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbListenerDefaultActionForwardList ¶
func NewDataAwsAlbListenerDefaultActionForwardList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsAlbListenerDefaultActionForwardList
type DataAwsAlbListenerDefaultActionForwardOutputReference ¶
type DataAwsAlbListenerDefaultActionForwardOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsAlbListenerDefaultActionForward
SetInternalValue(val *DataAwsAlbListenerDefaultActionForward)
Stickiness() DataAwsAlbListenerDefaultActionForwardStickinessList
TargetGroup() DataAwsAlbListenerDefaultActionForwardTargetGroupList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbListenerDefaultActionForwardOutputReference ¶
func NewDataAwsAlbListenerDefaultActionForwardOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsAlbListenerDefaultActionForwardOutputReference
type DataAwsAlbListenerDefaultActionForwardStickiness ¶
type DataAwsAlbListenerDefaultActionForwardStickiness struct {
}
type DataAwsAlbListenerDefaultActionForwardStickinessList ¶
type DataAwsAlbListenerDefaultActionForwardStickinessList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsAlbListenerDefaultActionForwardStickinessOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbListenerDefaultActionForwardStickinessList ¶
func NewDataAwsAlbListenerDefaultActionForwardStickinessList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsAlbListenerDefaultActionForwardStickinessList
type DataAwsAlbListenerDefaultActionForwardStickinessOutputReference ¶
type DataAwsAlbListenerDefaultActionForwardStickinessOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Duration() *float64
Enabled() cdktf.IResolvable
// Experimental.
Fqn() *string
InternalValue() *DataAwsAlbListenerDefaultActionForwardStickiness
SetInternalValue(val *DataAwsAlbListenerDefaultActionForwardStickiness)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbListenerDefaultActionForwardStickinessOutputReference ¶
func NewDataAwsAlbListenerDefaultActionForwardStickinessOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsAlbListenerDefaultActionForwardStickinessOutputReference
type DataAwsAlbListenerDefaultActionForwardTargetGroup ¶
type DataAwsAlbListenerDefaultActionForwardTargetGroup struct {
}
type DataAwsAlbListenerDefaultActionForwardTargetGroupList ¶
type DataAwsAlbListenerDefaultActionForwardTargetGroupList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsAlbListenerDefaultActionForwardTargetGroupOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbListenerDefaultActionForwardTargetGroupList ¶
func NewDataAwsAlbListenerDefaultActionForwardTargetGroupList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsAlbListenerDefaultActionForwardTargetGroupList
type DataAwsAlbListenerDefaultActionForwardTargetGroupOutputReference ¶
type DataAwsAlbListenerDefaultActionForwardTargetGroupOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsAlbListenerDefaultActionForwardTargetGroup
SetInternalValue(val *DataAwsAlbListenerDefaultActionForwardTargetGroup)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Weight() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbListenerDefaultActionForwardTargetGroupOutputReference ¶
func NewDataAwsAlbListenerDefaultActionForwardTargetGroupOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsAlbListenerDefaultActionForwardTargetGroupOutputReference
type DataAwsAlbListenerDefaultActionList ¶
type DataAwsAlbListenerDefaultActionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsAlbListenerDefaultActionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbListenerDefaultActionList ¶
func NewDataAwsAlbListenerDefaultActionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsAlbListenerDefaultActionList
type DataAwsAlbListenerDefaultActionOutputReference ¶
type DataAwsAlbListenerDefaultActionOutputReference interface {
cdktf.ComplexObject
AuthenticateCognito() DataAwsAlbListenerDefaultActionAuthenticateCognitoList
AuthenticateOidc() DataAwsAlbListenerDefaultActionAuthenticateOidcList
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FixedResponse() DataAwsAlbListenerDefaultActionFixedResponseList
Forward() DataAwsAlbListenerDefaultActionForwardList
// Experimental.
Fqn() *string
InternalValue() *DataAwsAlbListenerDefaultAction
SetInternalValue(val *DataAwsAlbListenerDefaultAction)
Order() *float64
Redirect() DataAwsAlbListenerDefaultActionRedirectList
TargetGroupArn() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbListenerDefaultActionOutputReference ¶
func NewDataAwsAlbListenerDefaultActionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsAlbListenerDefaultActionOutputReference
type DataAwsAlbListenerDefaultActionRedirect ¶
type DataAwsAlbListenerDefaultActionRedirect struct {
}
type DataAwsAlbListenerDefaultActionRedirectList ¶
type DataAwsAlbListenerDefaultActionRedirectList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsAlbListenerDefaultActionRedirectOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbListenerDefaultActionRedirectList ¶
func NewDataAwsAlbListenerDefaultActionRedirectList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsAlbListenerDefaultActionRedirectList
type DataAwsAlbListenerDefaultActionRedirectOutputReference ¶
type DataAwsAlbListenerDefaultActionRedirectOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Host() *string
InternalValue() *DataAwsAlbListenerDefaultActionRedirect
SetInternalValue(val *DataAwsAlbListenerDefaultActionRedirect)
Path() *string
Port() *string
Protocol() *string
Query() *string
StatusCode() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbListenerDefaultActionRedirectOutputReference ¶
func NewDataAwsAlbListenerDefaultActionRedirectOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsAlbListenerDefaultActionRedirectOutputReference
type DataAwsAlbListenerTimeouts ¶
type DataAwsAlbListenerTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/alb_listener#read DataAwsAlbListener#read}.
Read *string `field:"optional" json:"read" yaml:"read"`
}
type DataAwsAlbListenerTimeoutsOutputReference ¶
type DataAwsAlbListenerTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Read() *string
SetRead(val *string)
ReadInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetRead()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAlbListenerTimeoutsOutputReference ¶
func NewDataAwsAlbListenerTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsAlbListenerTimeoutsOutputReference
Source Files
¶
- DataAwsAlbListener.go
- DataAwsAlbListenerConfig.go
- DataAwsAlbListenerDefaultAction.go
- DataAwsAlbListenerDefaultActionAuthenticateCognito.go
- DataAwsAlbListenerDefaultActionAuthenticateCognitoList.go
- DataAwsAlbListenerDefaultActionAuthenticateCognitoList__checks.go
- DataAwsAlbListenerDefaultActionAuthenticateCognitoOutputReference.go
- DataAwsAlbListenerDefaultActionAuthenticateCognitoOutputReference__checks.go
- DataAwsAlbListenerDefaultActionAuthenticateOidc.go
- DataAwsAlbListenerDefaultActionAuthenticateOidcList.go
- DataAwsAlbListenerDefaultActionAuthenticateOidcList__checks.go
- DataAwsAlbListenerDefaultActionAuthenticateOidcOutputReference.go
- DataAwsAlbListenerDefaultActionAuthenticateOidcOutputReference__checks.go
- DataAwsAlbListenerDefaultActionFixedResponse.go
- DataAwsAlbListenerDefaultActionFixedResponseList.go
- DataAwsAlbListenerDefaultActionFixedResponseList__checks.go
- DataAwsAlbListenerDefaultActionFixedResponseOutputReference.go
- DataAwsAlbListenerDefaultActionFixedResponseOutputReference__checks.go
- DataAwsAlbListenerDefaultActionForward.go
- DataAwsAlbListenerDefaultActionForwardList.go
- DataAwsAlbListenerDefaultActionForwardList__checks.go
- DataAwsAlbListenerDefaultActionForwardOutputReference.go
- DataAwsAlbListenerDefaultActionForwardOutputReference__checks.go
- DataAwsAlbListenerDefaultActionForwardStickiness.go
- DataAwsAlbListenerDefaultActionForwardStickinessList.go
- DataAwsAlbListenerDefaultActionForwardStickinessList__checks.go
- DataAwsAlbListenerDefaultActionForwardStickinessOutputReference.go
- DataAwsAlbListenerDefaultActionForwardStickinessOutputReference__checks.go
- DataAwsAlbListenerDefaultActionForwardTargetGroup.go
- DataAwsAlbListenerDefaultActionForwardTargetGroupList.go
- DataAwsAlbListenerDefaultActionForwardTargetGroupList__checks.go
- DataAwsAlbListenerDefaultActionForwardTargetGroupOutputReference.go
- DataAwsAlbListenerDefaultActionForwardTargetGroupOutputReference__checks.go
- DataAwsAlbListenerDefaultActionList.go
- DataAwsAlbListenerDefaultActionList__checks.go
- DataAwsAlbListenerDefaultActionOutputReference.go
- DataAwsAlbListenerDefaultActionOutputReference__checks.go
- DataAwsAlbListenerDefaultActionRedirect.go
- DataAwsAlbListenerDefaultActionRedirectList.go
- DataAwsAlbListenerDefaultActionRedirectList__checks.go
- DataAwsAlbListenerDefaultActionRedirectOutputReference.go
- DataAwsAlbListenerDefaultActionRedirectOutputReference__checks.go
- DataAwsAlbListenerTimeouts.go
- DataAwsAlbListenerTimeoutsOutputReference.go
- DataAwsAlbListenerTimeoutsOutputReference__checks.go
- DataAwsAlbListener__checks.go
- main.go