Documentation
¶
Index ¶
- func DataAwsApiGatewayVpcLink_IsConstruct(x interface{}) *bool
- func DataAwsApiGatewayVpcLink_IsTerraformDataSource(x interface{}) *bool
- func DataAwsApiGatewayVpcLink_IsTerraformElement(x interface{}) *bool
- func DataAwsApiGatewayVpcLink_TfResourceType() *string
- func NewDataAwsApiGatewayVpcLink_Override(d DataAwsApiGatewayVpcLink, scope constructs.Construct, id *string, ...)
- type DataAwsApiGatewayVpcLink
- type DataAwsApiGatewayVpcLinkConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsApiGatewayVpcLink_IsConstruct ¶
func DataAwsApiGatewayVpcLink_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsApiGatewayVpcLink_IsTerraformDataSource ¶
func DataAwsApiGatewayVpcLink_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsApiGatewayVpcLink_IsTerraformElement ¶
func DataAwsApiGatewayVpcLink_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsApiGatewayVpcLink_TfResourceType ¶
func DataAwsApiGatewayVpcLink_TfResourceType() *string
func NewDataAwsApiGatewayVpcLink_Override ¶
func NewDataAwsApiGatewayVpcLink_Override(d DataAwsApiGatewayVpcLink, scope constructs.Construct, id *string, config *DataAwsApiGatewayVpcLinkConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/api_gateway_vpc_link aws_api_gateway_vpc_link} Data Source.
Types ¶
type DataAwsApiGatewayVpcLink ¶
type DataAwsApiGatewayVpcLink interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Status() *string
StatusMessage() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
TargetArns() *[]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/api_gateway_vpc_link aws_api_gateway_vpc_link}.
func NewDataAwsApiGatewayVpcLink ¶
func NewDataAwsApiGatewayVpcLink(scope constructs.Construct, id *string, config *DataAwsApiGatewayVpcLinkConfig) DataAwsApiGatewayVpcLink
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/api_gateway_vpc_link aws_api_gateway_vpc_link} Data Source.
type DataAwsApiGatewayVpcLinkConfig ¶
type DataAwsApiGatewayVpcLinkConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/api_gateway_vpc_link#name DataAwsApiGatewayVpcLink#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/api_gateway_vpc_link#tags DataAwsApiGatewayVpcLink#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}