Documentation
¶
Index ¶
- func DataAwsBackupFramework_IsConstruct(x interface{}) *bool
- func DataAwsBackupFramework_IsTerraformDataSource(x interface{}) *bool
- func DataAwsBackupFramework_IsTerraformElement(x interface{}) *bool
- func DataAwsBackupFramework_TfResourceType() *string
- func NewDataAwsBackupFrameworkControlInputParameterList_Override(d DataAwsBackupFrameworkControlInputParameterList, ...)
- func NewDataAwsBackupFrameworkControlInputParameterOutputReference_Override(d DataAwsBackupFrameworkControlInputParameterOutputReference, ...)
- func NewDataAwsBackupFrameworkControlList_Override(d DataAwsBackupFrameworkControlList, ...)
- func NewDataAwsBackupFrameworkControlOutputReference_Override(d DataAwsBackupFrameworkControlOutputReference, ...)
- func NewDataAwsBackupFrameworkControlScopeList_Override(d DataAwsBackupFrameworkControlScopeList, ...)
- func NewDataAwsBackupFrameworkControlScopeOutputReference_Override(d DataAwsBackupFrameworkControlScopeOutputReference, ...)
- func NewDataAwsBackupFramework_Override(d DataAwsBackupFramework, scope constructs.Construct, id *string, ...)
- type DataAwsBackupFramework
- type DataAwsBackupFrameworkConfig
- type DataAwsBackupFrameworkControl
- type DataAwsBackupFrameworkControlInputParameter
- type DataAwsBackupFrameworkControlInputParameterList
- type DataAwsBackupFrameworkControlInputParameterOutputReference
- type DataAwsBackupFrameworkControlList
- type DataAwsBackupFrameworkControlOutputReference
- type DataAwsBackupFrameworkControlScope
- type DataAwsBackupFrameworkControlScopeList
- type DataAwsBackupFrameworkControlScopeOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsBackupFramework_IsConstruct ¶
func DataAwsBackupFramework_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsBackupFramework_IsTerraformDataSource ¶
func DataAwsBackupFramework_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsBackupFramework_IsTerraformElement ¶
func DataAwsBackupFramework_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsBackupFramework_TfResourceType ¶
func DataAwsBackupFramework_TfResourceType() *string
func NewDataAwsBackupFrameworkControlInputParameterList_Override ¶
func NewDataAwsBackupFrameworkControlInputParameterList_Override(d DataAwsBackupFrameworkControlInputParameterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsBackupFrameworkControlInputParameterOutputReference_Override ¶
func NewDataAwsBackupFrameworkControlInputParameterOutputReference_Override(d DataAwsBackupFrameworkControlInputParameterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsBackupFrameworkControlList_Override ¶
func NewDataAwsBackupFrameworkControlList_Override(d DataAwsBackupFrameworkControlList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsBackupFrameworkControlOutputReference_Override ¶
func NewDataAwsBackupFrameworkControlOutputReference_Override(d DataAwsBackupFrameworkControlOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsBackupFrameworkControlScopeList_Override ¶
func NewDataAwsBackupFrameworkControlScopeList_Override(d DataAwsBackupFrameworkControlScopeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsBackupFrameworkControlScopeOutputReference_Override ¶
func NewDataAwsBackupFrameworkControlScopeOutputReference_Override(d DataAwsBackupFrameworkControlScopeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsBackupFramework_Override ¶
func NewDataAwsBackupFramework_Override(d DataAwsBackupFramework, scope constructs.Construct, id *string, config *DataAwsBackupFrameworkConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/backup_framework aws_backup_framework} Data Source.
Types ¶
type DataAwsBackupFramework ¶
type DataAwsBackupFramework interface {
cdktf.TerraformDataSource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
Control() DataAwsBackupFrameworkControlList
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreationTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeploymentStatus() *string
Description() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Status() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/backup_framework aws_backup_framework}.
func NewDataAwsBackupFramework ¶
func NewDataAwsBackupFramework(scope constructs.Construct, id *string, config *DataAwsBackupFrameworkConfig) DataAwsBackupFramework
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/backup_framework aws_backup_framework} Data Source.
type DataAwsBackupFrameworkConfig ¶
type DataAwsBackupFrameworkConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/backup_framework#name DataAwsBackupFramework#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/backup_framework#id DataAwsBackupFramework#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/backup_framework#tags DataAwsBackupFramework#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsBackupFrameworkControl ¶
type DataAwsBackupFrameworkControl struct {
}
type DataAwsBackupFrameworkControlInputParameter ¶
type DataAwsBackupFrameworkControlInputParameter struct {
}
type DataAwsBackupFrameworkControlInputParameterList ¶
type DataAwsBackupFrameworkControlInputParameterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsBackupFrameworkControlInputParameterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsBackupFrameworkControlInputParameterList ¶
func NewDataAwsBackupFrameworkControlInputParameterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsBackupFrameworkControlInputParameterList
type DataAwsBackupFrameworkControlInputParameterOutputReference ¶
type DataAwsBackupFrameworkControlInputParameterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsBackupFrameworkControlInputParameter
SetInternalValue(val *DataAwsBackupFrameworkControlInputParameter)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsBackupFrameworkControlInputParameterOutputReference ¶
func NewDataAwsBackupFrameworkControlInputParameterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsBackupFrameworkControlInputParameterOutputReference
type DataAwsBackupFrameworkControlList ¶
type DataAwsBackupFrameworkControlList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsBackupFrameworkControlOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsBackupFrameworkControlList ¶
func NewDataAwsBackupFrameworkControlList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsBackupFrameworkControlList
type DataAwsBackupFrameworkControlOutputReference ¶
type DataAwsBackupFrameworkControlOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InputParameter() DataAwsBackupFrameworkControlInputParameterList
InternalValue() *DataAwsBackupFrameworkControl
SetInternalValue(val *DataAwsBackupFrameworkControl)
Name() *string
Scope() DataAwsBackupFrameworkControlScopeList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsBackupFrameworkControlOutputReference ¶
func NewDataAwsBackupFrameworkControlOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsBackupFrameworkControlOutputReference
type DataAwsBackupFrameworkControlScope ¶
type DataAwsBackupFrameworkControlScope struct {
}
type DataAwsBackupFrameworkControlScopeList ¶
type DataAwsBackupFrameworkControlScopeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsBackupFrameworkControlScopeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsBackupFrameworkControlScopeList ¶
func NewDataAwsBackupFrameworkControlScopeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsBackupFrameworkControlScopeList
type DataAwsBackupFrameworkControlScopeOutputReference ¶
type DataAwsBackupFrameworkControlScopeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ComplianceResourceIds() *[]*string
ComplianceResourceTypes() *[]*string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsBackupFrameworkControlScope
SetInternalValue(val *DataAwsBackupFrameworkControlScope)
Tags() cdktf.StringMap
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsBackupFrameworkControlScopeOutputReference ¶
func NewDataAwsBackupFrameworkControlScopeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsBackupFrameworkControlScopeOutputReference
Source Files
¶
- DataAwsBackupFramework.go
- DataAwsBackupFrameworkConfig.go
- DataAwsBackupFrameworkControl.go
- DataAwsBackupFrameworkControlInputParameter.go
- DataAwsBackupFrameworkControlInputParameterList.go
- DataAwsBackupFrameworkControlInputParameterList__checks.go
- DataAwsBackupFrameworkControlInputParameterOutputReference.go
- DataAwsBackupFrameworkControlInputParameterOutputReference__checks.go
- DataAwsBackupFrameworkControlList.go
- DataAwsBackupFrameworkControlList__checks.go
- DataAwsBackupFrameworkControlOutputReference.go
- DataAwsBackupFrameworkControlOutputReference__checks.go
- DataAwsBackupFrameworkControlScope.go
- DataAwsBackupFrameworkControlScopeList.go
- DataAwsBackupFrameworkControlScopeList__checks.go
- DataAwsBackupFrameworkControlScopeOutputReference.go
- DataAwsBackupFrameworkControlScopeOutputReference__checks.go
- DataAwsBackupFramework__checks.go
- main.go