Documentation
¶
Index ¶
- func DataAwsBackupReportPlan_IsConstruct(x interface{}) *bool
- func DataAwsBackupReportPlan_IsTerraformDataSource(x interface{}) *bool
- func DataAwsBackupReportPlan_IsTerraformElement(x interface{}) *bool
- func DataAwsBackupReportPlan_TfResourceType() *string
- func NewDataAwsBackupReportPlanReportDeliveryChannelList_Override(d DataAwsBackupReportPlanReportDeliveryChannelList, ...)
- func NewDataAwsBackupReportPlanReportDeliveryChannelOutputReference_Override(d DataAwsBackupReportPlanReportDeliveryChannelOutputReference, ...)
- func NewDataAwsBackupReportPlanReportSettingList_Override(d DataAwsBackupReportPlanReportSettingList, ...)
- func NewDataAwsBackupReportPlanReportSettingOutputReference_Override(d DataAwsBackupReportPlanReportSettingOutputReference, ...)
- func NewDataAwsBackupReportPlan_Override(d DataAwsBackupReportPlan, scope constructs.Construct, id *string, ...)
- type DataAwsBackupReportPlan
- type DataAwsBackupReportPlanConfig
- type DataAwsBackupReportPlanReportDeliveryChannel
- type DataAwsBackupReportPlanReportDeliveryChannelList
- type DataAwsBackupReportPlanReportDeliveryChannelOutputReference
- type DataAwsBackupReportPlanReportSetting
- type DataAwsBackupReportPlanReportSettingList
- type DataAwsBackupReportPlanReportSettingOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsBackupReportPlan_IsConstruct ¶
func DataAwsBackupReportPlan_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsBackupReportPlan_IsTerraformDataSource ¶
func DataAwsBackupReportPlan_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsBackupReportPlan_IsTerraformElement ¶
func DataAwsBackupReportPlan_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsBackupReportPlan_TfResourceType ¶
func DataAwsBackupReportPlan_TfResourceType() *string
func NewDataAwsBackupReportPlanReportDeliveryChannelList_Override ¶
func NewDataAwsBackupReportPlanReportDeliveryChannelList_Override(d DataAwsBackupReportPlanReportDeliveryChannelList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsBackupReportPlanReportDeliveryChannelOutputReference_Override ¶
func NewDataAwsBackupReportPlanReportDeliveryChannelOutputReference_Override(d DataAwsBackupReportPlanReportDeliveryChannelOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsBackupReportPlanReportSettingList_Override ¶
func NewDataAwsBackupReportPlanReportSettingList_Override(d DataAwsBackupReportPlanReportSettingList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsBackupReportPlanReportSettingOutputReference_Override ¶
func NewDataAwsBackupReportPlanReportSettingOutputReference_Override(d DataAwsBackupReportPlanReportSettingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsBackupReportPlan_Override ¶
func NewDataAwsBackupReportPlan_Override(d DataAwsBackupReportPlan, scope constructs.Construct, id *string, config *DataAwsBackupReportPlanConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/backup_report_plan aws_backup_report_plan} Data Source.
Types ¶
type DataAwsBackupReportPlan ¶
type DataAwsBackupReportPlan interface {
cdktf.TerraformDataSource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreationTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeploymentStatus() *string
Description() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
ReportDeliveryChannel() DataAwsBackupReportPlanReportDeliveryChannelList
ReportSetting() DataAwsBackupReportPlanReportSettingList
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/backup_report_plan aws_backup_report_plan}.
func NewDataAwsBackupReportPlan ¶
func NewDataAwsBackupReportPlan(scope constructs.Construct, id *string, config *DataAwsBackupReportPlanConfig) DataAwsBackupReportPlan
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/backup_report_plan aws_backup_report_plan} Data Source.
type DataAwsBackupReportPlanConfig ¶
type DataAwsBackupReportPlanConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/backup_report_plan#name DataAwsBackupReportPlan#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/backup_report_plan#id DataAwsBackupReportPlan#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/backup_report_plan#tags DataAwsBackupReportPlan#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsBackupReportPlanReportDeliveryChannel ¶
type DataAwsBackupReportPlanReportDeliveryChannel struct {
}
type DataAwsBackupReportPlanReportDeliveryChannelList ¶
type DataAwsBackupReportPlanReportDeliveryChannelList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsBackupReportPlanReportDeliveryChannelOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsBackupReportPlanReportDeliveryChannelList ¶
func NewDataAwsBackupReportPlanReportDeliveryChannelList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsBackupReportPlanReportDeliveryChannelList
type DataAwsBackupReportPlanReportDeliveryChannelOutputReference ¶
type DataAwsBackupReportPlanReportDeliveryChannelOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Formats() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsBackupReportPlanReportDeliveryChannel
SetInternalValue(val *DataAwsBackupReportPlanReportDeliveryChannel)
S3BucketName() *string
S3KeyPrefix() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsBackupReportPlanReportDeliveryChannelOutputReference ¶
func NewDataAwsBackupReportPlanReportDeliveryChannelOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsBackupReportPlanReportDeliveryChannelOutputReference
type DataAwsBackupReportPlanReportSetting ¶
type DataAwsBackupReportPlanReportSetting struct {
}
type DataAwsBackupReportPlanReportSettingList ¶
type DataAwsBackupReportPlanReportSettingList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsBackupReportPlanReportSettingOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsBackupReportPlanReportSettingList ¶
func NewDataAwsBackupReportPlanReportSettingList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsBackupReportPlanReportSettingList
type DataAwsBackupReportPlanReportSettingOutputReference ¶
type DataAwsBackupReportPlanReportSettingOutputReference interface {
cdktf.ComplexObject
Accounts() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
FrameworkArns() *[]*string
InternalValue() *DataAwsBackupReportPlanReportSetting
SetInternalValue(val *DataAwsBackupReportPlanReportSetting)
NumberOfFrameworks() *float64
OrganizationUnits() *[]*string
Regions() *[]*string
ReportTemplate() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsBackupReportPlanReportSettingOutputReference ¶
func NewDataAwsBackupReportPlanReportSettingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsBackupReportPlanReportSettingOutputReference
Source Files
¶
- DataAwsBackupReportPlan.go
- DataAwsBackupReportPlanConfig.go
- DataAwsBackupReportPlanReportDeliveryChannel.go
- DataAwsBackupReportPlanReportDeliveryChannelList.go
- DataAwsBackupReportPlanReportDeliveryChannelList__checks.go
- DataAwsBackupReportPlanReportDeliveryChannelOutputReference.go
- DataAwsBackupReportPlanReportDeliveryChannelOutputReference__checks.go
- DataAwsBackupReportPlanReportSetting.go
- DataAwsBackupReportPlanReportSettingList.go
- DataAwsBackupReportPlanReportSettingList__checks.go
- DataAwsBackupReportPlanReportSettingOutputReference.go
- DataAwsBackupReportPlanReportSettingOutputReference__checks.go
- DataAwsBackupReportPlan__checks.go
- main.go