Documentation
¶
Index ¶
- func DataAwsConnectHoursOfOperation_IsConstruct(x interface{}) *bool
- func DataAwsConnectHoursOfOperation_IsTerraformDataSource(x interface{}) *bool
- func DataAwsConnectHoursOfOperation_IsTerraformElement(x interface{}) *bool
- func DataAwsConnectHoursOfOperation_TfResourceType() *string
- func NewDataAwsConnectHoursOfOperationConfigAList_Override(d DataAwsConnectHoursOfOperationConfigAList, ...)
- func NewDataAwsConnectHoursOfOperationConfigAOutputReference_Override(d DataAwsConnectHoursOfOperationConfigAOutputReference, ...)
- func NewDataAwsConnectHoursOfOperationConfigEndTimeList_Override(d DataAwsConnectHoursOfOperationConfigEndTimeList, ...)
- func NewDataAwsConnectHoursOfOperationConfigEndTimeOutputReference_Override(d DataAwsConnectHoursOfOperationConfigEndTimeOutputReference, ...)
- func NewDataAwsConnectHoursOfOperationConfigStartTimeList_Override(d DataAwsConnectHoursOfOperationConfigStartTimeList, ...)
- func NewDataAwsConnectHoursOfOperationConfigStartTimeOutputReference_Override(d DataAwsConnectHoursOfOperationConfigStartTimeOutputReference, ...)
- func NewDataAwsConnectHoursOfOperation_Override(d DataAwsConnectHoursOfOperation, scope constructs.Construct, id *string, ...)
- type DataAwsConnectHoursOfOperation
- type DataAwsConnectHoursOfOperationConfig
- type DataAwsConnectHoursOfOperationConfigA
- type DataAwsConnectHoursOfOperationConfigAList
- type DataAwsConnectHoursOfOperationConfigAOutputReference
- type DataAwsConnectHoursOfOperationConfigEndTime
- type DataAwsConnectHoursOfOperationConfigEndTimeList
- type DataAwsConnectHoursOfOperationConfigEndTimeOutputReference
- type DataAwsConnectHoursOfOperationConfigStartTime
- type DataAwsConnectHoursOfOperationConfigStartTimeList
- type DataAwsConnectHoursOfOperationConfigStartTimeOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsConnectHoursOfOperation_IsConstruct ¶
func DataAwsConnectHoursOfOperation_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsConnectHoursOfOperation_IsTerraformDataSource ¶
func DataAwsConnectHoursOfOperation_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsConnectHoursOfOperation_IsTerraformElement ¶
func DataAwsConnectHoursOfOperation_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsConnectHoursOfOperation_TfResourceType ¶
func DataAwsConnectHoursOfOperation_TfResourceType() *string
func NewDataAwsConnectHoursOfOperationConfigAList_Override ¶
func NewDataAwsConnectHoursOfOperationConfigAList_Override(d DataAwsConnectHoursOfOperationConfigAList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsConnectHoursOfOperationConfigAOutputReference_Override ¶
func NewDataAwsConnectHoursOfOperationConfigAOutputReference_Override(d DataAwsConnectHoursOfOperationConfigAOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsConnectHoursOfOperationConfigEndTimeList_Override ¶
func NewDataAwsConnectHoursOfOperationConfigEndTimeList_Override(d DataAwsConnectHoursOfOperationConfigEndTimeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsConnectHoursOfOperationConfigEndTimeOutputReference_Override ¶
func NewDataAwsConnectHoursOfOperationConfigEndTimeOutputReference_Override(d DataAwsConnectHoursOfOperationConfigEndTimeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsConnectHoursOfOperationConfigStartTimeList_Override ¶
func NewDataAwsConnectHoursOfOperationConfigStartTimeList_Override(d DataAwsConnectHoursOfOperationConfigStartTimeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsConnectHoursOfOperationConfigStartTimeOutputReference_Override ¶
func NewDataAwsConnectHoursOfOperationConfigStartTimeOutputReference_Override(d DataAwsConnectHoursOfOperationConfigStartTimeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsConnectHoursOfOperation_Override ¶
func NewDataAwsConnectHoursOfOperation_Override(d DataAwsConnectHoursOfOperation, scope constructs.Construct, id *string, config *DataAwsConnectHoursOfOperationConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/connect_hours_of_operation aws_connect_hours_of_operation} Data Source.
Types ¶
type DataAwsConnectHoursOfOperation ¶
type DataAwsConnectHoursOfOperation interface {
cdktf.TerraformDataSource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
Config() DataAwsConnectHoursOfOperationConfigAList
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HoursOfOperationArn() *string
HoursOfOperationId() *string
SetHoursOfOperationId(val *string)
HoursOfOperationIdInput() *string
Id() *string
SetId(val *string)
IdInput() *string
InstanceId() *string
SetInstanceId(val *string)
InstanceIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
TimeZone() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetHoursOfOperationId()
ResetId()
ResetName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/connect_hours_of_operation aws_connect_hours_of_operation}.
func NewDataAwsConnectHoursOfOperation ¶
func NewDataAwsConnectHoursOfOperation(scope constructs.Construct, id *string, config *DataAwsConnectHoursOfOperationConfig) DataAwsConnectHoursOfOperation
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/connect_hours_of_operation aws_connect_hours_of_operation} Data Source.
type DataAwsConnectHoursOfOperationConfig ¶
type DataAwsConnectHoursOfOperationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/connect_hours_of_operation#instance_id DataAwsConnectHoursOfOperation#instance_id}.
InstanceId *string `field:"required" json:"instanceId" yaml:"instanceId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/connect_hours_of_operation#hours_of_operation_id DataAwsConnectHoursOfOperation#hours_of_operation_id}.
HoursOfOperationId *string `field:"optional" json:"hoursOfOperationId" yaml:"hoursOfOperationId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/connect_hours_of_operation#id DataAwsConnectHoursOfOperation#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/connect_hours_of_operation#name DataAwsConnectHoursOfOperation#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/connect_hours_of_operation#tags DataAwsConnectHoursOfOperation#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsConnectHoursOfOperationConfigA ¶
type DataAwsConnectHoursOfOperationConfigA struct {
}
type DataAwsConnectHoursOfOperationConfigAList ¶
type DataAwsConnectHoursOfOperationConfigAList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsConnectHoursOfOperationConfigAOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectHoursOfOperationConfigAList ¶
func NewDataAwsConnectHoursOfOperationConfigAList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsConnectHoursOfOperationConfigAList
type DataAwsConnectHoursOfOperationConfigAOutputReference ¶
type DataAwsConnectHoursOfOperationConfigAOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Day() *string
EndTime() DataAwsConnectHoursOfOperationConfigEndTimeList
// Experimental.
Fqn() *string
InternalValue() *DataAwsConnectHoursOfOperationConfigA
SetInternalValue(val *DataAwsConnectHoursOfOperationConfigA)
StartTime() DataAwsConnectHoursOfOperationConfigStartTimeList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectHoursOfOperationConfigAOutputReference ¶
func NewDataAwsConnectHoursOfOperationConfigAOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsConnectHoursOfOperationConfigAOutputReference
type DataAwsConnectHoursOfOperationConfigEndTime ¶
type DataAwsConnectHoursOfOperationConfigEndTime struct {
}
type DataAwsConnectHoursOfOperationConfigEndTimeList ¶
type DataAwsConnectHoursOfOperationConfigEndTimeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsConnectHoursOfOperationConfigEndTimeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectHoursOfOperationConfigEndTimeList ¶
func NewDataAwsConnectHoursOfOperationConfigEndTimeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsConnectHoursOfOperationConfigEndTimeList
type DataAwsConnectHoursOfOperationConfigEndTimeOutputReference ¶
type DataAwsConnectHoursOfOperationConfigEndTimeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Hours() *float64
InternalValue() *DataAwsConnectHoursOfOperationConfigEndTime
SetInternalValue(val *DataAwsConnectHoursOfOperationConfigEndTime)
Minutes() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectHoursOfOperationConfigEndTimeOutputReference ¶
func NewDataAwsConnectHoursOfOperationConfigEndTimeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsConnectHoursOfOperationConfigEndTimeOutputReference
type DataAwsConnectHoursOfOperationConfigStartTime ¶
type DataAwsConnectHoursOfOperationConfigStartTime struct {
}
type DataAwsConnectHoursOfOperationConfigStartTimeList ¶
type DataAwsConnectHoursOfOperationConfigStartTimeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsConnectHoursOfOperationConfigStartTimeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectHoursOfOperationConfigStartTimeList ¶
func NewDataAwsConnectHoursOfOperationConfigStartTimeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsConnectHoursOfOperationConfigStartTimeList
type DataAwsConnectHoursOfOperationConfigStartTimeOutputReference ¶
type DataAwsConnectHoursOfOperationConfigStartTimeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Hours() *float64
InternalValue() *DataAwsConnectHoursOfOperationConfigStartTime
SetInternalValue(val *DataAwsConnectHoursOfOperationConfigStartTime)
Minutes() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsConnectHoursOfOperationConfigStartTimeOutputReference ¶
func NewDataAwsConnectHoursOfOperationConfigStartTimeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsConnectHoursOfOperationConfigStartTimeOutputReference
Source Files
¶
- DataAwsConnectHoursOfOperation.go
- DataAwsConnectHoursOfOperationConfig.go
- DataAwsConnectHoursOfOperationConfigA.go
- DataAwsConnectHoursOfOperationConfigAList.go
- DataAwsConnectHoursOfOperationConfigAList__checks.go
- DataAwsConnectHoursOfOperationConfigAOutputReference.go
- DataAwsConnectHoursOfOperationConfigAOutputReference__checks.go
- DataAwsConnectHoursOfOperationConfigEndTime.go
- DataAwsConnectHoursOfOperationConfigEndTimeList.go
- DataAwsConnectHoursOfOperationConfigEndTimeList__checks.go
- DataAwsConnectHoursOfOperationConfigEndTimeOutputReference.go
- DataAwsConnectHoursOfOperationConfigEndTimeOutputReference__checks.go
- DataAwsConnectHoursOfOperationConfigStartTime.go
- DataAwsConnectHoursOfOperationConfigStartTimeList.go
- DataAwsConnectHoursOfOperationConfigStartTimeList__checks.go
- DataAwsConnectHoursOfOperationConfigStartTimeOutputReference.go
- DataAwsConnectHoursOfOperationConfigStartTimeOutputReference__checks.go
- DataAwsConnectHoursOfOperation__checks.go
- main.go