Documentation
¶
Index ¶
- func DataAwsDmsEndpoint_IsConstruct(x interface{}) *bool
- func DataAwsDmsEndpoint_IsTerraformDataSource(x interface{}) *bool
- func DataAwsDmsEndpoint_IsTerraformElement(x interface{}) *bool
- func DataAwsDmsEndpoint_TfResourceType() *string
- func NewDataAwsDmsEndpointElasticsearchSettingsList_Override(d DataAwsDmsEndpointElasticsearchSettingsList, ...)
- func NewDataAwsDmsEndpointElasticsearchSettingsOutputReference_Override(d DataAwsDmsEndpointElasticsearchSettingsOutputReference, ...)
- func NewDataAwsDmsEndpointKafkaSettingsList_Override(d DataAwsDmsEndpointKafkaSettingsList, ...)
- func NewDataAwsDmsEndpointKafkaSettingsOutputReference_Override(d DataAwsDmsEndpointKafkaSettingsOutputReference, ...)
- func NewDataAwsDmsEndpointKinesisSettingsList_Override(d DataAwsDmsEndpointKinesisSettingsList, ...)
- func NewDataAwsDmsEndpointKinesisSettingsOutputReference_Override(d DataAwsDmsEndpointKinesisSettingsOutputReference, ...)
- func NewDataAwsDmsEndpointMongodbSettingsList_Override(d DataAwsDmsEndpointMongodbSettingsList, ...)
- func NewDataAwsDmsEndpointMongodbSettingsOutputReference_Override(d DataAwsDmsEndpointMongodbSettingsOutputReference, ...)
- func NewDataAwsDmsEndpointRedisSettingsList_Override(d DataAwsDmsEndpointRedisSettingsList, ...)
- func NewDataAwsDmsEndpointRedisSettingsOutputReference_Override(d DataAwsDmsEndpointRedisSettingsOutputReference, ...)
- func NewDataAwsDmsEndpointRedshiftSettingsList_Override(d DataAwsDmsEndpointRedshiftSettingsList, ...)
- func NewDataAwsDmsEndpointRedshiftSettingsOutputReference_Override(d DataAwsDmsEndpointRedshiftSettingsOutputReference, ...)
- func NewDataAwsDmsEndpointS3SettingsList_Override(d DataAwsDmsEndpointS3SettingsList, ...)
- func NewDataAwsDmsEndpointS3SettingsOutputReference_Override(d DataAwsDmsEndpointS3SettingsOutputReference, ...)
- func NewDataAwsDmsEndpoint_Override(d DataAwsDmsEndpoint, scope constructs.Construct, id *string, ...)
- type DataAwsDmsEndpoint
- type DataAwsDmsEndpointConfig
- type DataAwsDmsEndpointElasticsearchSettings
- type DataAwsDmsEndpointElasticsearchSettingsList
- type DataAwsDmsEndpointElasticsearchSettingsOutputReference
- type DataAwsDmsEndpointKafkaSettings
- type DataAwsDmsEndpointKafkaSettingsList
- type DataAwsDmsEndpointKafkaSettingsOutputReference
- type DataAwsDmsEndpointKinesisSettings
- type DataAwsDmsEndpointKinesisSettingsList
- type DataAwsDmsEndpointKinesisSettingsOutputReference
- type DataAwsDmsEndpointMongodbSettings
- type DataAwsDmsEndpointMongodbSettingsList
- type DataAwsDmsEndpointMongodbSettingsOutputReference
- type DataAwsDmsEndpointRedisSettings
- type DataAwsDmsEndpointRedisSettingsList
- type DataAwsDmsEndpointRedisSettingsOutputReference
- type DataAwsDmsEndpointRedshiftSettings
- type DataAwsDmsEndpointRedshiftSettingsList
- type DataAwsDmsEndpointRedshiftSettingsOutputReference
- type DataAwsDmsEndpointS3Settings
- type DataAwsDmsEndpointS3SettingsList
- type DataAwsDmsEndpointS3SettingsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsDmsEndpoint_IsConstruct ¶
func DataAwsDmsEndpoint_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsDmsEndpoint_IsTerraformDataSource ¶
func DataAwsDmsEndpoint_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsDmsEndpoint_IsTerraformElement ¶
func DataAwsDmsEndpoint_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsDmsEndpoint_TfResourceType ¶
func DataAwsDmsEndpoint_TfResourceType() *string
func NewDataAwsDmsEndpointElasticsearchSettingsList_Override ¶
func NewDataAwsDmsEndpointElasticsearchSettingsList_Override(d DataAwsDmsEndpointElasticsearchSettingsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsDmsEndpointElasticsearchSettingsOutputReference_Override ¶
func NewDataAwsDmsEndpointElasticsearchSettingsOutputReference_Override(d DataAwsDmsEndpointElasticsearchSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsDmsEndpointKafkaSettingsList_Override ¶
func NewDataAwsDmsEndpointKafkaSettingsList_Override(d DataAwsDmsEndpointKafkaSettingsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsDmsEndpointKafkaSettingsOutputReference_Override ¶
func NewDataAwsDmsEndpointKafkaSettingsOutputReference_Override(d DataAwsDmsEndpointKafkaSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsDmsEndpointKinesisSettingsList_Override ¶
func NewDataAwsDmsEndpointKinesisSettingsList_Override(d DataAwsDmsEndpointKinesisSettingsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsDmsEndpointKinesisSettingsOutputReference_Override ¶
func NewDataAwsDmsEndpointKinesisSettingsOutputReference_Override(d DataAwsDmsEndpointKinesisSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsDmsEndpointMongodbSettingsList_Override ¶
func NewDataAwsDmsEndpointMongodbSettingsList_Override(d DataAwsDmsEndpointMongodbSettingsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsDmsEndpointMongodbSettingsOutputReference_Override ¶
func NewDataAwsDmsEndpointMongodbSettingsOutputReference_Override(d DataAwsDmsEndpointMongodbSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsDmsEndpointRedisSettingsList_Override ¶
func NewDataAwsDmsEndpointRedisSettingsList_Override(d DataAwsDmsEndpointRedisSettingsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsDmsEndpointRedisSettingsOutputReference_Override ¶
func NewDataAwsDmsEndpointRedisSettingsOutputReference_Override(d DataAwsDmsEndpointRedisSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsDmsEndpointRedshiftSettingsList_Override ¶
func NewDataAwsDmsEndpointRedshiftSettingsList_Override(d DataAwsDmsEndpointRedshiftSettingsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsDmsEndpointRedshiftSettingsOutputReference_Override ¶
func NewDataAwsDmsEndpointRedshiftSettingsOutputReference_Override(d DataAwsDmsEndpointRedshiftSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsDmsEndpointS3SettingsList_Override ¶
func NewDataAwsDmsEndpointS3SettingsList_Override(d DataAwsDmsEndpointS3SettingsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsDmsEndpointS3SettingsOutputReference_Override ¶
func NewDataAwsDmsEndpointS3SettingsOutputReference_Override(d DataAwsDmsEndpointS3SettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsDmsEndpoint_Override ¶
func NewDataAwsDmsEndpoint_Override(d DataAwsDmsEndpoint, scope constructs.Construct, id *string, config *DataAwsDmsEndpointConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/dms_endpoint aws_dms_endpoint} Data Source.
Types ¶
type DataAwsDmsEndpoint ¶
type DataAwsDmsEndpoint interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
CertificateArn() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DatabaseName() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
ElasticsearchSettings() DataAwsDmsEndpointElasticsearchSettingsList
ElasticsearchSettingsInput() interface{}
EndpointArn() *string
EndpointId() *string
SetEndpointId(val *string)
EndpointIdInput() *string
EndpointType() *string
EngineName() *string
ExtraConnectionAttributes() *string
SetExtraConnectionAttributes(val *string)
ExtraConnectionAttributesInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
KafkaSettings() DataAwsDmsEndpointKafkaSettingsList
KafkaSettingsInput() interface{}
KinesisSettings() DataAwsDmsEndpointKinesisSettingsList
KmsKeyArn() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MongodbSettings() DataAwsDmsEndpointMongodbSettingsList
MongodbSettingsInput() interface{}
// The tree node.
Node() constructs.Node
Password() *string
Port() *float64
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
RedisSettings() DataAwsDmsEndpointRedisSettingsList
RedshiftSettings() DataAwsDmsEndpointRedshiftSettingsList
S3Settings() DataAwsDmsEndpointS3SettingsList
SecretsManagerAccessRoleArn() *string
SecretsManagerArn() *string
ServerName() *string
ServiceAccessRole() *string
SslMode() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Username() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutElasticsearchSettings(value interface{})
PutKafkaSettings(value interface{})
PutMongodbSettings(value interface{})
ResetElasticsearchSettings()
ResetExtraConnectionAttributes()
ResetId()
ResetKafkaSettings()
ResetMongodbSettings()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/dms_endpoint aws_dms_endpoint}.
func NewDataAwsDmsEndpoint ¶
func NewDataAwsDmsEndpoint(scope constructs.Construct, id *string, config *DataAwsDmsEndpointConfig) DataAwsDmsEndpoint
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/dms_endpoint aws_dms_endpoint} Data Source.
type DataAwsDmsEndpointConfig ¶
type DataAwsDmsEndpointConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/dms_endpoint#endpoint_id DataAwsDmsEndpoint#endpoint_id}.
EndpointId *string `field:"required" json:"endpointId" yaml:"endpointId"`
// elasticsearch_settings block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/dms_endpoint#elasticsearch_settings DataAwsDmsEndpoint#elasticsearch_settings}
ElasticsearchSettings interface{} `field:"optional" json:"elasticsearchSettings" yaml:"elasticsearchSettings"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/dms_endpoint#extra_connection_attributes DataAwsDmsEndpoint#extra_connection_attributes}.
ExtraConnectionAttributes *string `field:"optional" json:"extraConnectionAttributes" yaml:"extraConnectionAttributes"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/dms_endpoint#id DataAwsDmsEndpoint#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// kafka_settings block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/dms_endpoint#kafka_settings DataAwsDmsEndpoint#kafka_settings}
KafkaSettings interface{} `field:"optional" json:"kafkaSettings" yaml:"kafkaSettings"`
// mongodb_settings block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/dms_endpoint#mongodb_settings DataAwsDmsEndpoint#mongodb_settings}
MongodbSettings interface{} `field:"optional" json:"mongodbSettings" yaml:"mongodbSettings"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/dms_endpoint#tags DataAwsDmsEndpoint#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsDmsEndpointElasticsearchSettings ¶
type DataAwsDmsEndpointElasticsearchSettings struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/dms_endpoint#endpoint_uri DataAwsDmsEndpoint#endpoint_uri}.
EndpointUri *string `field:"required" json:"endpointUri" yaml:"endpointUri"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/dms_endpoint#service_access_role_arn DataAwsDmsEndpoint#service_access_role_arn}.
ServiceAccessRoleArn *string `field:"required" json:"serviceAccessRoleArn" yaml:"serviceAccessRoleArn"`
}
type DataAwsDmsEndpointElasticsearchSettingsList ¶
type DataAwsDmsEndpointElasticsearchSettingsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsDmsEndpointElasticsearchSettingsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDmsEndpointElasticsearchSettingsList ¶
func NewDataAwsDmsEndpointElasticsearchSettingsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsDmsEndpointElasticsearchSettingsList
type DataAwsDmsEndpointElasticsearchSettingsOutputReference ¶
type DataAwsDmsEndpointElasticsearchSettingsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EndpointUri() *string
SetEndpointUri(val *string)
EndpointUriInput() *string
ErrorRetryDuration() *float64
// Experimental.
Fqn() *string
FullLoadErrorPercentage() *float64
InternalValue() interface{}
SetInternalValue(val interface{})
ServiceAccessRoleArn() *string
SetServiceAccessRoleArn(val *string)
ServiceAccessRoleArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDmsEndpointElasticsearchSettingsOutputReference ¶
func NewDataAwsDmsEndpointElasticsearchSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsDmsEndpointElasticsearchSettingsOutputReference
type DataAwsDmsEndpointKafkaSettings ¶
type DataAwsDmsEndpointKafkaSettings struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/dms_endpoint#broker DataAwsDmsEndpoint#broker}.
Broker *string `field:"required" json:"broker" yaml:"broker"`
}
type DataAwsDmsEndpointKafkaSettingsList ¶
type DataAwsDmsEndpointKafkaSettingsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsDmsEndpointKafkaSettingsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDmsEndpointKafkaSettingsList ¶
func NewDataAwsDmsEndpointKafkaSettingsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsDmsEndpointKafkaSettingsList
type DataAwsDmsEndpointKafkaSettingsOutputReference ¶
type DataAwsDmsEndpointKafkaSettingsOutputReference interface {
cdktf.ComplexObject
Broker() *string
SetBroker(val *string)
BrokerInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IncludeControlDetails() cdktf.IResolvable
IncludeNullAndEmpty() cdktf.IResolvable
IncludePartitionValue() cdktf.IResolvable
IncludeTableAlterOperations() cdktf.IResolvable
IncludeTransactionDetails() cdktf.IResolvable
InternalValue() interface{}
SetInternalValue(val interface{})
MessageFormat() *string
MessageMaxBytes() *float64
NoHexPrefix() cdktf.IResolvable
PartitionIncludeSchemaTable() cdktf.IResolvable
SaslPassword() *string
SaslUsername() *string
SecurityProtocol() *string
SslCaCertificateArn() *string
SslClientCertificateArn() *string
SslClientKeyArn() *string
SslClientKeyPassword() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Topic() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDmsEndpointKafkaSettingsOutputReference ¶
func NewDataAwsDmsEndpointKafkaSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsDmsEndpointKafkaSettingsOutputReference
type DataAwsDmsEndpointKinesisSettings ¶
type DataAwsDmsEndpointKinesisSettings struct {
}
type DataAwsDmsEndpointKinesisSettingsList ¶
type DataAwsDmsEndpointKinesisSettingsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsDmsEndpointKinesisSettingsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDmsEndpointKinesisSettingsList ¶
func NewDataAwsDmsEndpointKinesisSettingsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsDmsEndpointKinesisSettingsList
type DataAwsDmsEndpointKinesisSettingsOutputReference ¶
type DataAwsDmsEndpointKinesisSettingsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IncludeControlDetails() cdktf.IResolvable
IncludeNullAndEmpty() cdktf.IResolvable
IncludePartitionValue() cdktf.IResolvable
IncludeTableAlterOperations() cdktf.IResolvable
IncludeTransactionDetails() cdktf.IResolvable
InternalValue() *DataAwsDmsEndpointKinesisSettings
SetInternalValue(val *DataAwsDmsEndpointKinesisSettings)
MessageFormat() *string
PartitionIncludeSchemaTable() cdktf.IResolvable
ServiceAccessRoleArn() *string
StreamArn() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDmsEndpointKinesisSettingsOutputReference ¶
func NewDataAwsDmsEndpointKinesisSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsDmsEndpointKinesisSettingsOutputReference
type DataAwsDmsEndpointMongodbSettings ¶
type DataAwsDmsEndpointMongodbSettings struct {
}
type DataAwsDmsEndpointMongodbSettingsList ¶
type DataAwsDmsEndpointMongodbSettingsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsDmsEndpointMongodbSettingsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDmsEndpointMongodbSettingsList ¶
func NewDataAwsDmsEndpointMongodbSettingsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsDmsEndpointMongodbSettingsList
type DataAwsDmsEndpointMongodbSettingsOutputReference ¶
type DataAwsDmsEndpointMongodbSettingsOutputReference interface {
cdktf.ComplexObject
AuthMechanism() *string
AuthSource() *string
AuthType() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DocsToInvestigate() *string
ExtractDocId() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
NestingLevel() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDmsEndpointMongodbSettingsOutputReference ¶
func NewDataAwsDmsEndpointMongodbSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsDmsEndpointMongodbSettingsOutputReference
type DataAwsDmsEndpointRedisSettings ¶
type DataAwsDmsEndpointRedisSettings struct {
}
type DataAwsDmsEndpointRedisSettingsList ¶
type DataAwsDmsEndpointRedisSettingsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsDmsEndpointRedisSettingsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDmsEndpointRedisSettingsList ¶
func NewDataAwsDmsEndpointRedisSettingsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsDmsEndpointRedisSettingsList
type DataAwsDmsEndpointRedisSettingsOutputReference ¶
type DataAwsDmsEndpointRedisSettingsOutputReference interface {
cdktf.ComplexObject
AuthPassword() *string
AuthType() *string
AuthUserName() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsDmsEndpointRedisSettings
SetInternalValue(val *DataAwsDmsEndpointRedisSettings)
Port() *float64
ServerName() *string
SslCaCertificateArn() *string
SslSecurityProtocol() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDmsEndpointRedisSettingsOutputReference ¶
func NewDataAwsDmsEndpointRedisSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsDmsEndpointRedisSettingsOutputReference
type DataAwsDmsEndpointRedshiftSettings ¶
type DataAwsDmsEndpointRedshiftSettings struct {
}
type DataAwsDmsEndpointRedshiftSettingsList ¶
type DataAwsDmsEndpointRedshiftSettingsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsDmsEndpointRedshiftSettingsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDmsEndpointRedshiftSettingsList ¶
func NewDataAwsDmsEndpointRedshiftSettingsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsDmsEndpointRedshiftSettingsList
type DataAwsDmsEndpointRedshiftSettingsOutputReference ¶
type DataAwsDmsEndpointRedshiftSettingsOutputReference interface {
cdktf.ComplexObject
BucketFolder() *string
BucketName() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EncryptionMode() *string
// Experimental.
Fqn() *string
InternalValue() *DataAwsDmsEndpointRedshiftSettings
SetInternalValue(val *DataAwsDmsEndpointRedshiftSettings)
ServerSideEncryptionKmsKeyId() *string
ServiceAccessRoleArn() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDmsEndpointRedshiftSettingsOutputReference ¶
func NewDataAwsDmsEndpointRedshiftSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsDmsEndpointRedshiftSettingsOutputReference
type DataAwsDmsEndpointS3Settings ¶
type DataAwsDmsEndpointS3Settings struct {
}
type DataAwsDmsEndpointS3SettingsList ¶
type DataAwsDmsEndpointS3SettingsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsDmsEndpointS3SettingsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDmsEndpointS3SettingsList ¶
func NewDataAwsDmsEndpointS3SettingsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsDmsEndpointS3SettingsList
type DataAwsDmsEndpointS3SettingsOutputReference ¶
type DataAwsDmsEndpointS3SettingsOutputReference interface {
cdktf.ComplexObject
AddColumnName() cdktf.IResolvable
BucketFolder() *string
BucketName() *string
CannedAclForObjects() *string
CdcInsertsAndUpdates() cdktf.IResolvable
CdcInsertsOnly() cdktf.IResolvable
CdcMaxBatchInterval() *float64
CdcMinFileSize() *float64
CdcPath() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CompressionType() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
CsvDelimiter() *string
CsvNoSupValue() *string
CsvNullValue() *string
CsvRowDelimiter() *string
DataFormat() *string
DataPageSize() *float64
DatePartitionDelimiter() *string
DatePartitionEnabled() cdktf.IResolvable
DatePartitionSequence() *string
DictPageSizeLimit() *float64
EnableStatistics() cdktf.IResolvable
EncodingType() *string
EncryptionMode() *string
ExternalTableDefinition() *string
// Experimental.
Fqn() *string
IgnoreHeaderRows() *float64
IgnoreHeadersRow() *float64
IncludeOpForFullLoad() cdktf.IResolvable
InternalValue() *DataAwsDmsEndpointS3Settings
SetInternalValue(val *DataAwsDmsEndpointS3Settings)
MaxFileSize() *float64
ParquetTimestampInMillisecond() cdktf.IResolvable
ParquetVersion() *string
PreserveTransactions() cdktf.IResolvable
Rfc4180() cdktf.IResolvable
RowGroupLength() *float64
ServerSideEncryptionKmsKeyId() *string
ServiceAccessRoleArn() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TimestampColumnName() *string
UseCsvNoSupValue() cdktf.IResolvable
UseTaskStartTimeForFullLoadTimestamp() cdktf.IResolvable
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsDmsEndpointS3SettingsOutputReference ¶
func NewDataAwsDmsEndpointS3SettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsDmsEndpointS3SettingsOutputReference
Source Files
¶
- DataAwsDmsEndpoint.go
- DataAwsDmsEndpointConfig.go
- DataAwsDmsEndpointElasticsearchSettings.go
- DataAwsDmsEndpointElasticsearchSettingsList.go
- DataAwsDmsEndpointElasticsearchSettingsList__checks.go
- DataAwsDmsEndpointElasticsearchSettingsOutputReference.go
- DataAwsDmsEndpointElasticsearchSettingsOutputReference__checks.go
- DataAwsDmsEndpointKafkaSettings.go
- DataAwsDmsEndpointKafkaSettingsList.go
- DataAwsDmsEndpointKafkaSettingsList__checks.go
- DataAwsDmsEndpointKafkaSettingsOutputReference.go
- DataAwsDmsEndpointKafkaSettingsOutputReference__checks.go
- DataAwsDmsEndpointKinesisSettings.go
- DataAwsDmsEndpointKinesisSettingsList.go
- DataAwsDmsEndpointKinesisSettingsList__checks.go
- DataAwsDmsEndpointKinesisSettingsOutputReference.go
- DataAwsDmsEndpointKinesisSettingsOutputReference__checks.go
- DataAwsDmsEndpointMongodbSettings.go
- DataAwsDmsEndpointMongodbSettingsList.go
- DataAwsDmsEndpointMongodbSettingsList__checks.go
- DataAwsDmsEndpointMongodbSettingsOutputReference.go
- DataAwsDmsEndpointMongodbSettingsOutputReference__checks.go
- DataAwsDmsEndpointRedisSettings.go
- DataAwsDmsEndpointRedisSettingsList.go
- DataAwsDmsEndpointRedisSettingsList__checks.go
- DataAwsDmsEndpointRedisSettingsOutputReference.go
- DataAwsDmsEndpointRedisSettingsOutputReference__checks.go
- DataAwsDmsEndpointRedshiftSettings.go
- DataAwsDmsEndpointRedshiftSettingsList.go
- DataAwsDmsEndpointRedshiftSettingsList__checks.go
- DataAwsDmsEndpointRedshiftSettingsOutputReference.go
- DataAwsDmsEndpointRedshiftSettingsOutputReference__checks.go
- DataAwsDmsEndpointS3Settings.go
- DataAwsDmsEndpointS3SettingsList.go
- DataAwsDmsEndpointS3SettingsList__checks.go
- DataAwsDmsEndpointS3SettingsOutputReference.go
- DataAwsDmsEndpointS3SettingsOutputReference__checks.go
- DataAwsDmsEndpoint__checks.go
- main.go