Documentation
¶
Index ¶
- func DataAwsEc2InstanceTypeOffering_IsConstruct(x interface{}) *bool
- func DataAwsEc2InstanceTypeOffering_IsTerraformDataSource(x interface{}) *bool
- func DataAwsEc2InstanceTypeOffering_IsTerraformElement(x interface{}) *bool
- func DataAwsEc2InstanceTypeOffering_TfResourceType() *string
- func NewDataAwsEc2InstanceTypeOfferingFilterList_Override(d DataAwsEc2InstanceTypeOfferingFilterList, ...)
- func NewDataAwsEc2InstanceTypeOfferingFilterOutputReference_Override(d DataAwsEc2InstanceTypeOfferingFilterOutputReference, ...)
- func NewDataAwsEc2InstanceTypeOfferingTimeoutsOutputReference_Override(d DataAwsEc2InstanceTypeOfferingTimeoutsOutputReference, ...)
- func NewDataAwsEc2InstanceTypeOffering_Override(d DataAwsEc2InstanceTypeOffering, scope constructs.Construct, id *string, ...)
- type DataAwsEc2InstanceTypeOffering
- type DataAwsEc2InstanceTypeOfferingConfig
- type DataAwsEc2InstanceTypeOfferingFilter
- type DataAwsEc2InstanceTypeOfferingFilterList
- type DataAwsEc2InstanceTypeOfferingFilterOutputReference
- type DataAwsEc2InstanceTypeOfferingTimeouts
- type DataAwsEc2InstanceTypeOfferingTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsEc2InstanceTypeOffering_IsConstruct ¶
func DataAwsEc2InstanceTypeOffering_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsEc2InstanceTypeOffering_IsTerraformDataSource ¶
func DataAwsEc2InstanceTypeOffering_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsEc2InstanceTypeOffering_IsTerraformElement ¶
func DataAwsEc2InstanceTypeOffering_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsEc2InstanceTypeOffering_TfResourceType ¶
func DataAwsEc2InstanceTypeOffering_TfResourceType() *string
func NewDataAwsEc2InstanceTypeOfferingFilterList_Override ¶
func NewDataAwsEc2InstanceTypeOfferingFilterList_Override(d DataAwsEc2InstanceTypeOfferingFilterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEc2InstanceTypeOfferingFilterOutputReference_Override ¶
func NewDataAwsEc2InstanceTypeOfferingFilterOutputReference_Override(d DataAwsEc2InstanceTypeOfferingFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEc2InstanceTypeOfferingTimeoutsOutputReference_Override ¶
func NewDataAwsEc2InstanceTypeOfferingTimeoutsOutputReference_Override(d DataAwsEc2InstanceTypeOfferingTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsEc2InstanceTypeOffering_Override ¶
func NewDataAwsEc2InstanceTypeOffering_Override(d DataAwsEc2InstanceTypeOffering, scope constructs.Construct, id *string, config *DataAwsEc2InstanceTypeOfferingConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_instance_type_offering aws_ec2_instance_type_offering} Data Source.
Types ¶
type DataAwsEc2InstanceTypeOffering ¶
type DataAwsEc2InstanceTypeOffering interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Filter() DataAwsEc2InstanceTypeOfferingFilterList
FilterInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InstanceType() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LocationType() *string
SetLocationType(val *string)
LocationTypeInput() *string
// The tree node.
Node() constructs.Node
PreferredInstanceTypes() *[]*string
SetPreferredInstanceTypes(val *[]*string)
PreferredInstanceTypesInput() *[]*string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DataAwsEc2InstanceTypeOfferingTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutFilter(value interface{})
PutTimeouts(value *DataAwsEc2InstanceTypeOfferingTimeouts)
ResetFilter()
ResetId()
ResetLocationType()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPreferredInstanceTypes()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_instance_type_offering aws_ec2_instance_type_offering}.
func NewDataAwsEc2InstanceTypeOffering ¶
func NewDataAwsEc2InstanceTypeOffering(scope constructs.Construct, id *string, config *DataAwsEc2InstanceTypeOfferingConfig) DataAwsEc2InstanceTypeOffering
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_instance_type_offering aws_ec2_instance_type_offering} Data Source.
type DataAwsEc2InstanceTypeOfferingConfig ¶
type DataAwsEc2InstanceTypeOfferingConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// filter block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_instance_type_offering#filter DataAwsEc2InstanceTypeOffering#filter}
Filter interface{} `field:"optional" json:"filter" yaml:"filter"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_instance_type_offering#id DataAwsEc2InstanceTypeOffering#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_instance_type_offering#location_type DataAwsEc2InstanceTypeOffering#location_type}.
LocationType *string `field:"optional" json:"locationType" yaml:"locationType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_instance_type_offering#preferred_instance_types DataAwsEc2InstanceTypeOffering#preferred_instance_types}.
PreferredInstanceTypes *[]*string `field:"optional" json:"preferredInstanceTypes" yaml:"preferredInstanceTypes"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_instance_type_offering#timeouts DataAwsEc2InstanceTypeOffering#timeouts}
Timeouts *DataAwsEc2InstanceTypeOfferingTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type DataAwsEc2InstanceTypeOfferingFilter ¶
type DataAwsEc2InstanceTypeOfferingFilter struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_instance_type_offering#name DataAwsEc2InstanceTypeOffering#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_instance_type_offering#values DataAwsEc2InstanceTypeOffering#values}.
Values *[]*string `field:"required" json:"values" yaml:"values"`
}
type DataAwsEc2InstanceTypeOfferingFilterList ¶
type DataAwsEc2InstanceTypeOfferingFilterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEc2InstanceTypeOfferingFilterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2InstanceTypeOfferingFilterList ¶
func NewDataAwsEc2InstanceTypeOfferingFilterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEc2InstanceTypeOfferingFilterList
type DataAwsEc2InstanceTypeOfferingFilterOutputReference ¶
type DataAwsEc2InstanceTypeOfferingFilterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
SetValues(val *[]*string)
ValuesInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2InstanceTypeOfferingFilterOutputReference ¶
func NewDataAwsEc2InstanceTypeOfferingFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEc2InstanceTypeOfferingFilterOutputReference
type DataAwsEc2InstanceTypeOfferingTimeouts ¶
type DataAwsEc2InstanceTypeOfferingTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_instance_type_offering#read DataAwsEc2InstanceTypeOffering#read}.
Read *string `field:"optional" json:"read" yaml:"read"`
}
type DataAwsEc2InstanceTypeOfferingTimeoutsOutputReference ¶
type DataAwsEc2InstanceTypeOfferingTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Read() *string
SetRead(val *string)
ReadInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetRead()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2InstanceTypeOfferingTimeoutsOutputReference ¶
func NewDataAwsEc2InstanceTypeOfferingTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsEc2InstanceTypeOfferingTimeoutsOutputReference
Source Files
¶
- DataAwsEc2InstanceTypeOffering.go
- DataAwsEc2InstanceTypeOfferingConfig.go
- DataAwsEc2InstanceTypeOfferingFilter.go
- DataAwsEc2InstanceTypeOfferingFilterList.go
- DataAwsEc2InstanceTypeOfferingFilterList__checks.go
- DataAwsEc2InstanceTypeOfferingFilterOutputReference.go
- DataAwsEc2InstanceTypeOfferingFilterOutputReference__checks.go
- DataAwsEc2InstanceTypeOfferingTimeouts.go
- DataAwsEc2InstanceTypeOfferingTimeoutsOutputReference.go
- DataAwsEc2InstanceTypeOfferingTimeoutsOutputReference__checks.go
- DataAwsEc2InstanceTypeOffering__checks.go
- main.go