Documentation
¶
Index ¶
- func DataAwsEc2TransitGatewayDxGatewayAttachment_IsConstruct(x interface{}) *bool
- func DataAwsEc2TransitGatewayDxGatewayAttachment_IsTerraformDataSource(x interface{}) *bool
- func DataAwsEc2TransitGatewayDxGatewayAttachment_IsTerraformElement(x interface{}) *bool
- func DataAwsEc2TransitGatewayDxGatewayAttachment_TfResourceType() *string
- func NewDataAwsEc2TransitGatewayDxGatewayAttachmentFilterList_Override(d DataAwsEc2TransitGatewayDxGatewayAttachmentFilterList, ...)
- func NewDataAwsEc2TransitGatewayDxGatewayAttachmentFilterOutputReference_Override(d DataAwsEc2TransitGatewayDxGatewayAttachmentFilterOutputReference, ...)
- func NewDataAwsEc2TransitGatewayDxGatewayAttachmentTimeoutsOutputReference_Override(d DataAwsEc2TransitGatewayDxGatewayAttachmentTimeoutsOutputReference, ...)
- func NewDataAwsEc2TransitGatewayDxGatewayAttachment_Override(d DataAwsEc2TransitGatewayDxGatewayAttachment, scope constructs.Construct, ...)
- type DataAwsEc2TransitGatewayDxGatewayAttachment
- type DataAwsEc2TransitGatewayDxGatewayAttachmentConfig
- type DataAwsEc2TransitGatewayDxGatewayAttachmentFilter
- type DataAwsEc2TransitGatewayDxGatewayAttachmentFilterList
- type DataAwsEc2TransitGatewayDxGatewayAttachmentFilterOutputReference
- type DataAwsEc2TransitGatewayDxGatewayAttachmentTimeouts
- type DataAwsEc2TransitGatewayDxGatewayAttachmentTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsEc2TransitGatewayDxGatewayAttachment_IsConstruct ¶
func DataAwsEc2TransitGatewayDxGatewayAttachment_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsEc2TransitGatewayDxGatewayAttachment_IsTerraformDataSource ¶
func DataAwsEc2TransitGatewayDxGatewayAttachment_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsEc2TransitGatewayDxGatewayAttachment_IsTerraformElement ¶
func DataAwsEc2TransitGatewayDxGatewayAttachment_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsEc2TransitGatewayDxGatewayAttachment_TfResourceType ¶
func DataAwsEc2TransitGatewayDxGatewayAttachment_TfResourceType() *string
func NewDataAwsEc2TransitGatewayDxGatewayAttachmentFilterList_Override ¶
func NewDataAwsEc2TransitGatewayDxGatewayAttachmentFilterList_Override(d DataAwsEc2TransitGatewayDxGatewayAttachmentFilterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEc2TransitGatewayDxGatewayAttachmentFilterOutputReference_Override ¶
func NewDataAwsEc2TransitGatewayDxGatewayAttachmentFilterOutputReference_Override(d DataAwsEc2TransitGatewayDxGatewayAttachmentFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEc2TransitGatewayDxGatewayAttachmentTimeoutsOutputReference_Override ¶
func NewDataAwsEc2TransitGatewayDxGatewayAttachmentTimeoutsOutputReference_Override(d DataAwsEc2TransitGatewayDxGatewayAttachmentTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsEc2TransitGatewayDxGatewayAttachment_Override ¶
func NewDataAwsEc2TransitGatewayDxGatewayAttachment_Override(d DataAwsEc2TransitGatewayDxGatewayAttachment, scope constructs.Construct, id *string, config *DataAwsEc2TransitGatewayDxGatewayAttachmentConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_transit_gateway_dx_gateway_attachment aws_ec2_transit_gateway_dx_gateway_attachment} Data Source.
Types ¶
type DataAwsEc2TransitGatewayDxGatewayAttachment ¶
type DataAwsEc2TransitGatewayDxGatewayAttachment interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DxGatewayId() *string
SetDxGatewayId(val *string)
DxGatewayIdInput() *string
Filter() DataAwsEc2TransitGatewayDxGatewayAttachmentFilterList
FilterInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DataAwsEc2TransitGatewayDxGatewayAttachmentTimeoutsOutputReference
TimeoutsInput() interface{}
TransitGatewayId() *string
SetTransitGatewayId(val *string)
TransitGatewayIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutFilter(value interface{})
PutTimeouts(value *DataAwsEc2TransitGatewayDxGatewayAttachmentTimeouts)
ResetDxGatewayId()
ResetFilter()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTimeouts()
ResetTransitGatewayId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_transit_gateway_dx_gateway_attachment aws_ec2_transit_gateway_dx_gateway_attachment}.
func NewDataAwsEc2TransitGatewayDxGatewayAttachment ¶
func NewDataAwsEc2TransitGatewayDxGatewayAttachment(scope constructs.Construct, id *string, config *DataAwsEc2TransitGatewayDxGatewayAttachmentConfig) DataAwsEc2TransitGatewayDxGatewayAttachment
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_transit_gateway_dx_gateway_attachment aws_ec2_transit_gateway_dx_gateway_attachment} Data Source.
type DataAwsEc2TransitGatewayDxGatewayAttachmentConfig ¶
type DataAwsEc2TransitGatewayDxGatewayAttachmentConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_transit_gateway_dx_gateway_attachment#dx_gateway_id DataAwsEc2TransitGatewayDxGatewayAttachment#dx_gateway_id}.
DxGatewayId *string `field:"optional" json:"dxGatewayId" yaml:"dxGatewayId"`
// filter block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_transit_gateway_dx_gateway_attachment#filter DataAwsEc2TransitGatewayDxGatewayAttachment#filter}
Filter interface{} `field:"optional" json:"filter" yaml:"filter"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_transit_gateway_dx_gateway_attachment#id DataAwsEc2TransitGatewayDxGatewayAttachment#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_transit_gateway_dx_gateway_attachment#tags DataAwsEc2TransitGatewayDxGatewayAttachment#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_transit_gateway_dx_gateway_attachment#timeouts DataAwsEc2TransitGatewayDxGatewayAttachment#timeouts}
Timeouts *DataAwsEc2TransitGatewayDxGatewayAttachmentTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_transit_gateway_dx_gateway_attachment#transit_gateway_id DataAwsEc2TransitGatewayDxGatewayAttachment#transit_gateway_id}.
TransitGatewayId *string `field:"optional" json:"transitGatewayId" yaml:"transitGatewayId"`
}
type DataAwsEc2TransitGatewayDxGatewayAttachmentFilter ¶
type DataAwsEc2TransitGatewayDxGatewayAttachmentFilter struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_transit_gateway_dx_gateway_attachment#name DataAwsEc2TransitGatewayDxGatewayAttachment#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_transit_gateway_dx_gateway_attachment#values DataAwsEc2TransitGatewayDxGatewayAttachment#values}.
Values *[]*string `field:"required" json:"values" yaml:"values"`
}
type DataAwsEc2TransitGatewayDxGatewayAttachmentFilterList ¶
type DataAwsEc2TransitGatewayDxGatewayAttachmentFilterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEc2TransitGatewayDxGatewayAttachmentFilterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2TransitGatewayDxGatewayAttachmentFilterList ¶
func NewDataAwsEc2TransitGatewayDxGatewayAttachmentFilterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEc2TransitGatewayDxGatewayAttachmentFilterList
type DataAwsEc2TransitGatewayDxGatewayAttachmentFilterOutputReference ¶
type DataAwsEc2TransitGatewayDxGatewayAttachmentFilterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
SetValues(val *[]*string)
ValuesInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2TransitGatewayDxGatewayAttachmentFilterOutputReference ¶
func NewDataAwsEc2TransitGatewayDxGatewayAttachmentFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEc2TransitGatewayDxGatewayAttachmentFilterOutputReference
type DataAwsEc2TransitGatewayDxGatewayAttachmentTimeouts ¶
type DataAwsEc2TransitGatewayDxGatewayAttachmentTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ec2_transit_gateway_dx_gateway_attachment#read DataAwsEc2TransitGatewayDxGatewayAttachment#read}.
Read *string `field:"optional" json:"read" yaml:"read"`
}
type DataAwsEc2TransitGatewayDxGatewayAttachmentTimeoutsOutputReference ¶
type DataAwsEc2TransitGatewayDxGatewayAttachmentTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Read() *string
SetRead(val *string)
ReadInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetRead()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2TransitGatewayDxGatewayAttachmentTimeoutsOutputReference ¶
func NewDataAwsEc2TransitGatewayDxGatewayAttachmentTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsEc2TransitGatewayDxGatewayAttachmentTimeoutsOutputReference
Source Files
¶
- DataAwsEc2TransitGatewayDxGatewayAttachment.go
- DataAwsEc2TransitGatewayDxGatewayAttachmentConfig.go
- DataAwsEc2TransitGatewayDxGatewayAttachmentFilter.go
- DataAwsEc2TransitGatewayDxGatewayAttachmentFilterList.go
- DataAwsEc2TransitGatewayDxGatewayAttachmentFilterList__checks.go
- DataAwsEc2TransitGatewayDxGatewayAttachmentFilterOutputReference.go
- DataAwsEc2TransitGatewayDxGatewayAttachmentFilterOutputReference__checks.go
- DataAwsEc2TransitGatewayDxGatewayAttachmentTimeouts.go
- DataAwsEc2TransitGatewayDxGatewayAttachmentTimeoutsOutputReference.go
- DataAwsEc2TransitGatewayDxGatewayAttachmentTimeoutsOutputReference__checks.go
- DataAwsEc2TransitGatewayDxGatewayAttachment__checks.go
- main.go