Documentation
¶
Index ¶
- func DataAwsEmrcontainersVirtualCluster_IsConstruct(x interface{}) *bool
- func DataAwsEmrcontainersVirtualCluster_IsTerraformDataSource(x interface{}) *bool
- func DataAwsEmrcontainersVirtualCluster_IsTerraformElement(x interface{}) *bool
- func DataAwsEmrcontainersVirtualCluster_TfResourceType() *string
- func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoList_Override(d DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoList, ...)
- func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference_Override(...)
- func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoList_Override(d DataAwsEmrcontainersVirtualClusterContainerProviderInfoList, ...)
- func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoOutputReference_Override(d DataAwsEmrcontainersVirtualClusterContainerProviderInfoOutputReference, ...)
- func NewDataAwsEmrcontainersVirtualClusterContainerProviderList_Override(d DataAwsEmrcontainersVirtualClusterContainerProviderList, ...)
- func NewDataAwsEmrcontainersVirtualClusterContainerProviderOutputReference_Override(d DataAwsEmrcontainersVirtualClusterContainerProviderOutputReference, ...)
- func NewDataAwsEmrcontainersVirtualCluster_Override(d DataAwsEmrcontainersVirtualCluster, scope constructs.Construct, id *string, ...)
- type DataAwsEmrcontainersVirtualCluster
- type DataAwsEmrcontainersVirtualClusterConfig
- type DataAwsEmrcontainersVirtualClusterContainerProvider
- type DataAwsEmrcontainersVirtualClusterContainerProviderInfo
- type DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfo
- type DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoList
- type DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference
- type DataAwsEmrcontainersVirtualClusterContainerProviderInfoList
- type DataAwsEmrcontainersVirtualClusterContainerProviderInfoOutputReference
- type DataAwsEmrcontainersVirtualClusterContainerProviderList
- type DataAwsEmrcontainersVirtualClusterContainerProviderOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsEmrcontainersVirtualCluster_IsConstruct ¶
func DataAwsEmrcontainersVirtualCluster_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsEmrcontainersVirtualCluster_IsTerraformDataSource ¶
func DataAwsEmrcontainersVirtualCluster_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsEmrcontainersVirtualCluster_IsTerraformElement ¶
func DataAwsEmrcontainersVirtualCluster_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsEmrcontainersVirtualCluster_TfResourceType ¶
func DataAwsEmrcontainersVirtualCluster_TfResourceType() *string
func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoList_Override ¶
func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoList_Override(d DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference_Override ¶
func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference_Override(d DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoList_Override ¶
func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoList_Override(d DataAwsEmrcontainersVirtualClusterContainerProviderInfoList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoOutputReference_Override ¶
func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoOutputReference_Override(d DataAwsEmrcontainersVirtualClusterContainerProviderInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEmrcontainersVirtualClusterContainerProviderList_Override ¶
func NewDataAwsEmrcontainersVirtualClusterContainerProviderList_Override(d DataAwsEmrcontainersVirtualClusterContainerProviderList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEmrcontainersVirtualClusterContainerProviderOutputReference_Override ¶
func NewDataAwsEmrcontainersVirtualClusterContainerProviderOutputReference_Override(d DataAwsEmrcontainersVirtualClusterContainerProviderOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEmrcontainersVirtualCluster_Override ¶
func NewDataAwsEmrcontainersVirtualCluster_Override(d DataAwsEmrcontainersVirtualCluster, scope constructs.Construct, id *string, config *DataAwsEmrcontainersVirtualClusterConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/emrcontainers_virtual_cluster aws_emrcontainers_virtual_cluster} Data Source.
Types ¶
type DataAwsEmrcontainersVirtualCluster ¶
type DataAwsEmrcontainersVirtualCluster interface {
cdktf.TerraformDataSource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ContainerProvider() DataAwsEmrcontainersVirtualClusterContainerProviderList
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreatedAt() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
State() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
VirtualClusterId() *string
SetVirtualClusterId(val *string)
VirtualClusterIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/emrcontainers_virtual_cluster aws_emrcontainers_virtual_cluster}.
func NewDataAwsEmrcontainersVirtualCluster ¶
func NewDataAwsEmrcontainersVirtualCluster(scope constructs.Construct, id *string, config *DataAwsEmrcontainersVirtualClusterConfig) DataAwsEmrcontainersVirtualCluster
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/emrcontainers_virtual_cluster aws_emrcontainers_virtual_cluster} Data Source.
type DataAwsEmrcontainersVirtualClusterConfig ¶
type DataAwsEmrcontainersVirtualClusterConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/emrcontainers_virtual_cluster#virtual_cluster_id DataAwsEmrcontainersVirtualCluster#virtual_cluster_id}.
VirtualClusterId *string `field:"required" json:"virtualClusterId" yaml:"virtualClusterId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/emrcontainers_virtual_cluster#id DataAwsEmrcontainersVirtualCluster#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/emrcontainers_virtual_cluster#tags DataAwsEmrcontainersVirtualCluster#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsEmrcontainersVirtualClusterContainerProvider ¶
type DataAwsEmrcontainersVirtualClusterContainerProvider struct {
}
type DataAwsEmrcontainersVirtualClusterContainerProviderInfo ¶
type DataAwsEmrcontainersVirtualClusterContainerProviderInfo struct {
}
type DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfo ¶
type DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfo struct {
}
type DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoList ¶
type DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoList ¶
func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoList
type DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference ¶
type DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfo
SetInternalValue(val *DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfo)
Namespace() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference ¶
func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference
type DataAwsEmrcontainersVirtualClusterContainerProviderInfoList ¶
type DataAwsEmrcontainersVirtualClusterContainerProviderInfoList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEmrcontainersVirtualClusterContainerProviderInfoOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoList ¶
func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEmrcontainersVirtualClusterContainerProviderInfoList
type DataAwsEmrcontainersVirtualClusterContainerProviderInfoOutputReference ¶
type DataAwsEmrcontainersVirtualClusterContainerProviderInfoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EksInfo() DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoList
// Experimental.
Fqn() *string
InternalValue() *DataAwsEmrcontainersVirtualClusterContainerProviderInfo
SetInternalValue(val *DataAwsEmrcontainersVirtualClusterContainerProviderInfo)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoOutputReference ¶
func NewDataAwsEmrcontainersVirtualClusterContainerProviderInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEmrcontainersVirtualClusterContainerProviderInfoOutputReference
type DataAwsEmrcontainersVirtualClusterContainerProviderList ¶
type DataAwsEmrcontainersVirtualClusterContainerProviderList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEmrcontainersVirtualClusterContainerProviderOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEmrcontainersVirtualClusterContainerProviderList ¶
func NewDataAwsEmrcontainersVirtualClusterContainerProviderList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEmrcontainersVirtualClusterContainerProviderList
type DataAwsEmrcontainersVirtualClusterContainerProviderOutputReference ¶
type DataAwsEmrcontainersVirtualClusterContainerProviderOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
Info() DataAwsEmrcontainersVirtualClusterContainerProviderInfoList
InternalValue() *DataAwsEmrcontainersVirtualClusterContainerProvider
SetInternalValue(val *DataAwsEmrcontainersVirtualClusterContainerProvider)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEmrcontainersVirtualClusterContainerProviderOutputReference ¶
func NewDataAwsEmrcontainersVirtualClusterContainerProviderOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEmrcontainersVirtualClusterContainerProviderOutputReference
Source Files
¶
- DataAwsEmrcontainersVirtualCluster.go
- DataAwsEmrcontainersVirtualClusterConfig.go
- DataAwsEmrcontainersVirtualClusterContainerProvider.go
- DataAwsEmrcontainersVirtualClusterContainerProviderInfo.go
- DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfo.go
- DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoList.go
- DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoList__checks.go
- DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference.go
- DataAwsEmrcontainersVirtualClusterContainerProviderInfoEksInfoOutputReference__checks.go
- DataAwsEmrcontainersVirtualClusterContainerProviderInfoList.go
- DataAwsEmrcontainersVirtualClusterContainerProviderInfoList__checks.go
- DataAwsEmrcontainersVirtualClusterContainerProviderInfoOutputReference.go
- DataAwsEmrcontainersVirtualClusterContainerProviderInfoOutputReference__checks.go
- DataAwsEmrcontainersVirtualClusterContainerProviderList.go
- DataAwsEmrcontainersVirtualClusterContainerProviderList__checks.go
- DataAwsEmrcontainersVirtualClusterContainerProviderOutputReference.go
- DataAwsEmrcontainersVirtualClusterContainerProviderOutputReference__checks.go
- DataAwsEmrcontainersVirtualCluster__checks.go
- main.go