Documentation
¶
Index ¶
- func DataAwsGlobalacceleratorCustomRoutingAccelerator_IsConstruct(x interface{}) *bool
- func DataAwsGlobalacceleratorCustomRoutingAccelerator_IsTerraformDataSource(x interface{}) *bool
- func DataAwsGlobalacceleratorCustomRoutingAccelerator_IsTerraformElement(x interface{}) *bool
- func DataAwsGlobalacceleratorCustomRoutingAccelerator_TfResourceType() *string
- func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesList_Override(d DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesList, ...)
- func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesOutputReference_Override(d DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesOutputReference, ...)
- func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsList_Override(d DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsList, ...)
- func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsOutputReference_Override(d DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsOutputReference, ...)
- func NewDataAwsGlobalacceleratorCustomRoutingAccelerator_Override(d DataAwsGlobalacceleratorCustomRoutingAccelerator, scope constructs.Construct, ...)
- type DataAwsGlobalacceleratorCustomRoutingAccelerator
- type DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributes
- type DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesList
- type DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesOutputReference
- type DataAwsGlobalacceleratorCustomRoutingAcceleratorConfig
- type DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSets
- type DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsList
- type DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsGlobalacceleratorCustomRoutingAccelerator_IsConstruct ¶
func DataAwsGlobalacceleratorCustomRoutingAccelerator_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsGlobalacceleratorCustomRoutingAccelerator_IsTerraformDataSource ¶
func DataAwsGlobalacceleratorCustomRoutingAccelerator_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsGlobalacceleratorCustomRoutingAccelerator_IsTerraformElement ¶
func DataAwsGlobalacceleratorCustomRoutingAccelerator_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsGlobalacceleratorCustomRoutingAccelerator_TfResourceType ¶
func DataAwsGlobalacceleratorCustomRoutingAccelerator_TfResourceType() *string
func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesList_Override ¶
func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesList_Override(d DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesOutputReference_Override ¶
func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesOutputReference_Override(d DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsList_Override ¶
func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsList_Override(d DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsOutputReference_Override ¶
func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsOutputReference_Override(d DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsGlobalacceleratorCustomRoutingAccelerator_Override ¶
func NewDataAwsGlobalacceleratorCustomRoutingAccelerator_Override(d DataAwsGlobalacceleratorCustomRoutingAccelerator, scope constructs.Construct, id *string, config *DataAwsGlobalacceleratorCustomRoutingAcceleratorConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/globalaccelerator_custom_routing_accelerator aws_globalaccelerator_custom_routing_accelerator} Data Source.
Types ¶
type DataAwsGlobalacceleratorCustomRoutingAccelerator ¶
type DataAwsGlobalacceleratorCustomRoutingAccelerator interface {
cdktf.TerraformDataSource
Arn() *string
SetArn(val *string)
ArnInput() *string
Attributes() DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesList
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DnsName() *string
Enabled() cdktf.IResolvable
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HostedZoneId() *string
Id() *string
SetId(val *string)
IdInput() *string
IpAddressType() *string
IpSets() DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsList
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetArn()
ResetId()
ResetName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/globalaccelerator_custom_routing_accelerator aws_globalaccelerator_custom_routing_accelerator}.
func NewDataAwsGlobalacceleratorCustomRoutingAccelerator ¶
func NewDataAwsGlobalacceleratorCustomRoutingAccelerator(scope constructs.Construct, id *string, config *DataAwsGlobalacceleratorCustomRoutingAcceleratorConfig) DataAwsGlobalacceleratorCustomRoutingAccelerator
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/globalaccelerator_custom_routing_accelerator aws_globalaccelerator_custom_routing_accelerator} Data Source.
type DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributes ¶
type DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributes struct {
}
type DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesList ¶
type DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesList ¶
func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesList
type DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesOutputReference ¶
type DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FlowLogsEnabled() cdktf.IResolvable
FlowLogsS3Bucket() *string
FlowLogsS3Prefix() *string
// Experimental.
Fqn() *string
InternalValue() *DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributes
SetInternalValue(val *DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributes)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesOutputReference ¶
func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesOutputReference
type DataAwsGlobalacceleratorCustomRoutingAcceleratorConfig ¶
type DataAwsGlobalacceleratorCustomRoutingAcceleratorConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/globalaccelerator_custom_routing_accelerator#arn DataAwsGlobalacceleratorCustomRoutingAccelerator#arn}.
Arn *string `field:"optional" json:"arn" yaml:"arn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/globalaccelerator_custom_routing_accelerator#id DataAwsGlobalacceleratorCustomRoutingAccelerator#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/globalaccelerator_custom_routing_accelerator#name DataAwsGlobalacceleratorCustomRoutingAccelerator#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/globalaccelerator_custom_routing_accelerator#tags DataAwsGlobalacceleratorCustomRoutingAccelerator#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSets ¶
type DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSets struct {
}
type DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsList ¶
type DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsList ¶
func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsList
type DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsOutputReference ¶
type DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSets
SetInternalValue(val *DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSets)
IpAddresses() *[]*string
IpFamily() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsOutputReference ¶
func NewDataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsOutputReference
Source Files
¶
- DataAwsGlobalacceleratorCustomRoutingAccelerator.go
- DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributes.go
- DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesList.go
- DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesList__checks.go
- DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesOutputReference.go
- DataAwsGlobalacceleratorCustomRoutingAcceleratorAttributesOutputReference__checks.go
- DataAwsGlobalacceleratorCustomRoutingAcceleratorConfig.go
- DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSets.go
- DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsList.go
- DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsList__checks.go
- DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsOutputReference.go
- DataAwsGlobalacceleratorCustomRoutingAcceleratorIpSetsOutputReference__checks.go
- DataAwsGlobalacceleratorCustomRoutingAccelerator__checks.go
- main.go