Documentation
¶
Index ¶
- func DataAwsKendraExperience_IsConstruct(x interface{}) *bool
- func DataAwsKendraExperience_IsTerraformDataSource(x interface{}) *bool
- func DataAwsKendraExperience_IsTerraformElement(x interface{}) *bool
- func DataAwsKendraExperience_TfResourceType() *string
- func NewDataAwsKendraExperienceConfigurationContentSourceConfigurationList_Override(d DataAwsKendraExperienceConfigurationContentSourceConfigurationList, ...)
- func NewDataAwsKendraExperienceConfigurationContentSourceConfigurationOutputReference_Override(...)
- func NewDataAwsKendraExperienceConfigurationList_Override(d DataAwsKendraExperienceConfigurationList, ...)
- func NewDataAwsKendraExperienceConfigurationOutputReference_Override(d DataAwsKendraExperienceConfigurationOutputReference, ...)
- func NewDataAwsKendraExperienceConfigurationUserIdentityConfigurationList_Override(d DataAwsKendraExperienceConfigurationUserIdentityConfigurationList, ...)
- func NewDataAwsKendraExperienceConfigurationUserIdentityConfigurationOutputReference_Override(d DataAwsKendraExperienceConfigurationUserIdentityConfigurationOutputReference, ...)
- func NewDataAwsKendraExperienceEndpointsList_Override(d DataAwsKendraExperienceEndpointsList, ...)
- func NewDataAwsKendraExperienceEndpointsOutputReference_Override(d DataAwsKendraExperienceEndpointsOutputReference, ...)
- func NewDataAwsKendraExperience_Override(d DataAwsKendraExperience, scope constructs.Construct, id *string, ...)
- type DataAwsKendraExperience
- type DataAwsKendraExperienceConfig
- type DataAwsKendraExperienceConfiguration
- type DataAwsKendraExperienceConfigurationContentSourceConfiguration
- type DataAwsKendraExperienceConfigurationContentSourceConfigurationList
- type DataAwsKendraExperienceConfigurationContentSourceConfigurationOutputReference
- type DataAwsKendraExperienceConfigurationList
- type DataAwsKendraExperienceConfigurationOutputReference
- type DataAwsKendraExperienceConfigurationUserIdentityConfiguration
- type DataAwsKendraExperienceConfigurationUserIdentityConfigurationList
- type DataAwsKendraExperienceConfigurationUserIdentityConfigurationOutputReference
- type DataAwsKendraExperienceEndpoints
- type DataAwsKendraExperienceEndpointsList
- type DataAwsKendraExperienceEndpointsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsKendraExperience_IsConstruct ¶
func DataAwsKendraExperience_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsKendraExperience_IsTerraformDataSource ¶
func DataAwsKendraExperience_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsKendraExperience_IsTerraformElement ¶
func DataAwsKendraExperience_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsKendraExperience_TfResourceType ¶
func DataAwsKendraExperience_TfResourceType() *string
func NewDataAwsKendraExperienceConfigurationContentSourceConfigurationList_Override ¶
func NewDataAwsKendraExperienceConfigurationContentSourceConfigurationList_Override(d DataAwsKendraExperienceConfigurationContentSourceConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsKendraExperienceConfigurationContentSourceConfigurationOutputReference_Override ¶
func NewDataAwsKendraExperienceConfigurationContentSourceConfigurationOutputReference_Override(d DataAwsKendraExperienceConfigurationContentSourceConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsKendraExperienceConfigurationList_Override ¶
func NewDataAwsKendraExperienceConfigurationList_Override(d DataAwsKendraExperienceConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsKendraExperienceConfigurationOutputReference_Override ¶
func NewDataAwsKendraExperienceConfigurationOutputReference_Override(d DataAwsKendraExperienceConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsKendraExperienceConfigurationUserIdentityConfigurationList_Override ¶
func NewDataAwsKendraExperienceConfigurationUserIdentityConfigurationList_Override(d DataAwsKendraExperienceConfigurationUserIdentityConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsKendraExperienceConfigurationUserIdentityConfigurationOutputReference_Override ¶
func NewDataAwsKendraExperienceConfigurationUserIdentityConfigurationOutputReference_Override(d DataAwsKendraExperienceConfigurationUserIdentityConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsKendraExperienceEndpointsList_Override ¶
func NewDataAwsKendraExperienceEndpointsList_Override(d DataAwsKendraExperienceEndpointsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsKendraExperienceEndpointsOutputReference_Override ¶
func NewDataAwsKendraExperienceEndpointsOutputReference_Override(d DataAwsKendraExperienceEndpointsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsKendraExperience_Override ¶
func NewDataAwsKendraExperience_Override(d DataAwsKendraExperience, scope constructs.Construct, id *string, config *DataAwsKendraExperienceConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/kendra_experience aws_kendra_experience} Data Source.
Types ¶
type DataAwsKendraExperience ¶
type DataAwsKendraExperience interface {
cdktf.TerraformDataSource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
Configuration() DataAwsKendraExperienceConfigurationList
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreatedAt() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
Endpoints() DataAwsKendraExperienceEndpointsList
ErrorMessage() *string
ExperienceId() *string
SetExperienceId(val *string)
ExperienceIdInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IndexId() *string
SetIndexId(val *string)
IndexIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
RoleArn() *string
Status() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
UpdatedAt() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/kendra_experience aws_kendra_experience}.
func NewDataAwsKendraExperience ¶
func NewDataAwsKendraExperience(scope constructs.Construct, id *string, config *DataAwsKendraExperienceConfig) DataAwsKendraExperience
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/kendra_experience aws_kendra_experience} Data Source.
type DataAwsKendraExperienceConfig ¶
type DataAwsKendraExperienceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/kendra_experience#experience_id DataAwsKendraExperience#experience_id}.
ExperienceId *string `field:"required" json:"experienceId" yaml:"experienceId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/kendra_experience#index_id DataAwsKendraExperience#index_id}.
IndexId *string `field:"required" json:"indexId" yaml:"indexId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/kendra_experience#id DataAwsKendraExperience#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type DataAwsKendraExperienceConfiguration ¶
type DataAwsKendraExperienceConfiguration struct {
}
type DataAwsKendraExperienceConfigurationContentSourceConfiguration ¶
type DataAwsKendraExperienceConfigurationContentSourceConfiguration struct {
}
type DataAwsKendraExperienceConfigurationContentSourceConfigurationList ¶
type DataAwsKendraExperienceConfigurationContentSourceConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsKendraExperienceConfigurationContentSourceConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsKendraExperienceConfigurationContentSourceConfigurationList ¶
func NewDataAwsKendraExperienceConfigurationContentSourceConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsKendraExperienceConfigurationContentSourceConfigurationList
type DataAwsKendraExperienceConfigurationContentSourceConfigurationOutputReference ¶
type DataAwsKendraExperienceConfigurationContentSourceConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DataSourceIds() *[]*string
DirectPutContent() cdktf.IResolvable
FaqIds() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsKendraExperienceConfigurationContentSourceConfiguration
SetInternalValue(val *DataAwsKendraExperienceConfigurationContentSourceConfiguration)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsKendraExperienceConfigurationContentSourceConfigurationOutputReference ¶
func NewDataAwsKendraExperienceConfigurationContentSourceConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsKendraExperienceConfigurationContentSourceConfigurationOutputReference
type DataAwsKendraExperienceConfigurationList ¶
type DataAwsKendraExperienceConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsKendraExperienceConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsKendraExperienceConfigurationList ¶
func NewDataAwsKendraExperienceConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsKendraExperienceConfigurationList
type DataAwsKendraExperienceConfigurationOutputReference ¶
type DataAwsKendraExperienceConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ContentSourceConfiguration() DataAwsKendraExperienceConfigurationContentSourceConfigurationList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsKendraExperienceConfiguration
SetInternalValue(val *DataAwsKendraExperienceConfiguration)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UserIdentityConfiguration() DataAwsKendraExperienceConfigurationUserIdentityConfigurationList
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsKendraExperienceConfigurationOutputReference ¶
func NewDataAwsKendraExperienceConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsKendraExperienceConfigurationOutputReference
type DataAwsKendraExperienceConfigurationUserIdentityConfiguration ¶
type DataAwsKendraExperienceConfigurationUserIdentityConfiguration struct {
}
type DataAwsKendraExperienceConfigurationUserIdentityConfigurationList ¶
type DataAwsKendraExperienceConfigurationUserIdentityConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsKendraExperienceConfigurationUserIdentityConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsKendraExperienceConfigurationUserIdentityConfigurationList ¶
func NewDataAwsKendraExperienceConfigurationUserIdentityConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsKendraExperienceConfigurationUserIdentityConfigurationList
type DataAwsKendraExperienceConfigurationUserIdentityConfigurationOutputReference ¶
type DataAwsKendraExperienceConfigurationUserIdentityConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IdentityAttributeName() *string
InternalValue() *DataAwsKendraExperienceConfigurationUserIdentityConfiguration
SetInternalValue(val *DataAwsKendraExperienceConfigurationUserIdentityConfiguration)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsKendraExperienceConfigurationUserIdentityConfigurationOutputReference ¶
func NewDataAwsKendraExperienceConfigurationUserIdentityConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsKendraExperienceConfigurationUserIdentityConfigurationOutputReference
type DataAwsKendraExperienceEndpoints ¶
type DataAwsKendraExperienceEndpoints struct {
}
type DataAwsKendraExperienceEndpointsList ¶
type DataAwsKendraExperienceEndpointsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsKendraExperienceEndpointsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsKendraExperienceEndpointsList ¶
func NewDataAwsKendraExperienceEndpointsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsKendraExperienceEndpointsList
type DataAwsKendraExperienceEndpointsOutputReference ¶
type DataAwsKendraExperienceEndpointsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Endpoint() *string
EndpointType() *string
// Experimental.
Fqn() *string
InternalValue() *DataAwsKendraExperienceEndpoints
SetInternalValue(val *DataAwsKendraExperienceEndpoints)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsKendraExperienceEndpointsOutputReference ¶
func NewDataAwsKendraExperienceEndpointsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsKendraExperienceEndpointsOutputReference
Source Files
¶
- DataAwsKendraExperience.go
- DataAwsKendraExperienceConfig.go
- DataAwsKendraExperienceConfiguration.go
- DataAwsKendraExperienceConfigurationContentSourceConfiguration.go
- DataAwsKendraExperienceConfigurationContentSourceConfigurationList.go
- DataAwsKendraExperienceConfigurationContentSourceConfigurationList__checks.go
- DataAwsKendraExperienceConfigurationContentSourceConfigurationOutputReference.go
- DataAwsKendraExperienceConfigurationContentSourceConfigurationOutputReference__checks.go
- DataAwsKendraExperienceConfigurationList.go
- DataAwsKendraExperienceConfigurationList__checks.go
- DataAwsKendraExperienceConfigurationOutputReference.go
- DataAwsKendraExperienceConfigurationOutputReference__checks.go
- DataAwsKendraExperienceConfigurationUserIdentityConfiguration.go
- DataAwsKendraExperienceConfigurationUserIdentityConfigurationList.go
- DataAwsKendraExperienceConfigurationUserIdentityConfigurationList__checks.go
- DataAwsKendraExperienceConfigurationUserIdentityConfigurationOutputReference.go
- DataAwsKendraExperienceConfigurationUserIdentityConfigurationOutputReference__checks.go
- DataAwsKendraExperienceEndpoints.go
- DataAwsKendraExperienceEndpointsList.go
- DataAwsKendraExperienceEndpointsList__checks.go
- DataAwsKendraExperienceEndpointsOutputReference.go
- DataAwsKendraExperienceEndpointsOutputReference__checks.go
- DataAwsKendraExperience__checks.go
- main.go