Documentation
¶
Index ¶
- func DataAwsLakeformationPermissions_IsConstruct(x interface{}) *bool
- func DataAwsLakeformationPermissions_IsTerraformDataSource(x interface{}) *bool
- func DataAwsLakeformationPermissions_IsTerraformElement(x interface{}) *bool
- func DataAwsLakeformationPermissions_TfResourceType() *string
- func NewDataAwsLakeformationPermissionsDataLocationOutputReference_Override(d DataAwsLakeformationPermissionsDataLocationOutputReference, ...)
- func NewDataAwsLakeformationPermissionsDatabaseOutputReference_Override(d DataAwsLakeformationPermissionsDatabaseOutputReference, ...)
- func NewDataAwsLakeformationPermissionsLfTagOutputReference_Override(d DataAwsLakeformationPermissionsLfTagOutputReference, ...)
- func NewDataAwsLakeformationPermissionsLfTagPolicyExpressionList_Override(d DataAwsLakeformationPermissionsLfTagPolicyExpressionList, ...)
- func NewDataAwsLakeformationPermissionsLfTagPolicyExpressionOutputReference_Override(d DataAwsLakeformationPermissionsLfTagPolicyExpressionOutputReference, ...)
- func NewDataAwsLakeformationPermissionsLfTagPolicyOutputReference_Override(d DataAwsLakeformationPermissionsLfTagPolicyOutputReference, ...)
- func NewDataAwsLakeformationPermissionsTableOutputReference_Override(d DataAwsLakeformationPermissionsTableOutputReference, ...)
- func NewDataAwsLakeformationPermissionsTableWithColumnsOutputReference_Override(d DataAwsLakeformationPermissionsTableWithColumnsOutputReference, ...)
- func NewDataAwsLakeformationPermissions_Override(d DataAwsLakeformationPermissions, scope constructs.Construct, id *string, ...)
- type DataAwsLakeformationPermissions
- type DataAwsLakeformationPermissionsConfig
- type DataAwsLakeformationPermissionsDataLocation
- type DataAwsLakeformationPermissionsDataLocationOutputReference
- type DataAwsLakeformationPermissionsDatabase
- type DataAwsLakeformationPermissionsDatabaseOutputReference
- type DataAwsLakeformationPermissionsLfTag
- type DataAwsLakeformationPermissionsLfTagOutputReference
- type DataAwsLakeformationPermissionsLfTagPolicy
- type DataAwsLakeformationPermissionsLfTagPolicyExpression
- type DataAwsLakeformationPermissionsLfTagPolicyExpressionList
- type DataAwsLakeformationPermissionsLfTagPolicyExpressionOutputReference
- type DataAwsLakeformationPermissionsLfTagPolicyOutputReference
- type DataAwsLakeformationPermissionsTable
- type DataAwsLakeformationPermissionsTableOutputReference
- type DataAwsLakeformationPermissionsTableWithColumns
- type DataAwsLakeformationPermissionsTableWithColumnsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsLakeformationPermissions_IsConstruct ¶
func DataAwsLakeformationPermissions_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsLakeformationPermissions_IsTerraformDataSource ¶
func DataAwsLakeformationPermissions_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsLakeformationPermissions_IsTerraformElement ¶
func DataAwsLakeformationPermissions_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsLakeformationPermissions_TfResourceType ¶
func DataAwsLakeformationPermissions_TfResourceType() *string
func NewDataAwsLakeformationPermissionsDataLocationOutputReference_Override ¶
func NewDataAwsLakeformationPermissionsDataLocationOutputReference_Override(d DataAwsLakeformationPermissionsDataLocationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsLakeformationPermissionsDatabaseOutputReference_Override ¶
func NewDataAwsLakeformationPermissionsDatabaseOutputReference_Override(d DataAwsLakeformationPermissionsDatabaseOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsLakeformationPermissionsLfTagOutputReference_Override ¶
func NewDataAwsLakeformationPermissionsLfTagOutputReference_Override(d DataAwsLakeformationPermissionsLfTagOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsLakeformationPermissionsLfTagPolicyExpressionList_Override ¶
func NewDataAwsLakeformationPermissionsLfTagPolicyExpressionList_Override(d DataAwsLakeformationPermissionsLfTagPolicyExpressionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLakeformationPermissionsLfTagPolicyExpressionOutputReference_Override ¶
func NewDataAwsLakeformationPermissionsLfTagPolicyExpressionOutputReference_Override(d DataAwsLakeformationPermissionsLfTagPolicyExpressionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLakeformationPermissionsLfTagPolicyOutputReference_Override ¶
func NewDataAwsLakeformationPermissionsLfTagPolicyOutputReference_Override(d DataAwsLakeformationPermissionsLfTagPolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsLakeformationPermissionsTableOutputReference_Override ¶
func NewDataAwsLakeformationPermissionsTableOutputReference_Override(d DataAwsLakeformationPermissionsTableOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsLakeformationPermissionsTableWithColumnsOutputReference_Override ¶
func NewDataAwsLakeformationPermissionsTableWithColumnsOutputReference_Override(d DataAwsLakeformationPermissionsTableWithColumnsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsLakeformationPermissions_Override ¶
func NewDataAwsLakeformationPermissions_Override(d DataAwsLakeformationPermissions, scope constructs.Construct, id *string, config *DataAwsLakeformationPermissionsConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions aws_lakeformation_permissions} Data Source.
Types ¶
type DataAwsLakeformationPermissions ¶
type DataAwsLakeformationPermissions interface {
cdktf.TerraformDataSource
CatalogId() *string
SetCatalogId(val *string)
CatalogIdInput() *string
CatalogResource() interface{}
SetCatalogResource(val interface{})
CatalogResourceInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
Database() DataAwsLakeformationPermissionsDatabaseOutputReference
DatabaseInput() *DataAwsLakeformationPermissionsDatabase
DataLocation() DataAwsLakeformationPermissionsDataLocationOutputReference
DataLocationInput() *DataAwsLakeformationPermissionsDataLocation
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
LfTag() DataAwsLakeformationPermissionsLfTagOutputReference
LfTagInput() *DataAwsLakeformationPermissionsLfTag
LfTagPolicy() DataAwsLakeformationPermissionsLfTagPolicyOutputReference
LfTagPolicyInput() *DataAwsLakeformationPermissionsLfTagPolicy
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
Permissions() *[]*string
PermissionsWithGrantOption() *[]*string
Principal() *string
SetPrincipal(val *string)
PrincipalInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Table() DataAwsLakeformationPermissionsTableOutputReference
TableInput() *DataAwsLakeformationPermissionsTable
TableWithColumns() DataAwsLakeformationPermissionsTableWithColumnsOutputReference
TableWithColumnsInput() *DataAwsLakeformationPermissionsTableWithColumns
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDatabase(value *DataAwsLakeformationPermissionsDatabase)
PutDataLocation(value *DataAwsLakeformationPermissionsDataLocation)
PutLfTag(value *DataAwsLakeformationPermissionsLfTag)
PutLfTagPolicy(value *DataAwsLakeformationPermissionsLfTagPolicy)
PutTable(value *DataAwsLakeformationPermissionsTable)
PutTableWithColumns(value *DataAwsLakeformationPermissionsTableWithColumns)
ResetCatalogId()
ResetCatalogResource()
ResetDatabase()
ResetDataLocation()
ResetId()
ResetLfTag()
ResetLfTagPolicy()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTable()
ResetTableWithColumns()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions aws_lakeformation_permissions}.
func NewDataAwsLakeformationPermissions ¶
func NewDataAwsLakeformationPermissions(scope constructs.Construct, id *string, config *DataAwsLakeformationPermissionsConfig) DataAwsLakeformationPermissions
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions aws_lakeformation_permissions} Data Source.
type DataAwsLakeformationPermissionsConfig ¶
type DataAwsLakeformationPermissionsConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#principal DataAwsLakeformationPermissions#principal}.
Principal *string `field:"required" json:"principal" yaml:"principal"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#catalog_id DataAwsLakeformationPermissions#catalog_id}.
CatalogId *string `field:"optional" json:"catalogId" yaml:"catalogId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#catalog_resource DataAwsLakeformationPermissions#catalog_resource}.
CatalogResource interface{} `field:"optional" json:"catalogResource" yaml:"catalogResource"`
// database block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#database DataAwsLakeformationPermissions#database}
Database *DataAwsLakeformationPermissionsDatabase `field:"optional" json:"database" yaml:"database"`
// data_location block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#data_location DataAwsLakeformationPermissions#data_location}
DataLocation *DataAwsLakeformationPermissionsDataLocation `field:"optional" json:"dataLocation" yaml:"dataLocation"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#id DataAwsLakeformationPermissions#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// lf_tag block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#lf_tag DataAwsLakeformationPermissions#lf_tag}
LfTag *DataAwsLakeformationPermissionsLfTag `field:"optional" json:"lfTag" yaml:"lfTag"`
// lf_tag_policy block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#lf_tag_policy DataAwsLakeformationPermissions#lf_tag_policy}
LfTagPolicy *DataAwsLakeformationPermissionsLfTagPolicy `field:"optional" json:"lfTagPolicy" yaml:"lfTagPolicy"`
// table block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#table DataAwsLakeformationPermissions#table}
Table *DataAwsLakeformationPermissionsTable `field:"optional" json:"table" yaml:"table"`
// table_with_columns block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#table_with_columns DataAwsLakeformationPermissions#table_with_columns}
TableWithColumns *DataAwsLakeformationPermissionsTableWithColumns `field:"optional" json:"tableWithColumns" yaml:"tableWithColumns"`
}
type DataAwsLakeformationPermissionsDataLocation ¶
type DataAwsLakeformationPermissionsDataLocation struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#arn DataAwsLakeformationPermissions#arn}.
Arn *string `field:"required" json:"arn" yaml:"arn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#catalog_id DataAwsLakeformationPermissions#catalog_id}.
CatalogId *string `field:"optional" json:"catalogId" yaml:"catalogId"`
}
type DataAwsLakeformationPermissionsDataLocationOutputReference ¶
type DataAwsLakeformationPermissionsDataLocationOutputReference interface {
cdktf.ComplexObject
Arn() *string
SetArn(val *string)
ArnInput() *string
CatalogId() *string
SetCatalogId(val *string)
CatalogIdInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLakeformationPermissionsDataLocation
SetInternalValue(val *DataAwsLakeformationPermissionsDataLocation)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCatalogId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLakeformationPermissionsDataLocationOutputReference ¶
func NewDataAwsLakeformationPermissionsDataLocationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsLakeformationPermissionsDataLocationOutputReference
type DataAwsLakeformationPermissionsDatabase ¶
type DataAwsLakeformationPermissionsDatabase struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#name DataAwsLakeformationPermissions#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#catalog_id DataAwsLakeformationPermissions#catalog_id}.
CatalogId *string `field:"optional" json:"catalogId" yaml:"catalogId"`
}
type DataAwsLakeformationPermissionsDatabaseOutputReference ¶
type DataAwsLakeformationPermissionsDatabaseOutputReference interface {
cdktf.ComplexObject
CatalogId() *string
SetCatalogId(val *string)
CatalogIdInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLakeformationPermissionsDatabase
SetInternalValue(val *DataAwsLakeformationPermissionsDatabase)
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCatalogId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLakeformationPermissionsDatabaseOutputReference ¶
func NewDataAwsLakeformationPermissionsDatabaseOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsLakeformationPermissionsDatabaseOutputReference
type DataAwsLakeformationPermissionsLfTag ¶
type DataAwsLakeformationPermissionsLfTag struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#key DataAwsLakeformationPermissions#key}.
Key *string `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#values DataAwsLakeformationPermissions#values}.
Values *[]*string `field:"required" json:"values" yaml:"values"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#catalog_id DataAwsLakeformationPermissions#catalog_id}.
CatalogId *string `field:"optional" json:"catalogId" yaml:"catalogId"`
}
type DataAwsLakeformationPermissionsLfTagOutputReference ¶
type DataAwsLakeformationPermissionsLfTagOutputReference interface {
cdktf.ComplexObject
CatalogId() *string
SetCatalogId(val *string)
CatalogIdInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLakeformationPermissionsLfTag
SetInternalValue(val *DataAwsLakeformationPermissionsLfTag)
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
SetValues(val *[]*string)
ValuesInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCatalogId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLakeformationPermissionsLfTagOutputReference ¶
func NewDataAwsLakeformationPermissionsLfTagOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsLakeformationPermissionsLfTagOutputReference
type DataAwsLakeformationPermissionsLfTagPolicy ¶
type DataAwsLakeformationPermissionsLfTagPolicy struct {
// expression block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#expression DataAwsLakeformationPermissions#expression}
Expression interface{} `field:"required" json:"expression" yaml:"expression"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#resource_type DataAwsLakeformationPermissions#resource_type}.
ResourceType *string `field:"required" json:"resourceType" yaml:"resourceType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#catalog_id DataAwsLakeformationPermissions#catalog_id}.
CatalogId *string `field:"optional" json:"catalogId" yaml:"catalogId"`
}
type DataAwsLakeformationPermissionsLfTagPolicyExpression ¶
type DataAwsLakeformationPermissionsLfTagPolicyExpression struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#key DataAwsLakeformationPermissions#key}.
Key *string `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#values DataAwsLakeformationPermissions#values}.
Values *[]*string `field:"required" json:"values" yaml:"values"`
}
type DataAwsLakeformationPermissionsLfTagPolicyExpressionList ¶
type DataAwsLakeformationPermissionsLfTagPolicyExpressionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLakeformationPermissionsLfTagPolicyExpressionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLakeformationPermissionsLfTagPolicyExpressionList ¶
func NewDataAwsLakeformationPermissionsLfTagPolicyExpressionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLakeformationPermissionsLfTagPolicyExpressionList
type DataAwsLakeformationPermissionsLfTagPolicyExpressionOutputReference ¶
type DataAwsLakeformationPermissionsLfTagPolicyExpressionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
SetValues(val *[]*string)
ValuesInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLakeformationPermissionsLfTagPolicyExpressionOutputReference ¶
func NewDataAwsLakeformationPermissionsLfTagPolicyExpressionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLakeformationPermissionsLfTagPolicyExpressionOutputReference
type DataAwsLakeformationPermissionsLfTagPolicyOutputReference ¶
type DataAwsLakeformationPermissionsLfTagPolicyOutputReference interface {
cdktf.ComplexObject
CatalogId() *string
SetCatalogId(val *string)
CatalogIdInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Expression() DataAwsLakeformationPermissionsLfTagPolicyExpressionList
ExpressionInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *DataAwsLakeformationPermissionsLfTagPolicy
SetInternalValue(val *DataAwsLakeformationPermissionsLfTagPolicy)
ResourceType() *string
SetResourceType(val *string)
ResourceTypeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutExpression(value interface{})
ResetCatalogId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLakeformationPermissionsLfTagPolicyOutputReference ¶
func NewDataAwsLakeformationPermissionsLfTagPolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsLakeformationPermissionsLfTagPolicyOutputReference
type DataAwsLakeformationPermissionsTable ¶
type DataAwsLakeformationPermissionsTable struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#database_name DataAwsLakeformationPermissions#database_name}.
DatabaseName *string `field:"required" json:"databaseName" yaml:"databaseName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#catalog_id DataAwsLakeformationPermissions#catalog_id}.
CatalogId *string `field:"optional" json:"catalogId" yaml:"catalogId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#name DataAwsLakeformationPermissions#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#wildcard DataAwsLakeformationPermissions#wildcard}.
Wildcard interface{} `field:"optional" json:"wildcard" yaml:"wildcard"`
}
type DataAwsLakeformationPermissionsTableOutputReference ¶
type DataAwsLakeformationPermissionsTableOutputReference interface {
cdktf.ComplexObject
CatalogId() *string
SetCatalogId(val *string)
CatalogIdInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DatabaseName() *string
SetDatabaseName(val *string)
DatabaseNameInput() *string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLakeformationPermissionsTable
SetInternalValue(val *DataAwsLakeformationPermissionsTable)
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Wildcard() interface{}
SetWildcard(val interface{})
WildcardInput() interface{}
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCatalogId()
ResetName()
ResetWildcard()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLakeformationPermissionsTableOutputReference ¶
func NewDataAwsLakeformationPermissionsTableOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsLakeformationPermissionsTableOutputReference
type DataAwsLakeformationPermissionsTableWithColumns ¶
type DataAwsLakeformationPermissionsTableWithColumns struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#database_name DataAwsLakeformationPermissions#database_name}.
DatabaseName *string `field:"required" json:"databaseName" yaml:"databaseName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#name DataAwsLakeformationPermissions#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#catalog_id DataAwsLakeformationPermissions#catalog_id}.
CatalogId *string `field:"optional" json:"catalogId" yaml:"catalogId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#column_names DataAwsLakeformationPermissions#column_names}.
ColumnNames *[]*string `field:"optional" json:"columnNames" yaml:"columnNames"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#excluded_column_names DataAwsLakeformationPermissions#excluded_column_names}.
ExcludedColumnNames *[]*string `field:"optional" json:"excludedColumnNames" yaml:"excludedColumnNames"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lakeformation_permissions#wildcard DataAwsLakeformationPermissions#wildcard}.
Wildcard interface{} `field:"optional" json:"wildcard" yaml:"wildcard"`
}
type DataAwsLakeformationPermissionsTableWithColumnsOutputReference ¶
type DataAwsLakeformationPermissionsTableWithColumnsOutputReference interface {
cdktf.ComplexObject
CatalogId() *string
SetCatalogId(val *string)
CatalogIdInput() *string
ColumnNames() *[]*string
SetColumnNames(val *[]*string)
ColumnNamesInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DatabaseName() *string
SetDatabaseName(val *string)
DatabaseNameInput() *string
ExcludedColumnNames() *[]*string
SetExcludedColumnNames(val *[]*string)
ExcludedColumnNamesInput() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLakeformationPermissionsTableWithColumns
SetInternalValue(val *DataAwsLakeformationPermissionsTableWithColumns)
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Wildcard() interface{}
SetWildcard(val interface{})
WildcardInput() interface{}
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCatalogId()
ResetColumnNames()
ResetExcludedColumnNames()
ResetWildcard()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLakeformationPermissionsTableWithColumnsOutputReference ¶
func NewDataAwsLakeformationPermissionsTableWithColumnsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsLakeformationPermissionsTableWithColumnsOutputReference
Source Files
¶
- DataAwsLakeformationPermissions.go
- DataAwsLakeformationPermissionsConfig.go
- DataAwsLakeformationPermissionsDataLocation.go
- DataAwsLakeformationPermissionsDataLocationOutputReference.go
- DataAwsLakeformationPermissionsDataLocationOutputReference__checks.go
- DataAwsLakeformationPermissionsDatabase.go
- DataAwsLakeformationPermissionsDatabaseOutputReference.go
- DataAwsLakeformationPermissionsDatabaseOutputReference__checks.go
- DataAwsLakeformationPermissionsLfTag.go
- DataAwsLakeformationPermissionsLfTagOutputReference.go
- DataAwsLakeformationPermissionsLfTagOutputReference__checks.go
- DataAwsLakeformationPermissionsLfTagPolicy.go
- DataAwsLakeformationPermissionsLfTagPolicyExpression.go
- DataAwsLakeformationPermissionsLfTagPolicyExpressionList.go
- DataAwsLakeformationPermissionsLfTagPolicyExpressionList__checks.go
- DataAwsLakeformationPermissionsLfTagPolicyExpressionOutputReference.go
- DataAwsLakeformationPermissionsLfTagPolicyExpressionOutputReference__checks.go
- DataAwsLakeformationPermissionsLfTagPolicyOutputReference.go
- DataAwsLakeformationPermissionsLfTagPolicyOutputReference__checks.go
- DataAwsLakeformationPermissionsTable.go
- DataAwsLakeformationPermissionsTableOutputReference.go
- DataAwsLakeformationPermissionsTableOutputReference__checks.go
- DataAwsLakeformationPermissionsTableWithColumns.go
- DataAwsLakeformationPermissionsTableWithColumnsOutputReference.go
- DataAwsLakeformationPermissionsTableWithColumnsOutputReference__checks.go
- DataAwsLakeformationPermissions__checks.go
- main.go