Documentation
¶
Index ¶
- func DataAwsLambdaFunction_IsConstruct(x interface{}) *bool
- func DataAwsLambdaFunction_IsTerraformDataSource(x interface{}) *bool
- func DataAwsLambdaFunction_IsTerraformElement(x interface{}) *bool
- func DataAwsLambdaFunction_TfResourceType() *string
- func NewDataAwsLambdaFunctionDeadLetterConfigList_Override(d DataAwsLambdaFunctionDeadLetterConfigList, ...)
- func NewDataAwsLambdaFunctionDeadLetterConfigOutputReference_Override(d DataAwsLambdaFunctionDeadLetterConfigOutputReference, ...)
- func NewDataAwsLambdaFunctionEnvironmentList_Override(d DataAwsLambdaFunctionEnvironmentList, ...)
- func NewDataAwsLambdaFunctionEnvironmentOutputReference_Override(d DataAwsLambdaFunctionEnvironmentOutputReference, ...)
- func NewDataAwsLambdaFunctionEphemeralStorageList_Override(d DataAwsLambdaFunctionEphemeralStorageList, ...)
- func NewDataAwsLambdaFunctionEphemeralStorageOutputReference_Override(d DataAwsLambdaFunctionEphemeralStorageOutputReference, ...)
- func NewDataAwsLambdaFunctionFileSystemConfigList_Override(d DataAwsLambdaFunctionFileSystemConfigList, ...)
- func NewDataAwsLambdaFunctionFileSystemConfigOutputReference_Override(d DataAwsLambdaFunctionFileSystemConfigOutputReference, ...)
- func NewDataAwsLambdaFunctionTracingConfigList_Override(d DataAwsLambdaFunctionTracingConfigList, ...)
- func NewDataAwsLambdaFunctionTracingConfigOutputReference_Override(d DataAwsLambdaFunctionTracingConfigOutputReference, ...)
- func NewDataAwsLambdaFunctionVpcConfigList_Override(d DataAwsLambdaFunctionVpcConfigList, ...)
- func NewDataAwsLambdaFunctionVpcConfigOutputReference_Override(d DataAwsLambdaFunctionVpcConfigOutputReference, ...)
- func NewDataAwsLambdaFunction_Override(d DataAwsLambdaFunction, scope constructs.Construct, id *string, ...)
- type DataAwsLambdaFunction
- type DataAwsLambdaFunctionConfig
- type DataAwsLambdaFunctionDeadLetterConfig
- type DataAwsLambdaFunctionDeadLetterConfigList
- type DataAwsLambdaFunctionDeadLetterConfigOutputReference
- type DataAwsLambdaFunctionEnvironment
- type DataAwsLambdaFunctionEnvironmentList
- type DataAwsLambdaFunctionEnvironmentOutputReference
- type DataAwsLambdaFunctionEphemeralStorage
- type DataAwsLambdaFunctionEphemeralStorageList
- type DataAwsLambdaFunctionEphemeralStorageOutputReference
- type DataAwsLambdaFunctionFileSystemConfig
- type DataAwsLambdaFunctionFileSystemConfigList
- type DataAwsLambdaFunctionFileSystemConfigOutputReference
- type DataAwsLambdaFunctionTracingConfig
- type DataAwsLambdaFunctionTracingConfigList
- type DataAwsLambdaFunctionTracingConfigOutputReference
- type DataAwsLambdaFunctionVpcConfig
- type DataAwsLambdaFunctionVpcConfigList
- type DataAwsLambdaFunctionVpcConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsLambdaFunction_IsConstruct ¶
func DataAwsLambdaFunction_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsLambdaFunction_IsTerraformDataSource ¶
func DataAwsLambdaFunction_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsLambdaFunction_IsTerraformElement ¶
func DataAwsLambdaFunction_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsLambdaFunction_TfResourceType ¶
func DataAwsLambdaFunction_TfResourceType() *string
func NewDataAwsLambdaFunctionDeadLetterConfigList_Override ¶
func NewDataAwsLambdaFunctionDeadLetterConfigList_Override(d DataAwsLambdaFunctionDeadLetterConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLambdaFunctionDeadLetterConfigOutputReference_Override ¶
func NewDataAwsLambdaFunctionDeadLetterConfigOutputReference_Override(d DataAwsLambdaFunctionDeadLetterConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLambdaFunctionEnvironmentList_Override ¶
func NewDataAwsLambdaFunctionEnvironmentList_Override(d DataAwsLambdaFunctionEnvironmentList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLambdaFunctionEnvironmentOutputReference_Override ¶
func NewDataAwsLambdaFunctionEnvironmentOutputReference_Override(d DataAwsLambdaFunctionEnvironmentOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLambdaFunctionEphemeralStorageList_Override ¶
func NewDataAwsLambdaFunctionEphemeralStorageList_Override(d DataAwsLambdaFunctionEphemeralStorageList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLambdaFunctionEphemeralStorageOutputReference_Override ¶
func NewDataAwsLambdaFunctionEphemeralStorageOutputReference_Override(d DataAwsLambdaFunctionEphemeralStorageOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLambdaFunctionFileSystemConfigList_Override ¶
func NewDataAwsLambdaFunctionFileSystemConfigList_Override(d DataAwsLambdaFunctionFileSystemConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLambdaFunctionFileSystemConfigOutputReference_Override ¶
func NewDataAwsLambdaFunctionFileSystemConfigOutputReference_Override(d DataAwsLambdaFunctionFileSystemConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLambdaFunctionTracingConfigList_Override ¶
func NewDataAwsLambdaFunctionTracingConfigList_Override(d DataAwsLambdaFunctionTracingConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLambdaFunctionTracingConfigOutputReference_Override ¶
func NewDataAwsLambdaFunctionTracingConfigOutputReference_Override(d DataAwsLambdaFunctionTracingConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLambdaFunctionVpcConfigList_Override ¶
func NewDataAwsLambdaFunctionVpcConfigList_Override(d DataAwsLambdaFunctionVpcConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLambdaFunctionVpcConfigOutputReference_Override ¶
func NewDataAwsLambdaFunctionVpcConfigOutputReference_Override(d DataAwsLambdaFunctionVpcConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLambdaFunction_Override ¶
func NewDataAwsLambdaFunction_Override(d DataAwsLambdaFunction, scope constructs.Construct, id *string, config *DataAwsLambdaFunctionConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lambda_function aws_lambda_function} Data Source.
Types ¶
type DataAwsLambdaFunction ¶
type DataAwsLambdaFunction interface {
cdktf.TerraformDataSource
Architectures() *[]*string
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CodeSigningConfigArn() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DeadLetterConfig() DataAwsLambdaFunctionDeadLetterConfigList
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
Environment() DataAwsLambdaFunctionEnvironmentList
EphemeralStorage() DataAwsLambdaFunctionEphemeralStorageList
FileSystemConfig() DataAwsLambdaFunctionFileSystemConfigList
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
FunctionName() *string
SetFunctionName(val *string)
FunctionNameInput() *string
Handler() *string
Id() *string
SetId(val *string)
IdInput() *string
ImageUri() *string
InvokeArn() *string
KmsKeyArn() *string
LastModified() *string
Layers() *[]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MemorySize() *float64
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
QualifiedArn() *string
QualifiedInvokeArn() *string
Qualifier() *string
SetQualifier(val *string)
QualifierInput() *string
// Experimental.
RawOverrides() interface{}
ReservedConcurrentExecutions() *float64
Role() *string
Runtime() *string
SigningJobArn() *string
SigningProfileVersionArn() *string
SourceCodeHash() *string
SourceCodeSize() *float64
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeout() *float64
TracingConfig() DataAwsLambdaFunctionTracingConfigList
Version() *string
VpcConfig() DataAwsLambdaFunctionVpcConfigList
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetQualifier()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lambda_function aws_lambda_function}.
func NewDataAwsLambdaFunction ¶
func NewDataAwsLambdaFunction(scope constructs.Construct, id *string, config *DataAwsLambdaFunctionConfig) DataAwsLambdaFunction
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lambda_function aws_lambda_function} Data Source.
type DataAwsLambdaFunctionConfig ¶
type DataAwsLambdaFunctionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lambda_function#function_name DataAwsLambdaFunction#function_name}.
FunctionName *string `field:"required" json:"functionName" yaml:"functionName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lambda_function#id DataAwsLambdaFunction#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lambda_function#qualifier DataAwsLambdaFunction#qualifier}.
Qualifier *string `field:"optional" json:"qualifier" yaml:"qualifier"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lambda_function#tags DataAwsLambdaFunction#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsLambdaFunctionDeadLetterConfig ¶
type DataAwsLambdaFunctionDeadLetterConfig struct {
}
type DataAwsLambdaFunctionDeadLetterConfigList ¶
type DataAwsLambdaFunctionDeadLetterConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLambdaFunctionDeadLetterConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLambdaFunctionDeadLetterConfigList ¶
func NewDataAwsLambdaFunctionDeadLetterConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLambdaFunctionDeadLetterConfigList
type DataAwsLambdaFunctionDeadLetterConfigOutputReference ¶
type DataAwsLambdaFunctionDeadLetterConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLambdaFunctionDeadLetterConfig
SetInternalValue(val *DataAwsLambdaFunctionDeadLetterConfig)
TargetArn() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLambdaFunctionDeadLetterConfigOutputReference ¶
func NewDataAwsLambdaFunctionDeadLetterConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLambdaFunctionDeadLetterConfigOutputReference
type DataAwsLambdaFunctionEnvironment ¶
type DataAwsLambdaFunctionEnvironment struct {
}
type DataAwsLambdaFunctionEnvironmentList ¶
type DataAwsLambdaFunctionEnvironmentList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLambdaFunctionEnvironmentOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLambdaFunctionEnvironmentList ¶
func NewDataAwsLambdaFunctionEnvironmentList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLambdaFunctionEnvironmentList
type DataAwsLambdaFunctionEnvironmentOutputReference ¶
type DataAwsLambdaFunctionEnvironmentOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLambdaFunctionEnvironment
SetInternalValue(val *DataAwsLambdaFunctionEnvironment)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Variables() cdktf.StringMap
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLambdaFunctionEnvironmentOutputReference ¶
func NewDataAwsLambdaFunctionEnvironmentOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLambdaFunctionEnvironmentOutputReference
type DataAwsLambdaFunctionEphemeralStorage ¶
type DataAwsLambdaFunctionEphemeralStorage struct {
}
type DataAwsLambdaFunctionEphemeralStorageList ¶
type DataAwsLambdaFunctionEphemeralStorageList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLambdaFunctionEphemeralStorageOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLambdaFunctionEphemeralStorageList ¶
func NewDataAwsLambdaFunctionEphemeralStorageList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLambdaFunctionEphemeralStorageList
type DataAwsLambdaFunctionEphemeralStorageOutputReference ¶
type DataAwsLambdaFunctionEphemeralStorageOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLambdaFunctionEphemeralStorage
SetInternalValue(val *DataAwsLambdaFunctionEphemeralStorage)
Size() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLambdaFunctionEphemeralStorageOutputReference ¶
func NewDataAwsLambdaFunctionEphemeralStorageOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLambdaFunctionEphemeralStorageOutputReference
type DataAwsLambdaFunctionFileSystemConfig ¶
type DataAwsLambdaFunctionFileSystemConfig struct {
}
type DataAwsLambdaFunctionFileSystemConfigList ¶
type DataAwsLambdaFunctionFileSystemConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLambdaFunctionFileSystemConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLambdaFunctionFileSystemConfigList ¶
func NewDataAwsLambdaFunctionFileSystemConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLambdaFunctionFileSystemConfigList
type DataAwsLambdaFunctionFileSystemConfigOutputReference ¶
type DataAwsLambdaFunctionFileSystemConfigOutputReference interface {
cdktf.ComplexObject
Arn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLambdaFunctionFileSystemConfig
SetInternalValue(val *DataAwsLambdaFunctionFileSystemConfig)
LocalMountPath() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLambdaFunctionFileSystemConfigOutputReference ¶
func NewDataAwsLambdaFunctionFileSystemConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLambdaFunctionFileSystemConfigOutputReference
type DataAwsLambdaFunctionTracingConfig ¶
type DataAwsLambdaFunctionTracingConfig struct {
}
type DataAwsLambdaFunctionTracingConfigList ¶
type DataAwsLambdaFunctionTracingConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLambdaFunctionTracingConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLambdaFunctionTracingConfigList ¶
func NewDataAwsLambdaFunctionTracingConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLambdaFunctionTracingConfigList
type DataAwsLambdaFunctionTracingConfigOutputReference ¶
type DataAwsLambdaFunctionTracingConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLambdaFunctionTracingConfig
SetInternalValue(val *DataAwsLambdaFunctionTracingConfig)
Mode() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLambdaFunctionTracingConfigOutputReference ¶
func NewDataAwsLambdaFunctionTracingConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLambdaFunctionTracingConfigOutputReference
type DataAwsLambdaFunctionVpcConfig ¶
type DataAwsLambdaFunctionVpcConfig struct {
}
type DataAwsLambdaFunctionVpcConfigList ¶
type DataAwsLambdaFunctionVpcConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLambdaFunctionVpcConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLambdaFunctionVpcConfigList ¶
func NewDataAwsLambdaFunctionVpcConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLambdaFunctionVpcConfigList
type DataAwsLambdaFunctionVpcConfigOutputReference ¶
type DataAwsLambdaFunctionVpcConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLambdaFunctionVpcConfig
SetInternalValue(val *DataAwsLambdaFunctionVpcConfig)
SecurityGroupIds() *[]*string
SubnetIds() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VpcId() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLambdaFunctionVpcConfigOutputReference ¶
func NewDataAwsLambdaFunctionVpcConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLambdaFunctionVpcConfigOutputReference
Source Files
¶
- DataAwsLambdaFunction.go
- DataAwsLambdaFunctionConfig.go
- DataAwsLambdaFunctionDeadLetterConfig.go
- DataAwsLambdaFunctionDeadLetterConfigList.go
- DataAwsLambdaFunctionDeadLetterConfigList__checks.go
- DataAwsLambdaFunctionDeadLetterConfigOutputReference.go
- DataAwsLambdaFunctionDeadLetterConfigOutputReference__checks.go
- DataAwsLambdaFunctionEnvironment.go
- DataAwsLambdaFunctionEnvironmentList.go
- DataAwsLambdaFunctionEnvironmentList__checks.go
- DataAwsLambdaFunctionEnvironmentOutputReference.go
- DataAwsLambdaFunctionEnvironmentOutputReference__checks.go
- DataAwsLambdaFunctionEphemeralStorage.go
- DataAwsLambdaFunctionEphemeralStorageList.go
- DataAwsLambdaFunctionEphemeralStorageList__checks.go
- DataAwsLambdaFunctionEphemeralStorageOutputReference.go
- DataAwsLambdaFunctionEphemeralStorageOutputReference__checks.go
- DataAwsLambdaFunctionFileSystemConfig.go
- DataAwsLambdaFunctionFileSystemConfigList.go
- DataAwsLambdaFunctionFileSystemConfigList__checks.go
- DataAwsLambdaFunctionFileSystemConfigOutputReference.go
- DataAwsLambdaFunctionFileSystemConfigOutputReference__checks.go
- DataAwsLambdaFunctionTracingConfig.go
- DataAwsLambdaFunctionTracingConfigList.go
- DataAwsLambdaFunctionTracingConfigList__checks.go
- DataAwsLambdaFunctionTracingConfigOutputReference.go
- DataAwsLambdaFunctionTracingConfigOutputReference__checks.go
- DataAwsLambdaFunctionVpcConfig.go
- DataAwsLambdaFunctionVpcConfigList.go
- DataAwsLambdaFunctionVpcConfigList__checks.go
- DataAwsLambdaFunctionVpcConfigOutputReference.go
- DataAwsLambdaFunctionVpcConfigOutputReference__checks.go
- DataAwsLambdaFunction__checks.go
- main.go