Documentation
¶
Index ¶
- func DataAwsLambdaFunctionUrl_IsConstruct(x interface{}) *bool
- func DataAwsLambdaFunctionUrl_IsTerraformDataSource(x interface{}) *bool
- func DataAwsLambdaFunctionUrl_IsTerraformElement(x interface{}) *bool
- func DataAwsLambdaFunctionUrl_TfResourceType() *string
- func NewDataAwsLambdaFunctionUrlCorsList_Override(d DataAwsLambdaFunctionUrlCorsList, ...)
- func NewDataAwsLambdaFunctionUrlCorsOutputReference_Override(d DataAwsLambdaFunctionUrlCorsOutputReference, ...)
- func NewDataAwsLambdaFunctionUrl_Override(d DataAwsLambdaFunctionUrl, scope constructs.Construct, id *string, ...)
- type DataAwsLambdaFunctionUrl
- type DataAwsLambdaFunctionUrlConfig
- type DataAwsLambdaFunctionUrlCors
- type DataAwsLambdaFunctionUrlCorsList
- type DataAwsLambdaFunctionUrlCorsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsLambdaFunctionUrl_IsConstruct ¶
func DataAwsLambdaFunctionUrl_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsLambdaFunctionUrl_IsTerraformDataSource ¶
func DataAwsLambdaFunctionUrl_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsLambdaFunctionUrl_IsTerraformElement ¶
func DataAwsLambdaFunctionUrl_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsLambdaFunctionUrl_TfResourceType ¶
func DataAwsLambdaFunctionUrl_TfResourceType() *string
func NewDataAwsLambdaFunctionUrlCorsList_Override ¶
func NewDataAwsLambdaFunctionUrlCorsList_Override(d DataAwsLambdaFunctionUrlCorsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLambdaFunctionUrlCorsOutputReference_Override ¶
func NewDataAwsLambdaFunctionUrlCorsOutputReference_Override(d DataAwsLambdaFunctionUrlCorsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLambdaFunctionUrl_Override ¶
func NewDataAwsLambdaFunctionUrl_Override(d DataAwsLambdaFunctionUrl, scope constructs.Construct, id *string, config *DataAwsLambdaFunctionUrlConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lambda_function_url aws_lambda_function_url} Data Source.
Types ¶
type DataAwsLambdaFunctionUrl ¶
type DataAwsLambdaFunctionUrl interface {
cdktf.TerraformDataSource
AuthorizationType() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
Cors() DataAwsLambdaFunctionUrlCorsList
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreationTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
FunctionArn() *string
FunctionName() *string
SetFunctionName(val *string)
FunctionNameInput() *string
FunctionUrl() *string
Id() *string
SetId(val *string)
IdInput() *string
InvokeMode() *string
LastModifiedTime() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
Qualifier() *string
SetQualifier(val *string)
QualifierInput() *string
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
UrlId() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetQualifier()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lambda_function_url aws_lambda_function_url}.
func NewDataAwsLambdaFunctionUrl ¶
func NewDataAwsLambdaFunctionUrl(scope constructs.Construct, id *string, config *DataAwsLambdaFunctionUrlConfig) DataAwsLambdaFunctionUrl
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lambda_function_url aws_lambda_function_url} Data Source.
type DataAwsLambdaFunctionUrlConfig ¶
type DataAwsLambdaFunctionUrlConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lambda_function_url#function_name DataAwsLambdaFunctionUrl#function_name}.
FunctionName *string `field:"required" json:"functionName" yaml:"functionName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lambda_function_url#id DataAwsLambdaFunctionUrl#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/lambda_function_url#qualifier DataAwsLambdaFunctionUrl#qualifier}.
Qualifier *string `field:"optional" json:"qualifier" yaml:"qualifier"`
}
type DataAwsLambdaFunctionUrlCors ¶
type DataAwsLambdaFunctionUrlCors struct {
}
type DataAwsLambdaFunctionUrlCorsList ¶
type DataAwsLambdaFunctionUrlCorsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLambdaFunctionUrlCorsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLambdaFunctionUrlCorsList ¶
func NewDataAwsLambdaFunctionUrlCorsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLambdaFunctionUrlCorsList
type DataAwsLambdaFunctionUrlCorsOutputReference ¶
type DataAwsLambdaFunctionUrlCorsOutputReference interface {
cdktf.ComplexObject
AllowCredentials() cdktf.IResolvable
AllowHeaders() *[]*string
AllowMethods() *[]*string
AllowOrigins() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
ExposeHeaders() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLambdaFunctionUrlCors
SetInternalValue(val *DataAwsLambdaFunctionUrlCors)
MaxAge() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLambdaFunctionUrlCorsOutputReference ¶
func NewDataAwsLambdaFunctionUrlCorsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLambdaFunctionUrlCorsOutputReference
Source Files
¶
- DataAwsLambdaFunctionUrl.go
- DataAwsLambdaFunctionUrlConfig.go
- DataAwsLambdaFunctionUrlCors.go
- DataAwsLambdaFunctionUrlCorsList.go
- DataAwsLambdaFunctionUrlCorsList__checks.go
- DataAwsLambdaFunctionUrlCorsOutputReference.go
- DataAwsLambdaFunctionUrlCorsOutputReference__checks.go
- DataAwsLambdaFunctionUrl__checks.go
- main.go