Documentation
¶
Index ¶
- func DataAwsLicensemanagerReceivedLicense_IsConstruct(x interface{}) *bool
- func DataAwsLicensemanagerReceivedLicense_IsTerraformDataSource(x interface{}) *bool
- func DataAwsLicensemanagerReceivedLicense_IsTerraformElement(x interface{}) *bool
- func DataAwsLicensemanagerReceivedLicense_TfResourceType() *string
- func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationList_Override(...)
- func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationOutputReference_Override(...)
- func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationList_Override(d DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationList, ...)
- func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationOutputReference_Override(d DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationOutputReference, ...)
- func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationList_Override(...)
- func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationOutputReference_Override(...)
- func NewDataAwsLicensemanagerReceivedLicenseEntitlementsList_Override(d DataAwsLicensemanagerReceivedLicenseEntitlementsList, ...)
- func NewDataAwsLicensemanagerReceivedLicenseEntitlementsOutputReference_Override(d DataAwsLicensemanagerReceivedLicenseEntitlementsOutputReference, ...)
- func NewDataAwsLicensemanagerReceivedLicenseIssuerList_Override(d DataAwsLicensemanagerReceivedLicenseIssuerList, ...)
- func NewDataAwsLicensemanagerReceivedLicenseIssuerOutputReference_Override(d DataAwsLicensemanagerReceivedLicenseIssuerOutputReference, ...)
- func NewDataAwsLicensemanagerReceivedLicenseLicenseMetadataList_Override(d DataAwsLicensemanagerReceivedLicenseLicenseMetadataList, ...)
- func NewDataAwsLicensemanagerReceivedLicenseLicenseMetadataOutputReference_Override(d DataAwsLicensemanagerReceivedLicenseLicenseMetadataOutputReference, ...)
- func NewDataAwsLicensemanagerReceivedLicenseReceivedMetadataList_Override(d DataAwsLicensemanagerReceivedLicenseReceivedMetadataList, ...)
- func NewDataAwsLicensemanagerReceivedLicenseReceivedMetadataOutputReference_Override(d DataAwsLicensemanagerReceivedLicenseReceivedMetadataOutputReference, ...)
- func NewDataAwsLicensemanagerReceivedLicenseValidityList_Override(d DataAwsLicensemanagerReceivedLicenseValidityList, ...)
- func NewDataAwsLicensemanagerReceivedLicenseValidityOutputReference_Override(d DataAwsLicensemanagerReceivedLicenseValidityOutputReference, ...)
- func NewDataAwsLicensemanagerReceivedLicense_Override(d DataAwsLicensemanagerReceivedLicense, scope constructs.Construct, id *string, ...)
- type DataAwsLicensemanagerReceivedLicense
- type DataAwsLicensemanagerReceivedLicenseConfig
- type DataAwsLicensemanagerReceivedLicenseConsumptionConfiguration
- type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfiguration
- type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationList
- type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationOutputReference
- type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationList
- type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationOutputReference
- type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfiguration
- type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationList
- type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationOutputReference
- type DataAwsLicensemanagerReceivedLicenseEntitlements
- type DataAwsLicensemanagerReceivedLicenseEntitlementsList
- type DataAwsLicensemanagerReceivedLicenseEntitlementsOutputReference
- type DataAwsLicensemanagerReceivedLicenseIssuer
- type DataAwsLicensemanagerReceivedLicenseIssuerList
- type DataAwsLicensemanagerReceivedLicenseIssuerOutputReference
- type DataAwsLicensemanagerReceivedLicenseLicenseMetadata
- type DataAwsLicensemanagerReceivedLicenseLicenseMetadataList
- type DataAwsLicensemanagerReceivedLicenseLicenseMetadataOutputReference
- type DataAwsLicensemanagerReceivedLicenseReceivedMetadata
- type DataAwsLicensemanagerReceivedLicenseReceivedMetadataList
- type DataAwsLicensemanagerReceivedLicenseReceivedMetadataOutputReference
- type DataAwsLicensemanagerReceivedLicenseValidity
- type DataAwsLicensemanagerReceivedLicenseValidityList
- type DataAwsLicensemanagerReceivedLicenseValidityOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsLicensemanagerReceivedLicense_IsConstruct ¶
func DataAwsLicensemanagerReceivedLicense_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsLicensemanagerReceivedLicense_IsTerraformDataSource ¶
func DataAwsLicensemanagerReceivedLicense_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsLicensemanagerReceivedLicense_IsTerraformElement ¶
func DataAwsLicensemanagerReceivedLicense_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsLicensemanagerReceivedLicense_TfResourceType ¶
func DataAwsLicensemanagerReceivedLicense_TfResourceType() *string
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationList_Override ¶
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationList_Override(d DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationOutputReference_Override ¶
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationOutputReference_Override(d DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationList_Override ¶
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationList_Override(d DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationOutputReference_Override ¶
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationOutputReference_Override(d DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationList_Override ¶
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationList_Override(d DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationOutputReference_Override ¶
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationOutputReference_Override(d DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLicensemanagerReceivedLicenseEntitlementsList_Override ¶
func NewDataAwsLicensemanagerReceivedLicenseEntitlementsList_Override(d DataAwsLicensemanagerReceivedLicenseEntitlementsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLicensemanagerReceivedLicenseEntitlementsOutputReference_Override ¶
func NewDataAwsLicensemanagerReceivedLicenseEntitlementsOutputReference_Override(d DataAwsLicensemanagerReceivedLicenseEntitlementsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLicensemanagerReceivedLicenseIssuerList_Override ¶
func NewDataAwsLicensemanagerReceivedLicenseIssuerList_Override(d DataAwsLicensemanagerReceivedLicenseIssuerList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLicensemanagerReceivedLicenseIssuerOutputReference_Override ¶
func NewDataAwsLicensemanagerReceivedLicenseIssuerOutputReference_Override(d DataAwsLicensemanagerReceivedLicenseIssuerOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLicensemanagerReceivedLicenseLicenseMetadataList_Override ¶
func NewDataAwsLicensemanagerReceivedLicenseLicenseMetadataList_Override(d DataAwsLicensemanagerReceivedLicenseLicenseMetadataList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLicensemanagerReceivedLicenseLicenseMetadataOutputReference_Override ¶
func NewDataAwsLicensemanagerReceivedLicenseLicenseMetadataOutputReference_Override(d DataAwsLicensemanagerReceivedLicenseLicenseMetadataOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLicensemanagerReceivedLicenseReceivedMetadataList_Override ¶
func NewDataAwsLicensemanagerReceivedLicenseReceivedMetadataList_Override(d DataAwsLicensemanagerReceivedLicenseReceivedMetadataList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLicensemanagerReceivedLicenseReceivedMetadataOutputReference_Override ¶
func NewDataAwsLicensemanagerReceivedLicenseReceivedMetadataOutputReference_Override(d DataAwsLicensemanagerReceivedLicenseReceivedMetadataOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLicensemanagerReceivedLicenseValidityList_Override ¶
func NewDataAwsLicensemanagerReceivedLicenseValidityList_Override(d DataAwsLicensemanagerReceivedLicenseValidityList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsLicensemanagerReceivedLicenseValidityOutputReference_Override ¶
func NewDataAwsLicensemanagerReceivedLicenseValidityOutputReference_Override(d DataAwsLicensemanagerReceivedLicenseValidityOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsLicensemanagerReceivedLicense_Override ¶
func NewDataAwsLicensemanagerReceivedLicense_Override(d DataAwsLicensemanagerReceivedLicense, scope constructs.Construct, id *string, config *DataAwsLicensemanagerReceivedLicenseConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/licensemanager_received_license aws_licensemanager_received_license} Data Source.
Types ¶
type DataAwsLicensemanagerReceivedLicense ¶
type DataAwsLicensemanagerReceivedLicense interface {
cdktf.TerraformDataSource
Beneficiary() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ConsumptionConfiguration() DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationList
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Entitlements() DataAwsLicensemanagerReceivedLicenseEntitlementsList
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HomeRegion() *string
Id() *string
SetId(val *string)
IdInput() *string
Issuer() DataAwsLicensemanagerReceivedLicenseIssuerList
LicenseArn() *string
SetLicenseArn(val *string)
LicenseArnInput() *string
LicenseMetadata() DataAwsLicensemanagerReceivedLicenseLicenseMetadataList
LicenseName() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
ProductName() *string
ProductSku() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
ReceivedMetadata() DataAwsLicensemanagerReceivedLicenseReceivedMetadataList
Status() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Validity() DataAwsLicensemanagerReceivedLicenseValidityList
Version() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/licensemanager_received_license aws_licensemanager_received_license}.
func NewDataAwsLicensemanagerReceivedLicense ¶
func NewDataAwsLicensemanagerReceivedLicense(scope constructs.Construct, id *string, config *DataAwsLicensemanagerReceivedLicenseConfig) DataAwsLicensemanagerReceivedLicense
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/licensemanager_received_license aws_licensemanager_received_license} Data Source.
type DataAwsLicensemanagerReceivedLicenseConfig ¶
type DataAwsLicensemanagerReceivedLicenseConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/licensemanager_received_license#license_arn DataAwsLicensemanagerReceivedLicense#license_arn}.
LicenseArn *string `field:"required" json:"licenseArn" yaml:"licenseArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/licensemanager_received_license#id DataAwsLicensemanagerReceivedLicense#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type DataAwsLicensemanagerReceivedLicenseConsumptionConfiguration ¶
type DataAwsLicensemanagerReceivedLicenseConsumptionConfiguration struct {
}
type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfiguration ¶
type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfiguration struct {
}
type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationList ¶
type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationList ¶
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationList
type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationOutputReference ¶
type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationOutputReference interface {
cdktf.ComplexObject
AllowEarlyCheckIn() cdktf.IResolvable
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfiguration
SetInternalValue(val *DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfiguration)
MaxTimeToLiveInMinutes() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationOutputReference ¶
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationOutputReference
type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationList ¶
type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationList ¶
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationList
type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationOutputReference ¶
type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationOutputReference interface {
cdktf.ComplexObject
BorrowConfiguration() DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationList
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLicensemanagerReceivedLicenseConsumptionConfiguration
SetInternalValue(val *DataAwsLicensemanagerReceivedLicenseConsumptionConfiguration)
ProvisionalConfiguration() DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationList
RenewType() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationOutputReference ¶
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationOutputReference
type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfiguration ¶
type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfiguration struct {
}
type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationList ¶
type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationList ¶
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationList
type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationOutputReference ¶
type DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfiguration
SetInternalValue(val *DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfiguration)
MaxTimeToLiveInMinutes() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationOutputReference ¶
func NewDataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationOutputReference
type DataAwsLicensemanagerReceivedLicenseEntitlements ¶
type DataAwsLicensemanagerReceivedLicenseEntitlements struct {
}
type DataAwsLicensemanagerReceivedLicenseEntitlementsList ¶
type DataAwsLicensemanagerReceivedLicenseEntitlementsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLicensemanagerReceivedLicenseEntitlementsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLicensemanagerReceivedLicenseEntitlementsList ¶
func NewDataAwsLicensemanagerReceivedLicenseEntitlementsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLicensemanagerReceivedLicenseEntitlementsList
type DataAwsLicensemanagerReceivedLicenseEntitlementsOutputReference ¶
type DataAwsLicensemanagerReceivedLicenseEntitlementsOutputReference interface {
cdktf.ComplexObject
AllowCheckIn() cdktf.IResolvable
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLicensemanagerReceivedLicenseEntitlements
SetInternalValue(val *DataAwsLicensemanagerReceivedLicenseEntitlements)
MaxCount() *float64
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Unit() *string
Value() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLicensemanagerReceivedLicenseEntitlementsOutputReference ¶
func NewDataAwsLicensemanagerReceivedLicenseEntitlementsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLicensemanagerReceivedLicenseEntitlementsOutputReference
type DataAwsLicensemanagerReceivedLicenseIssuer ¶
type DataAwsLicensemanagerReceivedLicenseIssuer struct {
}
type DataAwsLicensemanagerReceivedLicenseIssuerList ¶
type DataAwsLicensemanagerReceivedLicenseIssuerList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLicensemanagerReceivedLicenseIssuerOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLicensemanagerReceivedLicenseIssuerList ¶
func NewDataAwsLicensemanagerReceivedLicenseIssuerList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLicensemanagerReceivedLicenseIssuerList
type DataAwsLicensemanagerReceivedLicenseIssuerOutputReference ¶
type DataAwsLicensemanagerReceivedLicenseIssuerOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLicensemanagerReceivedLicenseIssuer
SetInternalValue(val *DataAwsLicensemanagerReceivedLicenseIssuer)
KeyFingerprint() *string
Name() *string
SignKey() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLicensemanagerReceivedLicenseIssuerOutputReference ¶
func NewDataAwsLicensemanagerReceivedLicenseIssuerOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLicensemanagerReceivedLicenseIssuerOutputReference
type DataAwsLicensemanagerReceivedLicenseLicenseMetadata ¶
type DataAwsLicensemanagerReceivedLicenseLicenseMetadata struct {
}
type DataAwsLicensemanagerReceivedLicenseLicenseMetadataList ¶
type DataAwsLicensemanagerReceivedLicenseLicenseMetadataList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLicensemanagerReceivedLicenseLicenseMetadataOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLicensemanagerReceivedLicenseLicenseMetadataList ¶
func NewDataAwsLicensemanagerReceivedLicenseLicenseMetadataList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLicensemanagerReceivedLicenseLicenseMetadataList
type DataAwsLicensemanagerReceivedLicenseLicenseMetadataOutputReference ¶
type DataAwsLicensemanagerReceivedLicenseLicenseMetadataOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLicensemanagerReceivedLicenseLicenseMetadata
SetInternalValue(val *DataAwsLicensemanagerReceivedLicenseLicenseMetadata)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLicensemanagerReceivedLicenseLicenseMetadataOutputReference ¶
func NewDataAwsLicensemanagerReceivedLicenseLicenseMetadataOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLicensemanagerReceivedLicenseLicenseMetadataOutputReference
type DataAwsLicensemanagerReceivedLicenseReceivedMetadata ¶
type DataAwsLicensemanagerReceivedLicenseReceivedMetadata struct {
}
type DataAwsLicensemanagerReceivedLicenseReceivedMetadataList ¶
type DataAwsLicensemanagerReceivedLicenseReceivedMetadataList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLicensemanagerReceivedLicenseReceivedMetadataOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLicensemanagerReceivedLicenseReceivedMetadataList ¶
func NewDataAwsLicensemanagerReceivedLicenseReceivedMetadataList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLicensemanagerReceivedLicenseReceivedMetadataList
type DataAwsLicensemanagerReceivedLicenseReceivedMetadataOutputReference ¶
type DataAwsLicensemanagerReceivedLicenseReceivedMetadataOutputReference interface {
cdktf.ComplexObject
AllowedOperations() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLicensemanagerReceivedLicenseReceivedMetadata
SetInternalValue(val *DataAwsLicensemanagerReceivedLicenseReceivedMetadata)
ReceivedStatus() *string
ReceivedStatusReason() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLicensemanagerReceivedLicenseReceivedMetadataOutputReference ¶
func NewDataAwsLicensemanagerReceivedLicenseReceivedMetadataOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLicensemanagerReceivedLicenseReceivedMetadataOutputReference
type DataAwsLicensemanagerReceivedLicenseValidity ¶
type DataAwsLicensemanagerReceivedLicenseValidity struct {
}
type DataAwsLicensemanagerReceivedLicenseValidityList ¶
type DataAwsLicensemanagerReceivedLicenseValidityList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsLicensemanagerReceivedLicenseValidityOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLicensemanagerReceivedLicenseValidityList ¶
func NewDataAwsLicensemanagerReceivedLicenseValidityList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsLicensemanagerReceivedLicenseValidityList
type DataAwsLicensemanagerReceivedLicenseValidityOutputReference ¶
type DataAwsLicensemanagerReceivedLicenseValidityOutputReference interface {
cdktf.ComplexObject
Begin() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
End() *string
// Experimental.
Fqn() *string
InternalValue() *DataAwsLicensemanagerReceivedLicenseValidity
SetInternalValue(val *DataAwsLicensemanagerReceivedLicenseValidity)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsLicensemanagerReceivedLicenseValidityOutputReference ¶
func NewDataAwsLicensemanagerReceivedLicenseValidityOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsLicensemanagerReceivedLicenseValidityOutputReference
Source Files
¶
- DataAwsLicensemanagerReceivedLicense.go
- DataAwsLicensemanagerReceivedLicenseConfig.go
- DataAwsLicensemanagerReceivedLicenseConsumptionConfiguration.go
- DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfiguration.go
- DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationList.go
- DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationList__checks.go
- DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationOutputReference.go
- DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationBorrowConfigurationOutputReference__checks.go
- DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationList.go
- DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationList__checks.go
- DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationOutputReference.go
- DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationOutputReference__checks.go
- DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfiguration.go
- DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationList.go
- DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationList__checks.go
- DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationOutputReference.go
- DataAwsLicensemanagerReceivedLicenseConsumptionConfigurationProvisionalConfigurationOutputReference__checks.go
- DataAwsLicensemanagerReceivedLicenseEntitlements.go
- DataAwsLicensemanagerReceivedLicenseEntitlementsList.go
- DataAwsLicensemanagerReceivedLicenseEntitlementsList__checks.go
- DataAwsLicensemanagerReceivedLicenseEntitlementsOutputReference.go
- DataAwsLicensemanagerReceivedLicenseEntitlementsOutputReference__checks.go
- DataAwsLicensemanagerReceivedLicenseIssuer.go
- DataAwsLicensemanagerReceivedLicenseIssuerList.go
- DataAwsLicensemanagerReceivedLicenseIssuerList__checks.go
- DataAwsLicensemanagerReceivedLicenseIssuerOutputReference.go
- DataAwsLicensemanagerReceivedLicenseIssuerOutputReference__checks.go
- DataAwsLicensemanagerReceivedLicenseLicenseMetadata.go
- DataAwsLicensemanagerReceivedLicenseLicenseMetadataList.go
- DataAwsLicensemanagerReceivedLicenseLicenseMetadataList__checks.go
- DataAwsLicensemanagerReceivedLicenseLicenseMetadataOutputReference.go
- DataAwsLicensemanagerReceivedLicenseLicenseMetadataOutputReference__checks.go
- DataAwsLicensemanagerReceivedLicenseReceivedMetadata.go
- DataAwsLicensemanagerReceivedLicenseReceivedMetadataList.go
- DataAwsLicensemanagerReceivedLicenseReceivedMetadataList__checks.go
- DataAwsLicensemanagerReceivedLicenseReceivedMetadataOutputReference.go
- DataAwsLicensemanagerReceivedLicenseReceivedMetadataOutputReference__checks.go
- DataAwsLicensemanagerReceivedLicenseValidity.go
- DataAwsLicensemanagerReceivedLicenseValidityList.go
- DataAwsLicensemanagerReceivedLicenseValidityList__checks.go
- DataAwsLicensemanagerReceivedLicenseValidityOutputReference.go
- DataAwsLicensemanagerReceivedLicenseValidityOutputReference__checks.go
- DataAwsLicensemanagerReceivedLicense__checks.go
- main.go