Documentation
¶
Index ¶
- func DataAwsMemorydbCluster_IsConstruct(x interface{}) *bool
- func DataAwsMemorydbCluster_IsTerraformDataSource(x interface{}) *bool
- func DataAwsMemorydbCluster_IsTerraformElement(x interface{}) *bool
- func DataAwsMemorydbCluster_TfResourceType() *string
- func NewDataAwsMemorydbClusterClusterEndpointList_Override(d DataAwsMemorydbClusterClusterEndpointList, ...)
- func NewDataAwsMemorydbClusterClusterEndpointOutputReference_Override(d DataAwsMemorydbClusterClusterEndpointOutputReference, ...)
- func NewDataAwsMemorydbClusterShardsList_Override(d DataAwsMemorydbClusterShardsList, ...)
- func NewDataAwsMemorydbClusterShardsNodesEndpointList_Override(d DataAwsMemorydbClusterShardsNodesEndpointList, ...)
- func NewDataAwsMemorydbClusterShardsNodesEndpointOutputReference_Override(d DataAwsMemorydbClusterShardsNodesEndpointOutputReference, ...)
- func NewDataAwsMemorydbClusterShardsNodesList_Override(d DataAwsMemorydbClusterShardsNodesList, ...)
- func NewDataAwsMemorydbClusterShardsNodesOutputReference_Override(d DataAwsMemorydbClusterShardsNodesOutputReference, ...)
- func NewDataAwsMemorydbClusterShardsOutputReference_Override(d DataAwsMemorydbClusterShardsOutputReference, ...)
- func NewDataAwsMemorydbCluster_Override(d DataAwsMemorydbCluster, scope constructs.Construct, id *string, ...)
- type DataAwsMemorydbCluster
- type DataAwsMemorydbClusterClusterEndpoint
- type DataAwsMemorydbClusterClusterEndpointList
- type DataAwsMemorydbClusterClusterEndpointOutputReference
- type DataAwsMemorydbClusterConfig
- type DataAwsMemorydbClusterShards
- type DataAwsMemorydbClusterShardsList
- type DataAwsMemorydbClusterShardsNodes
- type DataAwsMemorydbClusterShardsNodesEndpoint
- type DataAwsMemorydbClusterShardsNodesEndpointList
- type DataAwsMemorydbClusterShardsNodesEndpointOutputReference
- type DataAwsMemorydbClusterShardsNodesList
- type DataAwsMemorydbClusterShardsNodesOutputReference
- type DataAwsMemorydbClusterShardsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsMemorydbCluster_IsConstruct ¶
func DataAwsMemorydbCluster_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsMemorydbCluster_IsTerraformDataSource ¶
func DataAwsMemorydbCluster_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsMemorydbCluster_IsTerraformElement ¶
func DataAwsMemorydbCluster_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsMemorydbCluster_TfResourceType ¶
func DataAwsMemorydbCluster_TfResourceType() *string
func NewDataAwsMemorydbClusterClusterEndpointList_Override ¶
func NewDataAwsMemorydbClusterClusterEndpointList_Override(d DataAwsMemorydbClusterClusterEndpointList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsMemorydbClusterClusterEndpointOutputReference_Override ¶
func NewDataAwsMemorydbClusterClusterEndpointOutputReference_Override(d DataAwsMemorydbClusterClusterEndpointOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsMemorydbClusterShardsList_Override ¶
func NewDataAwsMemorydbClusterShardsList_Override(d DataAwsMemorydbClusterShardsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsMemorydbClusterShardsNodesEndpointList_Override ¶
func NewDataAwsMemorydbClusterShardsNodesEndpointList_Override(d DataAwsMemorydbClusterShardsNodesEndpointList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsMemorydbClusterShardsNodesEndpointOutputReference_Override ¶
func NewDataAwsMemorydbClusterShardsNodesEndpointOutputReference_Override(d DataAwsMemorydbClusterShardsNodesEndpointOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsMemorydbClusterShardsNodesList_Override ¶
func NewDataAwsMemorydbClusterShardsNodesList_Override(d DataAwsMemorydbClusterShardsNodesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsMemorydbClusterShardsNodesOutputReference_Override ¶
func NewDataAwsMemorydbClusterShardsNodesOutputReference_Override(d DataAwsMemorydbClusterShardsNodesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsMemorydbClusterShardsOutputReference_Override ¶
func NewDataAwsMemorydbClusterShardsOutputReference_Override(d DataAwsMemorydbClusterShardsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsMemorydbCluster_Override ¶
func NewDataAwsMemorydbCluster_Override(d DataAwsMemorydbCluster, scope constructs.Construct, id *string, config *DataAwsMemorydbClusterConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/memorydb_cluster aws_memorydb_cluster} Data Source.
Types ¶
type DataAwsMemorydbCluster ¶
type DataAwsMemorydbCluster interface {
cdktf.TerraformDataSource
AclName() *string
Arn() *string
AutoMinorVersionUpgrade() cdktf.IResolvable
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterEndpoint() DataAwsMemorydbClusterClusterEndpointList
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DataTiering() cdktf.IResolvable
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
EnginePatchVersion() *string
EngineVersion() *string
FinalSnapshotName() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
KmsKeyArn() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaintenanceWindow() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
NodeType() *string
NumReplicasPerShard() *float64
NumShards() *float64
ParameterGroupName() *string
Port() *float64
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
SecurityGroupIds() *[]*string
Shards() DataAwsMemorydbClusterShardsList
SnapshotRetentionLimit() *float64
SnapshotWindow() *string
SnsTopicArn() *string
SubnetGroupName() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
TlsEnabled() cdktf.IResolvable
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/memorydb_cluster aws_memorydb_cluster}.
func NewDataAwsMemorydbCluster ¶
func NewDataAwsMemorydbCluster(scope constructs.Construct, id *string, config *DataAwsMemorydbClusterConfig) DataAwsMemorydbCluster
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/memorydb_cluster aws_memorydb_cluster} Data Source.
type DataAwsMemorydbClusterClusterEndpoint ¶
type DataAwsMemorydbClusterClusterEndpoint struct {
}
type DataAwsMemorydbClusterClusterEndpointList ¶
type DataAwsMemorydbClusterClusterEndpointList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsMemorydbClusterClusterEndpointOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMemorydbClusterClusterEndpointList ¶
func NewDataAwsMemorydbClusterClusterEndpointList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsMemorydbClusterClusterEndpointList
type DataAwsMemorydbClusterClusterEndpointOutputReference ¶
type DataAwsMemorydbClusterClusterEndpointOutputReference interface {
cdktf.ComplexObject
Address() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsMemorydbClusterClusterEndpoint
SetInternalValue(val *DataAwsMemorydbClusterClusterEndpoint)
Port() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMemorydbClusterClusterEndpointOutputReference ¶
func NewDataAwsMemorydbClusterClusterEndpointOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsMemorydbClusterClusterEndpointOutputReference
type DataAwsMemorydbClusterConfig ¶
type DataAwsMemorydbClusterConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/memorydb_cluster#name DataAwsMemorydbCluster#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/memorydb_cluster#id DataAwsMemorydbCluster#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/memorydb_cluster#tags DataAwsMemorydbCluster#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsMemorydbClusterShards ¶
type DataAwsMemorydbClusterShards struct {
}
type DataAwsMemorydbClusterShardsList ¶
type DataAwsMemorydbClusterShardsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsMemorydbClusterShardsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMemorydbClusterShardsList ¶
func NewDataAwsMemorydbClusterShardsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsMemorydbClusterShardsList
type DataAwsMemorydbClusterShardsNodes ¶
type DataAwsMemorydbClusterShardsNodes struct {
}
type DataAwsMemorydbClusterShardsNodesEndpoint ¶
type DataAwsMemorydbClusterShardsNodesEndpoint struct {
}
type DataAwsMemorydbClusterShardsNodesEndpointList ¶
type DataAwsMemorydbClusterShardsNodesEndpointList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsMemorydbClusterShardsNodesEndpointOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMemorydbClusterShardsNodesEndpointList ¶
func NewDataAwsMemorydbClusterShardsNodesEndpointList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsMemorydbClusterShardsNodesEndpointList
type DataAwsMemorydbClusterShardsNodesEndpointOutputReference ¶
type DataAwsMemorydbClusterShardsNodesEndpointOutputReference interface {
cdktf.ComplexObject
Address() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsMemorydbClusterShardsNodesEndpoint
SetInternalValue(val *DataAwsMemorydbClusterShardsNodesEndpoint)
Port() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMemorydbClusterShardsNodesEndpointOutputReference ¶
func NewDataAwsMemorydbClusterShardsNodesEndpointOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsMemorydbClusterShardsNodesEndpointOutputReference
type DataAwsMemorydbClusterShardsNodesList ¶
type DataAwsMemorydbClusterShardsNodesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsMemorydbClusterShardsNodesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMemorydbClusterShardsNodesList ¶
func NewDataAwsMemorydbClusterShardsNodesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsMemorydbClusterShardsNodesList
type DataAwsMemorydbClusterShardsNodesOutputReference ¶
type DataAwsMemorydbClusterShardsNodesOutputReference interface {
cdktf.ComplexObject
AvailabilityZone() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CreateTime() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Endpoint() DataAwsMemorydbClusterShardsNodesEndpointList
// Experimental.
Fqn() *string
InternalValue() *DataAwsMemorydbClusterShardsNodes
SetInternalValue(val *DataAwsMemorydbClusterShardsNodes)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMemorydbClusterShardsNodesOutputReference ¶
func NewDataAwsMemorydbClusterShardsNodesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsMemorydbClusterShardsNodesOutputReference
type DataAwsMemorydbClusterShardsOutputReference ¶
type DataAwsMemorydbClusterShardsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsMemorydbClusterShards
SetInternalValue(val *DataAwsMemorydbClusterShards)
Name() *string
Nodes() DataAwsMemorydbClusterShardsNodesList
NumNodes() *float64
Slots() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsMemorydbClusterShardsOutputReference ¶
func NewDataAwsMemorydbClusterShardsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsMemorydbClusterShardsOutputReference
Source Files
¶
- DataAwsMemorydbCluster.go
- DataAwsMemorydbClusterClusterEndpoint.go
- DataAwsMemorydbClusterClusterEndpointList.go
- DataAwsMemorydbClusterClusterEndpointList__checks.go
- DataAwsMemorydbClusterClusterEndpointOutputReference.go
- DataAwsMemorydbClusterClusterEndpointOutputReference__checks.go
- DataAwsMemorydbClusterConfig.go
- DataAwsMemorydbClusterShards.go
- DataAwsMemorydbClusterShardsList.go
- DataAwsMemorydbClusterShardsList__checks.go
- DataAwsMemorydbClusterShardsNodes.go
- DataAwsMemorydbClusterShardsNodesEndpoint.go
- DataAwsMemorydbClusterShardsNodesEndpointList.go
- DataAwsMemorydbClusterShardsNodesEndpointList__checks.go
- DataAwsMemorydbClusterShardsNodesEndpointOutputReference.go
- DataAwsMemorydbClusterShardsNodesEndpointOutputReference__checks.go
- DataAwsMemorydbClusterShardsNodesList.go
- DataAwsMemorydbClusterShardsNodesList__checks.go
- DataAwsMemorydbClusterShardsNodesOutputReference.go
- DataAwsMemorydbClusterShardsNodesOutputReference__checks.go
- DataAwsMemorydbClusterShardsOutputReference.go
- DataAwsMemorydbClusterShardsOutputReference__checks.go
- DataAwsMemorydbCluster__checks.go
- main.go