Documentation
¶
Index ¶
- func DataAwsNetworkfirewallFirewall_IsConstruct(x interface{}) *bool
- func DataAwsNetworkfirewallFirewall_IsTerraformDataSource(x interface{}) *bool
- func DataAwsNetworkfirewallFirewall_IsTerraformElement(x interface{}) *bool
- func DataAwsNetworkfirewallFirewall_TfResourceType() *string
- func NewDataAwsNetworkfirewallFirewallEncryptionConfigurationList_Override(d DataAwsNetworkfirewallFirewallEncryptionConfigurationList, ...)
- func NewDataAwsNetworkfirewallFirewallEncryptionConfigurationOutputReference_Override(d DataAwsNetworkfirewallFirewallEncryptionConfigurationOutputReference, ...)
- func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesList_Override(...)
- func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesOutputReference_Override(...)
- func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsList_Override(d DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsList, ...)
- func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsOutputReference_Override(...)
- func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryList_Override(d DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryList, ...)
- func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryOutputReference_Override(...)
- func NewDataAwsNetworkfirewallFirewallFirewallStatusList_Override(d DataAwsNetworkfirewallFirewallFirewallStatusList, ...)
- func NewDataAwsNetworkfirewallFirewallFirewallStatusOutputReference_Override(d DataAwsNetworkfirewallFirewallFirewallStatusOutputReference, ...)
- func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList_Override(d DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList, ...)
- func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference_Override(...)
- func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesList_Override(d DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesList, ...)
- func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesOutputReference_Override(d DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesOutputReference, ...)
- func NewDataAwsNetworkfirewallFirewallSubnetMappingList_Override(d DataAwsNetworkfirewallFirewallSubnetMappingList, ...)
- func NewDataAwsNetworkfirewallFirewallSubnetMappingOutputReference_Override(d DataAwsNetworkfirewallFirewallSubnetMappingOutputReference, ...)
- func NewDataAwsNetworkfirewallFirewall_Override(d DataAwsNetworkfirewallFirewall, scope constructs.Construct, id *string, ...)
- type DataAwsNetworkfirewallFirewall
- type DataAwsNetworkfirewallFirewallConfig
- type DataAwsNetworkfirewallFirewallEncryptionConfiguration
- type DataAwsNetworkfirewallFirewallEncryptionConfigurationList
- type DataAwsNetworkfirewallFirewallEncryptionConfigurationOutputReference
- type DataAwsNetworkfirewallFirewallFirewallStatus
- type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummary
- type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrs
- type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferences
- type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesList
- type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesOutputReference
- type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsList
- type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsOutputReference
- type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryList
- type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryOutputReference
- type DataAwsNetworkfirewallFirewallFirewallStatusList
- type DataAwsNetworkfirewallFirewallFirewallStatusOutputReference
- type DataAwsNetworkfirewallFirewallFirewallStatusSyncStates
- type DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachment
- type DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList
- type DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference
- type DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesList
- type DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesOutputReference
- type DataAwsNetworkfirewallFirewallSubnetMapping
- type DataAwsNetworkfirewallFirewallSubnetMappingList
- type DataAwsNetworkfirewallFirewallSubnetMappingOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsNetworkfirewallFirewall_IsConstruct ¶
func DataAwsNetworkfirewallFirewall_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsNetworkfirewallFirewall_IsTerraformDataSource ¶
func DataAwsNetworkfirewallFirewall_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsNetworkfirewallFirewall_IsTerraformElement ¶
func DataAwsNetworkfirewallFirewall_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsNetworkfirewallFirewall_TfResourceType ¶
func DataAwsNetworkfirewallFirewall_TfResourceType() *string
func NewDataAwsNetworkfirewallFirewallEncryptionConfigurationList_Override ¶
func NewDataAwsNetworkfirewallFirewallEncryptionConfigurationList_Override(d DataAwsNetworkfirewallFirewallEncryptionConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsNetworkfirewallFirewallEncryptionConfigurationOutputReference_Override ¶
func NewDataAwsNetworkfirewallFirewallEncryptionConfigurationOutputReference_Override(d DataAwsNetworkfirewallFirewallEncryptionConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesList_Override ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesList_Override(d DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesOutputReference_Override ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesOutputReference_Override(d DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsList_Override ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsList_Override(d DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsOutputReference_Override ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsOutputReference_Override(d DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryList_Override ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryList_Override(d DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryOutputReference_Override ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryOutputReference_Override(d DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsNetworkfirewallFirewallFirewallStatusList_Override ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusList_Override(d DataAwsNetworkfirewallFirewallFirewallStatusList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsNetworkfirewallFirewallFirewallStatusOutputReference_Override ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusOutputReference_Override(d DataAwsNetworkfirewallFirewallFirewallStatusOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList_Override ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList_Override(d DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference_Override ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference_Override(d DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesList_Override ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesList_Override(d DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesOutputReference_Override ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesOutputReference_Override(d DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsNetworkfirewallFirewallSubnetMappingList_Override ¶
func NewDataAwsNetworkfirewallFirewallSubnetMappingList_Override(d DataAwsNetworkfirewallFirewallSubnetMappingList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsNetworkfirewallFirewallSubnetMappingOutputReference_Override ¶
func NewDataAwsNetworkfirewallFirewallSubnetMappingOutputReference_Override(d DataAwsNetworkfirewallFirewallSubnetMappingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsNetworkfirewallFirewall_Override ¶
func NewDataAwsNetworkfirewallFirewall_Override(d DataAwsNetworkfirewallFirewall, scope constructs.Construct, id *string, config *DataAwsNetworkfirewallFirewallConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/networkfirewall_firewall aws_networkfirewall_firewall} Data Source.
Types ¶
type DataAwsNetworkfirewallFirewall ¶
type DataAwsNetworkfirewallFirewall interface {
cdktf.TerraformDataSource
Arn() *string
SetArn(val *string)
ArnInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DeleteProtection() cdktf.IResolvable
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
EncryptionConfiguration() DataAwsNetworkfirewallFirewallEncryptionConfigurationList
FirewallPolicyArn() *string
FirewallPolicyChangeProtection() cdktf.IResolvable
FirewallStatus() DataAwsNetworkfirewallFirewallFirewallStatusList
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
SubnetChangeProtection() cdktf.IResolvable
SubnetMapping() DataAwsNetworkfirewallFirewallSubnetMappingList
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
UpdateToken() *string
VpcId() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetArn()
ResetId()
ResetName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/networkfirewall_firewall aws_networkfirewall_firewall}.
func NewDataAwsNetworkfirewallFirewall ¶
func NewDataAwsNetworkfirewallFirewall(scope constructs.Construct, id *string, config *DataAwsNetworkfirewallFirewallConfig) DataAwsNetworkfirewallFirewall
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/networkfirewall_firewall aws_networkfirewall_firewall} Data Source.
type DataAwsNetworkfirewallFirewallConfig ¶
type DataAwsNetworkfirewallFirewallConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/networkfirewall_firewall#arn DataAwsNetworkfirewallFirewall#arn}.
Arn *string `field:"optional" json:"arn" yaml:"arn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/networkfirewall_firewall#id DataAwsNetworkfirewallFirewall#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/networkfirewall_firewall#name DataAwsNetworkfirewallFirewall#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/networkfirewall_firewall#tags DataAwsNetworkfirewallFirewall#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsNetworkfirewallFirewallEncryptionConfiguration ¶
type DataAwsNetworkfirewallFirewallEncryptionConfiguration struct {
}
type DataAwsNetworkfirewallFirewallEncryptionConfigurationList ¶
type DataAwsNetworkfirewallFirewallEncryptionConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsNetworkfirewallFirewallEncryptionConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkfirewallFirewallEncryptionConfigurationList ¶
func NewDataAwsNetworkfirewallFirewallEncryptionConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsNetworkfirewallFirewallEncryptionConfigurationList
type DataAwsNetworkfirewallFirewallEncryptionConfigurationOutputReference ¶
type DataAwsNetworkfirewallFirewallEncryptionConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsNetworkfirewallFirewallEncryptionConfiguration
SetInternalValue(val *DataAwsNetworkfirewallFirewallEncryptionConfiguration)
KeyId() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkfirewallFirewallEncryptionConfigurationOutputReference ¶
func NewDataAwsNetworkfirewallFirewallEncryptionConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsNetworkfirewallFirewallEncryptionConfigurationOutputReference
type DataAwsNetworkfirewallFirewallFirewallStatus ¶
type DataAwsNetworkfirewallFirewallFirewallStatus struct {
}
type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummary ¶
type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummary struct {
}
type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrs ¶
type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrs struct {
}
type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferences ¶
type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferences struct {
}
type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesList ¶
type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesList ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesList
type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesOutputReference ¶
type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferences
SetInternalValue(val *DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferences)
ResolvedCidrCount() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesOutputReference ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesOutputReference
type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsList ¶
type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsList ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsList
type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsOutputReference ¶
type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsOutputReference interface {
cdktf.ComplexObject
AvailableCidrCount() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrs
SetInternalValue(val *DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrs)
IpSetReferences() DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UtilizedCidrCount() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsOutputReference ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsOutputReference
type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryList ¶
type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryList ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryList
type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryOutputReference ¶
type DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryOutputReference interface {
cdktf.ComplexObject
Cidrs() DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsList
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummary
SetInternalValue(val *DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummary)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryOutputReference ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryOutputReference
type DataAwsNetworkfirewallFirewallFirewallStatusList ¶
type DataAwsNetworkfirewallFirewallFirewallStatusList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsNetworkfirewallFirewallFirewallStatusOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkfirewallFirewallFirewallStatusList ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsNetworkfirewallFirewallFirewallStatusList
type DataAwsNetworkfirewallFirewallFirewallStatusOutputReference ¶
type DataAwsNetworkfirewallFirewallFirewallStatusOutputReference interface {
cdktf.ComplexObject
CapacityUsageSummary() DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryList
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ConfigurationSyncStateSummary() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsNetworkfirewallFirewallFirewallStatus
SetInternalValue(val *DataAwsNetworkfirewallFirewallFirewallStatus)
Status() *string
SyncStates() DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkfirewallFirewallFirewallStatusOutputReference ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsNetworkfirewallFirewallFirewallStatusOutputReference
type DataAwsNetworkfirewallFirewallFirewallStatusSyncStates ¶
type DataAwsNetworkfirewallFirewallFirewallStatusSyncStates struct {
}
type DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachment ¶
type DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachment struct {
}
type DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList ¶
type DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList
type DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference ¶
type DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EndpointId() *string
// Experimental.
Fqn() *string
InternalValue() *DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachment
SetInternalValue(val *DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachment)
Status() *string
SubnetId() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference
type DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesList ¶
type DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesList ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesList
type DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesOutputReference ¶
type DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesOutputReference interface {
cdktf.ComplexObject
Attachment() DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList
AvailabilityZone() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsNetworkfirewallFirewallFirewallStatusSyncStates
SetInternalValue(val *DataAwsNetworkfirewallFirewallFirewallStatusSyncStates)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesOutputReference ¶
func NewDataAwsNetworkfirewallFirewallFirewallStatusSyncStatesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesOutputReference
type DataAwsNetworkfirewallFirewallSubnetMapping ¶
type DataAwsNetworkfirewallFirewallSubnetMapping struct {
}
type DataAwsNetworkfirewallFirewallSubnetMappingList ¶
type DataAwsNetworkfirewallFirewallSubnetMappingList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsNetworkfirewallFirewallSubnetMappingOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkfirewallFirewallSubnetMappingList ¶
func NewDataAwsNetworkfirewallFirewallSubnetMappingList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsNetworkfirewallFirewallSubnetMappingList
type DataAwsNetworkfirewallFirewallSubnetMappingOutputReference ¶
type DataAwsNetworkfirewallFirewallSubnetMappingOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsNetworkfirewallFirewallSubnetMapping
SetInternalValue(val *DataAwsNetworkfirewallFirewallSubnetMapping)
SubnetId() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsNetworkfirewallFirewallSubnetMappingOutputReference ¶
func NewDataAwsNetworkfirewallFirewallSubnetMappingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsNetworkfirewallFirewallSubnetMappingOutputReference
Source Files
¶
- DataAwsNetworkfirewallFirewall.go
- DataAwsNetworkfirewallFirewallConfig.go
- DataAwsNetworkfirewallFirewallEncryptionConfiguration.go
- DataAwsNetworkfirewallFirewallEncryptionConfigurationList.go
- DataAwsNetworkfirewallFirewallEncryptionConfigurationList__checks.go
- DataAwsNetworkfirewallFirewallEncryptionConfigurationOutputReference.go
- DataAwsNetworkfirewallFirewallEncryptionConfigurationOutputReference__checks.go
- DataAwsNetworkfirewallFirewallFirewallStatus.go
- DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummary.go
- DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrs.go
- DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferences.go
- DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesList.go
- DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesList__checks.go
- DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesOutputReference.go
- DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsIpSetReferencesOutputReference__checks.go
- DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsList.go
- DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsList__checks.go
- DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsOutputReference.go
- DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryCidrsOutputReference__checks.go
- DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryList.go
- DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryList__checks.go
- DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryOutputReference.go
- DataAwsNetworkfirewallFirewallFirewallStatusCapacityUsageSummaryOutputReference__checks.go
- DataAwsNetworkfirewallFirewallFirewallStatusList.go
- DataAwsNetworkfirewallFirewallFirewallStatusList__checks.go
- DataAwsNetworkfirewallFirewallFirewallStatusOutputReference.go
- DataAwsNetworkfirewallFirewallFirewallStatusOutputReference__checks.go
- DataAwsNetworkfirewallFirewallFirewallStatusSyncStates.go
- DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachment.go
- DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList.go
- DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentList__checks.go
- DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference.go
- DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesAttachmentOutputReference__checks.go
- DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesList.go
- DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesList__checks.go
- DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesOutputReference.go
- DataAwsNetworkfirewallFirewallFirewallStatusSyncStatesOutputReference__checks.go
- DataAwsNetworkfirewallFirewallSubnetMapping.go
- DataAwsNetworkfirewallFirewallSubnetMappingList.go
- DataAwsNetworkfirewallFirewallSubnetMappingList__checks.go
- DataAwsNetworkfirewallFirewallSubnetMappingOutputReference.go
- DataAwsNetworkfirewallFirewallSubnetMappingOutputReference__checks.go
- DataAwsNetworkfirewallFirewall__checks.go
- main.go