Documentation
¶
Index ¶
- func DataAwsSecurityGroup_IsConstruct(x interface{}) *bool
- func DataAwsSecurityGroup_IsTerraformDataSource(x interface{}) *bool
- func DataAwsSecurityGroup_IsTerraformElement(x interface{}) *bool
- func DataAwsSecurityGroup_TfResourceType() *string
- func NewDataAwsSecurityGroupFilterList_Override(d DataAwsSecurityGroupFilterList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewDataAwsSecurityGroupFilterOutputReference_Override(d DataAwsSecurityGroupFilterOutputReference, ...)
- func NewDataAwsSecurityGroupTimeoutsOutputReference_Override(d DataAwsSecurityGroupTimeoutsOutputReference, ...)
- func NewDataAwsSecurityGroup_Override(d DataAwsSecurityGroup, scope constructs.Construct, id *string, ...)
- type DataAwsSecurityGroup
- type DataAwsSecurityGroupConfig
- type DataAwsSecurityGroupFilter
- type DataAwsSecurityGroupFilterList
- type DataAwsSecurityGroupFilterOutputReference
- type DataAwsSecurityGroupTimeouts
- type DataAwsSecurityGroupTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsSecurityGroup_IsConstruct ¶
func DataAwsSecurityGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsSecurityGroup_IsTerraformDataSource ¶
func DataAwsSecurityGroup_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsSecurityGroup_IsTerraformElement ¶
func DataAwsSecurityGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsSecurityGroup_TfResourceType ¶
func DataAwsSecurityGroup_TfResourceType() *string
func NewDataAwsSecurityGroupFilterList_Override ¶
func NewDataAwsSecurityGroupFilterList_Override(d DataAwsSecurityGroupFilterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsSecurityGroupFilterOutputReference_Override ¶
func NewDataAwsSecurityGroupFilterOutputReference_Override(d DataAwsSecurityGroupFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsSecurityGroupTimeoutsOutputReference_Override ¶
func NewDataAwsSecurityGroupTimeoutsOutputReference_Override(d DataAwsSecurityGroupTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsSecurityGroup_Override ¶
func NewDataAwsSecurityGroup_Override(d DataAwsSecurityGroup, scope constructs.Construct, id *string, config *DataAwsSecurityGroupConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/security_group aws_security_group} Data Source.
Types ¶
type DataAwsSecurityGroup ¶
type DataAwsSecurityGroup interface {
cdktf.TerraformDataSource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
Filter() DataAwsSecurityGroupFilterList
FilterInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DataAwsSecurityGroupTimeoutsOutputReference
TimeoutsInput() interface{}
VpcId() *string
SetVpcId(val *string)
VpcIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutFilter(value interface{})
PutTimeouts(value *DataAwsSecurityGroupTimeouts)
ResetFilter()
ResetId()
ResetName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTimeouts()
ResetVpcId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/security_group aws_security_group}.
func NewDataAwsSecurityGroup ¶
func NewDataAwsSecurityGroup(scope constructs.Construct, id *string, config *DataAwsSecurityGroupConfig) DataAwsSecurityGroup
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/security_group aws_security_group} Data Source.
type DataAwsSecurityGroupConfig ¶
type DataAwsSecurityGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// filter block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/security_group#filter DataAwsSecurityGroup#filter}
Filter interface{} `field:"optional" json:"filter" yaml:"filter"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/security_group#id DataAwsSecurityGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/security_group#name DataAwsSecurityGroup#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/security_group#tags DataAwsSecurityGroup#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/security_group#timeouts DataAwsSecurityGroup#timeouts}
Timeouts *DataAwsSecurityGroupTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/security_group#vpc_id DataAwsSecurityGroup#vpc_id}.
VpcId *string `field:"optional" json:"vpcId" yaml:"vpcId"`
}
type DataAwsSecurityGroupFilter ¶
type DataAwsSecurityGroupFilter struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/security_group#name DataAwsSecurityGroup#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/security_group#values DataAwsSecurityGroup#values}.
Values *[]*string `field:"required" json:"values" yaml:"values"`
}
type DataAwsSecurityGroupFilterList ¶
type DataAwsSecurityGroupFilterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsSecurityGroupFilterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSecurityGroupFilterList ¶
func NewDataAwsSecurityGroupFilterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsSecurityGroupFilterList
type DataAwsSecurityGroupFilterOutputReference ¶
type DataAwsSecurityGroupFilterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
SetValues(val *[]*string)
ValuesInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSecurityGroupFilterOutputReference ¶
func NewDataAwsSecurityGroupFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsSecurityGroupFilterOutputReference
type DataAwsSecurityGroupTimeouts ¶
type DataAwsSecurityGroupTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/security_group#read DataAwsSecurityGroup#read}.
Read *string `field:"optional" json:"read" yaml:"read"`
}
type DataAwsSecurityGroupTimeoutsOutputReference ¶
type DataAwsSecurityGroupTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Read() *string
SetRead(val *string)
ReadInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetRead()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSecurityGroupTimeoutsOutputReference ¶
func NewDataAwsSecurityGroupTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsSecurityGroupTimeoutsOutputReference
Source Files
¶
- DataAwsSecurityGroup.go
- DataAwsSecurityGroupConfig.go
- DataAwsSecurityGroupFilter.go
- DataAwsSecurityGroupFilterList.go
- DataAwsSecurityGroupFilterList__checks.go
- DataAwsSecurityGroupFilterOutputReference.go
- DataAwsSecurityGroupFilterOutputReference__checks.go
- DataAwsSecurityGroupTimeouts.go
- DataAwsSecurityGroupTimeoutsOutputReference.go
- DataAwsSecurityGroupTimeoutsOutputReference__checks.go
- DataAwsSecurityGroup__checks.go
- main.go