Documentation
¶
Index ¶
- func DataAwsSsmcontactsPlan_IsConstruct(x interface{}) *bool
- func DataAwsSsmcontactsPlan_IsTerraformDataSource(x interface{}) *bool
- func DataAwsSsmcontactsPlan_IsTerraformElement(x interface{}) *bool
- func DataAwsSsmcontactsPlan_TfResourceType() *string
- func NewDataAwsSsmcontactsPlanStageList_Override(d DataAwsSsmcontactsPlanStageList, ...)
- func NewDataAwsSsmcontactsPlanStageOutputReference_Override(d DataAwsSsmcontactsPlanStageOutputReference, ...)
- func NewDataAwsSsmcontactsPlanStageTargetChannelTargetInfoList_Override(d DataAwsSsmcontactsPlanStageTargetChannelTargetInfoList, ...)
- func NewDataAwsSsmcontactsPlanStageTargetChannelTargetInfoOutputReference_Override(d DataAwsSsmcontactsPlanStageTargetChannelTargetInfoOutputReference, ...)
- func NewDataAwsSsmcontactsPlanStageTargetContactTargetInfoList_Override(d DataAwsSsmcontactsPlanStageTargetContactTargetInfoList, ...)
- func NewDataAwsSsmcontactsPlanStageTargetContactTargetInfoOutputReference_Override(d DataAwsSsmcontactsPlanStageTargetContactTargetInfoOutputReference, ...)
- func NewDataAwsSsmcontactsPlanStageTargetList_Override(d DataAwsSsmcontactsPlanStageTargetList, ...)
- func NewDataAwsSsmcontactsPlanStageTargetOutputReference_Override(d DataAwsSsmcontactsPlanStageTargetOutputReference, ...)
- func NewDataAwsSsmcontactsPlan_Override(d DataAwsSsmcontactsPlan, scope constructs.Construct, id *string, ...)
- type DataAwsSsmcontactsPlan
- type DataAwsSsmcontactsPlanConfig
- type DataAwsSsmcontactsPlanStage
- type DataAwsSsmcontactsPlanStageList
- type DataAwsSsmcontactsPlanStageOutputReference
- type DataAwsSsmcontactsPlanStageTarget
- type DataAwsSsmcontactsPlanStageTargetChannelTargetInfo
- type DataAwsSsmcontactsPlanStageTargetChannelTargetInfoList
- type DataAwsSsmcontactsPlanStageTargetChannelTargetInfoOutputReference
- type DataAwsSsmcontactsPlanStageTargetContactTargetInfo
- type DataAwsSsmcontactsPlanStageTargetContactTargetInfoList
- type DataAwsSsmcontactsPlanStageTargetContactTargetInfoOutputReference
- type DataAwsSsmcontactsPlanStageTargetList
- type DataAwsSsmcontactsPlanStageTargetOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsSsmcontactsPlan_IsConstruct ¶
func DataAwsSsmcontactsPlan_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsSsmcontactsPlan_IsTerraformDataSource ¶
func DataAwsSsmcontactsPlan_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsSsmcontactsPlan_IsTerraformElement ¶
func DataAwsSsmcontactsPlan_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsSsmcontactsPlan_TfResourceType ¶
func DataAwsSsmcontactsPlan_TfResourceType() *string
func NewDataAwsSsmcontactsPlanStageList_Override ¶
func NewDataAwsSsmcontactsPlanStageList_Override(d DataAwsSsmcontactsPlanStageList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsSsmcontactsPlanStageOutputReference_Override ¶
func NewDataAwsSsmcontactsPlanStageOutputReference_Override(d DataAwsSsmcontactsPlanStageOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsSsmcontactsPlanStageTargetChannelTargetInfoList_Override ¶
func NewDataAwsSsmcontactsPlanStageTargetChannelTargetInfoList_Override(d DataAwsSsmcontactsPlanStageTargetChannelTargetInfoList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsSsmcontactsPlanStageTargetChannelTargetInfoOutputReference_Override ¶
func NewDataAwsSsmcontactsPlanStageTargetChannelTargetInfoOutputReference_Override(d DataAwsSsmcontactsPlanStageTargetChannelTargetInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsSsmcontactsPlanStageTargetContactTargetInfoList_Override ¶
func NewDataAwsSsmcontactsPlanStageTargetContactTargetInfoList_Override(d DataAwsSsmcontactsPlanStageTargetContactTargetInfoList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsSsmcontactsPlanStageTargetContactTargetInfoOutputReference_Override ¶
func NewDataAwsSsmcontactsPlanStageTargetContactTargetInfoOutputReference_Override(d DataAwsSsmcontactsPlanStageTargetContactTargetInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsSsmcontactsPlanStageTargetList_Override ¶
func NewDataAwsSsmcontactsPlanStageTargetList_Override(d DataAwsSsmcontactsPlanStageTargetList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsSsmcontactsPlanStageTargetOutputReference_Override ¶
func NewDataAwsSsmcontactsPlanStageTargetOutputReference_Override(d DataAwsSsmcontactsPlanStageTargetOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsSsmcontactsPlan_Override ¶
func NewDataAwsSsmcontactsPlan_Override(d DataAwsSsmcontactsPlan, scope constructs.Construct, id *string, config *DataAwsSsmcontactsPlanConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ssmcontacts_plan aws_ssmcontacts_plan} Data Source.
Types ¶
type DataAwsSsmcontactsPlan ¶
type DataAwsSsmcontactsPlan interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ContactId() *string
SetContactId(val *string)
ContactIdInput() *string
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Stage() DataAwsSsmcontactsPlanStageList
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ssmcontacts_plan aws_ssmcontacts_plan}.
func NewDataAwsSsmcontactsPlan ¶
func NewDataAwsSsmcontactsPlan(scope constructs.Construct, id *string, config *DataAwsSsmcontactsPlanConfig) DataAwsSsmcontactsPlan
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ssmcontacts_plan aws_ssmcontacts_plan} Data Source.
type DataAwsSsmcontactsPlanConfig ¶
type DataAwsSsmcontactsPlanConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ssmcontacts_plan#contact_id DataAwsSsmcontactsPlan#contact_id}.
ContactId *string `field:"required" json:"contactId" yaml:"contactId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ssmcontacts_plan#id DataAwsSsmcontactsPlan#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type DataAwsSsmcontactsPlanStage ¶
type DataAwsSsmcontactsPlanStage struct {
}
type DataAwsSsmcontactsPlanStageList ¶
type DataAwsSsmcontactsPlanStageList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsSsmcontactsPlanStageOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSsmcontactsPlanStageList ¶
func NewDataAwsSsmcontactsPlanStageList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsSsmcontactsPlanStageList
type DataAwsSsmcontactsPlanStageOutputReference ¶
type DataAwsSsmcontactsPlanStageOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DurationInMinutes() *float64
// Experimental.
Fqn() *string
InternalValue() *DataAwsSsmcontactsPlanStage
SetInternalValue(val *DataAwsSsmcontactsPlanStage)
Target() DataAwsSsmcontactsPlanStageTargetList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSsmcontactsPlanStageOutputReference ¶
func NewDataAwsSsmcontactsPlanStageOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsSsmcontactsPlanStageOutputReference
type DataAwsSsmcontactsPlanStageTarget ¶
type DataAwsSsmcontactsPlanStageTarget struct {
}
type DataAwsSsmcontactsPlanStageTargetChannelTargetInfo ¶
type DataAwsSsmcontactsPlanStageTargetChannelTargetInfo struct {
}
type DataAwsSsmcontactsPlanStageTargetChannelTargetInfoList ¶
type DataAwsSsmcontactsPlanStageTargetChannelTargetInfoList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsSsmcontactsPlanStageTargetChannelTargetInfoOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSsmcontactsPlanStageTargetChannelTargetInfoList ¶
func NewDataAwsSsmcontactsPlanStageTargetChannelTargetInfoList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsSsmcontactsPlanStageTargetChannelTargetInfoList
type DataAwsSsmcontactsPlanStageTargetChannelTargetInfoOutputReference ¶
type DataAwsSsmcontactsPlanStageTargetChannelTargetInfoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ContactChannelId() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsSsmcontactsPlanStageTargetChannelTargetInfo
SetInternalValue(val *DataAwsSsmcontactsPlanStageTargetChannelTargetInfo)
RetryIntervalInMinutes() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSsmcontactsPlanStageTargetChannelTargetInfoOutputReference ¶
func NewDataAwsSsmcontactsPlanStageTargetChannelTargetInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsSsmcontactsPlanStageTargetChannelTargetInfoOutputReference
type DataAwsSsmcontactsPlanStageTargetContactTargetInfo ¶
type DataAwsSsmcontactsPlanStageTargetContactTargetInfo struct {
}
type DataAwsSsmcontactsPlanStageTargetContactTargetInfoList ¶
type DataAwsSsmcontactsPlanStageTargetContactTargetInfoList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsSsmcontactsPlanStageTargetContactTargetInfoOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSsmcontactsPlanStageTargetContactTargetInfoList ¶
func NewDataAwsSsmcontactsPlanStageTargetContactTargetInfoList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsSsmcontactsPlanStageTargetContactTargetInfoList
type DataAwsSsmcontactsPlanStageTargetContactTargetInfoOutputReference ¶
type DataAwsSsmcontactsPlanStageTargetContactTargetInfoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ContactId() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsSsmcontactsPlanStageTargetContactTargetInfo
SetInternalValue(val *DataAwsSsmcontactsPlanStageTargetContactTargetInfo)
IsEssential() cdktf.IResolvable
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSsmcontactsPlanStageTargetContactTargetInfoOutputReference ¶
func NewDataAwsSsmcontactsPlanStageTargetContactTargetInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsSsmcontactsPlanStageTargetContactTargetInfoOutputReference
type DataAwsSsmcontactsPlanStageTargetList ¶
type DataAwsSsmcontactsPlanStageTargetList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsSsmcontactsPlanStageTargetOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSsmcontactsPlanStageTargetList ¶
func NewDataAwsSsmcontactsPlanStageTargetList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsSsmcontactsPlanStageTargetList
type DataAwsSsmcontactsPlanStageTargetOutputReference ¶
type DataAwsSsmcontactsPlanStageTargetOutputReference interface {
cdktf.ComplexObject
ChannelTargetInfo() DataAwsSsmcontactsPlanStageTargetChannelTargetInfoList
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ContactTargetInfo() DataAwsSsmcontactsPlanStageTargetContactTargetInfoList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsSsmcontactsPlanStageTarget
SetInternalValue(val *DataAwsSsmcontactsPlanStageTarget)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSsmcontactsPlanStageTargetOutputReference ¶
func NewDataAwsSsmcontactsPlanStageTargetOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsSsmcontactsPlanStageTargetOutputReference
Source Files
¶
- DataAwsSsmcontactsPlan.go
- DataAwsSsmcontactsPlanConfig.go
- DataAwsSsmcontactsPlanStage.go
- DataAwsSsmcontactsPlanStageList.go
- DataAwsSsmcontactsPlanStageList__checks.go
- DataAwsSsmcontactsPlanStageOutputReference.go
- DataAwsSsmcontactsPlanStageOutputReference__checks.go
- DataAwsSsmcontactsPlanStageTarget.go
- DataAwsSsmcontactsPlanStageTargetChannelTargetInfo.go
- DataAwsSsmcontactsPlanStageTargetChannelTargetInfoList.go
- DataAwsSsmcontactsPlanStageTargetChannelTargetInfoList__checks.go
- DataAwsSsmcontactsPlanStageTargetChannelTargetInfoOutputReference.go
- DataAwsSsmcontactsPlanStageTargetChannelTargetInfoOutputReference__checks.go
- DataAwsSsmcontactsPlanStageTargetContactTargetInfo.go
- DataAwsSsmcontactsPlanStageTargetContactTargetInfoList.go
- DataAwsSsmcontactsPlanStageTargetContactTargetInfoList__checks.go
- DataAwsSsmcontactsPlanStageTargetContactTargetInfoOutputReference.go
- DataAwsSsmcontactsPlanStageTargetContactTargetInfoOutputReference__checks.go
- DataAwsSsmcontactsPlanStageTargetList.go
- DataAwsSsmcontactsPlanStageTargetList__checks.go
- DataAwsSsmcontactsPlanStageTargetOutputReference.go
- DataAwsSsmcontactsPlanStageTargetOutputReference__checks.go
- DataAwsSsmcontactsPlan__checks.go
- main.go