Documentation
¶
Index ¶
- func DataAwsSsmPatchBaseline_IsConstruct(x interface{}) *bool
- func DataAwsSsmPatchBaseline_IsTerraformDataSource(x interface{}) *bool
- func DataAwsSsmPatchBaseline_IsTerraformElement(x interface{}) *bool
- func DataAwsSsmPatchBaseline_TfResourceType() *string
- func NewDataAwsSsmPatchBaselineApprovalRuleList_Override(d DataAwsSsmPatchBaselineApprovalRuleList, ...)
- func NewDataAwsSsmPatchBaselineApprovalRuleOutputReference_Override(d DataAwsSsmPatchBaselineApprovalRuleOutputReference, ...)
- func NewDataAwsSsmPatchBaselineApprovalRulePatchFilterList_Override(d DataAwsSsmPatchBaselineApprovalRulePatchFilterList, ...)
- func NewDataAwsSsmPatchBaselineApprovalRulePatchFilterOutputReference_Override(d DataAwsSsmPatchBaselineApprovalRulePatchFilterOutputReference, ...)
- func NewDataAwsSsmPatchBaselineGlobalFilterList_Override(d DataAwsSsmPatchBaselineGlobalFilterList, ...)
- func NewDataAwsSsmPatchBaselineGlobalFilterOutputReference_Override(d DataAwsSsmPatchBaselineGlobalFilterOutputReference, ...)
- func NewDataAwsSsmPatchBaselineSourceList_Override(d DataAwsSsmPatchBaselineSourceList, ...)
- func NewDataAwsSsmPatchBaselineSourceOutputReference_Override(d DataAwsSsmPatchBaselineSourceOutputReference, ...)
- func NewDataAwsSsmPatchBaseline_Override(d DataAwsSsmPatchBaseline, scope constructs.Construct, id *string, ...)
- type DataAwsSsmPatchBaseline
- type DataAwsSsmPatchBaselineApprovalRule
- type DataAwsSsmPatchBaselineApprovalRuleList
- type DataAwsSsmPatchBaselineApprovalRuleOutputReference
- type DataAwsSsmPatchBaselineApprovalRulePatchFilter
- type DataAwsSsmPatchBaselineApprovalRulePatchFilterList
- type DataAwsSsmPatchBaselineApprovalRulePatchFilterOutputReference
- type DataAwsSsmPatchBaselineConfig
- type DataAwsSsmPatchBaselineGlobalFilter
- type DataAwsSsmPatchBaselineGlobalFilterList
- type DataAwsSsmPatchBaselineGlobalFilterOutputReference
- type DataAwsSsmPatchBaselineSource
- type DataAwsSsmPatchBaselineSourceList
- type DataAwsSsmPatchBaselineSourceOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsSsmPatchBaseline_IsConstruct ¶
func DataAwsSsmPatchBaseline_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsSsmPatchBaseline_IsTerraformDataSource ¶
func DataAwsSsmPatchBaseline_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsSsmPatchBaseline_IsTerraformElement ¶
func DataAwsSsmPatchBaseline_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsSsmPatchBaseline_TfResourceType ¶
func DataAwsSsmPatchBaseline_TfResourceType() *string
func NewDataAwsSsmPatchBaselineApprovalRuleList_Override ¶
func NewDataAwsSsmPatchBaselineApprovalRuleList_Override(d DataAwsSsmPatchBaselineApprovalRuleList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsSsmPatchBaselineApprovalRuleOutputReference_Override ¶
func NewDataAwsSsmPatchBaselineApprovalRuleOutputReference_Override(d DataAwsSsmPatchBaselineApprovalRuleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsSsmPatchBaselineApprovalRulePatchFilterList_Override ¶
func NewDataAwsSsmPatchBaselineApprovalRulePatchFilterList_Override(d DataAwsSsmPatchBaselineApprovalRulePatchFilterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsSsmPatchBaselineApprovalRulePatchFilterOutputReference_Override ¶
func NewDataAwsSsmPatchBaselineApprovalRulePatchFilterOutputReference_Override(d DataAwsSsmPatchBaselineApprovalRulePatchFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsSsmPatchBaselineGlobalFilterList_Override ¶
func NewDataAwsSsmPatchBaselineGlobalFilterList_Override(d DataAwsSsmPatchBaselineGlobalFilterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsSsmPatchBaselineGlobalFilterOutputReference_Override ¶
func NewDataAwsSsmPatchBaselineGlobalFilterOutputReference_Override(d DataAwsSsmPatchBaselineGlobalFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsSsmPatchBaselineSourceList_Override ¶
func NewDataAwsSsmPatchBaselineSourceList_Override(d DataAwsSsmPatchBaselineSourceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsSsmPatchBaselineSourceOutputReference_Override ¶
func NewDataAwsSsmPatchBaselineSourceOutputReference_Override(d DataAwsSsmPatchBaselineSourceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsSsmPatchBaseline_Override ¶
func NewDataAwsSsmPatchBaseline_Override(d DataAwsSsmPatchBaseline, scope constructs.Construct, id *string, config *DataAwsSsmPatchBaselineConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ssm_patch_baseline aws_ssm_patch_baseline} Data Source.
Types ¶
type DataAwsSsmPatchBaseline ¶
type DataAwsSsmPatchBaseline interface {
cdktf.TerraformDataSource
ApprovalRule() DataAwsSsmPatchBaselineApprovalRuleList
ApprovedPatches() *[]*string
ApprovedPatchesComplianceLevel() *string
ApprovedPatchesEnableNonSecurity() cdktf.IResolvable
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DefaultBaseline() interface{}
SetDefaultBaseline(val interface{})
DefaultBaselineInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GlobalFilter() DataAwsSsmPatchBaselineGlobalFilterList
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
NamePrefix() *string
SetNamePrefix(val *string)
NamePrefixInput() *string
// The tree node.
Node() constructs.Node
OperatingSystem() *string
SetOperatingSystem(val *string)
OperatingSystemInput() *string
Owner() *string
SetOwner(val *string)
OwnerInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
RejectedPatches() *[]*string
RejectedPatchesAction() *string
Source() DataAwsSsmPatchBaselineSourceList
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetDefaultBaseline()
ResetId()
ResetNamePrefix()
ResetOperatingSystem()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ssm_patch_baseline aws_ssm_patch_baseline}.
func NewDataAwsSsmPatchBaseline ¶
func NewDataAwsSsmPatchBaseline(scope constructs.Construct, id *string, config *DataAwsSsmPatchBaselineConfig) DataAwsSsmPatchBaseline
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ssm_patch_baseline aws_ssm_patch_baseline} Data Source.
type DataAwsSsmPatchBaselineApprovalRule ¶
type DataAwsSsmPatchBaselineApprovalRule struct {
}
type DataAwsSsmPatchBaselineApprovalRuleList ¶
type DataAwsSsmPatchBaselineApprovalRuleList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsSsmPatchBaselineApprovalRuleOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSsmPatchBaselineApprovalRuleList ¶
func NewDataAwsSsmPatchBaselineApprovalRuleList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsSsmPatchBaselineApprovalRuleList
type DataAwsSsmPatchBaselineApprovalRuleOutputReference ¶
type DataAwsSsmPatchBaselineApprovalRuleOutputReference interface {
cdktf.ComplexObject
ApproveAfterDays() *float64
ApproveUntilDate() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ComplianceLevel() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EnableNonSecurity() cdktf.IResolvable
// Experimental.
Fqn() *string
InternalValue() *DataAwsSsmPatchBaselineApprovalRule
SetInternalValue(val *DataAwsSsmPatchBaselineApprovalRule)
PatchFilter() DataAwsSsmPatchBaselineApprovalRulePatchFilterList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSsmPatchBaselineApprovalRuleOutputReference ¶
func NewDataAwsSsmPatchBaselineApprovalRuleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsSsmPatchBaselineApprovalRuleOutputReference
type DataAwsSsmPatchBaselineApprovalRulePatchFilter ¶
type DataAwsSsmPatchBaselineApprovalRulePatchFilter struct {
}
type DataAwsSsmPatchBaselineApprovalRulePatchFilterList ¶
type DataAwsSsmPatchBaselineApprovalRulePatchFilterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsSsmPatchBaselineApprovalRulePatchFilterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSsmPatchBaselineApprovalRulePatchFilterList ¶
func NewDataAwsSsmPatchBaselineApprovalRulePatchFilterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsSsmPatchBaselineApprovalRulePatchFilterList
type DataAwsSsmPatchBaselineApprovalRulePatchFilterOutputReference ¶
type DataAwsSsmPatchBaselineApprovalRulePatchFilterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsSsmPatchBaselineApprovalRulePatchFilter
SetInternalValue(val *DataAwsSsmPatchBaselineApprovalRulePatchFilter)
Key() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSsmPatchBaselineApprovalRulePatchFilterOutputReference ¶
func NewDataAwsSsmPatchBaselineApprovalRulePatchFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsSsmPatchBaselineApprovalRulePatchFilterOutputReference
type DataAwsSsmPatchBaselineConfig ¶
type DataAwsSsmPatchBaselineConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ssm_patch_baseline#owner DataAwsSsmPatchBaseline#owner}.
Owner *string `field:"required" json:"owner" yaml:"owner"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ssm_patch_baseline#default_baseline DataAwsSsmPatchBaseline#default_baseline}.
DefaultBaseline interface{} `field:"optional" json:"defaultBaseline" yaml:"defaultBaseline"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ssm_patch_baseline#id DataAwsSsmPatchBaseline#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ssm_patch_baseline#name_prefix DataAwsSsmPatchBaseline#name_prefix}.
NamePrefix *string `field:"optional" json:"namePrefix" yaml:"namePrefix"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/ssm_patch_baseline#operating_system DataAwsSsmPatchBaseline#operating_system}.
OperatingSystem *string `field:"optional" json:"operatingSystem" yaml:"operatingSystem"`
}
type DataAwsSsmPatchBaselineGlobalFilter ¶
type DataAwsSsmPatchBaselineGlobalFilter struct {
}
type DataAwsSsmPatchBaselineGlobalFilterList ¶
type DataAwsSsmPatchBaselineGlobalFilterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsSsmPatchBaselineGlobalFilterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSsmPatchBaselineGlobalFilterList ¶
func NewDataAwsSsmPatchBaselineGlobalFilterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsSsmPatchBaselineGlobalFilterList
type DataAwsSsmPatchBaselineGlobalFilterOutputReference ¶
type DataAwsSsmPatchBaselineGlobalFilterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsSsmPatchBaselineGlobalFilter
SetInternalValue(val *DataAwsSsmPatchBaselineGlobalFilter)
Key() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSsmPatchBaselineGlobalFilterOutputReference ¶
func NewDataAwsSsmPatchBaselineGlobalFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsSsmPatchBaselineGlobalFilterOutputReference
type DataAwsSsmPatchBaselineSource ¶
type DataAwsSsmPatchBaselineSource struct {
}
type DataAwsSsmPatchBaselineSourceList ¶
type DataAwsSsmPatchBaselineSourceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsSsmPatchBaselineSourceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSsmPatchBaselineSourceList ¶
func NewDataAwsSsmPatchBaselineSourceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsSsmPatchBaselineSourceList
type DataAwsSsmPatchBaselineSourceOutputReference ¶
type DataAwsSsmPatchBaselineSourceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Configuration() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsSsmPatchBaselineSource
SetInternalValue(val *DataAwsSsmPatchBaselineSource)
Name() *string
Products() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsSsmPatchBaselineSourceOutputReference ¶
func NewDataAwsSsmPatchBaselineSourceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsSsmPatchBaselineSourceOutputReference
Source Files
¶
- DataAwsSsmPatchBaseline.go
- DataAwsSsmPatchBaselineApprovalRule.go
- DataAwsSsmPatchBaselineApprovalRuleList.go
- DataAwsSsmPatchBaselineApprovalRuleList__checks.go
- DataAwsSsmPatchBaselineApprovalRuleOutputReference.go
- DataAwsSsmPatchBaselineApprovalRuleOutputReference__checks.go
- DataAwsSsmPatchBaselineApprovalRulePatchFilter.go
- DataAwsSsmPatchBaselineApprovalRulePatchFilterList.go
- DataAwsSsmPatchBaselineApprovalRulePatchFilterList__checks.go
- DataAwsSsmPatchBaselineApprovalRulePatchFilterOutputReference.go
- DataAwsSsmPatchBaselineApprovalRulePatchFilterOutputReference__checks.go
- DataAwsSsmPatchBaselineConfig.go
- DataAwsSsmPatchBaselineGlobalFilter.go
- DataAwsSsmPatchBaselineGlobalFilterList.go
- DataAwsSsmPatchBaselineGlobalFilterList__checks.go
- DataAwsSsmPatchBaselineGlobalFilterOutputReference.go
- DataAwsSsmPatchBaselineGlobalFilterOutputReference__checks.go
- DataAwsSsmPatchBaselineSource.go
- DataAwsSsmPatchBaselineSourceList.go
- DataAwsSsmPatchBaselineSourceList__checks.go
- DataAwsSsmPatchBaselineSourceOutputReference.go
- DataAwsSsmPatchBaselineSourceOutputReference__checks.go
- DataAwsSsmPatchBaseline__checks.go
- main.go