Documentation
¶
Index ¶
- func DataAwsVpcDhcpOptions_IsConstruct(x interface{}) *bool
- func DataAwsVpcDhcpOptions_IsTerraformDataSource(x interface{}) *bool
- func DataAwsVpcDhcpOptions_IsTerraformElement(x interface{}) *bool
- func DataAwsVpcDhcpOptions_TfResourceType() *string
- func NewDataAwsVpcDhcpOptionsFilterList_Override(d DataAwsVpcDhcpOptionsFilterList, ...)
- func NewDataAwsVpcDhcpOptionsFilterOutputReference_Override(d DataAwsVpcDhcpOptionsFilterOutputReference, ...)
- func NewDataAwsVpcDhcpOptionsTimeoutsOutputReference_Override(d DataAwsVpcDhcpOptionsTimeoutsOutputReference, ...)
- func NewDataAwsVpcDhcpOptions_Override(d DataAwsVpcDhcpOptions, scope constructs.Construct, id *string, ...)
- type DataAwsVpcDhcpOptions
- type DataAwsVpcDhcpOptionsConfig
- type DataAwsVpcDhcpOptionsFilter
- type DataAwsVpcDhcpOptionsFilterList
- type DataAwsVpcDhcpOptionsFilterOutputReference
- type DataAwsVpcDhcpOptionsTimeouts
- type DataAwsVpcDhcpOptionsTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsVpcDhcpOptions_IsConstruct ¶
func DataAwsVpcDhcpOptions_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsVpcDhcpOptions_IsTerraformDataSource ¶
func DataAwsVpcDhcpOptions_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsVpcDhcpOptions_IsTerraformElement ¶
func DataAwsVpcDhcpOptions_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsVpcDhcpOptions_TfResourceType ¶
func DataAwsVpcDhcpOptions_TfResourceType() *string
func NewDataAwsVpcDhcpOptionsFilterList_Override ¶
func NewDataAwsVpcDhcpOptionsFilterList_Override(d DataAwsVpcDhcpOptionsFilterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsVpcDhcpOptionsFilterOutputReference_Override ¶
func NewDataAwsVpcDhcpOptionsFilterOutputReference_Override(d DataAwsVpcDhcpOptionsFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsVpcDhcpOptionsTimeoutsOutputReference_Override ¶
func NewDataAwsVpcDhcpOptionsTimeoutsOutputReference_Override(d DataAwsVpcDhcpOptionsTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDataAwsVpcDhcpOptions_Override ¶
func NewDataAwsVpcDhcpOptions_Override(d DataAwsVpcDhcpOptions, scope constructs.Construct, id *string, config *DataAwsVpcDhcpOptionsConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/vpc_dhcp_options aws_vpc_dhcp_options} Data Source.
Types ¶
type DataAwsVpcDhcpOptions ¶
type DataAwsVpcDhcpOptions interface {
cdktf.TerraformDataSource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DhcpOptionsId() *string
SetDhcpOptionsId(val *string)
DhcpOptionsIdInput() *string
DomainName() *string
DomainNameServers() *[]*string
Filter() DataAwsVpcDhcpOptionsFilterList
FilterInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
NetbiosNameServers() *[]*string
NetbiosNodeType() *string
// The tree node.
Node() constructs.Node
NtpServers() *[]*string
OwnerId() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DataAwsVpcDhcpOptionsTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutFilter(value interface{})
PutTimeouts(value *DataAwsVpcDhcpOptionsTimeouts)
ResetDhcpOptionsId()
ResetFilter()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/vpc_dhcp_options aws_vpc_dhcp_options}.
func NewDataAwsVpcDhcpOptions ¶
func NewDataAwsVpcDhcpOptions(scope constructs.Construct, id *string, config *DataAwsVpcDhcpOptionsConfig) DataAwsVpcDhcpOptions
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/vpc_dhcp_options aws_vpc_dhcp_options} Data Source.
type DataAwsVpcDhcpOptionsConfig ¶
type DataAwsVpcDhcpOptionsConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/vpc_dhcp_options#dhcp_options_id DataAwsVpcDhcpOptions#dhcp_options_id}.
DhcpOptionsId *string `field:"optional" json:"dhcpOptionsId" yaml:"dhcpOptionsId"`
// filter block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/vpc_dhcp_options#filter DataAwsVpcDhcpOptions#filter}
Filter interface{} `field:"optional" json:"filter" yaml:"filter"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/vpc_dhcp_options#id DataAwsVpcDhcpOptions#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/vpc_dhcp_options#tags DataAwsVpcDhcpOptions#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/vpc_dhcp_options#timeouts DataAwsVpcDhcpOptions#timeouts}
Timeouts *DataAwsVpcDhcpOptionsTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type DataAwsVpcDhcpOptionsFilter ¶
type DataAwsVpcDhcpOptionsFilter struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/vpc_dhcp_options#name DataAwsVpcDhcpOptions#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/vpc_dhcp_options#values DataAwsVpcDhcpOptions#values}.
Values *[]*string `field:"required" json:"values" yaml:"values"`
}
type DataAwsVpcDhcpOptionsFilterList ¶
type DataAwsVpcDhcpOptionsFilterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsVpcDhcpOptionsFilterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsVpcDhcpOptionsFilterList ¶
func NewDataAwsVpcDhcpOptionsFilterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsVpcDhcpOptionsFilterList
type DataAwsVpcDhcpOptionsFilterOutputReference ¶
type DataAwsVpcDhcpOptionsFilterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
SetValues(val *[]*string)
ValuesInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsVpcDhcpOptionsFilterOutputReference ¶
func NewDataAwsVpcDhcpOptionsFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsVpcDhcpOptionsFilterOutputReference
type DataAwsVpcDhcpOptionsTimeouts ¶
type DataAwsVpcDhcpOptionsTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/data-sources/vpc_dhcp_options#read DataAwsVpcDhcpOptions#read}.
Read *string `field:"optional" json:"read" yaml:"read"`
}
type DataAwsVpcDhcpOptionsTimeoutsOutputReference ¶
type DataAwsVpcDhcpOptionsTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Read() *string
SetRead(val *string)
ReadInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetRead()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsVpcDhcpOptionsTimeoutsOutputReference ¶
func NewDataAwsVpcDhcpOptionsTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DataAwsVpcDhcpOptionsTimeoutsOutputReference
Source Files
¶
- DataAwsVpcDhcpOptions.go
- DataAwsVpcDhcpOptionsConfig.go
- DataAwsVpcDhcpOptionsFilter.go
- DataAwsVpcDhcpOptionsFilterList.go
- DataAwsVpcDhcpOptionsFilterList__checks.go
- DataAwsVpcDhcpOptionsFilterOutputReference.go
- DataAwsVpcDhcpOptionsFilterOutputReference__checks.go
- DataAwsVpcDhcpOptionsTimeouts.go
- DataAwsVpcDhcpOptionsTimeoutsOutputReference.go
- DataAwsVpcDhcpOptionsTimeoutsOutputReference__checks.go
- DataAwsVpcDhcpOptions__checks.go
- main.go