Documentation
¶
Index ¶
- func DatasyncLocationObjectStorage_IsConstruct(x interface{}) *bool
- func DatasyncLocationObjectStorage_IsTerraformElement(x interface{}) *bool
- func DatasyncLocationObjectStorage_IsTerraformResource(x interface{}) *bool
- func DatasyncLocationObjectStorage_TfResourceType() *string
- func NewDatasyncLocationObjectStorage_Override(d DatasyncLocationObjectStorage, scope constructs.Construct, id *string, ...)
- type DatasyncLocationObjectStorage
- type DatasyncLocationObjectStorageConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DatasyncLocationObjectStorage_IsConstruct ¶
func DatasyncLocationObjectStorage_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DatasyncLocationObjectStorage_IsTerraformElement ¶
func DatasyncLocationObjectStorage_IsTerraformElement(x interface{}) *bool
Experimental.
func DatasyncLocationObjectStorage_IsTerraformResource ¶
func DatasyncLocationObjectStorage_IsTerraformResource(x interface{}) *bool
Experimental.
func DatasyncLocationObjectStorage_TfResourceType ¶
func DatasyncLocationObjectStorage_TfResourceType() *string
func NewDatasyncLocationObjectStorage_Override ¶
func NewDatasyncLocationObjectStorage_Override(d DatasyncLocationObjectStorage, scope constructs.Construct, id *string, config *DatasyncLocationObjectStorageConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_location_object_storage aws_datasync_location_object_storage} Resource.
Types ¶
type DatasyncLocationObjectStorage ¶
type DatasyncLocationObjectStorage interface {
cdktf.TerraformResource
AccessKey() *string
SetAccessKey(val *string)
AccessKeyInput() *string
AgentArns() *[]*string
SetAgentArns(val *[]*string)
AgentArnsInput() *[]*string
Arn() *string
BucketName() *string
SetBucketName(val *string)
BucketNameInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SecretKey() *string
SetSecretKey(val *string)
SecretKeyInput() *string
ServerCertificate() *string
SetServerCertificate(val *string)
ServerCertificateInput() *string
ServerHostname() *string
SetServerHostname(val *string)
ServerHostnameInput() *string
ServerPort() *float64
SetServerPort(val *float64)
ServerPortInput() *float64
ServerProtocol() *string
SetServerProtocol(val *string)
ServerProtocolInput() *string
Subdirectory() *string
SetSubdirectory(val *string)
SubdirectoryInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Uri() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetAccessKey()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSecretKey()
ResetServerCertificate()
ResetServerPort()
ResetServerProtocol()
ResetSubdirectory()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_location_object_storage aws_datasync_location_object_storage}.
func NewDatasyncLocationObjectStorage ¶
func NewDatasyncLocationObjectStorage(scope constructs.Construct, id *string, config *DatasyncLocationObjectStorageConfig) DatasyncLocationObjectStorage
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_location_object_storage aws_datasync_location_object_storage} Resource.
type DatasyncLocationObjectStorageConfig ¶
type DatasyncLocationObjectStorageConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_location_object_storage#agent_arns DatasyncLocationObjectStorage#agent_arns}.
AgentArns *[]*string `field:"required" json:"agentArns" yaml:"agentArns"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_location_object_storage#bucket_name DatasyncLocationObjectStorage#bucket_name}.
BucketName *string `field:"required" json:"bucketName" yaml:"bucketName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_location_object_storage#server_hostname DatasyncLocationObjectStorage#server_hostname}.
ServerHostname *string `field:"required" json:"serverHostname" yaml:"serverHostname"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_location_object_storage#access_key DatasyncLocationObjectStorage#access_key}.
AccessKey *string `field:"optional" json:"accessKey" yaml:"accessKey"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_location_object_storage#id DatasyncLocationObjectStorage#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_location_object_storage#secret_key DatasyncLocationObjectStorage#secret_key}.
SecretKey *string `field:"optional" json:"secretKey" yaml:"secretKey"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_location_object_storage#server_certificate DatasyncLocationObjectStorage#server_certificate}.
ServerCertificate *string `field:"optional" json:"serverCertificate" yaml:"serverCertificate"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_location_object_storage#server_port DatasyncLocationObjectStorage#server_port}.
ServerPort *float64 `field:"optional" json:"serverPort" yaml:"serverPort"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_location_object_storage#server_protocol DatasyncLocationObjectStorage#server_protocol}.
ServerProtocol *string `field:"optional" json:"serverProtocol" yaml:"serverProtocol"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_location_object_storage#subdirectory DatasyncLocationObjectStorage#subdirectory}.
Subdirectory *string `field:"optional" json:"subdirectory" yaml:"subdirectory"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_location_object_storage#tags DatasyncLocationObjectStorage#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_location_object_storage#tags_all DatasyncLocationObjectStorage#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}