Documentation
¶
Index ¶
- func DatasyncTask_IsConstruct(x interface{}) *bool
- func DatasyncTask_IsTerraformElement(x interface{}) *bool
- func DatasyncTask_IsTerraformResource(x interface{}) *bool
- func DatasyncTask_TfResourceType() *string
- func NewDatasyncTaskExcludesOutputReference_Override(d DatasyncTaskExcludesOutputReference, ...)
- func NewDatasyncTaskIncludesOutputReference_Override(d DatasyncTaskIncludesOutputReference, ...)
- func NewDatasyncTaskOptionsOutputReference_Override(d DatasyncTaskOptionsOutputReference, ...)
- func NewDatasyncTaskScheduleOutputReference_Override(d DatasyncTaskScheduleOutputReference, ...)
- func NewDatasyncTaskTimeoutsOutputReference_Override(d DatasyncTaskTimeoutsOutputReference, ...)
- func NewDatasyncTask_Override(d DatasyncTask, scope constructs.Construct, id *string, ...)
- type DatasyncTask
- type DatasyncTaskConfig
- type DatasyncTaskExcludes
- type DatasyncTaskExcludesOutputReference
- type DatasyncTaskIncludes
- type DatasyncTaskIncludesOutputReference
- type DatasyncTaskOptions
- type DatasyncTaskOptionsOutputReference
- type DatasyncTaskSchedule
- type DatasyncTaskScheduleOutputReference
- type DatasyncTaskTimeouts
- type DatasyncTaskTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DatasyncTask_IsConstruct ¶
func DatasyncTask_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DatasyncTask_IsTerraformElement ¶
func DatasyncTask_IsTerraformElement(x interface{}) *bool
Experimental.
func DatasyncTask_IsTerraformResource ¶
func DatasyncTask_IsTerraformResource(x interface{}) *bool
Experimental.
func DatasyncTask_TfResourceType ¶
func DatasyncTask_TfResourceType() *string
func NewDatasyncTaskExcludesOutputReference_Override ¶
func NewDatasyncTaskExcludesOutputReference_Override(d DatasyncTaskExcludesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDatasyncTaskIncludesOutputReference_Override ¶
func NewDatasyncTaskIncludesOutputReference_Override(d DatasyncTaskIncludesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDatasyncTaskOptionsOutputReference_Override ¶
func NewDatasyncTaskOptionsOutputReference_Override(d DatasyncTaskOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDatasyncTaskScheduleOutputReference_Override ¶
func NewDatasyncTaskScheduleOutputReference_Override(d DatasyncTaskScheduleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDatasyncTaskTimeoutsOutputReference_Override ¶
func NewDatasyncTaskTimeoutsOutputReference_Override(d DatasyncTaskTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDatasyncTask_Override ¶
func NewDatasyncTask_Override(d DatasyncTask, scope constructs.Construct, id *string, config *DatasyncTaskConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task aws_datasync_task} Resource.
Types ¶
type DatasyncTask ¶
type DatasyncTask interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CloudwatchLogGroupArn() *string
SetCloudwatchLogGroupArn(val *string)
CloudwatchLogGroupArnInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DestinationLocationArn() *string
SetDestinationLocationArn(val *string)
DestinationLocationArnInput() *string
Excludes() DatasyncTaskExcludesOutputReference
ExcludesInput() *DatasyncTaskExcludes
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Includes() DatasyncTaskIncludesOutputReference
IncludesInput() *DatasyncTaskIncludes
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Options() DatasyncTaskOptionsOutputReference
OptionsInput() *DatasyncTaskOptions
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Schedule() DatasyncTaskScheduleOutputReference
ScheduleInput() *DatasyncTaskSchedule
SourceLocationArn() *string
SetSourceLocationArn(val *string)
SourceLocationArnInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DatasyncTaskTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutExcludes(value *DatasyncTaskExcludes)
PutIncludes(value *DatasyncTaskIncludes)
PutOptions(value *DatasyncTaskOptions)
PutSchedule(value *DatasyncTaskSchedule)
PutTimeouts(value *DatasyncTaskTimeouts)
ResetCloudwatchLogGroupArn()
ResetExcludes()
ResetId()
ResetIncludes()
ResetName()
ResetOptions()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSchedule()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task aws_datasync_task}.
func NewDatasyncTask ¶
func NewDatasyncTask(scope constructs.Construct, id *string, config *DatasyncTaskConfig) DatasyncTask
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task aws_datasync_task} Resource.
type DatasyncTaskConfig ¶
type DatasyncTaskConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#destination_location_arn DatasyncTask#destination_location_arn}.
DestinationLocationArn *string `field:"required" json:"destinationLocationArn" yaml:"destinationLocationArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#source_location_arn DatasyncTask#source_location_arn}.
SourceLocationArn *string `field:"required" json:"sourceLocationArn" yaml:"sourceLocationArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#cloudwatch_log_group_arn DatasyncTask#cloudwatch_log_group_arn}.
CloudwatchLogGroupArn *string `field:"optional" json:"cloudwatchLogGroupArn" yaml:"cloudwatchLogGroupArn"`
// excludes block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#excludes DatasyncTask#excludes}
Excludes *DatasyncTaskExcludes `field:"optional" json:"excludes" yaml:"excludes"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#id DatasyncTask#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// includes block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#includes DatasyncTask#includes}
Includes *DatasyncTaskIncludes `field:"optional" json:"includes" yaml:"includes"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#name DatasyncTask#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#options DatasyncTask#options}
Options *DatasyncTaskOptions `field:"optional" json:"options" yaml:"options"`
// schedule block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#schedule DatasyncTask#schedule}
Schedule *DatasyncTaskSchedule `field:"optional" json:"schedule" yaml:"schedule"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#tags DatasyncTask#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#tags_all DatasyncTask#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#timeouts DatasyncTask#timeouts}
Timeouts *DatasyncTaskTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type DatasyncTaskExcludes ¶
type DatasyncTaskExcludes struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#filter_type DatasyncTask#filter_type}.
FilterType *string `field:"optional" json:"filterType" yaml:"filterType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#value DatasyncTask#value}.
Value *string `field:"optional" json:"value" yaml:"value"`
}
type DatasyncTaskExcludesOutputReference ¶
type DatasyncTaskExcludesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FilterType() *string
SetFilterType(val *string)
FilterTypeInput() *string
// Experimental.
Fqn() *string
InternalValue() *DatasyncTaskExcludes
SetInternalValue(val *DatasyncTaskExcludes)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetFilterType()
ResetValue()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDatasyncTaskExcludesOutputReference ¶
func NewDatasyncTaskExcludesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DatasyncTaskExcludesOutputReference
type DatasyncTaskIncludes ¶
type DatasyncTaskIncludes struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#filter_type DatasyncTask#filter_type}.
FilterType *string `field:"optional" json:"filterType" yaml:"filterType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#value DatasyncTask#value}.
Value *string `field:"optional" json:"value" yaml:"value"`
}
type DatasyncTaskIncludesOutputReference ¶
type DatasyncTaskIncludesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FilterType() *string
SetFilterType(val *string)
FilterTypeInput() *string
// Experimental.
Fqn() *string
InternalValue() *DatasyncTaskIncludes
SetInternalValue(val *DatasyncTaskIncludes)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetFilterType()
ResetValue()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDatasyncTaskIncludesOutputReference ¶
func NewDatasyncTaskIncludesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DatasyncTaskIncludesOutputReference
type DatasyncTaskOptions ¶
type DatasyncTaskOptions struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#atime DatasyncTask#atime}.
Atime *string `field:"optional" json:"atime" yaml:"atime"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#bytes_per_second DatasyncTask#bytes_per_second}.
BytesPerSecond *float64 `field:"optional" json:"bytesPerSecond" yaml:"bytesPerSecond"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#gid DatasyncTask#gid}.
Gid *string `field:"optional" json:"gid" yaml:"gid"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#log_level DatasyncTask#log_level}.
LogLevel *string `field:"optional" json:"logLevel" yaml:"logLevel"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#mtime DatasyncTask#mtime}.
Mtime *string `field:"optional" json:"mtime" yaml:"mtime"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#overwrite_mode DatasyncTask#overwrite_mode}.
OverwriteMode *string `field:"optional" json:"overwriteMode" yaml:"overwriteMode"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#posix_permissions DatasyncTask#posix_permissions}.
PosixPermissions *string `field:"optional" json:"posixPermissions" yaml:"posixPermissions"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#preserve_deleted_files DatasyncTask#preserve_deleted_files}.
PreserveDeletedFiles *string `field:"optional" json:"preserveDeletedFiles" yaml:"preserveDeletedFiles"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#preserve_devices DatasyncTask#preserve_devices}.
PreserveDevices *string `field:"optional" json:"preserveDevices" yaml:"preserveDevices"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#security_descriptor_copy_flags DatasyncTask#security_descriptor_copy_flags}.
SecurityDescriptorCopyFlags *string `field:"optional" json:"securityDescriptorCopyFlags" yaml:"securityDescriptorCopyFlags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#task_queueing DatasyncTask#task_queueing}.
TaskQueueing *string `field:"optional" json:"taskQueueing" yaml:"taskQueueing"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#transfer_mode DatasyncTask#transfer_mode}.
TransferMode *string `field:"optional" json:"transferMode" yaml:"transferMode"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#uid DatasyncTask#uid}.
Uid *string `field:"optional" json:"uid" yaml:"uid"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#verify_mode DatasyncTask#verify_mode}.
VerifyMode *string `field:"optional" json:"verifyMode" yaml:"verifyMode"`
}
type DatasyncTaskOptionsOutputReference ¶
type DatasyncTaskOptionsOutputReference interface {
cdktf.ComplexObject
Atime() *string
SetAtime(val *string)
AtimeInput() *string
BytesPerSecond() *float64
SetBytesPerSecond(val *float64)
BytesPerSecondInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Gid() *string
SetGid(val *string)
GidInput() *string
InternalValue() *DatasyncTaskOptions
SetInternalValue(val *DatasyncTaskOptions)
LogLevel() *string
SetLogLevel(val *string)
LogLevelInput() *string
Mtime() *string
SetMtime(val *string)
MtimeInput() *string
OverwriteMode() *string
SetOverwriteMode(val *string)
OverwriteModeInput() *string
PosixPermissions() *string
SetPosixPermissions(val *string)
PosixPermissionsInput() *string
PreserveDeletedFiles() *string
SetPreserveDeletedFiles(val *string)
PreserveDeletedFilesInput() *string
PreserveDevices() *string
SetPreserveDevices(val *string)
PreserveDevicesInput() *string
SecurityDescriptorCopyFlags() *string
SetSecurityDescriptorCopyFlags(val *string)
SecurityDescriptorCopyFlagsInput() *string
TaskQueueing() *string
SetTaskQueueing(val *string)
TaskQueueingInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TransferMode() *string
SetTransferMode(val *string)
TransferModeInput() *string
Uid() *string
SetUid(val *string)
UidInput() *string
VerifyMode() *string
SetVerifyMode(val *string)
VerifyModeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAtime()
ResetBytesPerSecond()
ResetGid()
ResetLogLevel()
ResetMtime()
ResetOverwriteMode()
ResetPosixPermissions()
ResetPreserveDeletedFiles()
ResetPreserveDevices()
ResetSecurityDescriptorCopyFlags()
ResetTaskQueueing()
ResetTransferMode()
ResetUid()
ResetVerifyMode()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDatasyncTaskOptionsOutputReference ¶
func NewDatasyncTaskOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DatasyncTaskOptionsOutputReference
type DatasyncTaskSchedule ¶
type DatasyncTaskSchedule struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#schedule_expression DatasyncTask#schedule_expression}.
ScheduleExpression *string `field:"required" json:"scheduleExpression" yaml:"scheduleExpression"`
}
type DatasyncTaskScheduleOutputReference ¶
type DatasyncTaskScheduleOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DatasyncTaskSchedule
SetInternalValue(val *DatasyncTaskSchedule)
ScheduleExpression() *string
SetScheduleExpression(val *string)
ScheduleExpressionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDatasyncTaskScheduleOutputReference ¶
func NewDatasyncTaskScheduleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DatasyncTaskScheduleOutputReference
type DatasyncTaskTimeouts ¶
type DatasyncTaskTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/datasync_task#create DatasyncTask#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
}
type DatasyncTaskTimeoutsOutputReference ¶
type DatasyncTaskTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDatasyncTaskTimeoutsOutputReference ¶
func NewDatasyncTaskTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DatasyncTaskTimeoutsOutputReference
Source Files
¶
- DatasyncTask.go
- DatasyncTaskConfig.go
- DatasyncTaskExcludes.go
- DatasyncTaskExcludesOutputReference.go
- DatasyncTaskExcludesOutputReference__checks.go
- DatasyncTaskIncludes.go
- DatasyncTaskIncludesOutputReference.go
- DatasyncTaskIncludesOutputReference__checks.go
- DatasyncTaskOptions.go
- DatasyncTaskOptionsOutputReference.go
- DatasyncTaskOptionsOutputReference__checks.go
- DatasyncTaskSchedule.go
- DatasyncTaskScheduleOutputReference.go
- DatasyncTaskScheduleOutputReference__checks.go
- DatasyncTaskTimeouts.go
- DatasyncTaskTimeoutsOutputReference.go
- DatasyncTaskTimeoutsOutputReference__checks.go
- DatasyncTask__checks.go
- main.go