Documentation
¶
Index ¶
- func DbInstance_IsConstruct(x interface{}) *bool
- func DbInstance_IsTerraformElement(x interface{}) *bool
- func DbInstance_IsTerraformResource(x interface{}) *bool
- func DbInstance_TfResourceType() *string
- func NewDbInstanceBlueGreenUpdateOutputReference_Override(d DbInstanceBlueGreenUpdateOutputReference, ...)
- func NewDbInstanceListenerEndpointList_Override(d DbInstanceListenerEndpointList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewDbInstanceListenerEndpointOutputReference_Override(d DbInstanceListenerEndpointOutputReference, ...)
- func NewDbInstanceMasterUserSecretList_Override(d DbInstanceMasterUserSecretList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewDbInstanceMasterUserSecretOutputReference_Override(d DbInstanceMasterUserSecretOutputReference, ...)
- func NewDbInstanceRestoreToPointInTimeOutputReference_Override(d DbInstanceRestoreToPointInTimeOutputReference, ...)
- func NewDbInstanceS3ImportOutputReference_Override(d DbInstanceS3ImportOutputReference, ...)
- func NewDbInstanceTimeoutsOutputReference_Override(d DbInstanceTimeoutsOutputReference, ...)
- func NewDbInstance_Override(d DbInstance, scope constructs.Construct, id *string, config *DbInstanceConfig)
- type DbInstance
- type DbInstanceBlueGreenUpdate
- type DbInstanceBlueGreenUpdateOutputReference
- type DbInstanceConfig
- type DbInstanceListenerEndpoint
- type DbInstanceListenerEndpointList
- type DbInstanceListenerEndpointOutputReference
- type DbInstanceMasterUserSecret
- type DbInstanceMasterUserSecretList
- type DbInstanceMasterUserSecretOutputReference
- type DbInstanceRestoreToPointInTime
- type DbInstanceRestoreToPointInTimeOutputReference
- type DbInstanceS3Import
- type DbInstanceS3ImportOutputReference
- type DbInstanceTimeouts
- type DbInstanceTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DbInstance_IsConstruct ¶
func DbInstance_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DbInstance_IsTerraformElement ¶
func DbInstance_IsTerraformElement(x interface{}) *bool
Experimental.
func DbInstance_IsTerraformResource ¶
func DbInstance_IsTerraformResource(x interface{}) *bool
Experimental.
func DbInstance_TfResourceType ¶
func DbInstance_TfResourceType() *string
func NewDbInstanceBlueGreenUpdateOutputReference_Override ¶
func NewDbInstanceBlueGreenUpdateOutputReference_Override(d DbInstanceBlueGreenUpdateOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDbInstanceListenerEndpointList_Override ¶
func NewDbInstanceListenerEndpointList_Override(d DbInstanceListenerEndpointList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDbInstanceListenerEndpointOutputReference_Override ¶
func NewDbInstanceListenerEndpointOutputReference_Override(d DbInstanceListenerEndpointOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDbInstanceMasterUserSecretList_Override ¶
func NewDbInstanceMasterUserSecretList_Override(d DbInstanceMasterUserSecretList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDbInstanceMasterUserSecretOutputReference_Override ¶
func NewDbInstanceMasterUserSecretOutputReference_Override(d DbInstanceMasterUserSecretOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDbInstanceRestoreToPointInTimeOutputReference_Override ¶
func NewDbInstanceRestoreToPointInTimeOutputReference_Override(d DbInstanceRestoreToPointInTimeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDbInstanceS3ImportOutputReference_Override ¶
func NewDbInstanceS3ImportOutputReference_Override(d DbInstanceS3ImportOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDbInstanceTimeoutsOutputReference_Override ¶
func NewDbInstanceTimeoutsOutputReference_Override(d DbInstanceTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDbInstance_Override ¶
func NewDbInstance_Override(d DbInstance, scope constructs.Construct, id *string, config *DbInstanceConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance aws_db_instance} Resource.
Types ¶
type DbInstance ¶
type DbInstance interface {
cdktf.TerraformResource
Address() *string
AllocatedStorage() *float64
SetAllocatedStorage(val *float64)
AllocatedStorageInput() *float64
AllowMajorVersionUpgrade() interface{}
SetAllowMajorVersionUpgrade(val interface{})
AllowMajorVersionUpgradeInput() interface{}
ApplyImmediately() interface{}
SetApplyImmediately(val interface{})
ApplyImmediatelyInput() interface{}
Arn() *string
AutoMinorVersionUpgrade() interface{}
SetAutoMinorVersionUpgrade(val interface{})
AutoMinorVersionUpgradeInput() interface{}
AvailabilityZone() *string
SetAvailabilityZone(val *string)
AvailabilityZoneInput() *string
BackupRetentionPeriod() *float64
SetBackupRetentionPeriod(val *float64)
BackupRetentionPeriodInput() *float64
BackupWindow() *string
SetBackupWindow(val *string)
BackupWindowInput() *string
BlueGreenUpdate() DbInstanceBlueGreenUpdateOutputReference
BlueGreenUpdateInput() *DbInstanceBlueGreenUpdate
CaCertIdentifier() *string
SetCaCertIdentifier(val *string)
CaCertIdentifierInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CharacterSetName() *string
SetCharacterSetName(val *string)
CharacterSetNameInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
CopyTagsToSnapshot() interface{}
SetCopyTagsToSnapshot(val interface{})
CopyTagsToSnapshotInput() interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CustomerOwnedIpEnabled() interface{}
SetCustomerOwnedIpEnabled(val interface{})
CustomerOwnedIpEnabledInput() interface{}
CustomIamInstanceProfile() *string
SetCustomIamInstanceProfile(val *string)
CustomIamInstanceProfileInput() *string
DbName() *string
SetDbName(val *string)
DbNameInput() *string
DbSubnetGroupName() *string
SetDbSubnetGroupName(val *string)
DbSubnetGroupNameInput() *string
DeleteAutomatedBackups() interface{}
SetDeleteAutomatedBackups(val interface{})
DeleteAutomatedBackupsInput() interface{}
DeletionProtection() interface{}
SetDeletionProtection(val interface{})
DeletionProtectionInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Domain() *string
SetDomain(val *string)
DomainIamRoleName() *string
SetDomainIamRoleName(val *string)
DomainIamRoleNameInput() *string
DomainInput() *string
EnabledCloudwatchLogsExports() *[]*string
SetEnabledCloudwatchLogsExports(val *[]*string)
EnabledCloudwatchLogsExportsInput() *[]*string
Endpoint() *string
Engine() *string
SetEngine(val *string)
EngineInput() *string
EngineVersion() *string
SetEngineVersion(val *string)
EngineVersionActual() *string
EngineVersionInput() *string
FinalSnapshotIdentifier() *string
SetFinalSnapshotIdentifier(val *string)
FinalSnapshotIdentifierInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HostedZoneId() *string
IamDatabaseAuthenticationEnabled() interface{}
SetIamDatabaseAuthenticationEnabled(val interface{})
IamDatabaseAuthenticationEnabledInput() interface{}
Id() *string
SetId(val *string)
Identifier() *string
SetIdentifier(val *string)
IdentifierInput() *string
IdentifierPrefix() *string
SetIdentifierPrefix(val *string)
IdentifierPrefixInput() *string
IdInput() *string
InstanceClass() *string
SetInstanceClass(val *string)
InstanceClassInput() *string
Iops() *float64
SetIops(val *float64)
IopsInput() *float64
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
LatestRestorableTime() *string
LicenseModel() *string
SetLicenseModel(val *string)
LicenseModelInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
ListenerEndpoint() DbInstanceListenerEndpointList
MaintenanceWindow() *string
SetMaintenanceWindow(val *string)
MaintenanceWindowInput() *string
ManageMasterUserPassword() interface{}
SetManageMasterUserPassword(val interface{})
ManageMasterUserPasswordInput() interface{}
MasterUserSecret() DbInstanceMasterUserSecretList
MasterUserSecretKmsKeyId() *string
SetMasterUserSecretKmsKeyId(val *string)
MasterUserSecretKmsKeyIdInput() *string
MaxAllocatedStorage() *float64
SetMaxAllocatedStorage(val *float64)
MaxAllocatedStorageInput() *float64
MonitoringInterval() *float64
SetMonitoringInterval(val *float64)
MonitoringIntervalInput() *float64
MonitoringRoleArn() *string
SetMonitoringRoleArn(val *string)
MonitoringRoleArnInput() *string
MultiAz() interface{}
SetMultiAz(val interface{})
MultiAzInput() interface{}
Name() *string
SetName(val *string)
NameInput() *string
NcharCharacterSetName() *string
SetNcharCharacterSetName(val *string)
NcharCharacterSetNameInput() *string
NetworkType() *string
SetNetworkType(val *string)
NetworkTypeInput() *string
// The tree node.
Node() constructs.Node
OptionGroupName() *string
SetOptionGroupName(val *string)
OptionGroupNameInput() *string
ParameterGroupName() *string
SetParameterGroupName(val *string)
ParameterGroupNameInput() *string
Password() *string
SetPassword(val *string)
PasswordInput() *string
PerformanceInsightsEnabled() interface{}
SetPerformanceInsightsEnabled(val interface{})
PerformanceInsightsEnabledInput() interface{}
PerformanceInsightsKmsKeyId() *string
SetPerformanceInsightsKmsKeyId(val *string)
PerformanceInsightsKmsKeyIdInput() *string
PerformanceInsightsRetentionPeriod() *float64
SetPerformanceInsightsRetentionPeriod(val *float64)
PerformanceInsightsRetentionPeriodInput() *float64
Port() *float64
SetPort(val *float64)
PortInput() *float64
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
PubliclyAccessible() interface{}
SetPubliclyAccessible(val interface{})
PubliclyAccessibleInput() interface{}
// Experimental.
RawOverrides() interface{}
ReplicaMode() *string
SetReplicaMode(val *string)
ReplicaModeInput() *string
Replicas() *[]*string
ReplicateSourceDb() *string
SetReplicateSourceDb(val *string)
ReplicateSourceDbInput() *string
ResourceId() *string
RestoreToPointInTime() DbInstanceRestoreToPointInTimeOutputReference
RestoreToPointInTimeInput() *DbInstanceRestoreToPointInTime
S3Import() DbInstanceS3ImportOutputReference
S3ImportInput() *DbInstanceS3Import
SecurityGroupNames() *[]*string
SetSecurityGroupNames(val *[]*string)
SecurityGroupNamesInput() *[]*string
SkipFinalSnapshot() interface{}
SetSkipFinalSnapshot(val interface{})
SkipFinalSnapshotInput() interface{}
SnapshotIdentifier() *string
SetSnapshotIdentifier(val *string)
SnapshotIdentifierInput() *string
Status() *string
StorageEncrypted() interface{}
SetStorageEncrypted(val interface{})
StorageEncryptedInput() interface{}
StorageThroughput() *float64
SetStorageThroughput(val *float64)
StorageThroughputInput() *float64
StorageType() *string
SetStorageType(val *string)
StorageTypeInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DbInstanceTimeoutsOutputReference
TimeoutsInput() interface{}
Timezone() *string
SetTimezone(val *string)
TimezoneInput() *string
Username() *string
SetUsername(val *string)
UsernameInput() *string
VpcSecurityGroupIds() *[]*string
SetVpcSecurityGroupIds(val *[]*string)
VpcSecurityGroupIdsInput() *[]*string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutBlueGreenUpdate(value *DbInstanceBlueGreenUpdate)
PutRestoreToPointInTime(value *DbInstanceRestoreToPointInTime)
PutS3Import(value *DbInstanceS3Import)
PutTimeouts(value *DbInstanceTimeouts)
ResetAllocatedStorage()
ResetAllowMajorVersionUpgrade()
ResetApplyImmediately()
ResetAutoMinorVersionUpgrade()
ResetAvailabilityZone()
ResetBackupRetentionPeriod()
ResetBackupWindow()
ResetBlueGreenUpdate()
ResetCaCertIdentifier()
ResetCharacterSetName()
ResetCopyTagsToSnapshot()
ResetCustomerOwnedIpEnabled()
ResetCustomIamInstanceProfile()
ResetDbName()
ResetDbSubnetGroupName()
ResetDeleteAutomatedBackups()
ResetDeletionProtection()
ResetDomain()
ResetDomainIamRoleName()
ResetEnabledCloudwatchLogsExports()
ResetEngine()
ResetEngineVersion()
ResetFinalSnapshotIdentifier()
ResetIamDatabaseAuthenticationEnabled()
ResetId()
ResetIdentifier()
ResetIdentifierPrefix()
ResetIops()
ResetKmsKeyId()
ResetLicenseModel()
ResetMaintenanceWindow()
ResetManageMasterUserPassword()
ResetMasterUserSecretKmsKeyId()
ResetMaxAllocatedStorage()
ResetMonitoringInterval()
ResetMonitoringRoleArn()
ResetMultiAz()
ResetName()
ResetNcharCharacterSetName()
ResetNetworkType()
ResetOptionGroupName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetParameterGroupName()
ResetPassword()
ResetPerformanceInsightsEnabled()
ResetPerformanceInsightsKmsKeyId()
ResetPerformanceInsightsRetentionPeriod()
ResetPort()
ResetPubliclyAccessible()
ResetReplicaMode()
ResetReplicateSourceDb()
ResetRestoreToPointInTime()
ResetS3Import()
ResetSecurityGroupNames()
ResetSkipFinalSnapshot()
ResetSnapshotIdentifier()
ResetStorageEncrypted()
ResetStorageThroughput()
ResetStorageType()
ResetTags()
ResetTagsAll()
ResetTimeouts()
ResetTimezone()
ResetUsername()
ResetVpcSecurityGroupIds()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance aws_db_instance}.
func NewDbInstance ¶
func NewDbInstance(scope constructs.Construct, id *string, config *DbInstanceConfig) DbInstance
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance aws_db_instance} Resource.
type DbInstanceBlueGreenUpdate ¶
type DbInstanceBlueGreenUpdate struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#enabled DbInstance#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
}
type DbInstanceBlueGreenUpdateOutputReference ¶
type DbInstanceBlueGreenUpdateOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *DbInstanceBlueGreenUpdate
SetInternalValue(val *DbInstanceBlueGreenUpdate)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnabled()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDbInstanceBlueGreenUpdateOutputReference ¶
func NewDbInstanceBlueGreenUpdateOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DbInstanceBlueGreenUpdateOutputReference
type DbInstanceConfig ¶
type DbInstanceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#instance_class DbInstance#instance_class}.
InstanceClass *string `field:"required" json:"instanceClass" yaml:"instanceClass"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#allocated_storage DbInstance#allocated_storage}.
AllocatedStorage *float64 `field:"optional" json:"allocatedStorage" yaml:"allocatedStorage"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#allow_major_version_upgrade DbInstance#allow_major_version_upgrade}.
AllowMajorVersionUpgrade interface{} `field:"optional" json:"allowMajorVersionUpgrade" yaml:"allowMajorVersionUpgrade"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#apply_immediately DbInstance#apply_immediately}.
ApplyImmediately interface{} `field:"optional" json:"applyImmediately" yaml:"applyImmediately"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#auto_minor_version_upgrade DbInstance#auto_minor_version_upgrade}.
AutoMinorVersionUpgrade interface{} `field:"optional" json:"autoMinorVersionUpgrade" yaml:"autoMinorVersionUpgrade"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#availability_zone DbInstance#availability_zone}.
AvailabilityZone *string `field:"optional" json:"availabilityZone" yaml:"availabilityZone"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#backup_retention_period DbInstance#backup_retention_period}.
BackupRetentionPeriod *float64 `field:"optional" json:"backupRetentionPeriod" yaml:"backupRetentionPeriod"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#backup_window DbInstance#backup_window}.
BackupWindow *string `field:"optional" json:"backupWindow" yaml:"backupWindow"`
// blue_green_update block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#blue_green_update DbInstance#blue_green_update}
BlueGreenUpdate *DbInstanceBlueGreenUpdate `field:"optional" json:"blueGreenUpdate" yaml:"blueGreenUpdate"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#ca_cert_identifier DbInstance#ca_cert_identifier}.
CaCertIdentifier *string `field:"optional" json:"caCertIdentifier" yaml:"caCertIdentifier"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#character_set_name DbInstance#character_set_name}.
CharacterSetName *string `field:"optional" json:"characterSetName" yaml:"characterSetName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#copy_tags_to_snapshot DbInstance#copy_tags_to_snapshot}.
CopyTagsToSnapshot interface{} `field:"optional" json:"copyTagsToSnapshot" yaml:"copyTagsToSnapshot"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#customer_owned_ip_enabled DbInstance#customer_owned_ip_enabled}.
CustomerOwnedIpEnabled interface{} `field:"optional" json:"customerOwnedIpEnabled" yaml:"customerOwnedIpEnabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#custom_iam_instance_profile DbInstance#custom_iam_instance_profile}.
CustomIamInstanceProfile *string `field:"optional" json:"customIamInstanceProfile" yaml:"customIamInstanceProfile"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#db_name DbInstance#db_name}.
DbName *string `field:"optional" json:"dbName" yaml:"dbName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#db_subnet_group_name DbInstance#db_subnet_group_name}.
DbSubnetGroupName *string `field:"optional" json:"dbSubnetGroupName" yaml:"dbSubnetGroupName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#delete_automated_backups DbInstance#delete_automated_backups}.
DeleteAutomatedBackups interface{} `field:"optional" json:"deleteAutomatedBackups" yaml:"deleteAutomatedBackups"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#deletion_protection DbInstance#deletion_protection}.
DeletionProtection interface{} `field:"optional" json:"deletionProtection" yaml:"deletionProtection"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#domain DbInstance#domain}.
Domain *string `field:"optional" json:"domain" yaml:"domain"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#domain_iam_role_name DbInstance#domain_iam_role_name}.
DomainIamRoleName *string `field:"optional" json:"domainIamRoleName" yaml:"domainIamRoleName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#enabled_cloudwatch_logs_exports DbInstance#enabled_cloudwatch_logs_exports}.
EnabledCloudwatchLogsExports *[]*string `field:"optional" json:"enabledCloudwatchLogsExports" yaml:"enabledCloudwatchLogsExports"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#engine DbInstance#engine}.
Engine *string `field:"optional" json:"engine" yaml:"engine"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#engine_version DbInstance#engine_version}.
EngineVersion *string `field:"optional" json:"engineVersion" yaml:"engineVersion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#final_snapshot_identifier DbInstance#final_snapshot_identifier}.
FinalSnapshotIdentifier *string `field:"optional" json:"finalSnapshotIdentifier" yaml:"finalSnapshotIdentifier"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#iam_database_authentication_enabled DbInstance#iam_database_authentication_enabled}.
IamDatabaseAuthenticationEnabled interface{} `field:"optional" json:"iamDatabaseAuthenticationEnabled" yaml:"iamDatabaseAuthenticationEnabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#id DbInstance#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#identifier DbInstance#identifier}.
Identifier *string `field:"optional" json:"identifier" yaml:"identifier"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#identifier_prefix DbInstance#identifier_prefix}.
IdentifierPrefix *string `field:"optional" json:"identifierPrefix" yaml:"identifierPrefix"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#iops DbInstance#iops}.
Iops *float64 `field:"optional" json:"iops" yaml:"iops"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#kms_key_id DbInstance#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#license_model DbInstance#license_model}.
LicenseModel *string `field:"optional" json:"licenseModel" yaml:"licenseModel"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#maintenance_window DbInstance#maintenance_window}.
MaintenanceWindow *string `field:"optional" json:"maintenanceWindow" yaml:"maintenanceWindow"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#manage_master_user_password DbInstance#manage_master_user_password}.
ManageMasterUserPassword interface{} `field:"optional" json:"manageMasterUserPassword" yaml:"manageMasterUserPassword"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#master_user_secret_kms_key_id DbInstance#master_user_secret_kms_key_id}.
MasterUserSecretKmsKeyId *string `field:"optional" json:"masterUserSecretKmsKeyId" yaml:"masterUserSecretKmsKeyId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#max_allocated_storage DbInstance#max_allocated_storage}.
MaxAllocatedStorage *float64 `field:"optional" json:"maxAllocatedStorage" yaml:"maxAllocatedStorage"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#monitoring_interval DbInstance#monitoring_interval}.
MonitoringInterval *float64 `field:"optional" json:"monitoringInterval" yaml:"monitoringInterval"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#monitoring_role_arn DbInstance#monitoring_role_arn}.
MonitoringRoleArn *string `field:"optional" json:"monitoringRoleArn" yaml:"monitoringRoleArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#multi_az DbInstance#multi_az}.
MultiAz interface{} `field:"optional" json:"multiAz" yaml:"multiAz"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#name DbInstance#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#nchar_character_set_name DbInstance#nchar_character_set_name}.
NcharCharacterSetName *string `field:"optional" json:"ncharCharacterSetName" yaml:"ncharCharacterSetName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#network_type DbInstance#network_type}.
NetworkType *string `field:"optional" json:"networkType" yaml:"networkType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#option_group_name DbInstance#option_group_name}.
OptionGroupName *string `field:"optional" json:"optionGroupName" yaml:"optionGroupName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#parameter_group_name DbInstance#parameter_group_name}.
ParameterGroupName *string `field:"optional" json:"parameterGroupName" yaml:"parameterGroupName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#password DbInstance#password}.
Password *string `field:"optional" json:"password" yaml:"password"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#performance_insights_enabled DbInstance#performance_insights_enabled}.
PerformanceInsightsEnabled interface{} `field:"optional" json:"performanceInsightsEnabled" yaml:"performanceInsightsEnabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#performance_insights_kms_key_id DbInstance#performance_insights_kms_key_id}.
PerformanceInsightsKmsKeyId *string `field:"optional" json:"performanceInsightsKmsKeyId" yaml:"performanceInsightsKmsKeyId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#performance_insights_retention_period DbInstance#performance_insights_retention_period}.
PerformanceInsightsRetentionPeriod *float64 `field:"optional" json:"performanceInsightsRetentionPeriod" yaml:"performanceInsightsRetentionPeriod"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#port DbInstance#port}.
Port *float64 `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#publicly_accessible DbInstance#publicly_accessible}.
PubliclyAccessible interface{} `field:"optional" json:"publiclyAccessible" yaml:"publiclyAccessible"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#replica_mode DbInstance#replica_mode}.
ReplicaMode *string `field:"optional" json:"replicaMode" yaml:"replicaMode"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#replicate_source_db DbInstance#replicate_source_db}.
ReplicateSourceDb *string `field:"optional" json:"replicateSourceDb" yaml:"replicateSourceDb"`
// restore_to_point_in_time block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#restore_to_point_in_time DbInstance#restore_to_point_in_time}
RestoreToPointInTime *DbInstanceRestoreToPointInTime `field:"optional" json:"restoreToPointInTime" yaml:"restoreToPointInTime"`
// s3_import block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#s3_import DbInstance#s3_import}
S3Import *DbInstanceS3Import `field:"optional" json:"s3Import" yaml:"s3Import"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#security_group_names DbInstance#security_group_names}.
SecurityGroupNames *[]*string `field:"optional" json:"securityGroupNames" yaml:"securityGroupNames"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#skip_final_snapshot DbInstance#skip_final_snapshot}.
SkipFinalSnapshot interface{} `field:"optional" json:"skipFinalSnapshot" yaml:"skipFinalSnapshot"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#snapshot_identifier DbInstance#snapshot_identifier}.
SnapshotIdentifier *string `field:"optional" json:"snapshotIdentifier" yaml:"snapshotIdentifier"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#storage_encrypted DbInstance#storage_encrypted}.
StorageEncrypted interface{} `field:"optional" json:"storageEncrypted" yaml:"storageEncrypted"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#storage_throughput DbInstance#storage_throughput}.
StorageThroughput *float64 `field:"optional" json:"storageThroughput" yaml:"storageThroughput"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#storage_type DbInstance#storage_type}.
StorageType *string `field:"optional" json:"storageType" yaml:"storageType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#tags DbInstance#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#tags_all DbInstance#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#timeouts DbInstance#timeouts}
Timeouts *DbInstanceTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#timezone DbInstance#timezone}.
Timezone *string `field:"optional" json:"timezone" yaml:"timezone"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#username DbInstance#username}.
Username *string `field:"optional" json:"username" yaml:"username"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#vpc_security_group_ids DbInstance#vpc_security_group_ids}.
VpcSecurityGroupIds *[]*string `field:"optional" json:"vpcSecurityGroupIds" yaml:"vpcSecurityGroupIds"`
}
type DbInstanceListenerEndpoint ¶
type DbInstanceListenerEndpoint struct {
}
type DbInstanceListenerEndpointList ¶
type DbInstanceListenerEndpointList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DbInstanceListenerEndpointOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDbInstanceListenerEndpointList ¶
func NewDbInstanceListenerEndpointList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DbInstanceListenerEndpointList
type DbInstanceListenerEndpointOutputReference ¶
type DbInstanceListenerEndpointOutputReference interface {
cdktf.ComplexObject
Address() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HostedZoneId() *string
InternalValue() *DbInstanceListenerEndpoint
SetInternalValue(val *DbInstanceListenerEndpoint)
Port() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDbInstanceListenerEndpointOutputReference ¶
func NewDbInstanceListenerEndpointOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DbInstanceListenerEndpointOutputReference
type DbInstanceMasterUserSecret ¶
type DbInstanceMasterUserSecret struct {
}
type DbInstanceMasterUserSecretList ¶
type DbInstanceMasterUserSecretList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DbInstanceMasterUserSecretOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDbInstanceMasterUserSecretList ¶
func NewDbInstanceMasterUserSecretList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DbInstanceMasterUserSecretList
type DbInstanceMasterUserSecretOutputReference ¶
type DbInstanceMasterUserSecretOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DbInstanceMasterUserSecret
SetInternalValue(val *DbInstanceMasterUserSecret)
KmsKeyId() *string
SecretArn() *string
SecretStatus() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDbInstanceMasterUserSecretOutputReference ¶
func NewDbInstanceMasterUserSecretOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DbInstanceMasterUserSecretOutputReference
type DbInstanceRestoreToPointInTime ¶
type DbInstanceRestoreToPointInTime struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#restore_time DbInstance#restore_time}.
RestoreTime *string `field:"optional" json:"restoreTime" yaml:"restoreTime"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#source_db_instance_automated_backups_arn DbInstance#source_db_instance_automated_backups_arn}.
SourceDbInstanceAutomatedBackupsArn *string `field:"optional" json:"sourceDbInstanceAutomatedBackupsArn" yaml:"sourceDbInstanceAutomatedBackupsArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#source_db_instance_identifier DbInstance#source_db_instance_identifier}.
SourceDbInstanceIdentifier *string `field:"optional" json:"sourceDbInstanceIdentifier" yaml:"sourceDbInstanceIdentifier"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#source_dbi_resource_id DbInstance#source_dbi_resource_id}.
SourceDbiResourceId *string `field:"optional" json:"sourceDbiResourceId" yaml:"sourceDbiResourceId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#use_latest_restorable_time DbInstance#use_latest_restorable_time}.
UseLatestRestorableTime interface{} `field:"optional" json:"useLatestRestorableTime" yaml:"useLatestRestorableTime"`
}
type DbInstanceRestoreToPointInTimeOutputReference ¶
type DbInstanceRestoreToPointInTimeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DbInstanceRestoreToPointInTime
SetInternalValue(val *DbInstanceRestoreToPointInTime)
RestoreTime() *string
SetRestoreTime(val *string)
RestoreTimeInput() *string
SourceDbInstanceAutomatedBackupsArn() *string
SetSourceDbInstanceAutomatedBackupsArn(val *string)
SourceDbInstanceAutomatedBackupsArnInput() *string
SourceDbInstanceIdentifier() *string
SetSourceDbInstanceIdentifier(val *string)
SourceDbInstanceIdentifierInput() *string
SourceDbiResourceId() *string
SetSourceDbiResourceId(val *string)
SourceDbiResourceIdInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UseLatestRestorableTime() interface{}
SetUseLatestRestorableTime(val interface{})
UseLatestRestorableTimeInput() interface{}
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetRestoreTime()
ResetSourceDbInstanceAutomatedBackupsArn()
ResetSourceDbInstanceIdentifier()
ResetSourceDbiResourceId()
ResetUseLatestRestorableTime()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDbInstanceRestoreToPointInTimeOutputReference ¶
func NewDbInstanceRestoreToPointInTimeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DbInstanceRestoreToPointInTimeOutputReference
type DbInstanceS3Import ¶
type DbInstanceS3Import struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#bucket_name DbInstance#bucket_name}.
BucketName *string `field:"required" json:"bucketName" yaml:"bucketName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#ingestion_role DbInstance#ingestion_role}.
IngestionRole *string `field:"required" json:"ingestionRole" yaml:"ingestionRole"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#source_engine DbInstance#source_engine}.
SourceEngine *string `field:"required" json:"sourceEngine" yaml:"sourceEngine"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#source_engine_version DbInstance#source_engine_version}.
SourceEngineVersion *string `field:"required" json:"sourceEngineVersion" yaml:"sourceEngineVersion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#bucket_prefix DbInstance#bucket_prefix}.
BucketPrefix *string `field:"optional" json:"bucketPrefix" yaml:"bucketPrefix"`
}
type DbInstanceS3ImportOutputReference ¶
type DbInstanceS3ImportOutputReference interface {
cdktf.ComplexObject
BucketName() *string
SetBucketName(val *string)
BucketNameInput() *string
BucketPrefix() *string
SetBucketPrefix(val *string)
BucketPrefixInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IngestionRole() *string
SetIngestionRole(val *string)
IngestionRoleInput() *string
InternalValue() *DbInstanceS3Import
SetInternalValue(val *DbInstanceS3Import)
SourceEngine() *string
SetSourceEngine(val *string)
SourceEngineInput() *string
SourceEngineVersion() *string
SetSourceEngineVersion(val *string)
SourceEngineVersionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBucketPrefix()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDbInstanceS3ImportOutputReference ¶
func NewDbInstanceS3ImportOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DbInstanceS3ImportOutputReference
type DbInstanceTimeouts ¶
type DbInstanceTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#create DbInstance#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#delete DbInstance#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/db_instance#update DbInstance#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type DbInstanceTimeoutsOutputReference ¶
type DbInstanceTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDbInstanceTimeoutsOutputReference ¶
func NewDbInstanceTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DbInstanceTimeoutsOutputReference
Source Files
¶
- DbInstance.go
- DbInstanceBlueGreenUpdate.go
- DbInstanceBlueGreenUpdateOutputReference.go
- DbInstanceBlueGreenUpdateOutputReference__checks.go
- DbInstanceConfig.go
- DbInstanceListenerEndpoint.go
- DbInstanceListenerEndpointList.go
- DbInstanceListenerEndpointList__checks.go
- DbInstanceListenerEndpointOutputReference.go
- DbInstanceListenerEndpointOutputReference__checks.go
- DbInstanceMasterUserSecret.go
- DbInstanceMasterUserSecretList.go
- DbInstanceMasterUserSecretList__checks.go
- DbInstanceMasterUserSecretOutputReference.go
- DbInstanceMasterUserSecretOutputReference__checks.go
- DbInstanceRestoreToPointInTime.go
- DbInstanceRestoreToPointInTimeOutputReference.go
- DbInstanceRestoreToPointInTimeOutputReference__checks.go
- DbInstanceS3Import.go
- DbInstanceS3ImportOutputReference.go
- DbInstanceS3ImportOutputReference__checks.go
- DbInstanceTimeouts.go
- DbInstanceTimeoutsOutputReference.go
- DbInstanceTimeoutsOutputReference__checks.go
- DbInstance__checks.go
- main.go