Documentation
¶
Index ¶
- func DefaultRouteTable_IsConstruct(x interface{}) *bool
- func DefaultRouteTable_IsTerraformElement(x interface{}) *bool
- func DefaultRouteTable_IsTerraformResource(x interface{}) *bool
- func DefaultRouteTable_TfResourceType() *string
- func NewDefaultRouteTableRouteList_Override(d DefaultRouteTableRouteList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewDefaultRouteTableRouteOutputReference_Override(d DefaultRouteTableRouteOutputReference, ...)
- func NewDefaultRouteTableTimeoutsOutputReference_Override(d DefaultRouteTableTimeoutsOutputReference, ...)
- func NewDefaultRouteTable_Override(d DefaultRouteTable, scope constructs.Construct, id *string, ...)
- type DefaultRouteTable
- type DefaultRouteTableConfig
- type DefaultRouteTableRoute
- type DefaultRouteTableRouteList
- type DefaultRouteTableRouteOutputReference
- type DefaultRouteTableTimeouts
- type DefaultRouteTableTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DefaultRouteTable_IsConstruct ¶
func DefaultRouteTable_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DefaultRouteTable_IsTerraformElement ¶
func DefaultRouteTable_IsTerraformElement(x interface{}) *bool
Experimental.
func DefaultRouteTable_IsTerraformResource ¶
func DefaultRouteTable_IsTerraformResource(x interface{}) *bool
Experimental.
func DefaultRouteTable_TfResourceType ¶
func DefaultRouteTable_TfResourceType() *string
func NewDefaultRouteTableRouteList_Override ¶
func NewDefaultRouteTableRouteList_Override(d DefaultRouteTableRouteList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDefaultRouteTableRouteOutputReference_Override ¶
func NewDefaultRouteTableRouteOutputReference_Override(d DefaultRouteTableRouteOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDefaultRouteTableTimeoutsOutputReference_Override ¶
func NewDefaultRouteTableTimeoutsOutputReference_Override(d DefaultRouteTableTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDefaultRouteTable_Override ¶
func NewDefaultRouteTable_Override(d DefaultRouteTable, scope constructs.Construct, id *string, config *DefaultRouteTableConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table aws_default_route_table} Resource.
Types ¶
type DefaultRouteTable ¶
type DefaultRouteTable interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DefaultRouteTableId() *string
SetDefaultRouteTableId(val *string)
DefaultRouteTableIdInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
OwnerId() *string
PropagatingVgws() *[]*string
SetPropagatingVgws(val *[]*string)
PropagatingVgwsInput() *[]*string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Route() DefaultRouteTableRouteList
RouteInput() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DefaultRouteTableTimeoutsOutputReference
TimeoutsInput() interface{}
VpcId() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutRoute(value interface{})
PutTimeouts(value *DefaultRouteTableTimeouts)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPropagatingVgws()
ResetRoute()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table aws_default_route_table}.
func NewDefaultRouteTable ¶
func NewDefaultRouteTable(scope constructs.Construct, id *string, config *DefaultRouteTableConfig) DefaultRouteTable
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table aws_default_route_table} Resource.
type DefaultRouteTableConfig ¶
type DefaultRouteTableConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#default_route_table_id DefaultRouteTable#default_route_table_id}.
DefaultRouteTableId *string `field:"required" json:"defaultRouteTableId" yaml:"defaultRouteTableId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#id DefaultRouteTable#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#propagating_vgws DefaultRouteTable#propagating_vgws}.
PropagatingVgws *[]*string `field:"optional" json:"propagatingVgws" yaml:"propagatingVgws"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#route DefaultRouteTable#route}.
Route interface{} `field:"optional" json:"route" yaml:"route"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#tags DefaultRouteTable#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#tags_all DefaultRouteTable#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#timeouts DefaultRouteTable#timeouts}
Timeouts *DefaultRouteTableTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type DefaultRouteTableRoute ¶
type DefaultRouteTableRoute struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#cidr_block DefaultRouteTable#cidr_block}.
CidrBlock *string `field:"optional" json:"cidrBlock" yaml:"cidrBlock"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#core_network_arn DefaultRouteTable#core_network_arn}.
CoreNetworkArn *string `field:"optional" json:"coreNetworkArn" yaml:"coreNetworkArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#destination_prefix_list_id DefaultRouteTable#destination_prefix_list_id}.
DestinationPrefixListId *string `field:"optional" json:"destinationPrefixListId" yaml:"destinationPrefixListId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#egress_only_gateway_id DefaultRouteTable#egress_only_gateway_id}.
EgressOnlyGatewayId *string `field:"optional" json:"egressOnlyGatewayId" yaml:"egressOnlyGatewayId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#gateway_id DefaultRouteTable#gateway_id}.
GatewayId *string `field:"optional" json:"gatewayId" yaml:"gatewayId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#instance_id DefaultRouteTable#instance_id}.
InstanceId *string `field:"optional" json:"instanceId" yaml:"instanceId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#ipv6_cidr_block DefaultRouteTable#ipv6_cidr_block}.
Ipv6CidrBlock *string `field:"optional" json:"ipv6CidrBlock" yaml:"ipv6CidrBlock"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#nat_gateway_id DefaultRouteTable#nat_gateway_id}.
NatGatewayId *string `field:"optional" json:"natGatewayId" yaml:"natGatewayId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#network_interface_id DefaultRouteTable#network_interface_id}.
NetworkInterfaceId *string `field:"optional" json:"networkInterfaceId" yaml:"networkInterfaceId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#transit_gateway_id DefaultRouteTable#transit_gateway_id}.
TransitGatewayId *string `field:"optional" json:"transitGatewayId" yaml:"transitGatewayId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#vpc_endpoint_id DefaultRouteTable#vpc_endpoint_id}.
VpcEndpointId *string `field:"optional" json:"vpcEndpointId" yaml:"vpcEndpointId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#vpc_peering_connection_id DefaultRouteTable#vpc_peering_connection_id}.
VpcPeeringConnectionId *string `field:"optional" json:"vpcPeeringConnectionId" yaml:"vpcPeeringConnectionId"`
}
type DefaultRouteTableRouteList ¶
type DefaultRouteTableRouteList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DefaultRouteTableRouteOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDefaultRouteTableRouteList ¶
func NewDefaultRouteTableRouteList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DefaultRouteTableRouteList
type DefaultRouteTableRouteOutputReference ¶
type DefaultRouteTableRouteOutputReference interface {
cdktf.ComplexObject
CidrBlock() *string
SetCidrBlock(val *string)
CidrBlockInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CoreNetworkArn() *string
SetCoreNetworkArn(val *string)
CoreNetworkArnInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DestinationPrefixListId() *string
SetDestinationPrefixListId(val *string)
DestinationPrefixListIdInput() *string
EgressOnlyGatewayId() *string
SetEgressOnlyGatewayId(val *string)
EgressOnlyGatewayIdInput() *string
// Experimental.
Fqn() *string
GatewayId() *string
SetGatewayId(val *string)
GatewayIdInput() *string
InstanceId() *string
SetInstanceId(val *string)
InstanceIdInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Ipv6CidrBlock() *string
SetIpv6CidrBlock(val *string)
Ipv6CidrBlockInput() *string
NatGatewayId() *string
SetNatGatewayId(val *string)
NatGatewayIdInput() *string
NetworkInterfaceId() *string
SetNetworkInterfaceId(val *string)
NetworkInterfaceIdInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TransitGatewayId() *string
SetTransitGatewayId(val *string)
TransitGatewayIdInput() *string
VpcEndpointId() *string
SetVpcEndpointId(val *string)
VpcEndpointIdInput() *string
VpcPeeringConnectionId() *string
SetVpcPeeringConnectionId(val *string)
VpcPeeringConnectionIdInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCidrBlock()
ResetCoreNetworkArn()
ResetDestinationPrefixListId()
ResetEgressOnlyGatewayId()
ResetGatewayId()
ResetInstanceId()
ResetIpv6CidrBlock()
ResetNatGatewayId()
ResetNetworkInterfaceId()
ResetTransitGatewayId()
ResetVpcEndpointId()
ResetVpcPeeringConnectionId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDefaultRouteTableRouteOutputReference ¶
func NewDefaultRouteTableRouteOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DefaultRouteTableRouteOutputReference
type DefaultRouteTableTimeouts ¶
type DefaultRouteTableTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#create DefaultRouteTable#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/default_route_table#update DefaultRouteTable#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type DefaultRouteTableTimeoutsOutputReference ¶
type DefaultRouteTableTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDefaultRouteTableTimeoutsOutputReference ¶
func NewDefaultRouteTableTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DefaultRouteTableTimeoutsOutputReference
Source Files
¶
- DefaultRouteTable.go
- DefaultRouteTableConfig.go
- DefaultRouteTableRoute.go
- DefaultRouteTableRouteList.go
- DefaultRouteTableRouteList__checks.go
- DefaultRouteTableRouteOutputReference.go
- DefaultRouteTableRouteOutputReference__checks.go
- DefaultRouteTableTimeouts.go
- DefaultRouteTableTimeoutsOutputReference.go
- DefaultRouteTableTimeoutsOutputReference__checks.go
- DefaultRouteTable__checks.go
- main.go