Documentation
¶
Index ¶
- func EcrReplicationConfiguration_IsConstruct(x interface{}) *bool
- func EcrReplicationConfiguration_IsTerraformElement(x interface{}) *bool
- func EcrReplicationConfiguration_IsTerraformResource(x interface{}) *bool
- func EcrReplicationConfiguration_TfResourceType() *string
- func NewEcrReplicationConfigurationReplicationConfigurationOutputReference_Override(e EcrReplicationConfigurationReplicationConfigurationOutputReference, ...)
- func NewEcrReplicationConfigurationReplicationConfigurationRuleDestinationList_Override(e EcrReplicationConfigurationReplicationConfigurationRuleDestinationList, ...)
- func NewEcrReplicationConfigurationReplicationConfigurationRuleDestinationOutputReference_Override(...)
- func NewEcrReplicationConfigurationReplicationConfigurationRuleList_Override(e EcrReplicationConfigurationReplicationConfigurationRuleList, ...)
- func NewEcrReplicationConfigurationReplicationConfigurationRuleOutputReference_Override(e EcrReplicationConfigurationReplicationConfigurationRuleOutputReference, ...)
- func NewEcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterList_Override(e EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterList, ...)
- func NewEcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterOutputReference_Override(...)
- func NewEcrReplicationConfiguration_Override(e EcrReplicationConfiguration, scope constructs.Construct, id *string, ...)
- type EcrReplicationConfiguration
- type EcrReplicationConfigurationConfig
- type EcrReplicationConfigurationReplicationConfiguration
- type EcrReplicationConfigurationReplicationConfigurationOutputReference
- type EcrReplicationConfigurationReplicationConfigurationRule
- type EcrReplicationConfigurationReplicationConfigurationRuleDestination
- type EcrReplicationConfigurationReplicationConfigurationRuleDestinationList
- type EcrReplicationConfigurationReplicationConfigurationRuleDestinationOutputReference
- type EcrReplicationConfigurationReplicationConfigurationRuleList
- type EcrReplicationConfigurationReplicationConfigurationRuleOutputReference
- type EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilter
- type EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterList
- type EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EcrReplicationConfiguration_IsConstruct ¶
func EcrReplicationConfiguration_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func EcrReplicationConfiguration_IsTerraformElement ¶
func EcrReplicationConfiguration_IsTerraformElement(x interface{}) *bool
Experimental.
func EcrReplicationConfiguration_IsTerraformResource ¶
func EcrReplicationConfiguration_IsTerraformResource(x interface{}) *bool
Experimental.
func EcrReplicationConfiguration_TfResourceType ¶
func EcrReplicationConfiguration_TfResourceType() *string
func NewEcrReplicationConfigurationReplicationConfigurationOutputReference_Override ¶
func NewEcrReplicationConfigurationReplicationConfigurationOutputReference_Override(e EcrReplicationConfigurationReplicationConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEcrReplicationConfigurationReplicationConfigurationRuleDestinationList_Override ¶
func NewEcrReplicationConfigurationReplicationConfigurationRuleDestinationList_Override(e EcrReplicationConfigurationReplicationConfigurationRuleDestinationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEcrReplicationConfigurationReplicationConfigurationRuleDestinationOutputReference_Override ¶
func NewEcrReplicationConfigurationReplicationConfigurationRuleDestinationOutputReference_Override(e EcrReplicationConfigurationReplicationConfigurationRuleDestinationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEcrReplicationConfigurationReplicationConfigurationRuleList_Override ¶
func NewEcrReplicationConfigurationReplicationConfigurationRuleList_Override(e EcrReplicationConfigurationReplicationConfigurationRuleList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEcrReplicationConfigurationReplicationConfigurationRuleOutputReference_Override ¶
func NewEcrReplicationConfigurationReplicationConfigurationRuleOutputReference_Override(e EcrReplicationConfigurationReplicationConfigurationRuleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterList_Override ¶
func NewEcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterList_Override(e EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterOutputReference_Override ¶
func NewEcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterOutputReference_Override(e EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEcrReplicationConfiguration_Override ¶
func NewEcrReplicationConfiguration_Override(e EcrReplicationConfiguration, scope constructs.Construct, id *string, config *EcrReplicationConfigurationConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ecr_replication_configuration aws_ecr_replication_configuration} Resource.
Types ¶
type EcrReplicationConfiguration ¶
type EcrReplicationConfiguration interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RegistryId() *string
ReplicationConfiguration() EcrReplicationConfigurationReplicationConfigurationOutputReference
ReplicationConfigurationInput() *EcrReplicationConfigurationReplicationConfiguration
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutReplicationConfiguration(value *EcrReplicationConfigurationReplicationConfiguration)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetReplicationConfiguration()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ecr_replication_configuration aws_ecr_replication_configuration}.
func NewEcrReplicationConfiguration ¶
func NewEcrReplicationConfiguration(scope constructs.Construct, id *string, config *EcrReplicationConfigurationConfig) EcrReplicationConfiguration
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ecr_replication_configuration aws_ecr_replication_configuration} Resource.
type EcrReplicationConfigurationConfig ¶
type EcrReplicationConfigurationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ecr_replication_configuration#id EcrReplicationConfiguration#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// replication_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ecr_replication_configuration#replication_configuration EcrReplicationConfiguration#replication_configuration}
ReplicationConfiguration *EcrReplicationConfigurationReplicationConfiguration `field:"optional" json:"replicationConfiguration" yaml:"replicationConfiguration"`
}
type EcrReplicationConfigurationReplicationConfiguration ¶
type EcrReplicationConfigurationReplicationConfiguration struct {
// rule block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ecr_replication_configuration#rule EcrReplicationConfiguration#rule}
Rule interface{} `field:"required" json:"rule" yaml:"rule"`
}
type EcrReplicationConfigurationReplicationConfigurationOutputReference ¶
type EcrReplicationConfigurationReplicationConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EcrReplicationConfigurationReplicationConfiguration
SetInternalValue(val *EcrReplicationConfigurationReplicationConfiguration)
Rule() EcrReplicationConfigurationReplicationConfigurationRuleList
RuleInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutRule(value interface{})
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcrReplicationConfigurationReplicationConfigurationOutputReference ¶
func NewEcrReplicationConfigurationReplicationConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EcrReplicationConfigurationReplicationConfigurationOutputReference
type EcrReplicationConfigurationReplicationConfigurationRule ¶
type EcrReplicationConfigurationReplicationConfigurationRule struct {
// destination block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ecr_replication_configuration#destination EcrReplicationConfiguration#destination}
Destination interface{} `field:"required" json:"destination" yaml:"destination"`
// repository_filter block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ecr_replication_configuration#repository_filter EcrReplicationConfiguration#repository_filter}
RepositoryFilter interface{} `field:"optional" json:"repositoryFilter" yaml:"repositoryFilter"`
}
type EcrReplicationConfigurationReplicationConfigurationRuleDestination ¶
type EcrReplicationConfigurationReplicationConfigurationRuleDestination struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ecr_replication_configuration#region EcrReplicationConfiguration#region}.
Region *string `field:"required" json:"region" yaml:"region"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ecr_replication_configuration#registry_id EcrReplicationConfiguration#registry_id}.
RegistryId *string `field:"required" json:"registryId" yaml:"registryId"`
}
type EcrReplicationConfigurationReplicationConfigurationRuleDestinationList ¶
type EcrReplicationConfigurationReplicationConfigurationRuleDestinationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EcrReplicationConfigurationReplicationConfigurationRuleDestinationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcrReplicationConfigurationReplicationConfigurationRuleDestinationList ¶
func NewEcrReplicationConfigurationReplicationConfigurationRuleDestinationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EcrReplicationConfigurationReplicationConfigurationRuleDestinationList
type EcrReplicationConfigurationReplicationConfigurationRuleDestinationOutputReference ¶
type EcrReplicationConfigurationReplicationConfigurationRuleDestinationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Region() *string
SetRegion(val *string)
RegionInput() *string
RegistryId() *string
SetRegistryId(val *string)
RegistryIdInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcrReplicationConfigurationReplicationConfigurationRuleDestinationOutputReference ¶
func NewEcrReplicationConfigurationReplicationConfigurationRuleDestinationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EcrReplicationConfigurationReplicationConfigurationRuleDestinationOutputReference
type EcrReplicationConfigurationReplicationConfigurationRuleList ¶
type EcrReplicationConfigurationReplicationConfigurationRuleList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EcrReplicationConfigurationReplicationConfigurationRuleOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcrReplicationConfigurationReplicationConfigurationRuleList ¶
func NewEcrReplicationConfigurationReplicationConfigurationRuleList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EcrReplicationConfigurationReplicationConfigurationRuleList
type EcrReplicationConfigurationReplicationConfigurationRuleOutputReference ¶
type EcrReplicationConfigurationReplicationConfigurationRuleOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Destination() EcrReplicationConfigurationReplicationConfigurationRuleDestinationList
DestinationInput() interface{}
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
RepositoryFilter() EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterList
RepositoryFilterInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutDestination(value interface{})
PutRepositoryFilter(value interface{})
ResetRepositoryFilter()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcrReplicationConfigurationReplicationConfigurationRuleOutputReference ¶
func NewEcrReplicationConfigurationReplicationConfigurationRuleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EcrReplicationConfigurationReplicationConfigurationRuleOutputReference
type EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilter ¶
type EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilter struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ecr_replication_configuration#filter EcrReplicationConfiguration#filter}.
Filter *string `field:"required" json:"filter" yaml:"filter"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ecr_replication_configuration#filter_type EcrReplicationConfiguration#filter_type}.
FilterType *string `field:"required" json:"filterType" yaml:"filterType"`
}
type EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterList ¶
type EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterList ¶
func NewEcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterList
type EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterOutputReference ¶
type EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Filter() *string
SetFilter(val *string)
FilterInput() *string
FilterType() *string
SetFilterType(val *string)
FilterTypeInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterOutputReference ¶
func NewEcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterOutputReference
Source Files
¶
- EcrReplicationConfiguration.go
- EcrReplicationConfigurationConfig.go
- EcrReplicationConfigurationReplicationConfiguration.go
- EcrReplicationConfigurationReplicationConfigurationOutputReference.go
- EcrReplicationConfigurationReplicationConfigurationOutputReference__checks.go
- EcrReplicationConfigurationReplicationConfigurationRule.go
- EcrReplicationConfigurationReplicationConfigurationRuleDestination.go
- EcrReplicationConfigurationReplicationConfigurationRuleDestinationList.go
- EcrReplicationConfigurationReplicationConfigurationRuleDestinationList__checks.go
- EcrReplicationConfigurationReplicationConfigurationRuleDestinationOutputReference.go
- EcrReplicationConfigurationReplicationConfigurationRuleDestinationOutputReference__checks.go
- EcrReplicationConfigurationReplicationConfigurationRuleList.go
- EcrReplicationConfigurationReplicationConfigurationRuleList__checks.go
- EcrReplicationConfigurationReplicationConfigurationRuleOutputReference.go
- EcrReplicationConfigurationReplicationConfigurationRuleOutputReference__checks.go
- EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilter.go
- EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterList.go
- EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterList__checks.go
- EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterOutputReference.go
- EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterOutputReference__checks.go
- EcrReplicationConfiguration__checks.go
- main.go