Documentation
¶
Index ¶
- func EksIdentityProviderConfig_IsConstruct(x interface{}) *bool
- func EksIdentityProviderConfig_IsTerraformElement(x interface{}) *bool
- func EksIdentityProviderConfig_IsTerraformResource(x interface{}) *bool
- func EksIdentityProviderConfig_TfResourceType() *string
- func NewEksIdentityProviderConfigOidcOutputReference_Override(e EksIdentityProviderConfigOidcOutputReference, ...)
- func NewEksIdentityProviderConfigTimeoutsOutputReference_Override(e EksIdentityProviderConfigTimeoutsOutputReference, ...)
- func NewEksIdentityProviderConfig_Override(e EksIdentityProviderConfig, scope constructs.Construct, id *string, ...)
- type EksIdentityProviderConfig
- type EksIdentityProviderConfigConfig
- type EksIdentityProviderConfigOidc
- type EksIdentityProviderConfigOidcOutputReference
- type EksIdentityProviderConfigTimeouts
- type EksIdentityProviderConfigTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EksIdentityProviderConfig_IsConstruct ¶
func EksIdentityProviderConfig_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func EksIdentityProviderConfig_IsTerraformElement ¶
func EksIdentityProviderConfig_IsTerraformElement(x interface{}) *bool
Experimental.
func EksIdentityProviderConfig_IsTerraformResource ¶
func EksIdentityProviderConfig_IsTerraformResource(x interface{}) *bool
Experimental.
func EksIdentityProviderConfig_TfResourceType ¶
func EksIdentityProviderConfig_TfResourceType() *string
func NewEksIdentityProviderConfigOidcOutputReference_Override ¶
func NewEksIdentityProviderConfigOidcOutputReference_Override(e EksIdentityProviderConfigOidcOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEksIdentityProviderConfigTimeoutsOutputReference_Override ¶
func NewEksIdentityProviderConfigTimeoutsOutputReference_Override(e EksIdentityProviderConfigTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEksIdentityProviderConfig_Override ¶
func NewEksIdentityProviderConfig_Override(e EksIdentityProviderConfig, scope constructs.Construct, id *string, config *EksIdentityProviderConfigConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/eks_identity_provider_config aws_eks_identity_provider_config} Resource.
Types ¶
type EksIdentityProviderConfig ¶
type EksIdentityProviderConfig interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterName() *string
SetClusterName(val *string)
ClusterNameInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
Oidc() EksIdentityProviderConfigOidcOutputReference
OidcInput() *EksIdentityProviderConfigOidc
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Status() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() EksIdentityProviderConfigTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutOidc(value *EksIdentityProviderConfigOidc)
PutTimeouts(value *EksIdentityProviderConfigTimeouts)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/eks_identity_provider_config aws_eks_identity_provider_config}.
func NewEksIdentityProviderConfig ¶
func NewEksIdentityProviderConfig(scope constructs.Construct, id *string, config *EksIdentityProviderConfigConfig) EksIdentityProviderConfig
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/eks_identity_provider_config aws_eks_identity_provider_config} Resource.
type EksIdentityProviderConfigConfig ¶
type EksIdentityProviderConfigConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/eks_identity_provider_config#cluster_name EksIdentityProviderConfig#cluster_name}.
ClusterName *string `field:"required" json:"clusterName" yaml:"clusterName"`
// oidc block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/eks_identity_provider_config#oidc EksIdentityProviderConfig#oidc}
Oidc *EksIdentityProviderConfigOidc `field:"required" json:"oidc" yaml:"oidc"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/eks_identity_provider_config#id EksIdentityProviderConfig#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/eks_identity_provider_config#tags EksIdentityProviderConfig#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/eks_identity_provider_config#tags_all EksIdentityProviderConfig#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/eks_identity_provider_config#timeouts EksIdentityProviderConfig#timeouts}
Timeouts *EksIdentityProviderConfigTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type EksIdentityProviderConfigOidc ¶
type EksIdentityProviderConfigOidc struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/eks_identity_provider_config#client_id EksIdentityProviderConfig#client_id}.
ClientId *string `field:"required" json:"clientId" yaml:"clientId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/eks_identity_provider_config#identity_provider_config_name EksIdentityProviderConfig#identity_provider_config_name}.
IdentityProviderConfigName *string `field:"required" json:"identityProviderConfigName" yaml:"identityProviderConfigName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/eks_identity_provider_config#issuer_url EksIdentityProviderConfig#issuer_url}.
IssuerUrl *string `field:"required" json:"issuerUrl" yaml:"issuerUrl"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/eks_identity_provider_config#groups_claim EksIdentityProviderConfig#groups_claim}.
GroupsClaim *string `field:"optional" json:"groupsClaim" yaml:"groupsClaim"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/eks_identity_provider_config#groups_prefix EksIdentityProviderConfig#groups_prefix}.
GroupsPrefix *string `field:"optional" json:"groupsPrefix" yaml:"groupsPrefix"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/eks_identity_provider_config#required_claims EksIdentityProviderConfig#required_claims}.
RequiredClaims *map[string]*string `field:"optional" json:"requiredClaims" yaml:"requiredClaims"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/eks_identity_provider_config#username_claim EksIdentityProviderConfig#username_claim}.
UsernameClaim *string `field:"optional" json:"usernameClaim" yaml:"usernameClaim"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/eks_identity_provider_config#username_prefix EksIdentityProviderConfig#username_prefix}.
UsernamePrefix *string `field:"optional" json:"usernamePrefix" yaml:"usernamePrefix"`
}
type EksIdentityProviderConfigOidcOutputReference ¶
type EksIdentityProviderConfigOidcOutputReference interface {
cdktf.ComplexObject
ClientId() *string
SetClientId(val *string)
ClientIdInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
GroupsClaim() *string
SetGroupsClaim(val *string)
GroupsClaimInput() *string
GroupsPrefix() *string
SetGroupsPrefix(val *string)
GroupsPrefixInput() *string
IdentityProviderConfigName() *string
SetIdentityProviderConfigName(val *string)
IdentityProviderConfigNameInput() *string
InternalValue() *EksIdentityProviderConfigOidc
SetInternalValue(val *EksIdentityProviderConfigOidc)
IssuerUrl() *string
SetIssuerUrl(val *string)
IssuerUrlInput() *string
RequiredClaims() *map[string]*string
SetRequiredClaims(val *map[string]*string)
RequiredClaimsInput() *map[string]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UsernameClaim() *string
SetUsernameClaim(val *string)
UsernameClaimInput() *string
UsernamePrefix() *string
SetUsernamePrefix(val *string)
UsernamePrefixInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetGroupsClaim()
ResetGroupsPrefix()
ResetRequiredClaims()
ResetUsernameClaim()
ResetUsernamePrefix()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksIdentityProviderConfigOidcOutputReference ¶
func NewEksIdentityProviderConfigOidcOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EksIdentityProviderConfigOidcOutputReference
type EksIdentityProviderConfigTimeouts ¶
type EksIdentityProviderConfigTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/eks_identity_provider_config#create EksIdentityProviderConfig#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/eks_identity_provider_config#delete EksIdentityProviderConfig#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type EksIdentityProviderConfigTimeoutsOutputReference ¶
type EksIdentityProviderConfigTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEksIdentityProviderConfigTimeoutsOutputReference ¶
func NewEksIdentityProviderConfigTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EksIdentityProviderConfigTimeoutsOutputReference
Source Files
¶
- EksIdentityProviderConfig.go
- EksIdentityProviderConfigConfig.go
- EksIdentityProviderConfigOidc.go
- EksIdentityProviderConfigOidcOutputReference.go
- EksIdentityProviderConfigOidcOutputReference__checks.go
- EksIdentityProviderConfigTimeouts.go
- EksIdentityProviderConfigTimeoutsOutputReference.go
- EksIdentityProviderConfigTimeoutsOutputReference__checks.go
- EksIdentityProviderConfig__checks.go
- main.go