Documentation
¶
Index ¶
- func ElasticacheGlobalReplicationGroup_IsConstruct(x interface{}) *bool
- func ElasticacheGlobalReplicationGroup_IsTerraformElement(x interface{}) *bool
- func ElasticacheGlobalReplicationGroup_IsTerraformResource(x interface{}) *bool
- func ElasticacheGlobalReplicationGroup_TfResourceType() *string
- func NewElasticacheGlobalReplicationGroupGlobalNodeGroupsList_Override(e ElasticacheGlobalReplicationGroupGlobalNodeGroupsList, ...)
- func NewElasticacheGlobalReplicationGroupGlobalNodeGroupsOutputReference_Override(e ElasticacheGlobalReplicationGroupGlobalNodeGroupsOutputReference, ...)
- func NewElasticacheGlobalReplicationGroupTimeoutsOutputReference_Override(e ElasticacheGlobalReplicationGroupTimeoutsOutputReference, ...)
- func NewElasticacheGlobalReplicationGroup_Override(e ElasticacheGlobalReplicationGroup, scope constructs.Construct, id *string, ...)
- type ElasticacheGlobalReplicationGroup
- type ElasticacheGlobalReplicationGroupConfig
- type ElasticacheGlobalReplicationGroupGlobalNodeGroups
- type ElasticacheGlobalReplicationGroupGlobalNodeGroupsList
- type ElasticacheGlobalReplicationGroupGlobalNodeGroupsOutputReference
- type ElasticacheGlobalReplicationGroupTimeouts
- type ElasticacheGlobalReplicationGroupTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ElasticacheGlobalReplicationGroup_IsConstruct ¶
func ElasticacheGlobalReplicationGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ElasticacheGlobalReplicationGroup_IsTerraformElement ¶
func ElasticacheGlobalReplicationGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func ElasticacheGlobalReplicationGroup_IsTerraformResource ¶
func ElasticacheGlobalReplicationGroup_IsTerraformResource(x interface{}) *bool
Experimental.
func ElasticacheGlobalReplicationGroup_TfResourceType ¶
func ElasticacheGlobalReplicationGroup_TfResourceType() *string
func NewElasticacheGlobalReplicationGroupGlobalNodeGroupsList_Override ¶
func NewElasticacheGlobalReplicationGroupGlobalNodeGroupsList_Override(e ElasticacheGlobalReplicationGroupGlobalNodeGroupsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewElasticacheGlobalReplicationGroupGlobalNodeGroupsOutputReference_Override ¶
func NewElasticacheGlobalReplicationGroupGlobalNodeGroupsOutputReference_Override(e ElasticacheGlobalReplicationGroupGlobalNodeGroupsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewElasticacheGlobalReplicationGroupTimeoutsOutputReference_Override ¶
func NewElasticacheGlobalReplicationGroupTimeoutsOutputReference_Override(e ElasticacheGlobalReplicationGroupTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewElasticacheGlobalReplicationGroup_Override ¶
func NewElasticacheGlobalReplicationGroup_Override(e ElasticacheGlobalReplicationGroup, scope constructs.Construct, id *string, config *ElasticacheGlobalReplicationGroupConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elasticache_global_replication_group aws_elasticache_global_replication_group} Resource.
Types ¶
type ElasticacheGlobalReplicationGroup ¶
type ElasticacheGlobalReplicationGroup interface {
cdktf.TerraformResource
Arn() *string
AtRestEncryptionEnabled() cdktf.IResolvable
AuthTokenEnabled() cdktf.IResolvable
AutomaticFailoverEnabled() interface{}
SetAutomaticFailoverEnabled(val interface{})
AutomaticFailoverEnabledInput() interface{}
CacheNodeType() *string
SetCacheNodeType(val *string)
CacheNodeTypeInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterEnabled() cdktf.IResolvable
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Engine() *string
EngineVersion() *string
SetEngineVersion(val *string)
EngineVersionActual() *string
EngineVersionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GlobalNodeGroups() ElasticacheGlobalReplicationGroupGlobalNodeGroupsList
GlobalReplicationGroupDescription() *string
SetGlobalReplicationGroupDescription(val *string)
GlobalReplicationGroupDescriptionInput() *string
GlobalReplicationGroupId() *string
GlobalReplicationGroupIdSuffix() *string
SetGlobalReplicationGroupIdSuffix(val *string)
GlobalReplicationGroupIdSuffixInput() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
NumNodeGroups() *float64
SetNumNodeGroups(val *float64)
NumNodeGroupsInput() *float64
ParameterGroupName() *string
SetParameterGroupName(val *string)
ParameterGroupNameInput() *string
PrimaryReplicationGroupId() *string
SetPrimaryReplicationGroupId(val *string)
PrimaryReplicationGroupIdInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() ElasticacheGlobalReplicationGroupTimeoutsOutputReference
TimeoutsInput() interface{}
TransitEncryptionEnabled() cdktf.IResolvable
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *ElasticacheGlobalReplicationGroupTimeouts)
ResetAutomaticFailoverEnabled()
ResetCacheNodeType()
ResetEngineVersion()
ResetGlobalReplicationGroupDescription()
ResetId()
ResetNumNodeGroups()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetParameterGroupName()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elasticache_global_replication_group aws_elasticache_global_replication_group}.
func NewElasticacheGlobalReplicationGroup ¶
func NewElasticacheGlobalReplicationGroup(scope constructs.Construct, id *string, config *ElasticacheGlobalReplicationGroupConfig) ElasticacheGlobalReplicationGroup
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elasticache_global_replication_group aws_elasticache_global_replication_group} Resource.
type ElasticacheGlobalReplicationGroupConfig ¶
type ElasticacheGlobalReplicationGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elasticache_global_replication_group#global_replication_group_id_suffix ElasticacheGlobalReplicationGroup#global_replication_group_id_suffix}.
GlobalReplicationGroupIdSuffix *string `field:"required" json:"globalReplicationGroupIdSuffix" yaml:"globalReplicationGroupIdSuffix"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elasticache_global_replication_group#primary_replication_group_id ElasticacheGlobalReplicationGroup#primary_replication_group_id}.
PrimaryReplicationGroupId *string `field:"required" json:"primaryReplicationGroupId" yaml:"primaryReplicationGroupId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elasticache_global_replication_group#automatic_failover_enabled ElasticacheGlobalReplicationGroup#automatic_failover_enabled}.
AutomaticFailoverEnabled interface{} `field:"optional" json:"automaticFailoverEnabled" yaml:"automaticFailoverEnabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elasticache_global_replication_group#cache_node_type ElasticacheGlobalReplicationGroup#cache_node_type}.
CacheNodeType *string `field:"optional" json:"cacheNodeType" yaml:"cacheNodeType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elasticache_global_replication_group#engine_version ElasticacheGlobalReplicationGroup#engine_version}.
EngineVersion *string `field:"optional" json:"engineVersion" yaml:"engineVersion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elasticache_global_replication_group#global_replication_group_description ElasticacheGlobalReplicationGroup#global_replication_group_description}.
GlobalReplicationGroupDescription *string `field:"optional" json:"globalReplicationGroupDescription" yaml:"globalReplicationGroupDescription"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elasticache_global_replication_group#id ElasticacheGlobalReplicationGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elasticache_global_replication_group#num_node_groups ElasticacheGlobalReplicationGroup#num_node_groups}.
NumNodeGroups *float64 `field:"optional" json:"numNodeGroups" yaml:"numNodeGroups"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elasticache_global_replication_group#parameter_group_name ElasticacheGlobalReplicationGroup#parameter_group_name}.
ParameterGroupName *string `field:"optional" json:"parameterGroupName" yaml:"parameterGroupName"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elasticache_global_replication_group#timeouts ElasticacheGlobalReplicationGroup#timeouts}
Timeouts *ElasticacheGlobalReplicationGroupTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type ElasticacheGlobalReplicationGroupGlobalNodeGroups ¶
type ElasticacheGlobalReplicationGroupGlobalNodeGroups struct {
}
type ElasticacheGlobalReplicationGroupGlobalNodeGroupsList ¶
type ElasticacheGlobalReplicationGroupGlobalNodeGroupsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ElasticacheGlobalReplicationGroupGlobalNodeGroupsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElasticacheGlobalReplicationGroupGlobalNodeGroupsList ¶
func NewElasticacheGlobalReplicationGroupGlobalNodeGroupsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ElasticacheGlobalReplicationGroupGlobalNodeGroupsList
type ElasticacheGlobalReplicationGroupGlobalNodeGroupsOutputReference ¶
type ElasticacheGlobalReplicationGroupGlobalNodeGroupsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
GlobalNodeGroupId() *string
InternalValue() *ElasticacheGlobalReplicationGroupGlobalNodeGroups
SetInternalValue(val *ElasticacheGlobalReplicationGroupGlobalNodeGroups)
Slots() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElasticacheGlobalReplicationGroupGlobalNodeGroupsOutputReference ¶
func NewElasticacheGlobalReplicationGroupGlobalNodeGroupsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ElasticacheGlobalReplicationGroupGlobalNodeGroupsOutputReference
type ElasticacheGlobalReplicationGroupTimeouts ¶
type ElasticacheGlobalReplicationGroupTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elasticache_global_replication_group#create ElasticacheGlobalReplicationGroup#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elasticache_global_replication_group#delete ElasticacheGlobalReplicationGroup#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elasticache_global_replication_group#update ElasticacheGlobalReplicationGroup#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type ElasticacheGlobalReplicationGroupTimeoutsOutputReference ¶
type ElasticacheGlobalReplicationGroupTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElasticacheGlobalReplicationGroupTimeoutsOutputReference ¶
func NewElasticacheGlobalReplicationGroupTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ElasticacheGlobalReplicationGroupTimeoutsOutputReference
Source Files
¶
- ElasticacheGlobalReplicationGroup.go
- ElasticacheGlobalReplicationGroupConfig.go
- ElasticacheGlobalReplicationGroupGlobalNodeGroups.go
- ElasticacheGlobalReplicationGroupGlobalNodeGroupsList.go
- ElasticacheGlobalReplicationGroupGlobalNodeGroupsList__checks.go
- ElasticacheGlobalReplicationGroupGlobalNodeGroupsOutputReference.go
- ElasticacheGlobalReplicationGroupGlobalNodeGroupsOutputReference__checks.go
- ElasticacheGlobalReplicationGroupTimeouts.go
- ElasticacheGlobalReplicationGroupTimeoutsOutputReference.go
- ElasticacheGlobalReplicationGroupTimeoutsOutputReference__checks.go
- ElasticacheGlobalReplicationGroup__checks.go
- main.go