Documentation
¶
Index ¶
- func ElastictranscoderPreset_IsConstruct(x interface{}) *bool
- func ElastictranscoderPreset_IsTerraformElement(x interface{}) *bool
- func ElastictranscoderPreset_IsTerraformResource(x interface{}) *bool
- func ElastictranscoderPreset_TfResourceType() *string
- func NewElastictranscoderPresetAudioCodecOptionsOutputReference_Override(e ElastictranscoderPresetAudioCodecOptionsOutputReference, ...)
- func NewElastictranscoderPresetAudioOutputReference_Override(e ElastictranscoderPresetAudioOutputReference, ...)
- func NewElastictranscoderPresetThumbnailsOutputReference_Override(e ElastictranscoderPresetThumbnailsOutputReference, ...)
- func NewElastictranscoderPresetVideoOutputReference_Override(e ElastictranscoderPresetVideoOutputReference, ...)
- func NewElastictranscoderPresetVideoWatermarksList_Override(e ElastictranscoderPresetVideoWatermarksList, ...)
- func NewElastictranscoderPresetVideoWatermarksOutputReference_Override(e ElastictranscoderPresetVideoWatermarksOutputReference, ...)
- func NewElastictranscoderPreset_Override(e ElastictranscoderPreset, scope constructs.Construct, id *string, ...)
- type ElastictranscoderPreset
- type ElastictranscoderPresetAudio
- type ElastictranscoderPresetAudioCodecOptions
- type ElastictranscoderPresetAudioCodecOptionsOutputReference
- type ElastictranscoderPresetAudioOutputReference
- type ElastictranscoderPresetConfig
- type ElastictranscoderPresetThumbnails
- type ElastictranscoderPresetThumbnailsOutputReference
- type ElastictranscoderPresetVideo
- type ElastictranscoderPresetVideoOutputReference
- type ElastictranscoderPresetVideoWatermarks
- type ElastictranscoderPresetVideoWatermarksList
- type ElastictranscoderPresetVideoWatermarksOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ElastictranscoderPreset_IsConstruct ¶
func ElastictranscoderPreset_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ElastictranscoderPreset_IsTerraformElement ¶
func ElastictranscoderPreset_IsTerraformElement(x interface{}) *bool
Experimental.
func ElastictranscoderPreset_IsTerraformResource ¶
func ElastictranscoderPreset_IsTerraformResource(x interface{}) *bool
Experimental.
func ElastictranscoderPreset_TfResourceType ¶
func ElastictranscoderPreset_TfResourceType() *string
func NewElastictranscoderPresetAudioCodecOptionsOutputReference_Override ¶
func NewElastictranscoderPresetAudioCodecOptionsOutputReference_Override(e ElastictranscoderPresetAudioCodecOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewElastictranscoderPresetAudioOutputReference_Override ¶
func NewElastictranscoderPresetAudioOutputReference_Override(e ElastictranscoderPresetAudioOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewElastictranscoderPresetThumbnailsOutputReference_Override ¶
func NewElastictranscoderPresetThumbnailsOutputReference_Override(e ElastictranscoderPresetThumbnailsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewElastictranscoderPresetVideoOutputReference_Override ¶
func NewElastictranscoderPresetVideoOutputReference_Override(e ElastictranscoderPresetVideoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewElastictranscoderPresetVideoWatermarksList_Override ¶
func NewElastictranscoderPresetVideoWatermarksList_Override(e ElastictranscoderPresetVideoWatermarksList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewElastictranscoderPresetVideoWatermarksOutputReference_Override ¶
func NewElastictranscoderPresetVideoWatermarksOutputReference_Override(e ElastictranscoderPresetVideoWatermarksOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewElastictranscoderPreset_Override ¶
func NewElastictranscoderPreset_Override(e ElastictranscoderPreset, scope constructs.Construct, id *string, config *ElastictranscoderPresetConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset aws_elastictranscoder_preset} Resource.
Types ¶
type ElastictranscoderPreset ¶
type ElastictranscoderPreset interface {
cdktf.TerraformResource
Arn() *string
Audio() ElastictranscoderPresetAudioOutputReference
AudioCodecOptions() ElastictranscoderPresetAudioCodecOptionsOutputReference
AudioCodecOptionsInput() *ElastictranscoderPresetAudioCodecOptions
AudioInput() *ElastictranscoderPresetAudio
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
Container() *string
SetContainer(val *string)
ContainerInput() *string
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Thumbnails() ElastictranscoderPresetThumbnailsOutputReference
ThumbnailsInput() *ElastictranscoderPresetThumbnails
Type() *string
SetType(val *string)
TypeInput() *string
Video() ElastictranscoderPresetVideoOutputReference
VideoCodecOptions() *map[string]*string
SetVideoCodecOptions(val *map[string]*string)
VideoCodecOptionsInput() *map[string]*string
VideoInput() *ElastictranscoderPresetVideo
VideoWatermarks() ElastictranscoderPresetVideoWatermarksList
VideoWatermarksInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAudio(value *ElastictranscoderPresetAudio)
PutAudioCodecOptions(value *ElastictranscoderPresetAudioCodecOptions)
PutThumbnails(value *ElastictranscoderPresetThumbnails)
PutVideo(value *ElastictranscoderPresetVideo)
PutVideoWatermarks(value interface{})
ResetAudio()
ResetAudioCodecOptions()
ResetDescription()
ResetId()
ResetName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetThumbnails()
ResetType()
ResetVideo()
ResetVideoCodecOptions()
ResetVideoWatermarks()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset aws_elastictranscoder_preset}.
func NewElastictranscoderPreset ¶
func NewElastictranscoderPreset(scope constructs.Construct, id *string, config *ElastictranscoderPresetConfig) ElastictranscoderPreset
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset aws_elastictranscoder_preset} Resource.
type ElastictranscoderPresetAudio ¶
type ElastictranscoderPresetAudio struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#audio_packing_mode ElastictranscoderPreset#audio_packing_mode}.
AudioPackingMode *string `field:"optional" json:"audioPackingMode" yaml:"audioPackingMode"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#bit_rate ElastictranscoderPreset#bit_rate}.
BitRate *string `field:"optional" json:"bitRate" yaml:"bitRate"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#channels ElastictranscoderPreset#channels}.
Channels *string `field:"optional" json:"channels" yaml:"channels"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#codec ElastictranscoderPreset#codec}.
Codec *string `field:"optional" json:"codec" yaml:"codec"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#sample_rate ElastictranscoderPreset#sample_rate}.
SampleRate *string `field:"optional" json:"sampleRate" yaml:"sampleRate"`
}
type ElastictranscoderPresetAudioCodecOptions ¶
type ElastictranscoderPresetAudioCodecOptions struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#bit_depth ElastictranscoderPreset#bit_depth}.
BitDepth *string `field:"optional" json:"bitDepth" yaml:"bitDepth"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#bit_order ElastictranscoderPreset#bit_order}.
BitOrder *string `field:"optional" json:"bitOrder" yaml:"bitOrder"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#profile ElastictranscoderPreset#profile}.
Profile *string `field:"optional" json:"profile" yaml:"profile"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#signed ElastictranscoderPreset#signed}.
Signed *string `field:"optional" json:"signed" yaml:"signed"`
}
type ElastictranscoderPresetAudioCodecOptionsOutputReference ¶
type ElastictranscoderPresetAudioCodecOptionsOutputReference interface {
cdktf.ComplexObject
BitDepth() *string
SetBitDepth(val *string)
BitDepthInput() *string
BitOrder() *string
SetBitOrder(val *string)
BitOrderInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ElastictranscoderPresetAudioCodecOptions
SetInternalValue(val *ElastictranscoderPresetAudioCodecOptions)
Profile() *string
SetProfile(val *string)
ProfileInput() *string
Signed() *string
SetSigned(val *string)
SignedInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBitDepth()
ResetBitOrder()
ResetProfile()
ResetSigned()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElastictranscoderPresetAudioCodecOptionsOutputReference ¶
func NewElastictranscoderPresetAudioCodecOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ElastictranscoderPresetAudioCodecOptionsOutputReference
type ElastictranscoderPresetAudioOutputReference ¶
type ElastictranscoderPresetAudioOutputReference interface {
cdktf.ComplexObject
AudioPackingMode() *string
SetAudioPackingMode(val *string)
AudioPackingModeInput() *string
BitRate() *string
SetBitRate(val *string)
BitRateInput() *string
Channels() *string
SetChannels(val *string)
ChannelsInput() *string
Codec() *string
SetCodec(val *string)
CodecInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ElastictranscoderPresetAudio
SetInternalValue(val *ElastictranscoderPresetAudio)
SampleRate() *string
SetSampleRate(val *string)
SampleRateInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAudioPackingMode()
ResetBitRate()
ResetChannels()
ResetCodec()
ResetSampleRate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElastictranscoderPresetAudioOutputReference ¶
func NewElastictranscoderPresetAudioOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ElastictranscoderPresetAudioOutputReference
type ElastictranscoderPresetConfig ¶
type ElastictranscoderPresetConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#container ElastictranscoderPreset#container}.
Container *string `field:"required" json:"container" yaml:"container"`
// audio block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#audio ElastictranscoderPreset#audio}
Audio *ElastictranscoderPresetAudio `field:"optional" json:"audio" yaml:"audio"`
// audio_codec_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#audio_codec_options ElastictranscoderPreset#audio_codec_options}
AudioCodecOptions *ElastictranscoderPresetAudioCodecOptions `field:"optional" json:"audioCodecOptions" yaml:"audioCodecOptions"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#description ElastictranscoderPreset#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#id ElastictranscoderPreset#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#name ElastictranscoderPreset#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// thumbnails block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#thumbnails ElastictranscoderPreset#thumbnails}
Thumbnails *ElastictranscoderPresetThumbnails `field:"optional" json:"thumbnails" yaml:"thumbnails"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#type ElastictranscoderPreset#type}.
Type *string `field:"optional" json:"type" yaml:"type"`
// video block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#video ElastictranscoderPreset#video}
Video *ElastictranscoderPresetVideo `field:"optional" json:"video" yaml:"video"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#video_codec_options ElastictranscoderPreset#video_codec_options}.
VideoCodecOptions *map[string]*string `field:"optional" json:"videoCodecOptions" yaml:"videoCodecOptions"`
// video_watermarks block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#video_watermarks ElastictranscoderPreset#video_watermarks}
VideoWatermarks interface{} `field:"optional" json:"videoWatermarks" yaml:"videoWatermarks"`
}
type ElastictranscoderPresetThumbnails ¶
type ElastictranscoderPresetThumbnails struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#aspect_ratio ElastictranscoderPreset#aspect_ratio}.
AspectRatio *string `field:"optional" json:"aspectRatio" yaml:"aspectRatio"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#format ElastictranscoderPreset#format}.
Format *string `field:"optional" json:"format" yaml:"format"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#interval ElastictranscoderPreset#interval}.
Interval *string `field:"optional" json:"interval" yaml:"interval"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#max_height ElastictranscoderPreset#max_height}.
MaxHeight *string `field:"optional" json:"maxHeight" yaml:"maxHeight"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#max_width ElastictranscoderPreset#max_width}.
MaxWidth *string `field:"optional" json:"maxWidth" yaml:"maxWidth"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#padding_policy ElastictranscoderPreset#padding_policy}.
PaddingPolicy *string `field:"optional" json:"paddingPolicy" yaml:"paddingPolicy"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#resolution ElastictranscoderPreset#resolution}.
Resolution *string `field:"optional" json:"resolution" yaml:"resolution"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#sizing_policy ElastictranscoderPreset#sizing_policy}.
SizingPolicy *string `field:"optional" json:"sizingPolicy" yaml:"sizingPolicy"`
}
type ElastictranscoderPresetThumbnailsOutputReference ¶
type ElastictranscoderPresetThumbnailsOutputReference interface {
cdktf.ComplexObject
AspectRatio() *string
SetAspectRatio(val *string)
AspectRatioInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Format() *string
SetFormat(val *string)
FormatInput() *string
// Experimental.
Fqn() *string
InternalValue() *ElastictranscoderPresetThumbnails
SetInternalValue(val *ElastictranscoderPresetThumbnails)
Interval() *string
SetInterval(val *string)
IntervalInput() *string
MaxHeight() *string
SetMaxHeight(val *string)
MaxHeightInput() *string
MaxWidth() *string
SetMaxWidth(val *string)
MaxWidthInput() *string
PaddingPolicy() *string
SetPaddingPolicy(val *string)
PaddingPolicyInput() *string
Resolution() *string
SetResolution(val *string)
ResolutionInput() *string
SizingPolicy() *string
SetSizingPolicy(val *string)
SizingPolicyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAspectRatio()
ResetFormat()
ResetInterval()
ResetMaxHeight()
ResetMaxWidth()
ResetPaddingPolicy()
ResetResolution()
ResetSizingPolicy()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElastictranscoderPresetThumbnailsOutputReference ¶
func NewElastictranscoderPresetThumbnailsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ElastictranscoderPresetThumbnailsOutputReference
type ElastictranscoderPresetVideo ¶
type ElastictranscoderPresetVideo struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#aspect_ratio ElastictranscoderPreset#aspect_ratio}.
AspectRatio *string `field:"optional" json:"aspectRatio" yaml:"aspectRatio"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#bit_rate ElastictranscoderPreset#bit_rate}.
BitRate *string `field:"optional" json:"bitRate" yaml:"bitRate"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#codec ElastictranscoderPreset#codec}.
Codec *string `field:"optional" json:"codec" yaml:"codec"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#display_aspect_ratio ElastictranscoderPreset#display_aspect_ratio}.
DisplayAspectRatio *string `field:"optional" json:"displayAspectRatio" yaml:"displayAspectRatio"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#fixed_gop ElastictranscoderPreset#fixed_gop}.
FixedGop *string `field:"optional" json:"fixedGop" yaml:"fixedGop"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#frame_rate ElastictranscoderPreset#frame_rate}.
FrameRate *string `field:"optional" json:"frameRate" yaml:"frameRate"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#keyframes_max_dist ElastictranscoderPreset#keyframes_max_dist}.
KeyframesMaxDist *string `field:"optional" json:"keyframesMaxDist" yaml:"keyframesMaxDist"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#max_frame_rate ElastictranscoderPreset#max_frame_rate}.
MaxFrameRate *string `field:"optional" json:"maxFrameRate" yaml:"maxFrameRate"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#max_height ElastictranscoderPreset#max_height}.
MaxHeight *string `field:"optional" json:"maxHeight" yaml:"maxHeight"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#max_width ElastictranscoderPreset#max_width}.
MaxWidth *string `field:"optional" json:"maxWidth" yaml:"maxWidth"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#padding_policy ElastictranscoderPreset#padding_policy}.
PaddingPolicy *string `field:"optional" json:"paddingPolicy" yaml:"paddingPolicy"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#resolution ElastictranscoderPreset#resolution}.
Resolution *string `field:"optional" json:"resolution" yaml:"resolution"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#sizing_policy ElastictranscoderPreset#sizing_policy}.
SizingPolicy *string `field:"optional" json:"sizingPolicy" yaml:"sizingPolicy"`
}
type ElastictranscoderPresetVideoOutputReference ¶
type ElastictranscoderPresetVideoOutputReference interface {
cdktf.ComplexObject
AspectRatio() *string
SetAspectRatio(val *string)
AspectRatioInput() *string
BitRate() *string
SetBitRate(val *string)
BitRateInput() *string
Codec() *string
SetCodec(val *string)
CodecInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DisplayAspectRatio() *string
SetDisplayAspectRatio(val *string)
DisplayAspectRatioInput() *string
FixedGop() *string
SetFixedGop(val *string)
FixedGopInput() *string
// Experimental.
Fqn() *string
FrameRate() *string
SetFrameRate(val *string)
FrameRateInput() *string
InternalValue() *ElastictranscoderPresetVideo
SetInternalValue(val *ElastictranscoderPresetVideo)
KeyframesMaxDist() *string
SetKeyframesMaxDist(val *string)
KeyframesMaxDistInput() *string
MaxFrameRate() *string
SetMaxFrameRate(val *string)
MaxFrameRateInput() *string
MaxHeight() *string
SetMaxHeight(val *string)
MaxHeightInput() *string
MaxWidth() *string
SetMaxWidth(val *string)
MaxWidthInput() *string
PaddingPolicy() *string
SetPaddingPolicy(val *string)
PaddingPolicyInput() *string
Resolution() *string
SetResolution(val *string)
ResolutionInput() *string
SizingPolicy() *string
SetSizingPolicy(val *string)
SizingPolicyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAspectRatio()
ResetBitRate()
ResetCodec()
ResetDisplayAspectRatio()
ResetFixedGop()
ResetFrameRate()
ResetKeyframesMaxDist()
ResetMaxFrameRate()
ResetMaxHeight()
ResetMaxWidth()
ResetPaddingPolicy()
ResetResolution()
ResetSizingPolicy()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElastictranscoderPresetVideoOutputReference ¶
func NewElastictranscoderPresetVideoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ElastictranscoderPresetVideoOutputReference
type ElastictranscoderPresetVideoWatermarks ¶
type ElastictranscoderPresetVideoWatermarks struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#horizontal_align ElastictranscoderPreset#horizontal_align}.
HorizontalAlign *string `field:"optional" json:"horizontalAlign" yaml:"horizontalAlign"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#horizontal_offset ElastictranscoderPreset#horizontal_offset}.
HorizontalOffset *string `field:"optional" json:"horizontalOffset" yaml:"horizontalOffset"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#id ElastictranscoderPreset#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#max_height ElastictranscoderPreset#max_height}.
MaxHeight *string `field:"optional" json:"maxHeight" yaml:"maxHeight"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#max_width ElastictranscoderPreset#max_width}.
MaxWidth *string `field:"optional" json:"maxWidth" yaml:"maxWidth"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#opacity ElastictranscoderPreset#opacity}.
Opacity *string `field:"optional" json:"opacity" yaml:"opacity"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#sizing_policy ElastictranscoderPreset#sizing_policy}.
SizingPolicy *string `field:"optional" json:"sizingPolicy" yaml:"sizingPolicy"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#target ElastictranscoderPreset#target}.
Target *string `field:"optional" json:"target" yaml:"target"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#vertical_align ElastictranscoderPreset#vertical_align}.
VerticalAlign *string `field:"optional" json:"verticalAlign" yaml:"verticalAlign"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/elastictranscoder_preset#vertical_offset ElastictranscoderPreset#vertical_offset}.
VerticalOffset *string `field:"optional" json:"verticalOffset" yaml:"verticalOffset"`
}
type ElastictranscoderPresetVideoWatermarksList ¶
type ElastictranscoderPresetVideoWatermarksList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ElastictranscoderPresetVideoWatermarksOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElastictranscoderPresetVideoWatermarksList ¶
func NewElastictranscoderPresetVideoWatermarksList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ElastictranscoderPresetVideoWatermarksList
type ElastictranscoderPresetVideoWatermarksOutputReference ¶
type ElastictranscoderPresetVideoWatermarksOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HorizontalAlign() *string
SetHorizontalAlign(val *string)
HorizontalAlignInput() *string
HorizontalOffset() *string
SetHorizontalOffset(val *string)
HorizontalOffsetInput() *string
Id() *string
SetId(val *string)
IdInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
MaxHeight() *string
SetMaxHeight(val *string)
MaxHeightInput() *string
MaxWidth() *string
SetMaxWidth(val *string)
MaxWidthInput() *string
Opacity() *string
SetOpacity(val *string)
OpacityInput() *string
SizingPolicy() *string
SetSizingPolicy(val *string)
SizingPolicyInput() *string
Target() *string
SetTarget(val *string)
TargetInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VerticalAlign() *string
SetVerticalAlign(val *string)
VerticalAlignInput() *string
VerticalOffset() *string
SetVerticalOffset(val *string)
VerticalOffsetInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetHorizontalAlign()
ResetHorizontalOffset()
ResetId()
ResetMaxHeight()
ResetMaxWidth()
ResetOpacity()
ResetSizingPolicy()
ResetTarget()
ResetVerticalAlign()
ResetVerticalOffset()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewElastictranscoderPresetVideoWatermarksOutputReference ¶
func NewElastictranscoderPresetVideoWatermarksOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ElastictranscoderPresetVideoWatermarksOutputReference
Source Files
¶
- ElastictranscoderPreset.go
- ElastictranscoderPresetAudio.go
- ElastictranscoderPresetAudioCodecOptions.go
- ElastictranscoderPresetAudioCodecOptionsOutputReference.go
- ElastictranscoderPresetAudioCodecOptionsOutputReference__checks.go
- ElastictranscoderPresetAudioOutputReference.go
- ElastictranscoderPresetAudioOutputReference__checks.go
- ElastictranscoderPresetConfig.go
- ElastictranscoderPresetThumbnails.go
- ElastictranscoderPresetThumbnailsOutputReference.go
- ElastictranscoderPresetThumbnailsOutputReference__checks.go
- ElastictranscoderPresetVideo.go
- ElastictranscoderPresetVideoOutputReference.go
- ElastictranscoderPresetVideoOutputReference__checks.go
- ElastictranscoderPresetVideoWatermarks.go
- ElastictranscoderPresetVideoWatermarksList.go
- ElastictranscoderPresetVideoWatermarksList__checks.go
- ElastictranscoderPresetVideoWatermarksOutputReference.go
- ElastictranscoderPresetVideoWatermarksOutputReference__checks.go
- ElastictranscoderPreset__checks.go
- main.go