Documentation
¶
Index ¶
- func EmrserverlessApplication_IsConstruct(x interface{}) *bool
- func EmrserverlessApplication_IsTerraformElement(x interface{}) *bool
- func EmrserverlessApplication_IsTerraformResource(x interface{}) *bool
- func EmrserverlessApplication_TfResourceType() *string
- func NewEmrserverlessApplicationAutoStartConfigurationOutputReference_Override(e EmrserverlessApplicationAutoStartConfigurationOutputReference, ...)
- func NewEmrserverlessApplicationAutoStopConfigurationOutputReference_Override(e EmrserverlessApplicationAutoStopConfigurationOutputReference, ...)
- func NewEmrserverlessApplicationImageConfigurationOutputReference_Override(e EmrserverlessApplicationImageConfigurationOutputReference, ...)
- func NewEmrserverlessApplicationInitialCapacityInitialCapacityConfigOutputReference_Override(e EmrserverlessApplicationInitialCapacityInitialCapacityConfigOutputReference, ...)
- func NewEmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfigurationOutputReference_Override(...)
- func NewEmrserverlessApplicationInitialCapacityList_Override(e EmrserverlessApplicationInitialCapacityList, ...)
- func NewEmrserverlessApplicationInitialCapacityOutputReference_Override(e EmrserverlessApplicationInitialCapacityOutputReference, ...)
- func NewEmrserverlessApplicationMaximumCapacityOutputReference_Override(e EmrserverlessApplicationMaximumCapacityOutputReference, ...)
- func NewEmrserverlessApplicationNetworkConfigurationOutputReference_Override(e EmrserverlessApplicationNetworkConfigurationOutputReference, ...)
- func NewEmrserverlessApplication_Override(e EmrserverlessApplication, scope constructs.Construct, id *string, ...)
- type EmrserverlessApplication
- type EmrserverlessApplicationAutoStartConfiguration
- type EmrserverlessApplicationAutoStartConfigurationOutputReference
- type EmrserverlessApplicationAutoStopConfiguration
- type EmrserverlessApplicationAutoStopConfigurationOutputReference
- type EmrserverlessApplicationConfig
- type EmrserverlessApplicationImageConfiguration
- type EmrserverlessApplicationImageConfigurationOutputReference
- type EmrserverlessApplicationInitialCapacity
- type EmrserverlessApplicationInitialCapacityInitialCapacityConfig
- type EmrserverlessApplicationInitialCapacityInitialCapacityConfigOutputReference
- type EmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfiguration
- type EmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfigurationOutputReference
- type EmrserverlessApplicationInitialCapacityList
- type EmrserverlessApplicationInitialCapacityOutputReference
- type EmrserverlessApplicationMaximumCapacity
- type EmrserverlessApplicationMaximumCapacityOutputReference
- type EmrserverlessApplicationNetworkConfiguration
- type EmrserverlessApplicationNetworkConfigurationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EmrserverlessApplication_IsConstruct ¶
func EmrserverlessApplication_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func EmrserverlessApplication_IsTerraformElement ¶
func EmrserverlessApplication_IsTerraformElement(x interface{}) *bool
Experimental.
func EmrserverlessApplication_IsTerraformResource ¶
func EmrserverlessApplication_IsTerraformResource(x interface{}) *bool
Experimental.
func EmrserverlessApplication_TfResourceType ¶
func EmrserverlessApplication_TfResourceType() *string
func NewEmrserverlessApplicationAutoStartConfigurationOutputReference_Override ¶
func NewEmrserverlessApplicationAutoStartConfigurationOutputReference_Override(e EmrserverlessApplicationAutoStartConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEmrserverlessApplicationAutoStopConfigurationOutputReference_Override ¶
func NewEmrserverlessApplicationAutoStopConfigurationOutputReference_Override(e EmrserverlessApplicationAutoStopConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEmrserverlessApplicationImageConfigurationOutputReference_Override ¶
func NewEmrserverlessApplicationImageConfigurationOutputReference_Override(e EmrserverlessApplicationImageConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEmrserverlessApplicationInitialCapacityInitialCapacityConfigOutputReference_Override ¶
func NewEmrserverlessApplicationInitialCapacityInitialCapacityConfigOutputReference_Override(e EmrserverlessApplicationInitialCapacityInitialCapacityConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfigurationOutputReference_Override ¶
func NewEmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfigurationOutputReference_Override(e EmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEmrserverlessApplicationInitialCapacityList_Override ¶
func NewEmrserverlessApplicationInitialCapacityList_Override(e EmrserverlessApplicationInitialCapacityList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEmrserverlessApplicationInitialCapacityOutputReference_Override ¶
func NewEmrserverlessApplicationInitialCapacityOutputReference_Override(e EmrserverlessApplicationInitialCapacityOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEmrserverlessApplicationMaximumCapacityOutputReference_Override ¶
func NewEmrserverlessApplicationMaximumCapacityOutputReference_Override(e EmrserverlessApplicationMaximumCapacityOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEmrserverlessApplicationNetworkConfigurationOutputReference_Override ¶
func NewEmrserverlessApplicationNetworkConfigurationOutputReference_Override(e EmrserverlessApplicationNetworkConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEmrserverlessApplication_Override ¶
func NewEmrserverlessApplication_Override(e EmrserverlessApplication, scope constructs.Construct, id *string, config *EmrserverlessApplicationConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application aws_emrserverless_application} Resource.
Types ¶
type EmrserverlessApplication ¶
type EmrserverlessApplication interface {
cdktf.TerraformResource
Architecture() *string
SetArchitecture(val *string)
ArchitectureInput() *string
Arn() *string
AutoStartConfiguration() EmrserverlessApplicationAutoStartConfigurationOutputReference
AutoStartConfigurationInput() *EmrserverlessApplicationAutoStartConfiguration
AutoStopConfiguration() EmrserverlessApplicationAutoStopConfigurationOutputReference
AutoStopConfigurationInput() *EmrserverlessApplicationAutoStopConfiguration
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
ImageConfiguration() EmrserverlessApplicationImageConfigurationOutputReference
ImageConfigurationInput() *EmrserverlessApplicationImageConfiguration
InitialCapacity() EmrserverlessApplicationInitialCapacityList
InitialCapacityInput() interface{}
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaximumCapacity() EmrserverlessApplicationMaximumCapacityOutputReference
MaximumCapacityInput() *EmrserverlessApplicationMaximumCapacity
Name() *string
SetName(val *string)
NameInput() *string
NetworkConfiguration() EmrserverlessApplicationNetworkConfigurationOutputReference
NetworkConfigurationInput() *EmrserverlessApplicationNetworkConfiguration
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ReleaseLabel() *string
SetReleaseLabel(val *string)
ReleaseLabelInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAutoStartConfiguration(value *EmrserverlessApplicationAutoStartConfiguration)
PutAutoStopConfiguration(value *EmrserverlessApplicationAutoStopConfiguration)
PutImageConfiguration(value *EmrserverlessApplicationImageConfiguration)
PutInitialCapacity(value interface{})
PutMaximumCapacity(value *EmrserverlessApplicationMaximumCapacity)
PutNetworkConfiguration(value *EmrserverlessApplicationNetworkConfiguration)
ResetArchitecture()
ResetAutoStartConfiguration()
ResetAutoStopConfiguration()
ResetId()
ResetImageConfiguration()
ResetInitialCapacity()
ResetMaximumCapacity()
ResetNetworkConfiguration()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application aws_emrserverless_application}.
func NewEmrserverlessApplication ¶
func NewEmrserverlessApplication(scope constructs.Construct, id *string, config *EmrserverlessApplicationConfig) EmrserverlessApplication
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application aws_emrserverless_application} Resource.
type EmrserverlessApplicationAutoStartConfiguration ¶
type EmrserverlessApplicationAutoStartConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#enabled EmrserverlessApplication#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
}
type EmrserverlessApplicationAutoStartConfigurationOutputReference ¶
type EmrserverlessApplicationAutoStartConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *EmrserverlessApplicationAutoStartConfiguration
SetInternalValue(val *EmrserverlessApplicationAutoStartConfiguration)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnabled()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrserverlessApplicationAutoStartConfigurationOutputReference ¶
func NewEmrserverlessApplicationAutoStartConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EmrserverlessApplicationAutoStartConfigurationOutputReference
type EmrserverlessApplicationAutoStopConfiguration ¶
type EmrserverlessApplicationAutoStopConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#enabled EmrserverlessApplication#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#idle_timeout_minutes EmrserverlessApplication#idle_timeout_minutes}.
IdleTimeoutMinutes *float64 `field:"optional" json:"idleTimeoutMinutes" yaml:"idleTimeoutMinutes"`
}
type EmrserverlessApplicationAutoStopConfigurationOutputReference ¶
type EmrserverlessApplicationAutoStopConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
IdleTimeoutMinutes() *float64
SetIdleTimeoutMinutes(val *float64)
IdleTimeoutMinutesInput() *float64
InternalValue() *EmrserverlessApplicationAutoStopConfiguration
SetInternalValue(val *EmrserverlessApplicationAutoStopConfiguration)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnabled()
ResetIdleTimeoutMinutes()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrserverlessApplicationAutoStopConfigurationOutputReference ¶
func NewEmrserverlessApplicationAutoStopConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EmrserverlessApplicationAutoStopConfigurationOutputReference
type EmrserverlessApplicationConfig ¶
type EmrserverlessApplicationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#name EmrserverlessApplication#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#release_label EmrserverlessApplication#release_label}.
ReleaseLabel *string `field:"required" json:"releaseLabel" yaml:"releaseLabel"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#type EmrserverlessApplication#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#architecture EmrserverlessApplication#architecture}.
Architecture *string `field:"optional" json:"architecture" yaml:"architecture"`
// auto_start_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#auto_start_configuration EmrserverlessApplication#auto_start_configuration}
AutoStartConfiguration *EmrserverlessApplicationAutoStartConfiguration `field:"optional" json:"autoStartConfiguration" yaml:"autoStartConfiguration"`
// auto_stop_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#auto_stop_configuration EmrserverlessApplication#auto_stop_configuration}
AutoStopConfiguration *EmrserverlessApplicationAutoStopConfiguration `field:"optional" json:"autoStopConfiguration" yaml:"autoStopConfiguration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#id EmrserverlessApplication#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// image_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#image_configuration EmrserverlessApplication#image_configuration}
ImageConfiguration *EmrserverlessApplicationImageConfiguration `field:"optional" json:"imageConfiguration" yaml:"imageConfiguration"`
// initial_capacity block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#initial_capacity EmrserverlessApplication#initial_capacity}
InitialCapacity interface{} `field:"optional" json:"initialCapacity" yaml:"initialCapacity"`
// maximum_capacity block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#maximum_capacity EmrserverlessApplication#maximum_capacity}
MaximumCapacity *EmrserverlessApplicationMaximumCapacity `field:"optional" json:"maximumCapacity" yaml:"maximumCapacity"`
// network_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#network_configuration EmrserverlessApplication#network_configuration}
NetworkConfiguration *EmrserverlessApplicationNetworkConfiguration `field:"optional" json:"networkConfiguration" yaml:"networkConfiguration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#tags EmrserverlessApplication#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#tags_all EmrserverlessApplication#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type EmrserverlessApplicationImageConfiguration ¶
type EmrserverlessApplicationImageConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#image_uri EmrserverlessApplication#image_uri}.
ImageUri *string `field:"required" json:"imageUri" yaml:"imageUri"`
}
type EmrserverlessApplicationImageConfigurationOutputReference ¶
type EmrserverlessApplicationImageConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
ImageUri() *string
SetImageUri(val *string)
ImageUriInput() *string
InternalValue() *EmrserverlessApplicationImageConfiguration
SetInternalValue(val *EmrserverlessApplicationImageConfiguration)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrserverlessApplicationImageConfigurationOutputReference ¶
func NewEmrserverlessApplicationImageConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EmrserverlessApplicationImageConfigurationOutputReference
type EmrserverlessApplicationInitialCapacity ¶
type EmrserverlessApplicationInitialCapacity struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#initial_capacity_type EmrserverlessApplication#initial_capacity_type}.
InitialCapacityType *string `field:"required" json:"initialCapacityType" yaml:"initialCapacityType"`
// initial_capacity_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#initial_capacity_config EmrserverlessApplication#initial_capacity_config}
InitialCapacityConfig *EmrserverlessApplicationInitialCapacityInitialCapacityConfig `field:"optional" json:"initialCapacityConfig" yaml:"initialCapacityConfig"`
}
type EmrserverlessApplicationInitialCapacityInitialCapacityConfig ¶
type EmrserverlessApplicationInitialCapacityInitialCapacityConfig struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#worker_count EmrserverlessApplication#worker_count}.
WorkerCount *float64 `field:"required" json:"workerCount" yaml:"workerCount"`
// worker_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#worker_configuration EmrserverlessApplication#worker_configuration}
WorkerConfiguration *EmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfiguration `field:"optional" json:"workerConfiguration" yaml:"workerConfiguration"`
}
type EmrserverlessApplicationInitialCapacityInitialCapacityConfigOutputReference ¶
type EmrserverlessApplicationInitialCapacityInitialCapacityConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EmrserverlessApplicationInitialCapacityInitialCapacityConfig
SetInternalValue(val *EmrserverlessApplicationInitialCapacityInitialCapacityConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
WorkerConfiguration() EmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfigurationOutputReference
WorkerConfigurationInput() *EmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfiguration
WorkerCount() *float64
SetWorkerCount(val *float64)
WorkerCountInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutWorkerConfiguration(value *EmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfiguration)
ResetWorkerConfiguration()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrserverlessApplicationInitialCapacityInitialCapacityConfigOutputReference ¶
func NewEmrserverlessApplicationInitialCapacityInitialCapacityConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EmrserverlessApplicationInitialCapacityInitialCapacityConfigOutputReference
type EmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfiguration ¶
type EmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#cpu EmrserverlessApplication#cpu}.
Cpu *string `field:"required" json:"cpu" yaml:"cpu"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#memory EmrserverlessApplication#memory}.
Memory *string `field:"required" json:"memory" yaml:"memory"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#disk EmrserverlessApplication#disk}.
Disk *string `field:"optional" json:"disk" yaml:"disk"`
}
type EmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfigurationOutputReference ¶
type EmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Cpu() *string
SetCpu(val *string)
CpuInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Disk() *string
SetDisk(val *string)
DiskInput() *string
// Experimental.
Fqn() *string
InternalValue() *EmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfiguration
SetInternalValue(val *EmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfiguration)
Memory() *string
SetMemory(val *string)
MemoryInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDisk()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfigurationOutputReference ¶
func NewEmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfigurationOutputReference
type EmrserverlessApplicationInitialCapacityList ¶
type EmrserverlessApplicationInitialCapacityList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EmrserverlessApplicationInitialCapacityOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrserverlessApplicationInitialCapacityList ¶
func NewEmrserverlessApplicationInitialCapacityList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EmrserverlessApplicationInitialCapacityList
type EmrserverlessApplicationInitialCapacityOutputReference ¶
type EmrserverlessApplicationInitialCapacityOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InitialCapacityConfig() EmrserverlessApplicationInitialCapacityInitialCapacityConfigOutputReference
InitialCapacityConfigInput() *EmrserverlessApplicationInitialCapacityInitialCapacityConfig
InitialCapacityType() *string
SetInitialCapacityType(val *string)
InitialCapacityTypeInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutInitialCapacityConfig(value *EmrserverlessApplicationInitialCapacityInitialCapacityConfig)
ResetInitialCapacityConfig()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrserverlessApplicationInitialCapacityOutputReference ¶
func NewEmrserverlessApplicationInitialCapacityOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EmrserverlessApplicationInitialCapacityOutputReference
type EmrserverlessApplicationMaximumCapacity ¶
type EmrserverlessApplicationMaximumCapacity struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#cpu EmrserverlessApplication#cpu}.
Cpu *string `field:"required" json:"cpu" yaml:"cpu"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#memory EmrserverlessApplication#memory}.
Memory *string `field:"required" json:"memory" yaml:"memory"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#disk EmrserverlessApplication#disk}.
Disk *string `field:"optional" json:"disk" yaml:"disk"`
}
type EmrserverlessApplicationMaximumCapacityOutputReference ¶
type EmrserverlessApplicationMaximumCapacityOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Cpu() *string
SetCpu(val *string)
CpuInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Disk() *string
SetDisk(val *string)
DiskInput() *string
// Experimental.
Fqn() *string
InternalValue() *EmrserverlessApplicationMaximumCapacity
SetInternalValue(val *EmrserverlessApplicationMaximumCapacity)
Memory() *string
SetMemory(val *string)
MemoryInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDisk()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrserverlessApplicationMaximumCapacityOutputReference ¶
func NewEmrserverlessApplicationMaximumCapacityOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EmrserverlessApplicationMaximumCapacityOutputReference
type EmrserverlessApplicationNetworkConfiguration ¶
type EmrserverlessApplicationNetworkConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#security_group_ids EmrserverlessApplication#security_group_ids}.
SecurityGroupIds *[]*string `field:"optional" json:"securityGroupIds" yaml:"securityGroupIds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/emrserverless_application#subnet_ids EmrserverlessApplication#subnet_ids}.
SubnetIds *[]*string `field:"optional" json:"subnetIds" yaml:"subnetIds"`
}
type EmrserverlessApplicationNetworkConfigurationOutputReference ¶
type EmrserverlessApplicationNetworkConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EmrserverlessApplicationNetworkConfiguration
SetInternalValue(val *EmrserverlessApplicationNetworkConfiguration)
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
SubnetIds() *[]*string
SetSubnetIds(val *[]*string)
SubnetIdsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetSecurityGroupIds()
ResetSubnetIds()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrserverlessApplicationNetworkConfigurationOutputReference ¶
func NewEmrserverlessApplicationNetworkConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EmrserverlessApplicationNetworkConfigurationOutputReference
Source Files
¶
- EmrserverlessApplication.go
- EmrserverlessApplicationAutoStartConfiguration.go
- EmrserverlessApplicationAutoStartConfigurationOutputReference.go
- EmrserverlessApplicationAutoStartConfigurationOutputReference__checks.go
- EmrserverlessApplicationAutoStopConfiguration.go
- EmrserverlessApplicationAutoStopConfigurationOutputReference.go
- EmrserverlessApplicationAutoStopConfigurationOutputReference__checks.go
- EmrserverlessApplicationConfig.go
- EmrserverlessApplicationImageConfiguration.go
- EmrserverlessApplicationImageConfigurationOutputReference.go
- EmrserverlessApplicationImageConfigurationOutputReference__checks.go
- EmrserverlessApplicationInitialCapacity.go
- EmrserverlessApplicationInitialCapacityInitialCapacityConfig.go
- EmrserverlessApplicationInitialCapacityInitialCapacityConfigOutputReference.go
- EmrserverlessApplicationInitialCapacityInitialCapacityConfigOutputReference__checks.go
- EmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfiguration.go
- EmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfigurationOutputReference.go
- EmrserverlessApplicationInitialCapacityInitialCapacityConfigWorkerConfigurationOutputReference__checks.go
- EmrserverlessApplicationInitialCapacityList.go
- EmrserverlessApplicationInitialCapacityList__checks.go
- EmrserverlessApplicationInitialCapacityOutputReference.go
- EmrserverlessApplicationInitialCapacityOutputReference__checks.go
- EmrserverlessApplicationMaximumCapacity.go
- EmrserverlessApplicationMaximumCapacityOutputReference.go
- EmrserverlessApplicationMaximumCapacityOutputReference__checks.go
- EmrserverlessApplicationNetworkConfiguration.go
- EmrserverlessApplicationNetworkConfigurationOutputReference.go
- EmrserverlessApplicationNetworkConfigurationOutputReference__checks.go
- EmrserverlessApplication__checks.go
- main.go