Documentation
¶
Index ¶
- func EvidentlyFeature_IsConstruct(x interface{}) *bool
- func EvidentlyFeature_IsTerraformElement(x interface{}) *bool
- func EvidentlyFeature_IsTerraformResource(x interface{}) *bool
- func EvidentlyFeature_TfResourceType() *string
- func NewEvidentlyFeatureEvaluationRulesList_Override(e EvidentlyFeatureEvaluationRulesList, ...)
- func NewEvidentlyFeatureEvaluationRulesOutputReference_Override(e EvidentlyFeatureEvaluationRulesOutputReference, ...)
- func NewEvidentlyFeatureTimeoutsOutputReference_Override(e EvidentlyFeatureTimeoutsOutputReference, ...)
- func NewEvidentlyFeatureVariationsList_Override(e EvidentlyFeatureVariationsList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewEvidentlyFeatureVariationsOutputReference_Override(e EvidentlyFeatureVariationsOutputReference, ...)
- func NewEvidentlyFeatureVariationsValueOutputReference_Override(e EvidentlyFeatureVariationsValueOutputReference, ...)
- func NewEvidentlyFeature_Override(e EvidentlyFeature, scope constructs.Construct, id *string, ...)
- type EvidentlyFeature
- type EvidentlyFeatureConfig
- type EvidentlyFeatureEvaluationRules
- type EvidentlyFeatureEvaluationRulesList
- type EvidentlyFeatureEvaluationRulesOutputReference
- type EvidentlyFeatureTimeouts
- type EvidentlyFeatureTimeoutsOutputReference
- type EvidentlyFeatureVariations
- type EvidentlyFeatureVariationsList
- type EvidentlyFeatureVariationsOutputReference
- type EvidentlyFeatureVariationsValue
- type EvidentlyFeatureVariationsValueOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EvidentlyFeature_IsConstruct ¶
func EvidentlyFeature_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func EvidentlyFeature_IsTerraformElement ¶
func EvidentlyFeature_IsTerraformElement(x interface{}) *bool
Experimental.
func EvidentlyFeature_IsTerraformResource ¶
func EvidentlyFeature_IsTerraformResource(x interface{}) *bool
Experimental.
func EvidentlyFeature_TfResourceType ¶
func EvidentlyFeature_TfResourceType() *string
func NewEvidentlyFeatureEvaluationRulesList_Override ¶
func NewEvidentlyFeatureEvaluationRulesList_Override(e EvidentlyFeatureEvaluationRulesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEvidentlyFeatureEvaluationRulesOutputReference_Override ¶
func NewEvidentlyFeatureEvaluationRulesOutputReference_Override(e EvidentlyFeatureEvaluationRulesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEvidentlyFeatureTimeoutsOutputReference_Override ¶
func NewEvidentlyFeatureTimeoutsOutputReference_Override(e EvidentlyFeatureTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEvidentlyFeatureVariationsList_Override ¶
func NewEvidentlyFeatureVariationsList_Override(e EvidentlyFeatureVariationsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEvidentlyFeatureVariationsOutputReference_Override ¶
func NewEvidentlyFeatureVariationsOutputReference_Override(e EvidentlyFeatureVariationsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEvidentlyFeatureVariationsValueOutputReference_Override ¶
func NewEvidentlyFeatureVariationsValueOutputReference_Override(e EvidentlyFeatureVariationsValueOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEvidentlyFeature_Override ¶
func NewEvidentlyFeature_Override(e EvidentlyFeature, scope constructs.Construct, id *string, config *EvidentlyFeatureConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature aws_evidently_feature} Resource.
Types ¶
type EvidentlyFeature ¶
type EvidentlyFeature interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreatedTime() *string
DefaultVariation() *string
SetDefaultVariation(val *string)
DefaultVariationInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
EntityOverrides() *map[string]*string
SetEntityOverrides(val *map[string]*string)
EntityOverridesInput() *map[string]*string
EvaluationRules() EvidentlyFeatureEvaluationRulesList
EvaluationStrategy() *string
SetEvaluationStrategy(val *string)
EvaluationStrategyInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
LastUpdatedTime() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Status() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() EvidentlyFeatureTimeoutsOutputReference
TimeoutsInput() interface{}
ValueType() *string
Variations() EvidentlyFeatureVariationsList
VariationsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *EvidentlyFeatureTimeouts)
PutVariations(value interface{})
ResetDefaultVariation()
ResetDescription()
ResetEntityOverrides()
ResetEvaluationStrategy()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature aws_evidently_feature}.
func NewEvidentlyFeature ¶
func NewEvidentlyFeature(scope constructs.Construct, id *string, config *EvidentlyFeatureConfig) EvidentlyFeature
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature aws_evidently_feature} Resource.
type EvidentlyFeatureConfig ¶
type EvidentlyFeatureConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#name EvidentlyFeature#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#project EvidentlyFeature#project}.
Project *string `field:"required" json:"project" yaml:"project"`
// variations block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#variations EvidentlyFeature#variations}
Variations interface{} `field:"required" json:"variations" yaml:"variations"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#default_variation EvidentlyFeature#default_variation}.
DefaultVariation *string `field:"optional" json:"defaultVariation" yaml:"defaultVariation"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#description EvidentlyFeature#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#entity_overrides EvidentlyFeature#entity_overrides}.
EntityOverrides *map[string]*string `field:"optional" json:"entityOverrides" yaml:"entityOverrides"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#evaluation_strategy EvidentlyFeature#evaluation_strategy}.
EvaluationStrategy *string `field:"optional" json:"evaluationStrategy" yaml:"evaluationStrategy"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#id EvidentlyFeature#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#tags EvidentlyFeature#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#tags_all EvidentlyFeature#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#timeouts EvidentlyFeature#timeouts}
Timeouts *EvidentlyFeatureTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type EvidentlyFeatureEvaluationRules ¶
type EvidentlyFeatureEvaluationRules struct {
}
type EvidentlyFeatureEvaluationRulesList ¶
type EvidentlyFeatureEvaluationRulesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EvidentlyFeatureEvaluationRulesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyFeatureEvaluationRulesList ¶
func NewEvidentlyFeatureEvaluationRulesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EvidentlyFeatureEvaluationRulesList
type EvidentlyFeatureEvaluationRulesOutputReference ¶
type EvidentlyFeatureEvaluationRulesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EvidentlyFeatureEvaluationRules
SetInternalValue(val *EvidentlyFeatureEvaluationRules)
Name() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyFeatureEvaluationRulesOutputReference ¶
func NewEvidentlyFeatureEvaluationRulesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EvidentlyFeatureEvaluationRulesOutputReference
type EvidentlyFeatureTimeouts ¶
type EvidentlyFeatureTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#create EvidentlyFeature#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#delete EvidentlyFeature#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#update EvidentlyFeature#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type EvidentlyFeatureTimeoutsOutputReference ¶
type EvidentlyFeatureTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyFeatureTimeoutsOutputReference ¶
func NewEvidentlyFeatureTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EvidentlyFeatureTimeoutsOutputReference
type EvidentlyFeatureVariations ¶
type EvidentlyFeatureVariations struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#name EvidentlyFeature#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// value block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#value EvidentlyFeature#value}
Value *EvidentlyFeatureVariationsValue `field:"required" json:"value" yaml:"value"`
}
type EvidentlyFeatureVariationsList ¶
type EvidentlyFeatureVariationsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EvidentlyFeatureVariationsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyFeatureVariationsList ¶
func NewEvidentlyFeatureVariationsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EvidentlyFeatureVariationsList
type EvidentlyFeatureVariationsOutputReference ¶
type EvidentlyFeatureVariationsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() EvidentlyFeatureVariationsValueOutputReference
ValueInput() *EvidentlyFeatureVariationsValue
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutValue(value *EvidentlyFeatureVariationsValue)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyFeatureVariationsOutputReference ¶
func NewEvidentlyFeatureVariationsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EvidentlyFeatureVariationsOutputReference
type EvidentlyFeatureVariationsValue ¶
type EvidentlyFeatureVariationsValue struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#bool_value EvidentlyFeature#bool_value}.
BoolValue *string `field:"optional" json:"boolValue" yaml:"boolValue"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#double_value EvidentlyFeature#double_value}.
DoubleValue *string `field:"optional" json:"doubleValue" yaml:"doubleValue"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#long_value EvidentlyFeature#long_value}.
LongValue *string `field:"optional" json:"longValue" yaml:"longValue"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_feature#string_value EvidentlyFeature#string_value}.
StringValue *string `field:"optional" json:"stringValue" yaml:"stringValue"`
}
type EvidentlyFeatureVariationsValueOutputReference ¶
type EvidentlyFeatureVariationsValueOutputReference interface {
cdktf.ComplexObject
BoolValue() *string
SetBoolValue(val *string)
BoolValueInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DoubleValue() *string
SetDoubleValue(val *string)
DoubleValueInput() *string
// Experimental.
Fqn() *string
InternalValue() *EvidentlyFeatureVariationsValue
SetInternalValue(val *EvidentlyFeatureVariationsValue)
LongValue() *string
SetLongValue(val *string)
LongValueInput() *string
StringValue() *string
SetStringValue(val *string)
StringValueInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBoolValue()
ResetDoubleValue()
ResetLongValue()
ResetStringValue()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyFeatureVariationsValueOutputReference ¶
func NewEvidentlyFeatureVariationsValueOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EvidentlyFeatureVariationsValueOutputReference
Source Files
¶
- EvidentlyFeature.go
- EvidentlyFeatureConfig.go
- EvidentlyFeatureEvaluationRules.go
- EvidentlyFeatureEvaluationRulesList.go
- EvidentlyFeatureEvaluationRulesList__checks.go
- EvidentlyFeatureEvaluationRulesOutputReference.go
- EvidentlyFeatureEvaluationRulesOutputReference__checks.go
- EvidentlyFeatureTimeouts.go
- EvidentlyFeatureTimeoutsOutputReference.go
- EvidentlyFeatureTimeoutsOutputReference__checks.go
- EvidentlyFeatureVariations.go
- EvidentlyFeatureVariationsList.go
- EvidentlyFeatureVariationsList__checks.go
- EvidentlyFeatureVariationsOutputReference.go
- EvidentlyFeatureVariationsOutputReference__checks.go
- EvidentlyFeatureVariationsValue.go
- EvidentlyFeatureVariationsValueOutputReference.go
- EvidentlyFeatureVariationsValueOutputReference__checks.go
- EvidentlyFeature__checks.go
- main.go