Documentation
¶
Index ¶
- func EvidentlyLaunch_IsConstruct(x interface{}) *bool
- func EvidentlyLaunch_IsTerraformElement(x interface{}) *bool
- func EvidentlyLaunch_IsTerraformResource(x interface{}) *bool
- func EvidentlyLaunch_TfResourceType() *string
- func NewEvidentlyLaunchExecutionList_Override(e EvidentlyLaunchExecutionList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewEvidentlyLaunchExecutionOutputReference_Override(e EvidentlyLaunchExecutionOutputReference, ...)
- func NewEvidentlyLaunchGroupsList_Override(e EvidentlyLaunchGroupsList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewEvidentlyLaunchGroupsOutputReference_Override(e EvidentlyLaunchGroupsOutputReference, ...)
- func NewEvidentlyLaunchMetricMonitorsList_Override(e EvidentlyLaunchMetricMonitorsList, ...)
- func NewEvidentlyLaunchMetricMonitorsMetricDefinitionOutputReference_Override(e EvidentlyLaunchMetricMonitorsMetricDefinitionOutputReference, ...)
- func NewEvidentlyLaunchMetricMonitorsOutputReference_Override(e EvidentlyLaunchMetricMonitorsOutputReference, ...)
- func NewEvidentlyLaunchScheduledSplitsConfigOutputReference_Override(e EvidentlyLaunchScheduledSplitsConfigOutputReference, ...)
- func NewEvidentlyLaunchScheduledSplitsConfigStepsList_Override(e EvidentlyLaunchScheduledSplitsConfigStepsList, ...)
- func NewEvidentlyLaunchScheduledSplitsConfigStepsOutputReference_Override(e EvidentlyLaunchScheduledSplitsConfigStepsOutputReference, ...)
- func NewEvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesList_Override(e EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesList, ...)
- func NewEvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesOutputReference_Override(e EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesOutputReference, ...)
- func NewEvidentlyLaunchTimeoutsOutputReference_Override(e EvidentlyLaunchTimeoutsOutputReference, ...)
- func NewEvidentlyLaunch_Override(e EvidentlyLaunch, scope constructs.Construct, id *string, ...)
- type EvidentlyLaunch
- type EvidentlyLaunchConfig
- type EvidentlyLaunchExecution
- type EvidentlyLaunchExecutionList
- type EvidentlyLaunchExecutionOutputReference
- type EvidentlyLaunchGroups
- type EvidentlyLaunchGroupsList
- type EvidentlyLaunchGroupsOutputReference
- type EvidentlyLaunchMetricMonitors
- type EvidentlyLaunchMetricMonitorsList
- type EvidentlyLaunchMetricMonitorsMetricDefinition
- type EvidentlyLaunchMetricMonitorsMetricDefinitionOutputReference
- type EvidentlyLaunchMetricMonitorsOutputReference
- type EvidentlyLaunchScheduledSplitsConfig
- type EvidentlyLaunchScheduledSplitsConfigOutputReference
- type EvidentlyLaunchScheduledSplitsConfigSteps
- type EvidentlyLaunchScheduledSplitsConfigStepsList
- type EvidentlyLaunchScheduledSplitsConfigStepsOutputReference
- type EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverrides
- type EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesList
- type EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesOutputReference
- type EvidentlyLaunchTimeouts
- type EvidentlyLaunchTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EvidentlyLaunch_IsConstruct ¶
func EvidentlyLaunch_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func EvidentlyLaunch_IsTerraformElement ¶
func EvidentlyLaunch_IsTerraformElement(x interface{}) *bool
Experimental.
func EvidentlyLaunch_IsTerraformResource ¶
func EvidentlyLaunch_IsTerraformResource(x interface{}) *bool
Experimental.
func EvidentlyLaunch_TfResourceType ¶
func EvidentlyLaunch_TfResourceType() *string
func NewEvidentlyLaunchExecutionList_Override ¶
func NewEvidentlyLaunchExecutionList_Override(e EvidentlyLaunchExecutionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEvidentlyLaunchExecutionOutputReference_Override ¶
func NewEvidentlyLaunchExecutionOutputReference_Override(e EvidentlyLaunchExecutionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEvidentlyLaunchGroupsList_Override ¶
func NewEvidentlyLaunchGroupsList_Override(e EvidentlyLaunchGroupsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEvidentlyLaunchGroupsOutputReference_Override ¶
func NewEvidentlyLaunchGroupsOutputReference_Override(e EvidentlyLaunchGroupsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEvidentlyLaunchMetricMonitorsList_Override ¶
func NewEvidentlyLaunchMetricMonitorsList_Override(e EvidentlyLaunchMetricMonitorsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEvidentlyLaunchMetricMonitorsMetricDefinitionOutputReference_Override ¶
func NewEvidentlyLaunchMetricMonitorsMetricDefinitionOutputReference_Override(e EvidentlyLaunchMetricMonitorsMetricDefinitionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEvidentlyLaunchMetricMonitorsOutputReference_Override ¶
func NewEvidentlyLaunchMetricMonitorsOutputReference_Override(e EvidentlyLaunchMetricMonitorsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEvidentlyLaunchScheduledSplitsConfigOutputReference_Override ¶
func NewEvidentlyLaunchScheduledSplitsConfigOutputReference_Override(e EvidentlyLaunchScheduledSplitsConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEvidentlyLaunchScheduledSplitsConfigStepsList_Override ¶
func NewEvidentlyLaunchScheduledSplitsConfigStepsList_Override(e EvidentlyLaunchScheduledSplitsConfigStepsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEvidentlyLaunchScheduledSplitsConfigStepsOutputReference_Override ¶
func NewEvidentlyLaunchScheduledSplitsConfigStepsOutputReference_Override(e EvidentlyLaunchScheduledSplitsConfigStepsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesList_Override ¶
func NewEvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesList_Override(e EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesOutputReference_Override ¶
func NewEvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesOutputReference_Override(e EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEvidentlyLaunchTimeoutsOutputReference_Override ¶
func NewEvidentlyLaunchTimeoutsOutputReference_Override(e EvidentlyLaunchTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEvidentlyLaunch_Override ¶
func NewEvidentlyLaunch_Override(e EvidentlyLaunch, scope constructs.Construct, id *string, config *EvidentlyLaunchConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch aws_evidently_launch} Resource.
Types ¶
type EvidentlyLaunch ¶
type EvidentlyLaunch interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreatedTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Execution() EvidentlyLaunchExecutionList
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Groups() EvidentlyLaunchGroupsList
GroupsInput() interface{}
Id() *string
SetId(val *string)
IdInput() *string
LastUpdatedTime() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MetricMonitors() EvidentlyLaunchMetricMonitorsList
MetricMonitorsInput() interface{}
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
RandomizationSalt() *string
SetRandomizationSalt(val *string)
RandomizationSaltInput() *string
// Experimental.
RawOverrides() interface{}
ScheduledSplitsConfig() EvidentlyLaunchScheduledSplitsConfigOutputReference
ScheduledSplitsConfigInput() *EvidentlyLaunchScheduledSplitsConfig
Status() *string
StatusReason() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() EvidentlyLaunchTimeoutsOutputReference
TimeoutsInput() interface{}
Type() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutGroups(value interface{})
PutMetricMonitors(value interface{})
PutScheduledSplitsConfig(value *EvidentlyLaunchScheduledSplitsConfig)
PutTimeouts(value *EvidentlyLaunchTimeouts)
ResetDescription()
ResetId()
ResetMetricMonitors()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRandomizationSalt()
ResetScheduledSplitsConfig()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch aws_evidently_launch}.
func NewEvidentlyLaunch ¶
func NewEvidentlyLaunch(scope constructs.Construct, id *string, config *EvidentlyLaunchConfig) EvidentlyLaunch
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch aws_evidently_launch} Resource.
type EvidentlyLaunchConfig ¶
type EvidentlyLaunchConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// groups block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#groups EvidentlyLaunch#groups}
Groups interface{} `field:"required" json:"groups" yaml:"groups"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#name EvidentlyLaunch#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#project EvidentlyLaunch#project}.
Project *string `field:"required" json:"project" yaml:"project"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#description EvidentlyLaunch#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#id EvidentlyLaunch#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// metric_monitors block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#metric_monitors EvidentlyLaunch#metric_monitors}
MetricMonitors interface{} `field:"optional" json:"metricMonitors" yaml:"metricMonitors"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#randomization_salt EvidentlyLaunch#randomization_salt}.
RandomizationSalt *string `field:"optional" json:"randomizationSalt" yaml:"randomizationSalt"`
// scheduled_splits_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#scheduled_splits_config EvidentlyLaunch#scheduled_splits_config}
ScheduledSplitsConfig *EvidentlyLaunchScheduledSplitsConfig `field:"optional" json:"scheduledSplitsConfig" yaml:"scheduledSplitsConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#tags EvidentlyLaunch#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#tags_all EvidentlyLaunch#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#timeouts EvidentlyLaunch#timeouts}
Timeouts *EvidentlyLaunchTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type EvidentlyLaunchExecution ¶
type EvidentlyLaunchExecution struct {
}
type EvidentlyLaunchExecutionList ¶
type EvidentlyLaunchExecutionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EvidentlyLaunchExecutionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyLaunchExecutionList ¶
func NewEvidentlyLaunchExecutionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EvidentlyLaunchExecutionList
type EvidentlyLaunchExecutionOutputReference ¶
type EvidentlyLaunchExecutionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EndedTime() *string
// Experimental.
Fqn() *string
InternalValue() *EvidentlyLaunchExecution
SetInternalValue(val *EvidentlyLaunchExecution)
StartedTime() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyLaunchExecutionOutputReference ¶
func NewEvidentlyLaunchExecutionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EvidentlyLaunchExecutionOutputReference
type EvidentlyLaunchGroups ¶
type EvidentlyLaunchGroups struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#feature EvidentlyLaunch#feature}.
Feature *string `field:"required" json:"feature" yaml:"feature"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#name EvidentlyLaunch#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#variation EvidentlyLaunch#variation}.
Variation *string `field:"required" json:"variation" yaml:"variation"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#description EvidentlyLaunch#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
}
type EvidentlyLaunchGroupsList ¶
type EvidentlyLaunchGroupsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EvidentlyLaunchGroupsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyLaunchGroupsList ¶
func NewEvidentlyLaunchGroupsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EvidentlyLaunchGroupsList
type EvidentlyLaunchGroupsOutputReference ¶
type EvidentlyLaunchGroupsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Feature() *string
SetFeature(val *string)
FeatureInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Variation() *string
SetVariation(val *string)
VariationInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDescription()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyLaunchGroupsOutputReference ¶
func NewEvidentlyLaunchGroupsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EvidentlyLaunchGroupsOutputReference
type EvidentlyLaunchMetricMonitors ¶
type EvidentlyLaunchMetricMonitors struct {
// metric_definition block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#metric_definition EvidentlyLaunch#metric_definition}
MetricDefinition *EvidentlyLaunchMetricMonitorsMetricDefinition `field:"required" json:"metricDefinition" yaml:"metricDefinition"`
}
type EvidentlyLaunchMetricMonitorsList ¶
type EvidentlyLaunchMetricMonitorsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EvidentlyLaunchMetricMonitorsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyLaunchMetricMonitorsList ¶
func NewEvidentlyLaunchMetricMonitorsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EvidentlyLaunchMetricMonitorsList
type EvidentlyLaunchMetricMonitorsMetricDefinition ¶
type EvidentlyLaunchMetricMonitorsMetricDefinition struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#entity_id_key EvidentlyLaunch#entity_id_key}.
EntityIdKey *string `field:"required" json:"entityIdKey" yaml:"entityIdKey"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#name EvidentlyLaunch#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#value_key EvidentlyLaunch#value_key}.
ValueKey *string `field:"required" json:"valueKey" yaml:"valueKey"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#event_pattern EvidentlyLaunch#event_pattern}.
EventPattern *string `field:"optional" json:"eventPattern" yaml:"eventPattern"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#unit_label EvidentlyLaunch#unit_label}.
UnitLabel *string `field:"optional" json:"unitLabel" yaml:"unitLabel"`
}
type EvidentlyLaunchMetricMonitorsMetricDefinitionOutputReference ¶
type EvidentlyLaunchMetricMonitorsMetricDefinitionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EntityIdKey() *string
SetEntityIdKey(val *string)
EntityIdKeyInput() *string
EventPattern() *string
SetEventPattern(val *string)
EventPatternInput() *string
// Experimental.
Fqn() *string
InternalValue() *EvidentlyLaunchMetricMonitorsMetricDefinition
SetInternalValue(val *EvidentlyLaunchMetricMonitorsMetricDefinition)
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UnitLabel() *string
SetUnitLabel(val *string)
UnitLabelInput() *string
ValueKey() *string
SetValueKey(val *string)
ValueKeyInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEventPattern()
ResetUnitLabel()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyLaunchMetricMonitorsMetricDefinitionOutputReference ¶
func NewEvidentlyLaunchMetricMonitorsMetricDefinitionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EvidentlyLaunchMetricMonitorsMetricDefinitionOutputReference
type EvidentlyLaunchMetricMonitorsOutputReference ¶
type EvidentlyLaunchMetricMonitorsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
MetricDefinition() EvidentlyLaunchMetricMonitorsMetricDefinitionOutputReference
MetricDefinitionInput() *EvidentlyLaunchMetricMonitorsMetricDefinition
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutMetricDefinition(value *EvidentlyLaunchMetricMonitorsMetricDefinition)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyLaunchMetricMonitorsOutputReference ¶
func NewEvidentlyLaunchMetricMonitorsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EvidentlyLaunchMetricMonitorsOutputReference
type EvidentlyLaunchScheduledSplitsConfig ¶
type EvidentlyLaunchScheduledSplitsConfig struct {
// steps block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#steps EvidentlyLaunch#steps}
Steps interface{} `field:"required" json:"steps" yaml:"steps"`
}
type EvidentlyLaunchScheduledSplitsConfigOutputReference ¶
type EvidentlyLaunchScheduledSplitsConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EvidentlyLaunchScheduledSplitsConfig
SetInternalValue(val *EvidentlyLaunchScheduledSplitsConfig)
Steps() EvidentlyLaunchScheduledSplitsConfigStepsList
StepsInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutSteps(value interface{})
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyLaunchScheduledSplitsConfigOutputReference ¶
func NewEvidentlyLaunchScheduledSplitsConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EvidentlyLaunchScheduledSplitsConfigOutputReference
type EvidentlyLaunchScheduledSplitsConfigSteps ¶
type EvidentlyLaunchScheduledSplitsConfigSteps struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#group_weights EvidentlyLaunch#group_weights}.
GroupWeights *map[string]*float64 `field:"required" json:"groupWeights" yaml:"groupWeights"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#start_time EvidentlyLaunch#start_time}.
StartTime *string `field:"required" json:"startTime" yaml:"startTime"`
// segment_overrides block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#segment_overrides EvidentlyLaunch#segment_overrides}
SegmentOverrides interface{} `field:"optional" json:"segmentOverrides" yaml:"segmentOverrides"`
}
type EvidentlyLaunchScheduledSplitsConfigStepsList ¶
type EvidentlyLaunchScheduledSplitsConfigStepsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EvidentlyLaunchScheduledSplitsConfigStepsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyLaunchScheduledSplitsConfigStepsList ¶
func NewEvidentlyLaunchScheduledSplitsConfigStepsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EvidentlyLaunchScheduledSplitsConfigStepsList
type EvidentlyLaunchScheduledSplitsConfigStepsOutputReference ¶
type EvidentlyLaunchScheduledSplitsConfigStepsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
GroupWeights() *map[string]*float64
SetGroupWeights(val *map[string]*float64)
GroupWeightsInput() *map[string]*float64
InternalValue() interface{}
SetInternalValue(val interface{})
SegmentOverrides() EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesList
SegmentOverridesInput() interface{}
StartTime() *string
SetStartTime(val *string)
StartTimeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutSegmentOverrides(value interface{})
ResetSegmentOverrides()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyLaunchScheduledSplitsConfigStepsOutputReference ¶
func NewEvidentlyLaunchScheduledSplitsConfigStepsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EvidentlyLaunchScheduledSplitsConfigStepsOutputReference
type EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverrides ¶
type EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverrides struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#evaluation_order EvidentlyLaunch#evaluation_order}.
EvaluationOrder *float64 `field:"required" json:"evaluationOrder" yaml:"evaluationOrder"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#segment EvidentlyLaunch#segment}.
Segment *string `field:"required" json:"segment" yaml:"segment"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#weights EvidentlyLaunch#weights}.
Weights *map[string]*float64 `field:"required" json:"weights" yaml:"weights"`
}
type EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesList ¶
type EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesList ¶
func NewEvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesList
type EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesOutputReference ¶
type EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EvaluationOrder() *float64
SetEvaluationOrder(val *float64)
EvaluationOrderInput() *float64
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Segment() *string
SetSegment(val *string)
SegmentInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Weights() *map[string]*float64
SetWeights(val *map[string]*float64)
WeightsInput() *map[string]*float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesOutputReference ¶
func NewEvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesOutputReference
type EvidentlyLaunchTimeouts ¶
type EvidentlyLaunchTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#create EvidentlyLaunch#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#delete EvidentlyLaunch#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/evidently_launch#update EvidentlyLaunch#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type EvidentlyLaunchTimeoutsOutputReference ¶
type EvidentlyLaunchTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEvidentlyLaunchTimeoutsOutputReference ¶
func NewEvidentlyLaunchTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EvidentlyLaunchTimeoutsOutputReference
Source Files
¶
- EvidentlyLaunch.go
- EvidentlyLaunchConfig.go
- EvidentlyLaunchExecution.go
- EvidentlyLaunchExecutionList.go
- EvidentlyLaunchExecutionList__checks.go
- EvidentlyLaunchExecutionOutputReference.go
- EvidentlyLaunchExecutionOutputReference__checks.go
- EvidentlyLaunchGroups.go
- EvidentlyLaunchGroupsList.go
- EvidentlyLaunchGroupsList__checks.go
- EvidentlyLaunchGroupsOutputReference.go
- EvidentlyLaunchGroupsOutputReference__checks.go
- EvidentlyLaunchMetricMonitors.go
- EvidentlyLaunchMetricMonitorsList.go
- EvidentlyLaunchMetricMonitorsList__checks.go
- EvidentlyLaunchMetricMonitorsMetricDefinition.go
- EvidentlyLaunchMetricMonitorsMetricDefinitionOutputReference.go
- EvidentlyLaunchMetricMonitorsMetricDefinitionOutputReference__checks.go
- EvidentlyLaunchMetricMonitorsOutputReference.go
- EvidentlyLaunchMetricMonitorsOutputReference__checks.go
- EvidentlyLaunchScheduledSplitsConfig.go
- EvidentlyLaunchScheduledSplitsConfigOutputReference.go
- EvidentlyLaunchScheduledSplitsConfigOutputReference__checks.go
- EvidentlyLaunchScheduledSplitsConfigSteps.go
- EvidentlyLaunchScheduledSplitsConfigStepsList.go
- EvidentlyLaunchScheduledSplitsConfigStepsList__checks.go
- EvidentlyLaunchScheduledSplitsConfigStepsOutputReference.go
- EvidentlyLaunchScheduledSplitsConfigStepsOutputReference__checks.go
- EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverrides.go
- EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesList.go
- EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesList__checks.go
- EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesOutputReference.go
- EvidentlyLaunchScheduledSplitsConfigStepsSegmentOverridesOutputReference__checks.go
- EvidentlyLaunchTimeouts.go
- EvidentlyLaunchTimeoutsOutputReference.go
- EvidentlyLaunchTimeoutsOutputReference__checks.go
- EvidentlyLaunch__checks.go
- main.go