Documentation
¶
Index ¶
- func FsxFileCache_IsConstruct(x interface{}) *bool
- func FsxFileCache_IsTerraformElement(x interface{}) *bool
- func FsxFileCache_IsTerraformResource(x interface{}) *bool
- func FsxFileCache_TfResourceType() *string
- func NewFsxFileCacheDataRepositoryAssociationList_Override(f FsxFileCacheDataRepositoryAssociationList, ...)
- func NewFsxFileCacheDataRepositoryAssociationNfsList_Override(f FsxFileCacheDataRepositoryAssociationNfsList, ...)
- func NewFsxFileCacheDataRepositoryAssociationNfsOutputReference_Override(f FsxFileCacheDataRepositoryAssociationNfsOutputReference, ...)
- func NewFsxFileCacheDataRepositoryAssociationOutputReference_Override(f FsxFileCacheDataRepositoryAssociationOutputReference, ...)
- func NewFsxFileCacheLustreConfigurationList_Override(f FsxFileCacheLustreConfigurationList, ...)
- func NewFsxFileCacheLustreConfigurationLogConfigurationList_Override(f FsxFileCacheLustreConfigurationLogConfigurationList, ...)
- func NewFsxFileCacheLustreConfigurationLogConfigurationOutputReference_Override(f FsxFileCacheLustreConfigurationLogConfigurationOutputReference, ...)
- func NewFsxFileCacheLustreConfigurationMetadataConfigurationList_Override(f FsxFileCacheLustreConfigurationMetadataConfigurationList, ...)
- func NewFsxFileCacheLustreConfigurationMetadataConfigurationOutputReference_Override(f FsxFileCacheLustreConfigurationMetadataConfigurationOutputReference, ...)
- func NewFsxFileCacheLustreConfigurationOutputReference_Override(f FsxFileCacheLustreConfigurationOutputReference, ...)
- func NewFsxFileCacheTimeoutsOutputReference_Override(f FsxFileCacheTimeoutsOutputReference, ...)
- func NewFsxFileCache_Override(f FsxFileCache, scope constructs.Construct, id *string, ...)
- type FsxFileCache
- type FsxFileCacheConfig
- type FsxFileCacheDataRepositoryAssociation
- type FsxFileCacheDataRepositoryAssociationList
- type FsxFileCacheDataRepositoryAssociationNfs
- type FsxFileCacheDataRepositoryAssociationNfsList
- type FsxFileCacheDataRepositoryAssociationNfsOutputReference
- type FsxFileCacheDataRepositoryAssociationOutputReference
- type FsxFileCacheLustreConfiguration
- type FsxFileCacheLustreConfigurationList
- type FsxFileCacheLustreConfigurationLogConfiguration
- type FsxFileCacheLustreConfigurationLogConfigurationList
- type FsxFileCacheLustreConfigurationLogConfigurationOutputReference
- type FsxFileCacheLustreConfigurationMetadataConfiguration
- type FsxFileCacheLustreConfigurationMetadataConfigurationList
- type FsxFileCacheLustreConfigurationMetadataConfigurationOutputReference
- type FsxFileCacheLustreConfigurationOutputReference
- type FsxFileCacheTimeouts
- type FsxFileCacheTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FsxFileCache_IsConstruct ¶
func FsxFileCache_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func FsxFileCache_IsTerraformElement ¶
func FsxFileCache_IsTerraformElement(x interface{}) *bool
Experimental.
func FsxFileCache_IsTerraformResource ¶
func FsxFileCache_IsTerraformResource(x interface{}) *bool
Experimental.
func FsxFileCache_TfResourceType ¶
func FsxFileCache_TfResourceType() *string
func NewFsxFileCacheDataRepositoryAssociationList_Override ¶
func NewFsxFileCacheDataRepositoryAssociationList_Override(f FsxFileCacheDataRepositoryAssociationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewFsxFileCacheDataRepositoryAssociationNfsList_Override ¶
func NewFsxFileCacheDataRepositoryAssociationNfsList_Override(f FsxFileCacheDataRepositoryAssociationNfsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewFsxFileCacheDataRepositoryAssociationNfsOutputReference_Override ¶
func NewFsxFileCacheDataRepositoryAssociationNfsOutputReference_Override(f FsxFileCacheDataRepositoryAssociationNfsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewFsxFileCacheDataRepositoryAssociationOutputReference_Override ¶
func NewFsxFileCacheDataRepositoryAssociationOutputReference_Override(f FsxFileCacheDataRepositoryAssociationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewFsxFileCacheLustreConfigurationList_Override ¶
func NewFsxFileCacheLustreConfigurationList_Override(f FsxFileCacheLustreConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewFsxFileCacheLustreConfigurationLogConfigurationList_Override ¶
func NewFsxFileCacheLustreConfigurationLogConfigurationList_Override(f FsxFileCacheLustreConfigurationLogConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewFsxFileCacheLustreConfigurationLogConfigurationOutputReference_Override ¶
func NewFsxFileCacheLustreConfigurationLogConfigurationOutputReference_Override(f FsxFileCacheLustreConfigurationLogConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewFsxFileCacheLustreConfigurationMetadataConfigurationList_Override ¶
func NewFsxFileCacheLustreConfigurationMetadataConfigurationList_Override(f FsxFileCacheLustreConfigurationMetadataConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewFsxFileCacheLustreConfigurationMetadataConfigurationOutputReference_Override ¶
func NewFsxFileCacheLustreConfigurationMetadataConfigurationOutputReference_Override(f FsxFileCacheLustreConfigurationMetadataConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewFsxFileCacheLustreConfigurationOutputReference_Override ¶
func NewFsxFileCacheLustreConfigurationOutputReference_Override(f FsxFileCacheLustreConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewFsxFileCacheTimeoutsOutputReference_Override ¶
func NewFsxFileCacheTimeoutsOutputReference_Override(f FsxFileCacheTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFsxFileCache_Override ¶
func NewFsxFileCache_Override(f FsxFileCache, scope constructs.Construct, id *string, config *FsxFileCacheConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache aws_fsx_file_cache} Resource.
Types ¶
type FsxFileCache ¶
type FsxFileCache interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
CopyTagsToDataRepositoryAssociations() interface{}
SetCopyTagsToDataRepositoryAssociations(val interface{})
CopyTagsToDataRepositoryAssociationsInput() interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DataRepositoryAssociation() FsxFileCacheDataRepositoryAssociationList
DataRepositoryAssociationIds() *[]*string
DataRepositoryAssociationInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DnsName() *string
FileCacheId() *string
FileCacheType() *string
SetFileCacheType(val *string)
FileCacheTypeInput() *string
FileCacheTypeVersion() *string
SetFileCacheTypeVersion(val *string)
FileCacheTypeVersionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LustreConfiguration() FsxFileCacheLustreConfigurationList
LustreConfigurationInput() interface{}
NetworkInterfaceIds() *[]*string
// The tree node.
Node() constructs.Node
OwnerId() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
StorageCapacity() *float64
SetStorageCapacity(val *float64)
StorageCapacityInput() *float64
SubnetIds() *[]*string
SetSubnetIds(val *[]*string)
SubnetIdsInput() *[]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() FsxFileCacheTimeoutsOutputReference
TimeoutsInput() interface{}
VpcId() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDataRepositoryAssociation(value interface{})
PutLustreConfiguration(value interface{})
PutTimeouts(value *FsxFileCacheTimeouts)
ResetCopyTagsToDataRepositoryAssociations()
ResetDataRepositoryAssociation()
ResetId()
ResetKmsKeyId()
ResetLustreConfiguration()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSecurityGroupIds()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache aws_fsx_file_cache}.
func NewFsxFileCache ¶
func NewFsxFileCache(scope constructs.Construct, id *string, config *FsxFileCacheConfig) FsxFileCache
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache aws_fsx_file_cache} Resource.
type FsxFileCacheConfig ¶
type FsxFileCacheConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#file_cache_type FsxFileCache#file_cache_type}.
FileCacheType *string `field:"required" json:"fileCacheType" yaml:"fileCacheType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#file_cache_type_version FsxFileCache#file_cache_type_version}.
FileCacheTypeVersion *string `field:"required" json:"fileCacheTypeVersion" yaml:"fileCacheTypeVersion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#storage_capacity FsxFileCache#storage_capacity}.
StorageCapacity *float64 `field:"required" json:"storageCapacity" yaml:"storageCapacity"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#subnet_ids FsxFileCache#subnet_ids}.
SubnetIds *[]*string `field:"required" json:"subnetIds" yaml:"subnetIds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#copy_tags_to_data_repository_associations FsxFileCache#copy_tags_to_data_repository_associations}.
CopyTagsToDataRepositoryAssociations interface{} `field:"optional" json:"copyTagsToDataRepositoryAssociations" yaml:"copyTagsToDataRepositoryAssociations"`
// data_repository_association block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#data_repository_association FsxFileCache#data_repository_association}
DataRepositoryAssociation interface{} `field:"optional" json:"dataRepositoryAssociation" yaml:"dataRepositoryAssociation"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#id FsxFileCache#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#kms_key_id FsxFileCache#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
// lustre_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#lustre_configuration FsxFileCache#lustre_configuration}
LustreConfiguration interface{} `field:"optional" json:"lustreConfiguration" yaml:"lustreConfiguration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#security_group_ids FsxFileCache#security_group_ids}.
SecurityGroupIds *[]*string `field:"optional" json:"securityGroupIds" yaml:"securityGroupIds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#tags FsxFileCache#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#tags_all FsxFileCache#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#timeouts FsxFileCache#timeouts}
Timeouts *FsxFileCacheTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type FsxFileCacheDataRepositoryAssociation ¶
type FsxFileCacheDataRepositoryAssociation struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#data_repository_path FsxFileCache#data_repository_path}.
DataRepositoryPath *string `field:"required" json:"dataRepositoryPath" yaml:"dataRepositoryPath"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#file_cache_path FsxFileCache#file_cache_path}.
FileCachePath *string `field:"required" json:"fileCachePath" yaml:"fileCachePath"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#data_repository_subdirectories FsxFileCache#data_repository_subdirectories}.
DataRepositorySubdirectories *[]*string `field:"optional" json:"dataRepositorySubdirectories" yaml:"dataRepositorySubdirectories"`
// nfs block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#nfs FsxFileCache#nfs}
Nfs interface{} `field:"optional" json:"nfs" yaml:"nfs"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#tags FsxFileCache#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type FsxFileCacheDataRepositoryAssociationList ¶
type FsxFileCacheDataRepositoryAssociationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) FsxFileCacheDataRepositoryAssociationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxFileCacheDataRepositoryAssociationList ¶
func NewFsxFileCacheDataRepositoryAssociationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) FsxFileCacheDataRepositoryAssociationList
type FsxFileCacheDataRepositoryAssociationNfs ¶
type FsxFileCacheDataRepositoryAssociationNfs struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#version FsxFileCache#version}.
Version *string `field:"required" json:"version" yaml:"version"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#dns_ips FsxFileCache#dns_ips}.
DnsIps *[]*string `field:"optional" json:"dnsIps" yaml:"dnsIps"`
}
type FsxFileCacheDataRepositoryAssociationNfsList ¶
type FsxFileCacheDataRepositoryAssociationNfsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) FsxFileCacheDataRepositoryAssociationNfsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxFileCacheDataRepositoryAssociationNfsList ¶
func NewFsxFileCacheDataRepositoryAssociationNfsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) FsxFileCacheDataRepositoryAssociationNfsList
type FsxFileCacheDataRepositoryAssociationNfsOutputReference ¶
type FsxFileCacheDataRepositoryAssociationNfsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DnsIps() *[]*string
SetDnsIps(val *[]*string)
DnsIpsInput() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Version() *string
SetVersion(val *string)
VersionInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDnsIps()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxFileCacheDataRepositoryAssociationNfsOutputReference ¶
func NewFsxFileCacheDataRepositoryAssociationNfsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) FsxFileCacheDataRepositoryAssociationNfsOutputReference
type FsxFileCacheDataRepositoryAssociationOutputReference ¶
type FsxFileCacheDataRepositoryAssociationOutputReference interface {
cdktf.ComplexObject
AssociationId() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DataRepositoryPath() *string
SetDataRepositoryPath(val *string)
DataRepositoryPathInput() *string
DataRepositorySubdirectories() *[]*string
SetDataRepositorySubdirectories(val *[]*string)
DataRepositorySubdirectoriesInput() *[]*string
FileCacheId() *string
FileCachePath() *string
SetFileCachePath(val *string)
FileCachePathInput() *string
FileSystemId() *string
FileSystemPath() *string
// Experimental.
Fqn() *string
ImportedFileChunkSize() *float64
InternalValue() interface{}
SetInternalValue(val interface{})
Nfs() FsxFileCacheDataRepositoryAssociationNfsList
NfsInput() interface{}
ResourceArn() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutNfs(value interface{})
ResetDataRepositorySubdirectories()
ResetNfs()
ResetTags()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxFileCacheDataRepositoryAssociationOutputReference ¶
func NewFsxFileCacheDataRepositoryAssociationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) FsxFileCacheDataRepositoryAssociationOutputReference
type FsxFileCacheLustreConfiguration ¶
type FsxFileCacheLustreConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#deployment_type FsxFileCache#deployment_type}.
DeploymentType *string `field:"required" json:"deploymentType" yaml:"deploymentType"`
// metadata_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#metadata_configuration FsxFileCache#metadata_configuration}
MetadataConfiguration interface{} `field:"required" json:"metadataConfiguration" yaml:"metadataConfiguration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#per_unit_storage_throughput FsxFileCache#per_unit_storage_throughput}.
PerUnitStorageThroughput *float64 `field:"required" json:"perUnitStorageThroughput" yaml:"perUnitStorageThroughput"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#weekly_maintenance_start_time FsxFileCache#weekly_maintenance_start_time}.
WeeklyMaintenanceStartTime *string `field:"optional" json:"weeklyMaintenanceStartTime" yaml:"weeklyMaintenanceStartTime"`
}
type FsxFileCacheLustreConfigurationList ¶
type FsxFileCacheLustreConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) FsxFileCacheLustreConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxFileCacheLustreConfigurationList ¶
func NewFsxFileCacheLustreConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) FsxFileCacheLustreConfigurationList
type FsxFileCacheLustreConfigurationLogConfiguration ¶
type FsxFileCacheLustreConfigurationLogConfiguration struct {
}
type FsxFileCacheLustreConfigurationLogConfigurationList ¶
type FsxFileCacheLustreConfigurationLogConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) FsxFileCacheLustreConfigurationLogConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxFileCacheLustreConfigurationLogConfigurationList ¶
func NewFsxFileCacheLustreConfigurationLogConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) FsxFileCacheLustreConfigurationLogConfigurationList
type FsxFileCacheLustreConfigurationLogConfigurationOutputReference ¶
type FsxFileCacheLustreConfigurationLogConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Destination() *string
// Experimental.
Fqn() *string
InternalValue() *FsxFileCacheLustreConfigurationLogConfiguration
SetInternalValue(val *FsxFileCacheLustreConfigurationLogConfiguration)
Level() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxFileCacheLustreConfigurationLogConfigurationOutputReference ¶
func NewFsxFileCacheLustreConfigurationLogConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) FsxFileCacheLustreConfigurationLogConfigurationOutputReference
type FsxFileCacheLustreConfigurationMetadataConfiguration ¶
type FsxFileCacheLustreConfigurationMetadataConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#storage_capacity FsxFileCache#storage_capacity}.
StorageCapacity *float64 `field:"required" json:"storageCapacity" yaml:"storageCapacity"`
}
type FsxFileCacheLustreConfigurationMetadataConfigurationList ¶
type FsxFileCacheLustreConfigurationMetadataConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) FsxFileCacheLustreConfigurationMetadataConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxFileCacheLustreConfigurationMetadataConfigurationList ¶
func NewFsxFileCacheLustreConfigurationMetadataConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) FsxFileCacheLustreConfigurationMetadataConfigurationList
type FsxFileCacheLustreConfigurationMetadataConfigurationOutputReference ¶
type FsxFileCacheLustreConfigurationMetadataConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
StorageCapacity() *float64
SetStorageCapacity(val *float64)
StorageCapacityInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxFileCacheLustreConfigurationMetadataConfigurationOutputReference ¶
func NewFsxFileCacheLustreConfigurationMetadataConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) FsxFileCacheLustreConfigurationMetadataConfigurationOutputReference
type FsxFileCacheLustreConfigurationOutputReference ¶
type FsxFileCacheLustreConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeploymentType() *string
SetDeploymentType(val *string)
DeploymentTypeInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
LogConfiguration() FsxFileCacheLustreConfigurationLogConfigurationList
MetadataConfiguration() FsxFileCacheLustreConfigurationMetadataConfigurationList
MetadataConfigurationInput() interface{}
MountName() *string
PerUnitStorageThroughput() *float64
SetPerUnitStorageThroughput(val *float64)
PerUnitStorageThroughputInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
WeeklyMaintenanceStartTime() *string
SetWeeklyMaintenanceStartTime(val *string)
WeeklyMaintenanceStartTimeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutMetadataConfiguration(value interface{})
ResetWeeklyMaintenanceStartTime()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxFileCacheLustreConfigurationOutputReference ¶
func NewFsxFileCacheLustreConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) FsxFileCacheLustreConfigurationOutputReference
type FsxFileCacheTimeouts ¶
type FsxFileCacheTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#create FsxFileCache#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#delete FsxFileCache#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_file_cache#update FsxFileCache#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type FsxFileCacheTimeoutsOutputReference ¶
type FsxFileCacheTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxFileCacheTimeoutsOutputReference ¶
func NewFsxFileCacheTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FsxFileCacheTimeoutsOutputReference
Source Files
¶
- FsxFileCache.go
- FsxFileCacheConfig.go
- FsxFileCacheDataRepositoryAssociation.go
- FsxFileCacheDataRepositoryAssociationList.go
- FsxFileCacheDataRepositoryAssociationList__checks.go
- FsxFileCacheDataRepositoryAssociationNfs.go
- FsxFileCacheDataRepositoryAssociationNfsList.go
- FsxFileCacheDataRepositoryAssociationNfsList__checks.go
- FsxFileCacheDataRepositoryAssociationNfsOutputReference.go
- FsxFileCacheDataRepositoryAssociationNfsOutputReference__checks.go
- FsxFileCacheDataRepositoryAssociationOutputReference.go
- FsxFileCacheDataRepositoryAssociationOutputReference__checks.go
- FsxFileCacheLustreConfiguration.go
- FsxFileCacheLustreConfigurationList.go
- FsxFileCacheLustreConfigurationList__checks.go
- FsxFileCacheLustreConfigurationLogConfiguration.go
- FsxFileCacheLustreConfigurationLogConfigurationList.go
- FsxFileCacheLustreConfigurationLogConfigurationList__checks.go
- FsxFileCacheLustreConfigurationLogConfigurationOutputReference.go
- FsxFileCacheLustreConfigurationLogConfigurationOutputReference__checks.go
- FsxFileCacheLustreConfigurationMetadataConfiguration.go
- FsxFileCacheLustreConfigurationMetadataConfigurationList.go
- FsxFileCacheLustreConfigurationMetadataConfigurationList__checks.go
- FsxFileCacheLustreConfigurationMetadataConfigurationOutputReference.go
- FsxFileCacheLustreConfigurationMetadataConfigurationOutputReference__checks.go
- FsxFileCacheLustreConfigurationOutputReference.go
- FsxFileCacheLustreConfigurationOutputReference__checks.go
- FsxFileCacheTimeouts.go
- FsxFileCacheTimeoutsOutputReference.go
- FsxFileCacheTimeoutsOutputReference__checks.go
- FsxFileCache__checks.go
- main.go