Documentation
¶
Index ¶
- func FsxOpenzfsFileSystem_IsConstruct(x interface{}) *bool
- func FsxOpenzfsFileSystem_IsTerraformElement(x interface{}) *bool
- func FsxOpenzfsFileSystem_IsTerraformResource(x interface{}) *bool
- func FsxOpenzfsFileSystem_TfResourceType() *string
- func NewFsxOpenzfsFileSystemDiskIopsConfigurationOutputReference_Override(f FsxOpenzfsFileSystemDiskIopsConfigurationOutputReference, ...)
- func NewFsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsList_Override(...)
- func NewFsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsOutputReference_Override(...)
- func NewFsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsOutputReference_Override(f FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsOutputReference, ...)
- func NewFsxOpenzfsFileSystemRootVolumeConfigurationOutputReference_Override(f FsxOpenzfsFileSystemRootVolumeConfigurationOutputReference, ...)
- func NewFsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasList_Override(f FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasList, ...)
- func NewFsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasOutputReference_Override(f FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasOutputReference, ...)
- func NewFsxOpenzfsFileSystemTimeoutsOutputReference_Override(f FsxOpenzfsFileSystemTimeoutsOutputReference, ...)
- func NewFsxOpenzfsFileSystem_Override(f FsxOpenzfsFileSystem, scope constructs.Construct, id *string, ...)
- type FsxOpenzfsFileSystem
- type FsxOpenzfsFileSystemConfig
- type FsxOpenzfsFileSystemDiskIopsConfiguration
- type FsxOpenzfsFileSystemDiskIopsConfigurationOutputReference
- type FsxOpenzfsFileSystemRootVolumeConfiguration
- type FsxOpenzfsFileSystemRootVolumeConfigurationNfsExports
- type FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurations
- type FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsList
- type FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsOutputReference
- type FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsOutputReference
- type FsxOpenzfsFileSystemRootVolumeConfigurationOutputReference
- type FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotas
- type FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasList
- type FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasOutputReference
- type FsxOpenzfsFileSystemTimeouts
- type FsxOpenzfsFileSystemTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FsxOpenzfsFileSystem_IsConstruct ¶
func FsxOpenzfsFileSystem_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func FsxOpenzfsFileSystem_IsTerraformElement ¶
func FsxOpenzfsFileSystem_IsTerraformElement(x interface{}) *bool
Experimental.
func FsxOpenzfsFileSystem_IsTerraformResource ¶
func FsxOpenzfsFileSystem_IsTerraformResource(x interface{}) *bool
Experimental.
func FsxOpenzfsFileSystem_TfResourceType ¶
func FsxOpenzfsFileSystem_TfResourceType() *string
func NewFsxOpenzfsFileSystemDiskIopsConfigurationOutputReference_Override ¶
func NewFsxOpenzfsFileSystemDiskIopsConfigurationOutputReference_Override(f FsxOpenzfsFileSystemDiskIopsConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsList_Override ¶
func NewFsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsList_Override(f FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewFsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsOutputReference_Override ¶
func NewFsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsOutputReference_Override(f FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewFsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsOutputReference_Override ¶
func NewFsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsOutputReference_Override(f FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFsxOpenzfsFileSystemRootVolumeConfigurationOutputReference_Override ¶
func NewFsxOpenzfsFileSystemRootVolumeConfigurationOutputReference_Override(f FsxOpenzfsFileSystemRootVolumeConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasList_Override ¶
func NewFsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasList_Override(f FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewFsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasOutputReference_Override ¶
func NewFsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasOutputReference_Override(f FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewFsxOpenzfsFileSystemTimeoutsOutputReference_Override ¶
func NewFsxOpenzfsFileSystemTimeoutsOutputReference_Override(f FsxOpenzfsFileSystemTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewFsxOpenzfsFileSystem_Override ¶
func NewFsxOpenzfsFileSystem_Override(f FsxOpenzfsFileSystem, scope constructs.Construct, id *string, config *FsxOpenzfsFileSystemConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system aws_fsx_openzfs_file_system} Resource.
Types ¶
type FsxOpenzfsFileSystem ¶
type FsxOpenzfsFileSystem interface {
cdktf.TerraformResource
Arn() *string
AutomaticBackupRetentionDays() *float64
SetAutomaticBackupRetentionDays(val *float64)
AutomaticBackupRetentionDaysInput() *float64
BackupId() *string
SetBackupId(val *string)
BackupIdInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
CopyTagsToBackups() interface{}
SetCopyTagsToBackups(val interface{})
CopyTagsToBackupsInput() interface{}
CopyTagsToVolumes() interface{}
SetCopyTagsToVolumes(val interface{})
CopyTagsToVolumesInput() interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DailyAutomaticBackupStartTime() *string
SetDailyAutomaticBackupStartTime(val *string)
DailyAutomaticBackupStartTimeInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeploymentType() *string
SetDeploymentType(val *string)
DeploymentTypeInput() *string
DiskIopsConfiguration() FsxOpenzfsFileSystemDiskIopsConfigurationOutputReference
DiskIopsConfigurationInput() *FsxOpenzfsFileSystemDiskIopsConfiguration
DnsName() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
NetworkInterfaceIds() *[]*string
// The tree node.
Node() constructs.Node
OwnerId() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RootVolumeConfiguration() FsxOpenzfsFileSystemRootVolumeConfigurationOutputReference
RootVolumeConfigurationInput() *FsxOpenzfsFileSystemRootVolumeConfiguration
RootVolumeId() *string
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
StorageCapacity() *float64
SetStorageCapacity(val *float64)
StorageCapacityInput() *float64
StorageType() *string
SetStorageType(val *string)
StorageTypeInput() *string
SubnetIds() *[]*string
SetSubnetIds(val *[]*string)
SubnetIdsInput() *[]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
ThroughputCapacity() *float64
SetThroughputCapacity(val *float64)
ThroughputCapacityInput() *float64
Timeouts() FsxOpenzfsFileSystemTimeoutsOutputReference
TimeoutsInput() interface{}
VpcId() *string
WeeklyMaintenanceStartTime() *string
SetWeeklyMaintenanceStartTime(val *string)
WeeklyMaintenanceStartTimeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDiskIopsConfiguration(value *FsxOpenzfsFileSystemDiskIopsConfiguration)
PutRootVolumeConfiguration(value *FsxOpenzfsFileSystemRootVolumeConfiguration)
PutTimeouts(value *FsxOpenzfsFileSystemTimeouts)
ResetAutomaticBackupRetentionDays()
ResetBackupId()
ResetCopyTagsToBackups()
ResetCopyTagsToVolumes()
ResetDailyAutomaticBackupStartTime()
ResetDiskIopsConfiguration()
ResetId()
ResetKmsKeyId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRootVolumeConfiguration()
ResetSecurityGroupIds()
ResetStorageCapacity()
ResetStorageType()
ResetTags()
ResetTagsAll()
ResetTimeouts()
ResetWeeklyMaintenanceStartTime()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system aws_fsx_openzfs_file_system}.
func NewFsxOpenzfsFileSystem ¶
func NewFsxOpenzfsFileSystem(scope constructs.Construct, id *string, config *FsxOpenzfsFileSystemConfig) FsxOpenzfsFileSystem
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system aws_fsx_openzfs_file_system} Resource.
type FsxOpenzfsFileSystemConfig ¶
type FsxOpenzfsFileSystemConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#deployment_type FsxOpenzfsFileSystem#deployment_type}.
DeploymentType *string `field:"required" json:"deploymentType" yaml:"deploymentType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#subnet_ids FsxOpenzfsFileSystem#subnet_ids}.
SubnetIds *[]*string `field:"required" json:"subnetIds" yaml:"subnetIds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#throughput_capacity FsxOpenzfsFileSystem#throughput_capacity}.
ThroughputCapacity *float64 `field:"required" json:"throughputCapacity" yaml:"throughputCapacity"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#automatic_backup_retention_days FsxOpenzfsFileSystem#automatic_backup_retention_days}.
AutomaticBackupRetentionDays *float64 `field:"optional" json:"automaticBackupRetentionDays" yaml:"automaticBackupRetentionDays"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#backup_id FsxOpenzfsFileSystem#backup_id}.
BackupId *string `field:"optional" json:"backupId" yaml:"backupId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#copy_tags_to_backups FsxOpenzfsFileSystem#copy_tags_to_backups}.
CopyTagsToBackups interface{} `field:"optional" json:"copyTagsToBackups" yaml:"copyTagsToBackups"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#copy_tags_to_volumes FsxOpenzfsFileSystem#copy_tags_to_volumes}.
CopyTagsToVolumes interface{} `field:"optional" json:"copyTagsToVolumes" yaml:"copyTagsToVolumes"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#daily_automatic_backup_start_time FsxOpenzfsFileSystem#daily_automatic_backup_start_time}.
DailyAutomaticBackupStartTime *string `field:"optional" json:"dailyAutomaticBackupStartTime" yaml:"dailyAutomaticBackupStartTime"`
// disk_iops_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#disk_iops_configuration FsxOpenzfsFileSystem#disk_iops_configuration}
DiskIopsConfiguration *FsxOpenzfsFileSystemDiskIopsConfiguration `field:"optional" json:"diskIopsConfiguration" yaml:"diskIopsConfiguration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#id FsxOpenzfsFileSystem#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#kms_key_id FsxOpenzfsFileSystem#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
// root_volume_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#root_volume_configuration FsxOpenzfsFileSystem#root_volume_configuration}
RootVolumeConfiguration *FsxOpenzfsFileSystemRootVolumeConfiguration `field:"optional" json:"rootVolumeConfiguration" yaml:"rootVolumeConfiguration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#security_group_ids FsxOpenzfsFileSystem#security_group_ids}.
SecurityGroupIds *[]*string `field:"optional" json:"securityGroupIds" yaml:"securityGroupIds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#storage_capacity FsxOpenzfsFileSystem#storage_capacity}.
StorageCapacity *float64 `field:"optional" json:"storageCapacity" yaml:"storageCapacity"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#storage_type FsxOpenzfsFileSystem#storage_type}.
StorageType *string `field:"optional" json:"storageType" yaml:"storageType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#tags FsxOpenzfsFileSystem#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#tags_all FsxOpenzfsFileSystem#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#timeouts FsxOpenzfsFileSystem#timeouts}
Timeouts *FsxOpenzfsFileSystemTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#weekly_maintenance_start_time FsxOpenzfsFileSystem#weekly_maintenance_start_time}.
WeeklyMaintenanceStartTime *string `field:"optional" json:"weeklyMaintenanceStartTime" yaml:"weeklyMaintenanceStartTime"`
}
type FsxOpenzfsFileSystemDiskIopsConfiguration ¶
type FsxOpenzfsFileSystemDiskIopsConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#iops FsxOpenzfsFileSystem#iops}.
Iops *float64 `field:"optional" json:"iops" yaml:"iops"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#mode FsxOpenzfsFileSystem#mode}.
Mode *string `field:"optional" json:"mode" yaml:"mode"`
}
type FsxOpenzfsFileSystemDiskIopsConfigurationOutputReference ¶
type FsxOpenzfsFileSystemDiskIopsConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *FsxOpenzfsFileSystemDiskIopsConfiguration
SetInternalValue(val *FsxOpenzfsFileSystemDiskIopsConfiguration)
Iops() *float64
SetIops(val *float64)
IopsInput() *float64
Mode() *string
SetMode(val *string)
ModeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetIops()
ResetMode()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxOpenzfsFileSystemDiskIopsConfigurationOutputReference ¶
func NewFsxOpenzfsFileSystemDiskIopsConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FsxOpenzfsFileSystemDiskIopsConfigurationOutputReference
type FsxOpenzfsFileSystemRootVolumeConfiguration ¶
type FsxOpenzfsFileSystemRootVolumeConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#copy_tags_to_snapshots FsxOpenzfsFileSystem#copy_tags_to_snapshots}.
CopyTagsToSnapshots interface{} `field:"optional" json:"copyTagsToSnapshots" yaml:"copyTagsToSnapshots"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#data_compression_type FsxOpenzfsFileSystem#data_compression_type}.
DataCompressionType *string `field:"optional" json:"dataCompressionType" yaml:"dataCompressionType"`
// nfs_exports block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#nfs_exports FsxOpenzfsFileSystem#nfs_exports}
NfsExports *FsxOpenzfsFileSystemRootVolumeConfigurationNfsExports `field:"optional" json:"nfsExports" yaml:"nfsExports"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#read_only FsxOpenzfsFileSystem#read_only}.
ReadOnly interface{} `field:"optional" json:"readOnly" yaml:"readOnly"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#record_size_kib FsxOpenzfsFileSystem#record_size_kib}.
RecordSizeKib *float64 `field:"optional" json:"recordSizeKib" yaml:"recordSizeKib"`
// user_and_group_quotas block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#user_and_group_quotas FsxOpenzfsFileSystem#user_and_group_quotas}
UserAndGroupQuotas interface{} `field:"optional" json:"userAndGroupQuotas" yaml:"userAndGroupQuotas"`
}
type FsxOpenzfsFileSystemRootVolumeConfigurationNfsExports ¶
type FsxOpenzfsFileSystemRootVolumeConfigurationNfsExports struct {
// client_configurations block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#client_configurations FsxOpenzfsFileSystem#client_configurations}
ClientConfigurations interface{} `field:"required" json:"clientConfigurations" yaml:"clientConfigurations"`
}
type FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurations ¶
type FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurations struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#clients FsxOpenzfsFileSystem#clients}.
Clients *string `field:"required" json:"clients" yaml:"clients"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#options FsxOpenzfsFileSystem#options}.
Options *[]*string `field:"required" json:"options" yaml:"options"`
}
type FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsList ¶
type FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsList ¶
func NewFsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsList
type FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsOutputReference ¶
type FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsOutputReference interface {
cdktf.ComplexObject
Clients() *string
SetClients(val *string)
ClientsInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Options() *[]*string
SetOptions(val *[]*string)
OptionsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsOutputReference ¶
func NewFsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsOutputReference
type FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsOutputReference ¶
type FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsOutputReference interface {
cdktf.ComplexObject
ClientConfigurations() FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsList
ClientConfigurationsInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *FsxOpenzfsFileSystemRootVolumeConfigurationNfsExports
SetInternalValue(val *FsxOpenzfsFileSystemRootVolumeConfigurationNfsExports)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutClientConfigurations(value interface{})
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsOutputReference ¶
func NewFsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsOutputReference
type FsxOpenzfsFileSystemRootVolumeConfigurationOutputReference ¶
type FsxOpenzfsFileSystemRootVolumeConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CopyTagsToSnapshots() interface{}
SetCopyTagsToSnapshots(val interface{})
CopyTagsToSnapshotsInput() interface{}
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DataCompressionType() *string
SetDataCompressionType(val *string)
DataCompressionTypeInput() *string
// Experimental.
Fqn() *string
InternalValue() *FsxOpenzfsFileSystemRootVolumeConfiguration
SetInternalValue(val *FsxOpenzfsFileSystemRootVolumeConfiguration)
NfsExports() FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsOutputReference
NfsExportsInput() *FsxOpenzfsFileSystemRootVolumeConfigurationNfsExports
ReadOnly() interface{}
SetReadOnly(val interface{})
ReadOnlyInput() interface{}
RecordSizeKib() *float64
SetRecordSizeKib(val *float64)
RecordSizeKibInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UserAndGroupQuotas() FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasList
UserAndGroupQuotasInput() interface{}
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutNfsExports(value *FsxOpenzfsFileSystemRootVolumeConfigurationNfsExports)
PutUserAndGroupQuotas(value interface{})
ResetCopyTagsToSnapshots()
ResetDataCompressionType()
ResetNfsExports()
ResetReadOnly()
ResetRecordSizeKib()
ResetUserAndGroupQuotas()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxOpenzfsFileSystemRootVolumeConfigurationOutputReference ¶
func NewFsxOpenzfsFileSystemRootVolumeConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FsxOpenzfsFileSystemRootVolumeConfigurationOutputReference
type FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotas ¶
type FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotas struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#id FsxOpenzfsFileSystem#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *float64 `field:"required" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#storage_capacity_quota_gib FsxOpenzfsFileSystem#storage_capacity_quota_gib}.
StorageCapacityQuotaGib *float64 `field:"required" json:"storageCapacityQuotaGib" yaml:"storageCapacityQuotaGib"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#type FsxOpenzfsFileSystem#type}.
Type *string `field:"required" json:"type" yaml:"type"`
}
type FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasList ¶
type FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasList ¶
func NewFsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasList
type FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasOutputReference ¶
type FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *float64
SetId(val *float64)
IdInput() *float64
InternalValue() interface{}
SetInternalValue(val interface{})
StorageCapacityQuotaGib() *float64
SetStorageCapacityQuotaGib(val *float64)
StorageCapacityQuotaGibInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasOutputReference ¶
func NewFsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasOutputReference
type FsxOpenzfsFileSystemTimeouts ¶
type FsxOpenzfsFileSystemTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#create FsxOpenzfsFileSystem#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#delete FsxOpenzfsFileSystem#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/fsx_openzfs_file_system#update FsxOpenzfsFileSystem#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type FsxOpenzfsFileSystemTimeoutsOutputReference ¶
type FsxOpenzfsFileSystemTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewFsxOpenzfsFileSystemTimeoutsOutputReference ¶
func NewFsxOpenzfsFileSystemTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) FsxOpenzfsFileSystemTimeoutsOutputReference
Source Files
¶
- FsxOpenzfsFileSystem.go
- FsxOpenzfsFileSystemConfig.go
- FsxOpenzfsFileSystemDiskIopsConfiguration.go
- FsxOpenzfsFileSystemDiskIopsConfigurationOutputReference.go
- FsxOpenzfsFileSystemDiskIopsConfigurationOutputReference__checks.go
- FsxOpenzfsFileSystemRootVolumeConfiguration.go
- FsxOpenzfsFileSystemRootVolumeConfigurationNfsExports.go
- FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurations.go
- FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsList.go
- FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsList__checks.go
- FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsOutputReference.go
- FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsOutputReference__checks.go
- FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsOutputReference.go
- FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsOutputReference__checks.go
- FsxOpenzfsFileSystemRootVolumeConfigurationOutputReference.go
- FsxOpenzfsFileSystemRootVolumeConfigurationOutputReference__checks.go
- FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotas.go
- FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasList.go
- FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasList__checks.go
- FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasOutputReference.go
- FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasOutputReference__checks.go
- FsxOpenzfsFileSystemTimeouts.go
- FsxOpenzfsFileSystemTimeoutsOutputReference.go
- FsxOpenzfsFileSystemTimeoutsOutputReference__checks.go
- FsxOpenzfsFileSystem__checks.go
- main.go