Documentation
¶
Index ¶
- func GameliftGameSessionQueue_IsConstruct(x interface{}) *bool
- func GameliftGameSessionQueue_IsTerraformElement(x interface{}) *bool
- func GameliftGameSessionQueue_IsTerraformResource(x interface{}) *bool
- func GameliftGameSessionQueue_TfResourceType() *string
- func NewGameliftGameSessionQueuePlayerLatencyPolicyList_Override(g GameliftGameSessionQueuePlayerLatencyPolicyList, ...)
- func NewGameliftGameSessionQueuePlayerLatencyPolicyOutputReference_Override(g GameliftGameSessionQueuePlayerLatencyPolicyOutputReference, ...)
- func NewGameliftGameSessionQueue_Override(g GameliftGameSessionQueue, scope constructs.Construct, id *string, ...)
- type GameliftGameSessionQueue
- type GameliftGameSessionQueueConfig
- type GameliftGameSessionQueuePlayerLatencyPolicy
- type GameliftGameSessionQueuePlayerLatencyPolicyList
- type GameliftGameSessionQueuePlayerLatencyPolicyOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GameliftGameSessionQueue_IsConstruct ¶
func GameliftGameSessionQueue_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GameliftGameSessionQueue_IsTerraformElement ¶
func GameliftGameSessionQueue_IsTerraformElement(x interface{}) *bool
Experimental.
func GameliftGameSessionQueue_IsTerraformResource ¶
func GameliftGameSessionQueue_IsTerraformResource(x interface{}) *bool
Experimental.
func GameliftGameSessionQueue_TfResourceType ¶
func GameliftGameSessionQueue_TfResourceType() *string
func NewGameliftGameSessionQueuePlayerLatencyPolicyList_Override ¶
func NewGameliftGameSessionQueuePlayerLatencyPolicyList_Override(g GameliftGameSessionQueuePlayerLatencyPolicyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGameliftGameSessionQueuePlayerLatencyPolicyOutputReference_Override ¶
func NewGameliftGameSessionQueuePlayerLatencyPolicyOutputReference_Override(g GameliftGameSessionQueuePlayerLatencyPolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGameliftGameSessionQueue_Override ¶
func NewGameliftGameSessionQueue_Override(g GameliftGameSessionQueue, scope constructs.Construct, id *string, config *GameliftGameSessionQueueConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_game_session_queue aws_gamelift_game_session_queue} Resource.
Types ¶
type GameliftGameSessionQueue ¶
type GameliftGameSessionQueue interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CustomEventData() *string
SetCustomEventData(val *string)
CustomEventDataInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Destinations() *[]*string
SetDestinations(val *[]*string)
DestinationsInput() *[]*string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
NotificationTarget() *string
SetNotificationTarget(val *string)
NotificationTargetInput() *string
PlayerLatencyPolicy() GameliftGameSessionQueuePlayerLatencyPolicyList
PlayerLatencyPolicyInput() interface{}
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
TimeoutInSeconds() *float64
SetTimeoutInSeconds(val *float64)
TimeoutInSecondsInput() *float64
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutPlayerLatencyPolicy(value interface{})
ResetCustomEventData()
ResetDestinations()
ResetId()
ResetNotificationTarget()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPlayerLatencyPolicy()
ResetTags()
ResetTagsAll()
ResetTimeoutInSeconds()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_game_session_queue aws_gamelift_game_session_queue}.
func NewGameliftGameSessionQueue ¶
func NewGameliftGameSessionQueue(scope constructs.Construct, id *string, config *GameliftGameSessionQueueConfig) GameliftGameSessionQueue
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_game_session_queue aws_gamelift_game_session_queue} Resource.
type GameliftGameSessionQueueConfig ¶
type GameliftGameSessionQueueConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_game_session_queue#name GameliftGameSessionQueue#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_game_session_queue#custom_event_data GameliftGameSessionQueue#custom_event_data}.
CustomEventData *string `field:"optional" json:"customEventData" yaml:"customEventData"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_game_session_queue#destinations GameliftGameSessionQueue#destinations}.
Destinations *[]*string `field:"optional" json:"destinations" yaml:"destinations"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_game_session_queue#id GameliftGameSessionQueue#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_game_session_queue#notification_target GameliftGameSessionQueue#notification_target}.
NotificationTarget *string `field:"optional" json:"notificationTarget" yaml:"notificationTarget"`
// player_latency_policy block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_game_session_queue#player_latency_policy GameliftGameSessionQueue#player_latency_policy}
PlayerLatencyPolicy interface{} `field:"optional" json:"playerLatencyPolicy" yaml:"playerLatencyPolicy"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_game_session_queue#tags GameliftGameSessionQueue#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_game_session_queue#tags_all GameliftGameSessionQueue#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_game_session_queue#timeout_in_seconds GameliftGameSessionQueue#timeout_in_seconds}.
TimeoutInSeconds *float64 `field:"optional" json:"timeoutInSeconds" yaml:"timeoutInSeconds"`
}
type GameliftGameSessionQueuePlayerLatencyPolicy ¶
type GameliftGameSessionQueuePlayerLatencyPolicy struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_game_session_queue#maximum_individual_player_latency_milliseconds GameliftGameSessionQueue#maximum_individual_player_latency_milliseconds}.
MaximumIndividualPlayerLatencyMilliseconds *float64 `field:"required" json:"maximumIndividualPlayerLatencyMilliseconds" yaml:"maximumIndividualPlayerLatencyMilliseconds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_game_session_queue#policy_duration_seconds GameliftGameSessionQueue#policy_duration_seconds}.
PolicyDurationSeconds *float64 `field:"optional" json:"policyDurationSeconds" yaml:"policyDurationSeconds"`
}
type GameliftGameSessionQueuePlayerLatencyPolicyList ¶
type GameliftGameSessionQueuePlayerLatencyPolicyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GameliftGameSessionQueuePlayerLatencyPolicyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGameliftGameSessionQueuePlayerLatencyPolicyList ¶
func NewGameliftGameSessionQueuePlayerLatencyPolicyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GameliftGameSessionQueuePlayerLatencyPolicyList
type GameliftGameSessionQueuePlayerLatencyPolicyOutputReference ¶
type GameliftGameSessionQueuePlayerLatencyPolicyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
MaximumIndividualPlayerLatencyMilliseconds() *float64
SetMaximumIndividualPlayerLatencyMilliseconds(val *float64)
MaximumIndividualPlayerLatencyMillisecondsInput() *float64
PolicyDurationSeconds() *float64
SetPolicyDurationSeconds(val *float64)
PolicyDurationSecondsInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetPolicyDurationSeconds()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGameliftGameSessionQueuePlayerLatencyPolicyOutputReference ¶
func NewGameliftGameSessionQueuePlayerLatencyPolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GameliftGameSessionQueuePlayerLatencyPolicyOutputReference
Source Files
¶
- GameliftGameSessionQueue.go
- GameliftGameSessionQueueConfig.go
- GameliftGameSessionQueuePlayerLatencyPolicy.go
- GameliftGameSessionQueuePlayerLatencyPolicyList.go
- GameliftGameSessionQueuePlayerLatencyPolicyList__checks.go
- GameliftGameSessionQueuePlayerLatencyPolicyOutputReference.go
- GameliftGameSessionQueuePlayerLatencyPolicyOutputReference__checks.go
- GameliftGameSessionQueue__checks.go
- main.go