Documentation
¶
Index ¶
- func GameliftScript_IsConstruct(x interface{}) *bool
- func GameliftScript_IsTerraformElement(x interface{}) *bool
- func GameliftScript_IsTerraformResource(x interface{}) *bool
- func GameliftScript_TfResourceType() *string
- func NewGameliftScriptStorageLocationOutputReference_Override(g GameliftScriptStorageLocationOutputReference, ...)
- func NewGameliftScript_Override(g GameliftScript, scope constructs.Construct, id *string, ...)
- type GameliftScript
- type GameliftScriptConfig
- type GameliftScriptStorageLocation
- type GameliftScriptStorageLocationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GameliftScript_IsConstruct ¶
func GameliftScript_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GameliftScript_IsTerraformElement ¶
func GameliftScript_IsTerraformElement(x interface{}) *bool
Experimental.
func GameliftScript_IsTerraformResource ¶
func GameliftScript_IsTerraformResource(x interface{}) *bool
Experimental.
func GameliftScript_TfResourceType ¶
func GameliftScript_TfResourceType() *string
func NewGameliftScriptStorageLocationOutputReference_Override ¶
func NewGameliftScriptStorageLocationOutputReference_Override(g GameliftScriptStorageLocationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGameliftScript_Override ¶
func NewGameliftScript_Override(g GameliftScript, scope constructs.Construct, id *string, config *GameliftScriptConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_script aws_gamelift_script} Resource.
Types ¶
type GameliftScript ¶
type GameliftScript interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
StorageLocation() GameliftScriptStorageLocationOutputReference
StorageLocationInput() *GameliftScriptStorageLocation
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Version() *string
SetVersion(val *string)
VersionInput() *string
ZipFile() *string
SetZipFile(val *string)
ZipFileInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutStorageLocation(value *GameliftScriptStorageLocation)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetStorageLocation()
ResetTags()
ResetTagsAll()
ResetVersion()
ResetZipFile()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_script aws_gamelift_script}.
func NewGameliftScript ¶
func NewGameliftScript(scope constructs.Construct, id *string, config *GameliftScriptConfig) GameliftScript
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_script aws_gamelift_script} Resource.
type GameliftScriptConfig ¶
type GameliftScriptConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_script#name GameliftScript#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_script#id GameliftScript#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// storage_location block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_script#storage_location GameliftScript#storage_location}
StorageLocation *GameliftScriptStorageLocation `field:"optional" json:"storageLocation" yaml:"storageLocation"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_script#tags GameliftScript#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_script#tags_all GameliftScript#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_script#version GameliftScript#version}.
Version *string `field:"optional" json:"version" yaml:"version"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_script#zip_file GameliftScript#zip_file}.
ZipFile *string `field:"optional" json:"zipFile" yaml:"zipFile"`
}
type GameliftScriptStorageLocation ¶
type GameliftScriptStorageLocation struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_script#bucket GameliftScript#bucket}.
Bucket *string `field:"required" json:"bucket" yaml:"bucket"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_script#key GameliftScript#key}.
Key *string `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_script#role_arn GameliftScript#role_arn}.
RoleArn *string `field:"required" json:"roleArn" yaml:"roleArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/gamelift_script#object_version GameliftScript#object_version}.
ObjectVersion *string `field:"optional" json:"objectVersion" yaml:"objectVersion"`
}
type GameliftScriptStorageLocationOutputReference ¶
type GameliftScriptStorageLocationOutputReference interface {
cdktf.ComplexObject
Bucket() *string
SetBucket(val *string)
BucketInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GameliftScriptStorageLocation
SetInternalValue(val *GameliftScriptStorageLocation)
Key() *string
SetKey(val *string)
KeyInput() *string
ObjectVersion() *string
SetObjectVersion(val *string)
ObjectVersionInput() *string
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetObjectVersion()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGameliftScriptStorageLocationOutputReference ¶
func NewGameliftScriptStorageLocationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GameliftScriptStorageLocationOutputReference