Documentation
¶
Index ¶
- func GlobalacceleratorCustomRoutingListener_IsConstruct(x interface{}) *bool
- func GlobalacceleratorCustomRoutingListener_IsTerraformElement(x interface{}) *bool
- func GlobalacceleratorCustomRoutingListener_IsTerraformResource(x interface{}) *bool
- func GlobalacceleratorCustomRoutingListener_TfResourceType() *string
- func NewGlobalacceleratorCustomRoutingListenerPortRangeList_Override(g GlobalacceleratorCustomRoutingListenerPortRangeList, ...)
- func NewGlobalacceleratorCustomRoutingListenerPortRangeOutputReference_Override(g GlobalacceleratorCustomRoutingListenerPortRangeOutputReference, ...)
- func NewGlobalacceleratorCustomRoutingListenerTimeoutsOutputReference_Override(g GlobalacceleratorCustomRoutingListenerTimeoutsOutputReference, ...)
- func NewGlobalacceleratorCustomRoutingListener_Override(g GlobalacceleratorCustomRoutingListener, scope constructs.Construct, ...)
- type GlobalacceleratorCustomRoutingListener
- type GlobalacceleratorCustomRoutingListenerConfig
- type GlobalacceleratorCustomRoutingListenerPortRange
- type GlobalacceleratorCustomRoutingListenerPortRangeList
- type GlobalacceleratorCustomRoutingListenerPortRangeOutputReference
- type GlobalacceleratorCustomRoutingListenerTimeouts
- type GlobalacceleratorCustomRoutingListenerTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GlobalacceleratorCustomRoutingListener_IsConstruct ¶
func GlobalacceleratorCustomRoutingListener_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GlobalacceleratorCustomRoutingListener_IsTerraformElement ¶
func GlobalacceleratorCustomRoutingListener_IsTerraformElement(x interface{}) *bool
Experimental.
func GlobalacceleratorCustomRoutingListener_IsTerraformResource ¶
func GlobalacceleratorCustomRoutingListener_IsTerraformResource(x interface{}) *bool
Experimental.
func GlobalacceleratorCustomRoutingListener_TfResourceType ¶
func GlobalacceleratorCustomRoutingListener_TfResourceType() *string
func NewGlobalacceleratorCustomRoutingListenerPortRangeList_Override ¶
func NewGlobalacceleratorCustomRoutingListenerPortRangeList_Override(g GlobalacceleratorCustomRoutingListenerPortRangeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGlobalacceleratorCustomRoutingListenerPortRangeOutputReference_Override ¶
func NewGlobalacceleratorCustomRoutingListenerPortRangeOutputReference_Override(g GlobalacceleratorCustomRoutingListenerPortRangeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGlobalacceleratorCustomRoutingListenerTimeoutsOutputReference_Override ¶
func NewGlobalacceleratorCustomRoutingListenerTimeoutsOutputReference_Override(g GlobalacceleratorCustomRoutingListenerTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGlobalacceleratorCustomRoutingListener_Override ¶
func NewGlobalacceleratorCustomRoutingListener_Override(g GlobalacceleratorCustomRoutingListener, scope constructs.Construct, id *string, config *GlobalacceleratorCustomRoutingListenerConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/globalaccelerator_custom_routing_listener aws_globalaccelerator_custom_routing_listener} Resource.
Types ¶
type GlobalacceleratorCustomRoutingListener ¶
type GlobalacceleratorCustomRoutingListener interface {
cdktf.TerraformResource
AcceleratorArn() *string
SetAcceleratorArn(val *string)
AcceleratorArnInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
PortRange() GlobalacceleratorCustomRoutingListenerPortRangeList
PortRangeInput() interface{}
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GlobalacceleratorCustomRoutingListenerTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutPortRange(value interface{})
PutTimeouts(value *GlobalacceleratorCustomRoutingListenerTimeouts)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/globalaccelerator_custom_routing_listener aws_globalaccelerator_custom_routing_listener}.
func NewGlobalacceleratorCustomRoutingListener ¶
func NewGlobalacceleratorCustomRoutingListener(scope constructs.Construct, id *string, config *GlobalacceleratorCustomRoutingListenerConfig) GlobalacceleratorCustomRoutingListener
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/globalaccelerator_custom_routing_listener aws_globalaccelerator_custom_routing_listener} Resource.
type GlobalacceleratorCustomRoutingListenerConfig ¶
type GlobalacceleratorCustomRoutingListenerConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/globalaccelerator_custom_routing_listener#accelerator_arn GlobalacceleratorCustomRoutingListener#accelerator_arn}.
AcceleratorArn *string `field:"required" json:"acceleratorArn" yaml:"acceleratorArn"`
// port_range block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/globalaccelerator_custom_routing_listener#port_range GlobalacceleratorCustomRoutingListener#port_range}
PortRange interface{} `field:"required" json:"portRange" yaml:"portRange"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/globalaccelerator_custom_routing_listener#id GlobalacceleratorCustomRoutingListener#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/globalaccelerator_custom_routing_listener#timeouts GlobalacceleratorCustomRoutingListener#timeouts}
Timeouts *GlobalacceleratorCustomRoutingListenerTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GlobalacceleratorCustomRoutingListenerPortRange ¶
type GlobalacceleratorCustomRoutingListenerPortRange struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/globalaccelerator_custom_routing_listener#from_port GlobalacceleratorCustomRoutingListener#from_port}.
FromPort *float64 `field:"optional" json:"fromPort" yaml:"fromPort"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/globalaccelerator_custom_routing_listener#to_port GlobalacceleratorCustomRoutingListener#to_port}.
ToPort *float64 `field:"optional" json:"toPort" yaml:"toPort"`
}
type GlobalacceleratorCustomRoutingListenerPortRangeList ¶
type GlobalacceleratorCustomRoutingListenerPortRangeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GlobalacceleratorCustomRoutingListenerPortRangeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlobalacceleratorCustomRoutingListenerPortRangeList ¶
func NewGlobalacceleratorCustomRoutingListenerPortRangeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GlobalacceleratorCustomRoutingListenerPortRangeList
type GlobalacceleratorCustomRoutingListenerPortRangeOutputReference ¶
type GlobalacceleratorCustomRoutingListenerPortRangeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
FromPort() *float64
SetFromPort(val *float64)
FromPortInput() *float64
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ToPort() *float64
SetToPort(val *float64)
ToPortInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetFromPort()
ResetToPort()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlobalacceleratorCustomRoutingListenerPortRangeOutputReference ¶
func NewGlobalacceleratorCustomRoutingListenerPortRangeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GlobalacceleratorCustomRoutingListenerPortRangeOutputReference
type GlobalacceleratorCustomRoutingListenerTimeouts ¶
type GlobalacceleratorCustomRoutingListenerTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/globalaccelerator_custom_routing_listener#create GlobalacceleratorCustomRoutingListener#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/globalaccelerator_custom_routing_listener#delete GlobalacceleratorCustomRoutingListener#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/globalaccelerator_custom_routing_listener#update GlobalacceleratorCustomRoutingListener#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GlobalacceleratorCustomRoutingListenerTimeoutsOutputReference ¶
type GlobalacceleratorCustomRoutingListenerTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGlobalacceleratorCustomRoutingListenerTimeoutsOutputReference ¶
func NewGlobalacceleratorCustomRoutingListenerTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GlobalacceleratorCustomRoutingListenerTimeoutsOutputReference
Source Files
¶
- GlobalacceleratorCustomRoutingListener.go
- GlobalacceleratorCustomRoutingListenerConfig.go
- GlobalacceleratorCustomRoutingListenerPortRange.go
- GlobalacceleratorCustomRoutingListenerPortRangeList.go
- GlobalacceleratorCustomRoutingListenerPortRangeList__checks.go
- GlobalacceleratorCustomRoutingListenerPortRangeOutputReference.go
- GlobalacceleratorCustomRoutingListenerPortRangeOutputReference__checks.go
- GlobalacceleratorCustomRoutingListenerTimeouts.go
- GlobalacceleratorCustomRoutingListenerTimeoutsOutputReference.go
- GlobalacceleratorCustomRoutingListenerTimeoutsOutputReference__checks.go
- GlobalacceleratorCustomRoutingListener__checks.go
- main.go