Documentation
¶
Index ¶
- func GluePartitionIndex_IsConstruct(x interface{}) *bool
- func GluePartitionIndex_IsTerraformElement(x interface{}) *bool
- func GluePartitionIndex_IsTerraformResource(x interface{}) *bool
- func GluePartitionIndex_TfResourceType() *string
- func NewGluePartitionIndexPartitionIndexOutputReference_Override(g GluePartitionIndexPartitionIndexOutputReference, ...)
- func NewGluePartitionIndexTimeoutsOutputReference_Override(g GluePartitionIndexTimeoutsOutputReference, ...)
- func NewGluePartitionIndex_Override(g GluePartitionIndex, scope constructs.Construct, id *string, ...)
- type GluePartitionIndex
- type GluePartitionIndexConfig
- type GluePartitionIndexPartitionIndex
- type GluePartitionIndexPartitionIndexOutputReference
- type GluePartitionIndexTimeouts
- type GluePartitionIndexTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GluePartitionIndex_IsConstruct ¶
func GluePartitionIndex_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GluePartitionIndex_IsTerraformElement ¶
func GluePartitionIndex_IsTerraformElement(x interface{}) *bool
Experimental.
func GluePartitionIndex_IsTerraformResource ¶
func GluePartitionIndex_IsTerraformResource(x interface{}) *bool
Experimental.
func GluePartitionIndex_TfResourceType ¶
func GluePartitionIndex_TfResourceType() *string
func NewGluePartitionIndexPartitionIndexOutputReference_Override ¶
func NewGluePartitionIndexPartitionIndexOutputReference_Override(g GluePartitionIndexPartitionIndexOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGluePartitionIndexTimeoutsOutputReference_Override ¶
func NewGluePartitionIndexTimeoutsOutputReference_Override(g GluePartitionIndexTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGluePartitionIndex_Override ¶
func NewGluePartitionIndex_Override(g GluePartitionIndex, scope constructs.Construct, id *string, config *GluePartitionIndexConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/glue_partition_index aws_glue_partition_index} Resource.
Types ¶
type GluePartitionIndex ¶
type GluePartitionIndex interface {
cdktf.TerraformResource
CatalogId() *string
SetCatalogId(val *string)
CatalogIdInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DatabaseName() *string
SetDatabaseName(val *string)
DatabaseNameInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
PartitionIndex() GluePartitionIndexPartitionIndexOutputReference
PartitionIndexInput() *GluePartitionIndexPartitionIndex
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
TableName() *string
SetTableName(val *string)
TableNameInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GluePartitionIndexTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutPartitionIndex(value *GluePartitionIndexPartitionIndex)
PutTimeouts(value *GluePartitionIndexTimeouts)
ResetCatalogId()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/glue_partition_index aws_glue_partition_index}.
func NewGluePartitionIndex ¶
func NewGluePartitionIndex(scope constructs.Construct, id *string, config *GluePartitionIndexConfig) GluePartitionIndex
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/glue_partition_index aws_glue_partition_index} Resource.
type GluePartitionIndexConfig ¶
type GluePartitionIndexConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/glue_partition_index#database_name GluePartitionIndex#database_name}.
DatabaseName *string `field:"required" json:"databaseName" yaml:"databaseName"`
// partition_index block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/glue_partition_index#partition_index GluePartitionIndex#partition_index}
PartitionIndex *GluePartitionIndexPartitionIndex `field:"required" json:"partitionIndex" yaml:"partitionIndex"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/glue_partition_index#table_name GluePartitionIndex#table_name}.
TableName *string `field:"required" json:"tableName" yaml:"tableName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/glue_partition_index#catalog_id GluePartitionIndex#catalog_id}.
CatalogId *string `field:"optional" json:"catalogId" yaml:"catalogId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/glue_partition_index#id GluePartitionIndex#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/glue_partition_index#timeouts GluePartitionIndex#timeouts}
Timeouts *GluePartitionIndexTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GluePartitionIndexPartitionIndex ¶
type GluePartitionIndexPartitionIndex struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/glue_partition_index#index_name GluePartitionIndex#index_name}.
IndexName *string `field:"optional" json:"indexName" yaml:"indexName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/glue_partition_index#keys GluePartitionIndex#keys}.
Keys *[]*string `field:"optional" json:"keys" yaml:"keys"`
}
type GluePartitionIndexPartitionIndexOutputReference ¶
type GluePartitionIndexPartitionIndexOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IndexName() *string
SetIndexName(val *string)
IndexNameInput() *string
IndexStatus() *string
InternalValue() *GluePartitionIndexPartitionIndex
SetInternalValue(val *GluePartitionIndexPartitionIndex)
Keys() *[]*string
SetKeys(val *[]*string)
KeysInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetIndexName()
ResetKeys()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGluePartitionIndexPartitionIndexOutputReference ¶
func NewGluePartitionIndexPartitionIndexOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GluePartitionIndexPartitionIndexOutputReference
type GluePartitionIndexTimeouts ¶
type GluePartitionIndexTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/glue_partition_index#create GluePartitionIndex#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/glue_partition_index#delete GluePartitionIndex#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type GluePartitionIndexTimeoutsOutputReference ¶
type GluePartitionIndexTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGluePartitionIndexTimeoutsOutputReference ¶
func NewGluePartitionIndexTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GluePartitionIndexTimeoutsOutputReference
Source Files
¶
- GluePartitionIndex.go
- GluePartitionIndexConfig.go
- GluePartitionIndexPartitionIndex.go
- GluePartitionIndexPartitionIndexOutputReference.go
- GluePartitionIndexPartitionIndexOutputReference__checks.go
- GluePartitionIndexTimeouts.go
- GluePartitionIndexTimeoutsOutputReference.go
- GluePartitionIndexTimeoutsOutputReference__checks.go
- GluePartitionIndex__checks.go
- main.go