Documentation
¶
Index ¶
- func IdentitystoreUser_IsConstruct(x interface{}) *bool
- func IdentitystoreUser_IsTerraformElement(x interface{}) *bool
- func IdentitystoreUser_IsTerraformResource(x interface{}) *bool
- func IdentitystoreUser_TfResourceType() *string
- func NewIdentitystoreUserAddressesOutputReference_Override(i IdentitystoreUserAddressesOutputReference, ...)
- func NewIdentitystoreUserEmailsOutputReference_Override(i IdentitystoreUserEmailsOutputReference, ...)
- func NewIdentitystoreUserExternalIdsList_Override(i IdentitystoreUserExternalIdsList, ...)
- func NewIdentitystoreUserExternalIdsOutputReference_Override(i IdentitystoreUserExternalIdsOutputReference, ...)
- func NewIdentitystoreUserNameOutputReference_Override(i IdentitystoreUserNameOutputReference, ...)
- func NewIdentitystoreUserPhoneNumbersOutputReference_Override(i IdentitystoreUserPhoneNumbersOutputReference, ...)
- func NewIdentitystoreUser_Override(i IdentitystoreUser, scope constructs.Construct, id *string, ...)
- type IdentitystoreUser
- type IdentitystoreUserAddresses
- type IdentitystoreUserAddressesOutputReference
- type IdentitystoreUserConfig
- type IdentitystoreUserEmails
- type IdentitystoreUserEmailsOutputReference
- type IdentitystoreUserExternalIds
- type IdentitystoreUserExternalIdsList
- type IdentitystoreUserExternalIdsOutputReference
- type IdentitystoreUserName
- type IdentitystoreUserNameOutputReference
- type IdentitystoreUserPhoneNumbers
- type IdentitystoreUserPhoneNumbersOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IdentitystoreUser_IsConstruct ¶
func IdentitystoreUser_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func IdentitystoreUser_IsTerraformElement ¶
func IdentitystoreUser_IsTerraformElement(x interface{}) *bool
Experimental.
func IdentitystoreUser_IsTerraformResource ¶
func IdentitystoreUser_IsTerraformResource(x interface{}) *bool
Experimental.
func IdentitystoreUser_TfResourceType ¶
func IdentitystoreUser_TfResourceType() *string
func NewIdentitystoreUserAddressesOutputReference_Override ¶
func NewIdentitystoreUserAddressesOutputReference_Override(i IdentitystoreUserAddressesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewIdentitystoreUserEmailsOutputReference_Override ¶
func NewIdentitystoreUserEmailsOutputReference_Override(i IdentitystoreUserEmailsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewIdentitystoreUserExternalIdsList_Override ¶
func NewIdentitystoreUserExternalIdsList_Override(i IdentitystoreUserExternalIdsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewIdentitystoreUserExternalIdsOutputReference_Override ¶
func NewIdentitystoreUserExternalIdsOutputReference_Override(i IdentitystoreUserExternalIdsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewIdentitystoreUserNameOutputReference_Override ¶
func NewIdentitystoreUserNameOutputReference_Override(i IdentitystoreUserNameOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewIdentitystoreUserPhoneNumbersOutputReference_Override ¶
func NewIdentitystoreUserPhoneNumbersOutputReference_Override(i IdentitystoreUserPhoneNumbersOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewIdentitystoreUser_Override ¶
func NewIdentitystoreUser_Override(i IdentitystoreUser, scope constructs.Construct, id *string, config *IdentitystoreUserConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user aws_identitystore_user} Resource.
Types ¶
type IdentitystoreUser ¶
type IdentitystoreUser interface {
cdktf.TerraformResource
Addresses() IdentitystoreUserAddressesOutputReference
AddressesInput() *IdentitystoreUserAddresses
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
Emails() IdentitystoreUserEmailsOutputReference
EmailsInput() *IdentitystoreUserEmails
ExternalIds() IdentitystoreUserExternalIdsList
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdentityStoreId() *string
SetIdentityStoreId(val *string)
IdentityStoreIdInput() *string
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Locale() *string
SetLocale(val *string)
LocaleInput() *string
Name() IdentitystoreUserNameOutputReference
NameInput() *IdentitystoreUserName
Nickname() *string
SetNickname(val *string)
NicknameInput() *string
// The tree node.
Node() constructs.Node
PhoneNumbers() IdentitystoreUserPhoneNumbersOutputReference
PhoneNumbersInput() *IdentitystoreUserPhoneNumbers
PreferredLanguage() *string
SetPreferredLanguage(val *string)
PreferredLanguageInput() *string
ProfileUrl() *string
SetProfileUrl(val *string)
ProfileUrlInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timezone() *string
SetTimezone(val *string)
TimezoneInput() *string
Title() *string
SetTitle(val *string)
TitleInput() *string
UserId() *string
UserName() *string
SetUserName(val *string)
UserNameInput() *string
UserType() *string
SetUserType(val *string)
UserTypeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAddresses(value *IdentitystoreUserAddresses)
PutEmails(value *IdentitystoreUserEmails)
PutName(value *IdentitystoreUserName)
PutPhoneNumbers(value *IdentitystoreUserPhoneNumbers)
ResetAddresses()
ResetEmails()
ResetId()
ResetLocale()
ResetNickname()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPhoneNumbers()
ResetPreferredLanguage()
ResetProfileUrl()
ResetTimezone()
ResetTitle()
ResetUserType()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user aws_identitystore_user}.
func NewIdentitystoreUser ¶
func NewIdentitystoreUser(scope constructs.Construct, id *string, config *IdentitystoreUserConfig) IdentitystoreUser
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user aws_identitystore_user} Resource.
type IdentitystoreUserAddresses ¶
type IdentitystoreUserAddresses struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#country IdentitystoreUser#country}.
Country *string `field:"optional" json:"country" yaml:"country"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#formatted IdentitystoreUser#formatted}.
Formatted *string `field:"optional" json:"formatted" yaml:"formatted"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#locality IdentitystoreUser#locality}.
Locality *string `field:"optional" json:"locality" yaml:"locality"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#postal_code IdentitystoreUser#postal_code}.
PostalCode *string `field:"optional" json:"postalCode" yaml:"postalCode"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#primary IdentitystoreUser#primary}.
Primary interface{} `field:"optional" json:"primary" yaml:"primary"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#region IdentitystoreUser#region}.
Region *string `field:"optional" json:"region" yaml:"region"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#street_address IdentitystoreUser#street_address}.
StreetAddress *string `field:"optional" json:"streetAddress" yaml:"streetAddress"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#type IdentitystoreUser#type}.
Type *string `field:"optional" json:"type" yaml:"type"`
}
type IdentitystoreUserAddressesOutputReference ¶
type IdentitystoreUserAddressesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Country() *string
SetCountry(val *string)
CountryInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Formatted() *string
SetFormatted(val *string)
FormattedInput() *string
// Experimental.
Fqn() *string
InternalValue() *IdentitystoreUserAddresses
SetInternalValue(val *IdentitystoreUserAddresses)
Locality() *string
SetLocality(val *string)
LocalityInput() *string
PostalCode() *string
SetPostalCode(val *string)
PostalCodeInput() *string
Primary() interface{}
SetPrimary(val interface{})
PrimaryInput() interface{}
Region() *string
SetRegion(val *string)
RegionInput() *string
StreetAddress() *string
SetStreetAddress(val *string)
StreetAddressInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCountry()
ResetFormatted()
ResetLocality()
ResetPostalCode()
ResetPrimary()
ResetRegion()
ResetStreetAddress()
ResetType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIdentitystoreUserAddressesOutputReference ¶
func NewIdentitystoreUserAddressesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) IdentitystoreUserAddressesOutputReference
type IdentitystoreUserConfig ¶
type IdentitystoreUserConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#display_name IdentitystoreUser#display_name}.
DisplayName *string `field:"required" json:"displayName" yaml:"displayName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#identity_store_id IdentitystoreUser#identity_store_id}.
IdentityStoreId *string `field:"required" json:"identityStoreId" yaml:"identityStoreId"`
// name block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#name IdentitystoreUser#name}
Name *IdentitystoreUserName `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#user_name IdentitystoreUser#user_name}.
UserName *string `field:"required" json:"userName" yaml:"userName"`
// addresses block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#addresses IdentitystoreUser#addresses}
Addresses *IdentitystoreUserAddresses `field:"optional" json:"addresses" yaml:"addresses"`
// emails block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#emails IdentitystoreUser#emails}
Emails *IdentitystoreUserEmails `field:"optional" json:"emails" yaml:"emails"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#id IdentitystoreUser#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#locale IdentitystoreUser#locale}.
Locale *string `field:"optional" json:"locale" yaml:"locale"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#nickname IdentitystoreUser#nickname}.
Nickname *string `field:"optional" json:"nickname" yaml:"nickname"`
// phone_numbers block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#phone_numbers IdentitystoreUser#phone_numbers}
PhoneNumbers *IdentitystoreUserPhoneNumbers `field:"optional" json:"phoneNumbers" yaml:"phoneNumbers"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#preferred_language IdentitystoreUser#preferred_language}.
PreferredLanguage *string `field:"optional" json:"preferredLanguage" yaml:"preferredLanguage"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#profile_url IdentitystoreUser#profile_url}.
ProfileUrl *string `field:"optional" json:"profileUrl" yaml:"profileUrl"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#timezone IdentitystoreUser#timezone}.
Timezone *string `field:"optional" json:"timezone" yaml:"timezone"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#title IdentitystoreUser#title}.
Title *string `field:"optional" json:"title" yaml:"title"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#user_type IdentitystoreUser#user_type}.
UserType *string `field:"optional" json:"userType" yaml:"userType"`
}
type IdentitystoreUserEmails ¶
type IdentitystoreUserEmails struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#primary IdentitystoreUser#primary}.
Primary interface{} `field:"optional" json:"primary" yaml:"primary"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#type IdentitystoreUser#type}.
Type *string `field:"optional" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#value IdentitystoreUser#value}.
Value *string `field:"optional" json:"value" yaml:"value"`
}
type IdentitystoreUserEmailsOutputReference ¶
type IdentitystoreUserEmailsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *IdentitystoreUserEmails
SetInternalValue(val *IdentitystoreUserEmails)
Primary() interface{}
SetPrimary(val interface{})
PrimaryInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetPrimary()
ResetType()
ResetValue()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIdentitystoreUserEmailsOutputReference ¶
func NewIdentitystoreUserEmailsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) IdentitystoreUserEmailsOutputReference
type IdentitystoreUserExternalIds ¶
type IdentitystoreUserExternalIds struct {
}
type IdentitystoreUserExternalIdsList ¶
type IdentitystoreUserExternalIdsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) IdentitystoreUserExternalIdsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIdentitystoreUserExternalIdsList ¶
func NewIdentitystoreUserExternalIdsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) IdentitystoreUserExternalIdsList
type IdentitystoreUserExternalIdsOutputReference ¶
type IdentitystoreUserExternalIdsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *IdentitystoreUserExternalIds
SetInternalValue(val *IdentitystoreUserExternalIds)
Issuer() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIdentitystoreUserExternalIdsOutputReference ¶
func NewIdentitystoreUserExternalIdsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) IdentitystoreUserExternalIdsOutputReference
type IdentitystoreUserName ¶
type IdentitystoreUserName struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#family_name IdentitystoreUser#family_name}.
FamilyName *string `field:"required" json:"familyName" yaml:"familyName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#given_name IdentitystoreUser#given_name}.
GivenName *string `field:"required" json:"givenName" yaml:"givenName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#formatted IdentitystoreUser#formatted}.
Formatted *string `field:"optional" json:"formatted" yaml:"formatted"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#honorific_prefix IdentitystoreUser#honorific_prefix}.
HonorificPrefix *string `field:"optional" json:"honorificPrefix" yaml:"honorificPrefix"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#honorific_suffix IdentitystoreUser#honorific_suffix}.
HonorificSuffix *string `field:"optional" json:"honorificSuffix" yaml:"honorificSuffix"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#middle_name IdentitystoreUser#middle_name}.
MiddleName *string `field:"optional" json:"middleName" yaml:"middleName"`
}
type IdentitystoreUserNameOutputReference ¶
type IdentitystoreUserNameOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FamilyName() *string
SetFamilyName(val *string)
FamilyNameInput() *string
Formatted() *string
SetFormatted(val *string)
FormattedInput() *string
// Experimental.
Fqn() *string
GivenName() *string
SetGivenName(val *string)
GivenNameInput() *string
HonorificPrefix() *string
SetHonorificPrefix(val *string)
HonorificPrefixInput() *string
HonorificSuffix() *string
SetHonorificSuffix(val *string)
HonorificSuffixInput() *string
InternalValue() *IdentitystoreUserName
SetInternalValue(val *IdentitystoreUserName)
MiddleName() *string
SetMiddleName(val *string)
MiddleNameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetFormatted()
ResetHonorificPrefix()
ResetHonorificSuffix()
ResetMiddleName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIdentitystoreUserNameOutputReference ¶
func NewIdentitystoreUserNameOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) IdentitystoreUserNameOutputReference
type IdentitystoreUserPhoneNumbers ¶
type IdentitystoreUserPhoneNumbers struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#primary IdentitystoreUser#primary}.
Primary interface{} `field:"optional" json:"primary" yaml:"primary"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#type IdentitystoreUser#type}.
Type *string `field:"optional" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/identitystore_user#value IdentitystoreUser#value}.
Value *string `field:"optional" json:"value" yaml:"value"`
}
type IdentitystoreUserPhoneNumbersOutputReference ¶
type IdentitystoreUserPhoneNumbersOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *IdentitystoreUserPhoneNumbers
SetInternalValue(val *IdentitystoreUserPhoneNumbers)
Primary() interface{}
SetPrimary(val interface{})
PrimaryInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetPrimary()
ResetType()
ResetValue()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIdentitystoreUserPhoneNumbersOutputReference ¶
func NewIdentitystoreUserPhoneNumbersOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) IdentitystoreUserPhoneNumbersOutputReference
Source Files
¶
- IdentitystoreUser.go
- IdentitystoreUserAddresses.go
- IdentitystoreUserAddressesOutputReference.go
- IdentitystoreUserAddressesOutputReference__checks.go
- IdentitystoreUserConfig.go
- IdentitystoreUserEmails.go
- IdentitystoreUserEmailsOutputReference.go
- IdentitystoreUserEmailsOutputReference__checks.go
- IdentitystoreUserExternalIds.go
- IdentitystoreUserExternalIdsList.go
- IdentitystoreUserExternalIdsList__checks.go
- IdentitystoreUserExternalIdsOutputReference.go
- IdentitystoreUserExternalIdsOutputReference__checks.go
- IdentitystoreUserName.go
- IdentitystoreUserNameOutputReference.go
- IdentitystoreUserNameOutputReference__checks.go
- IdentitystoreUserPhoneNumbers.go
- IdentitystoreUserPhoneNumbersOutputReference.go
- IdentitystoreUserPhoneNumbersOutputReference__checks.go
- IdentitystoreUser__checks.go
- main.go