Documentation
¶
Index ¶
- func ImagebuilderInfrastructureConfiguration_IsConstruct(x interface{}) *bool
- func ImagebuilderInfrastructureConfiguration_IsTerraformElement(x interface{}) *bool
- func ImagebuilderInfrastructureConfiguration_IsTerraformResource(x interface{}) *bool
- func ImagebuilderInfrastructureConfiguration_TfResourceType() *string
- func NewImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference_Override(...)
- func NewImagebuilderInfrastructureConfigurationLoggingOutputReference_Override(i ImagebuilderInfrastructureConfigurationLoggingOutputReference, ...)
- func NewImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference_Override(i ImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference, ...)
- func NewImagebuilderInfrastructureConfiguration_Override(i ImagebuilderInfrastructureConfiguration, scope constructs.Construct, ...)
- type ImagebuilderInfrastructureConfiguration
- type ImagebuilderInfrastructureConfigurationConfig
- type ImagebuilderInfrastructureConfigurationInstanceMetadataOptions
- type ImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference
- type ImagebuilderInfrastructureConfigurationLogging
- type ImagebuilderInfrastructureConfigurationLoggingOutputReference
- type ImagebuilderInfrastructureConfigurationLoggingS3Logs
- type ImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ImagebuilderInfrastructureConfiguration_IsConstruct ¶
func ImagebuilderInfrastructureConfiguration_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ImagebuilderInfrastructureConfiguration_IsTerraformElement ¶
func ImagebuilderInfrastructureConfiguration_IsTerraformElement(x interface{}) *bool
Experimental.
func ImagebuilderInfrastructureConfiguration_IsTerraformResource ¶
func ImagebuilderInfrastructureConfiguration_IsTerraformResource(x interface{}) *bool
Experimental.
func ImagebuilderInfrastructureConfiguration_TfResourceType ¶
func ImagebuilderInfrastructureConfiguration_TfResourceType() *string
func NewImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference_Override ¶
func NewImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference_Override(i ImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewImagebuilderInfrastructureConfigurationLoggingOutputReference_Override ¶
func NewImagebuilderInfrastructureConfigurationLoggingOutputReference_Override(i ImagebuilderInfrastructureConfigurationLoggingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference_Override ¶
func NewImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference_Override(i ImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewImagebuilderInfrastructureConfiguration_Override ¶
func NewImagebuilderInfrastructureConfiguration_Override(i ImagebuilderInfrastructureConfiguration, scope constructs.Construct, id *string, config *ImagebuilderInfrastructureConfigurationConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration aws_imagebuilder_infrastructure_configuration} Resource.
Types ¶
type ImagebuilderInfrastructureConfiguration ¶
type ImagebuilderInfrastructureConfiguration interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DateCreated() *string
DateUpdated() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InstanceMetadataOptions() ImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference
InstanceMetadataOptionsInput() *ImagebuilderInfrastructureConfigurationInstanceMetadataOptions
InstanceProfileName() *string
SetInstanceProfileName(val *string)
InstanceProfileNameInput() *string
InstanceTypes() *[]*string
SetInstanceTypes(val *[]*string)
InstanceTypesInput() *[]*string
KeyPair() *string
SetKeyPair(val *string)
KeyPairInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Logging() ImagebuilderInfrastructureConfigurationLoggingOutputReference
LoggingInput() *ImagebuilderInfrastructureConfigurationLogging
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ResourceTags() *map[string]*string
SetResourceTags(val *map[string]*string)
ResourceTagsInput() *map[string]*string
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
SnsTopicArn() *string
SetSnsTopicArn(val *string)
SnsTopicArnInput() *string
SubnetId() *string
SetSubnetId(val *string)
SubnetIdInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
TerminateInstanceOnFailure() interface{}
SetTerminateInstanceOnFailure(val interface{})
TerminateInstanceOnFailureInput() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutInstanceMetadataOptions(value *ImagebuilderInfrastructureConfigurationInstanceMetadataOptions)
PutLogging(value *ImagebuilderInfrastructureConfigurationLogging)
ResetDescription()
ResetId()
ResetInstanceMetadataOptions()
ResetInstanceTypes()
ResetKeyPair()
ResetLogging()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetResourceTags()
ResetSecurityGroupIds()
ResetSnsTopicArn()
ResetSubnetId()
ResetTags()
ResetTagsAll()
ResetTerminateInstanceOnFailure()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration aws_imagebuilder_infrastructure_configuration}.
func NewImagebuilderInfrastructureConfiguration ¶
func NewImagebuilderInfrastructureConfiguration(scope constructs.Construct, id *string, config *ImagebuilderInfrastructureConfigurationConfig) ImagebuilderInfrastructureConfiguration
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration aws_imagebuilder_infrastructure_configuration} Resource.
type ImagebuilderInfrastructureConfigurationConfig ¶
type ImagebuilderInfrastructureConfigurationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#instance_profile_name ImagebuilderInfrastructureConfiguration#instance_profile_name}.
InstanceProfileName *string `field:"required" json:"instanceProfileName" yaml:"instanceProfileName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#name ImagebuilderInfrastructureConfiguration#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#description ImagebuilderInfrastructureConfiguration#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#id ImagebuilderInfrastructureConfiguration#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// instance_metadata_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#instance_metadata_options ImagebuilderInfrastructureConfiguration#instance_metadata_options}
InstanceMetadataOptions *ImagebuilderInfrastructureConfigurationInstanceMetadataOptions `field:"optional" json:"instanceMetadataOptions" yaml:"instanceMetadataOptions"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#instance_types ImagebuilderInfrastructureConfiguration#instance_types}.
InstanceTypes *[]*string `field:"optional" json:"instanceTypes" yaml:"instanceTypes"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#key_pair ImagebuilderInfrastructureConfiguration#key_pair}.
KeyPair *string `field:"optional" json:"keyPair" yaml:"keyPair"`
// logging block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#logging ImagebuilderInfrastructureConfiguration#logging}
Logging *ImagebuilderInfrastructureConfigurationLogging `field:"optional" json:"logging" yaml:"logging"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#resource_tags ImagebuilderInfrastructureConfiguration#resource_tags}.
ResourceTags *map[string]*string `field:"optional" json:"resourceTags" yaml:"resourceTags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#security_group_ids ImagebuilderInfrastructureConfiguration#security_group_ids}.
SecurityGroupIds *[]*string `field:"optional" json:"securityGroupIds" yaml:"securityGroupIds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#sns_topic_arn ImagebuilderInfrastructureConfiguration#sns_topic_arn}.
SnsTopicArn *string `field:"optional" json:"snsTopicArn" yaml:"snsTopicArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#subnet_id ImagebuilderInfrastructureConfiguration#subnet_id}.
SubnetId *string `field:"optional" json:"subnetId" yaml:"subnetId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#tags ImagebuilderInfrastructureConfiguration#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#tags_all ImagebuilderInfrastructureConfiguration#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#terminate_instance_on_failure ImagebuilderInfrastructureConfiguration#terminate_instance_on_failure}.
TerminateInstanceOnFailure interface{} `field:"optional" json:"terminateInstanceOnFailure" yaml:"terminateInstanceOnFailure"`
}
type ImagebuilderInfrastructureConfigurationInstanceMetadataOptions ¶
type ImagebuilderInfrastructureConfigurationInstanceMetadataOptions struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#http_put_response_hop_limit ImagebuilderInfrastructureConfiguration#http_put_response_hop_limit}.
HttpPutResponseHopLimit *float64 `field:"optional" json:"httpPutResponseHopLimit" yaml:"httpPutResponseHopLimit"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#http_tokens ImagebuilderInfrastructureConfiguration#http_tokens}.
HttpTokens *string `field:"optional" json:"httpTokens" yaml:"httpTokens"`
}
type ImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference ¶
type ImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HttpPutResponseHopLimit() *float64
SetHttpPutResponseHopLimit(val *float64)
HttpPutResponseHopLimitInput() *float64
HttpTokens() *string
SetHttpTokens(val *string)
HttpTokensInput() *string
InternalValue() *ImagebuilderInfrastructureConfigurationInstanceMetadataOptions
SetInternalValue(val *ImagebuilderInfrastructureConfigurationInstanceMetadataOptions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetHttpPutResponseHopLimit()
ResetHttpTokens()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference ¶
func NewImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference
type ImagebuilderInfrastructureConfigurationLogging ¶
type ImagebuilderInfrastructureConfigurationLogging struct {
// s3_logs block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#s3_logs ImagebuilderInfrastructureConfiguration#s3_logs}
S3Logs *ImagebuilderInfrastructureConfigurationLoggingS3Logs `field:"required" json:"s3Logs" yaml:"s3Logs"`
}
type ImagebuilderInfrastructureConfigurationLoggingOutputReference ¶
type ImagebuilderInfrastructureConfigurationLoggingOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ImagebuilderInfrastructureConfigurationLogging
SetInternalValue(val *ImagebuilderInfrastructureConfigurationLogging)
S3Logs() ImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference
S3LogsInput() *ImagebuilderInfrastructureConfigurationLoggingS3Logs
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutS3Logs(value *ImagebuilderInfrastructureConfigurationLoggingS3Logs)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewImagebuilderInfrastructureConfigurationLoggingOutputReference ¶
func NewImagebuilderInfrastructureConfigurationLoggingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ImagebuilderInfrastructureConfigurationLoggingOutputReference
type ImagebuilderInfrastructureConfigurationLoggingS3Logs ¶
type ImagebuilderInfrastructureConfigurationLoggingS3Logs struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#s3_bucket_name ImagebuilderInfrastructureConfiguration#s3_bucket_name}.
S3BucketName *string `field:"required" json:"s3BucketName" yaml:"s3BucketName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/imagebuilder_infrastructure_configuration#s3_key_prefix ImagebuilderInfrastructureConfiguration#s3_key_prefix}.
S3KeyPrefix *string `field:"optional" json:"s3KeyPrefix" yaml:"s3KeyPrefix"`
}
type ImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference ¶
type ImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ImagebuilderInfrastructureConfigurationLoggingS3Logs
SetInternalValue(val *ImagebuilderInfrastructureConfigurationLoggingS3Logs)
S3BucketName() *string
SetS3BucketName(val *string)
S3BucketNameInput() *string
S3KeyPrefix() *string
SetS3KeyPrefix(val *string)
S3KeyPrefixInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetS3KeyPrefix()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference ¶
func NewImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference
Source Files
¶
- ImagebuilderInfrastructureConfiguration.go
- ImagebuilderInfrastructureConfigurationConfig.go
- ImagebuilderInfrastructureConfigurationInstanceMetadataOptions.go
- ImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference.go
- ImagebuilderInfrastructureConfigurationInstanceMetadataOptionsOutputReference__checks.go
- ImagebuilderInfrastructureConfigurationLogging.go
- ImagebuilderInfrastructureConfigurationLoggingOutputReference.go
- ImagebuilderInfrastructureConfigurationLoggingOutputReference__checks.go
- ImagebuilderInfrastructureConfigurationLoggingS3Logs.go
- ImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference.go
- ImagebuilderInfrastructureConfigurationLoggingS3LogsOutputReference__checks.go
- ImagebuilderInfrastructureConfiguration__checks.go
- main.go