Documentation
¶
Index ¶
- func IotThingGroup_IsConstruct(x interface{}) *bool
- func IotThingGroup_IsTerraformElement(x interface{}) *bool
- func IotThingGroup_IsTerraformResource(x interface{}) *bool
- func IotThingGroup_TfResourceType() *string
- func NewIotThingGroupMetadataList_Override(i IotThingGroupMetadataList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewIotThingGroupMetadataOutputReference_Override(i IotThingGroupMetadataOutputReference, ...)
- func NewIotThingGroupMetadataRootToParentGroupsList_Override(i IotThingGroupMetadataRootToParentGroupsList, ...)
- func NewIotThingGroupMetadataRootToParentGroupsOutputReference_Override(i IotThingGroupMetadataRootToParentGroupsOutputReference, ...)
- func NewIotThingGroupPropertiesAttributePayloadOutputReference_Override(i IotThingGroupPropertiesAttributePayloadOutputReference, ...)
- func NewIotThingGroupPropertiesOutputReference_Override(i IotThingGroupPropertiesOutputReference, ...)
- func NewIotThingGroup_Override(i IotThingGroup, scope constructs.Construct, id *string, ...)
- type IotThingGroup
- type IotThingGroupConfig
- type IotThingGroupMetadata
- type IotThingGroupMetadataList
- type IotThingGroupMetadataOutputReference
- type IotThingGroupMetadataRootToParentGroups
- type IotThingGroupMetadataRootToParentGroupsList
- type IotThingGroupMetadataRootToParentGroupsOutputReference
- type IotThingGroupProperties
- type IotThingGroupPropertiesAttributePayload
- type IotThingGroupPropertiesAttributePayloadOutputReference
- type IotThingGroupPropertiesOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IotThingGroup_IsConstruct ¶
func IotThingGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func IotThingGroup_IsTerraformElement ¶
func IotThingGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func IotThingGroup_IsTerraformResource ¶
func IotThingGroup_IsTerraformResource(x interface{}) *bool
Experimental.
func IotThingGroup_TfResourceType ¶
func IotThingGroup_TfResourceType() *string
func NewIotThingGroupMetadataList_Override ¶
func NewIotThingGroupMetadataList_Override(i IotThingGroupMetadataList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewIotThingGroupMetadataOutputReference_Override ¶
func NewIotThingGroupMetadataOutputReference_Override(i IotThingGroupMetadataOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewIotThingGroupMetadataRootToParentGroupsList_Override ¶
func NewIotThingGroupMetadataRootToParentGroupsList_Override(i IotThingGroupMetadataRootToParentGroupsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewIotThingGroupMetadataRootToParentGroupsOutputReference_Override ¶
func NewIotThingGroupMetadataRootToParentGroupsOutputReference_Override(i IotThingGroupMetadataRootToParentGroupsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewIotThingGroupPropertiesAttributePayloadOutputReference_Override ¶
func NewIotThingGroupPropertiesAttributePayloadOutputReference_Override(i IotThingGroupPropertiesAttributePayloadOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewIotThingGroupPropertiesOutputReference_Override ¶
func NewIotThingGroupPropertiesOutputReference_Override(i IotThingGroupPropertiesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewIotThingGroup_Override ¶
func NewIotThingGroup_Override(i IotThingGroup, scope constructs.Construct, id *string, config *IotThingGroupConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/iot_thing_group aws_iot_thing_group} Resource.
Types ¶
type IotThingGroup ¶
type IotThingGroup interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Metadata() IotThingGroupMetadataList
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
ParentGroupName() *string
SetParentGroupName(val *string)
ParentGroupNameInput() *string
Properties() IotThingGroupPropertiesOutputReference
PropertiesInput() *IotThingGroupProperties
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Version() *float64
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutProperties(value *IotThingGroupProperties)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetParentGroupName()
ResetProperties()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/iot_thing_group aws_iot_thing_group}.
func NewIotThingGroup ¶
func NewIotThingGroup(scope constructs.Construct, id *string, config *IotThingGroupConfig) IotThingGroup
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/iot_thing_group aws_iot_thing_group} Resource.
type IotThingGroupConfig ¶
type IotThingGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/iot_thing_group#name IotThingGroup#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/iot_thing_group#id IotThingGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/iot_thing_group#parent_group_name IotThingGroup#parent_group_name}.
ParentGroupName *string `field:"optional" json:"parentGroupName" yaml:"parentGroupName"`
// properties block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/iot_thing_group#properties IotThingGroup#properties}
Properties *IotThingGroupProperties `field:"optional" json:"properties" yaml:"properties"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/iot_thing_group#tags IotThingGroup#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/iot_thing_group#tags_all IotThingGroup#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type IotThingGroupMetadata ¶
type IotThingGroupMetadata struct {
}
type IotThingGroupMetadataList ¶
type IotThingGroupMetadataList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) IotThingGroupMetadataOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIotThingGroupMetadataList ¶
func NewIotThingGroupMetadataList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) IotThingGroupMetadataList
type IotThingGroupMetadataOutputReference ¶
type IotThingGroupMetadataOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CreationDate() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *IotThingGroupMetadata
SetInternalValue(val *IotThingGroupMetadata)
ParentGroupName() *string
RootToParentGroups() IotThingGroupMetadataRootToParentGroupsList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIotThingGroupMetadataOutputReference ¶
func NewIotThingGroupMetadataOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) IotThingGroupMetadataOutputReference
type IotThingGroupMetadataRootToParentGroups ¶
type IotThingGroupMetadataRootToParentGroups struct {
}
type IotThingGroupMetadataRootToParentGroupsList ¶
type IotThingGroupMetadataRootToParentGroupsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) IotThingGroupMetadataRootToParentGroupsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIotThingGroupMetadataRootToParentGroupsList ¶
func NewIotThingGroupMetadataRootToParentGroupsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) IotThingGroupMetadataRootToParentGroupsList
type IotThingGroupMetadataRootToParentGroupsOutputReference ¶
type IotThingGroupMetadataRootToParentGroupsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
GroupArn() *string
GroupName() *string
InternalValue() *IotThingGroupMetadataRootToParentGroups
SetInternalValue(val *IotThingGroupMetadataRootToParentGroups)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIotThingGroupMetadataRootToParentGroupsOutputReference ¶
func NewIotThingGroupMetadataRootToParentGroupsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) IotThingGroupMetadataRootToParentGroupsOutputReference
type IotThingGroupProperties ¶
type IotThingGroupProperties struct {
// attribute_payload block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/iot_thing_group#attribute_payload IotThingGroup#attribute_payload}
AttributePayload *IotThingGroupPropertiesAttributePayload `field:"optional" json:"attributePayload" yaml:"attributePayload"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/iot_thing_group#description IotThingGroup#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
}
type IotThingGroupPropertiesAttributePayload ¶
type IotThingGroupPropertiesAttributePayload struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/iot_thing_group#attributes IotThingGroup#attributes}.
Attributes *map[string]*string `field:"optional" json:"attributes" yaml:"attributes"`
}
type IotThingGroupPropertiesAttributePayloadOutputReference ¶
type IotThingGroupPropertiesAttributePayloadOutputReference interface {
cdktf.ComplexObject
Attributes() *map[string]*string
SetAttributes(val *map[string]*string)
AttributesInput() *map[string]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *IotThingGroupPropertiesAttributePayload
SetInternalValue(val *IotThingGroupPropertiesAttributePayload)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAttributes()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIotThingGroupPropertiesAttributePayloadOutputReference ¶
func NewIotThingGroupPropertiesAttributePayloadOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) IotThingGroupPropertiesAttributePayloadOutputReference
type IotThingGroupPropertiesOutputReference ¶
type IotThingGroupPropertiesOutputReference interface {
cdktf.ComplexObject
AttributePayload() IotThingGroupPropertiesAttributePayloadOutputReference
AttributePayloadInput() *IotThingGroupPropertiesAttributePayload
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
Fqn() *string
InternalValue() *IotThingGroupProperties
SetInternalValue(val *IotThingGroupProperties)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAttributePayload(value *IotThingGroupPropertiesAttributePayload)
ResetAttributePayload()
ResetDescription()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewIotThingGroupPropertiesOutputReference ¶
func NewIotThingGroupPropertiesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) IotThingGroupPropertiesOutputReference
Source Files
¶
- IotThingGroup.go
- IotThingGroupConfig.go
- IotThingGroupMetadata.go
- IotThingGroupMetadataList.go
- IotThingGroupMetadataList__checks.go
- IotThingGroupMetadataOutputReference.go
- IotThingGroupMetadataOutputReference__checks.go
- IotThingGroupMetadataRootToParentGroups.go
- IotThingGroupMetadataRootToParentGroupsList.go
- IotThingGroupMetadataRootToParentGroupsList__checks.go
- IotThingGroupMetadataRootToParentGroupsOutputReference.go
- IotThingGroupMetadataRootToParentGroupsOutputReference__checks.go
- IotThingGroupProperties.go
- IotThingGroupPropertiesAttributePayload.go
- IotThingGroupPropertiesAttributePayloadOutputReference.go
- IotThingGroupPropertiesAttributePayloadOutputReference__checks.go
- IotThingGroupPropertiesOutputReference.go
- IotThingGroupPropertiesOutputReference__checks.go
- IotThingGroup__checks.go
- main.go