Documentation
¶
Index ¶
- func LakeformationResourceLfTags_IsConstruct(x interface{}) *bool
- func LakeformationResourceLfTags_IsTerraformElement(x interface{}) *bool
- func LakeformationResourceLfTags_IsTerraformResource(x interface{}) *bool
- func LakeformationResourceLfTags_TfResourceType() *string
- func NewLakeformationResourceLfTagsDatabaseOutputReference_Override(l LakeformationResourceLfTagsDatabaseOutputReference, ...)
- func NewLakeformationResourceLfTagsLfTagList_Override(l LakeformationResourceLfTagsLfTagList, ...)
- func NewLakeformationResourceLfTagsLfTagOutputReference_Override(l LakeformationResourceLfTagsLfTagOutputReference, ...)
- func NewLakeformationResourceLfTagsTableOutputReference_Override(l LakeformationResourceLfTagsTableOutputReference, ...)
- func NewLakeformationResourceLfTagsTableWithColumnsOutputReference_Override(l LakeformationResourceLfTagsTableWithColumnsOutputReference, ...)
- func NewLakeformationResourceLfTagsTimeoutsOutputReference_Override(l LakeformationResourceLfTagsTimeoutsOutputReference, ...)
- func NewLakeformationResourceLfTags_Override(l LakeformationResourceLfTags, scope constructs.Construct, id *string, ...)
- type LakeformationResourceLfTags
- type LakeformationResourceLfTagsConfig
- type LakeformationResourceLfTagsDatabase
- type LakeformationResourceLfTagsDatabaseOutputReference
- type LakeformationResourceLfTagsLfTag
- type LakeformationResourceLfTagsLfTagList
- type LakeformationResourceLfTagsLfTagOutputReference
- type LakeformationResourceLfTagsTable
- type LakeformationResourceLfTagsTableOutputReference
- type LakeformationResourceLfTagsTableWithColumns
- type LakeformationResourceLfTagsTableWithColumnsOutputReference
- type LakeformationResourceLfTagsTimeouts
- type LakeformationResourceLfTagsTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LakeformationResourceLfTags_IsConstruct ¶
func LakeformationResourceLfTags_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func LakeformationResourceLfTags_IsTerraformElement ¶
func LakeformationResourceLfTags_IsTerraformElement(x interface{}) *bool
Experimental.
func LakeformationResourceLfTags_IsTerraformResource ¶
func LakeformationResourceLfTags_IsTerraformResource(x interface{}) *bool
Experimental.
func LakeformationResourceLfTags_TfResourceType ¶
func LakeformationResourceLfTags_TfResourceType() *string
func NewLakeformationResourceLfTagsDatabaseOutputReference_Override ¶
func NewLakeformationResourceLfTagsDatabaseOutputReference_Override(l LakeformationResourceLfTagsDatabaseOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLakeformationResourceLfTagsLfTagList_Override ¶
func NewLakeformationResourceLfTagsLfTagList_Override(l LakeformationResourceLfTagsLfTagList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewLakeformationResourceLfTagsLfTagOutputReference_Override ¶
func NewLakeformationResourceLfTagsLfTagOutputReference_Override(l LakeformationResourceLfTagsLfTagOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewLakeformationResourceLfTagsTableOutputReference_Override ¶
func NewLakeformationResourceLfTagsTableOutputReference_Override(l LakeformationResourceLfTagsTableOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLakeformationResourceLfTagsTableWithColumnsOutputReference_Override ¶
func NewLakeformationResourceLfTagsTableWithColumnsOutputReference_Override(l LakeformationResourceLfTagsTableWithColumnsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLakeformationResourceLfTagsTimeoutsOutputReference_Override ¶
func NewLakeformationResourceLfTagsTimeoutsOutputReference_Override(l LakeformationResourceLfTagsTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLakeformationResourceLfTags_Override ¶
func NewLakeformationResourceLfTags_Override(l LakeformationResourceLfTags, scope constructs.Construct, id *string, config *LakeformationResourceLfTagsConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags aws_lakeformation_resource_lf_tags} Resource.
Types ¶
type LakeformationResourceLfTags ¶
type LakeformationResourceLfTags interface {
cdktf.TerraformResource
CatalogId() *string
SetCatalogId(val *string)
CatalogIdInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
Database() LakeformationResourceLfTagsDatabaseOutputReference
DatabaseInput() *LakeformationResourceLfTagsDatabase
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
LfTag() LakeformationResourceLfTagsLfTagList
LfTagInput() interface{}
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Table() LakeformationResourceLfTagsTableOutputReference
TableInput() *LakeformationResourceLfTagsTable
TableWithColumns() LakeformationResourceLfTagsTableWithColumnsOutputReference
TableWithColumnsInput() *LakeformationResourceLfTagsTableWithColumns
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() LakeformationResourceLfTagsTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDatabase(value *LakeformationResourceLfTagsDatabase)
PutLfTag(value interface{})
PutTable(value *LakeformationResourceLfTagsTable)
PutTableWithColumns(value *LakeformationResourceLfTagsTableWithColumns)
PutTimeouts(value *LakeformationResourceLfTagsTimeouts)
ResetCatalogId()
ResetDatabase()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTable()
ResetTableWithColumns()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags aws_lakeformation_resource_lf_tags}.
func NewLakeformationResourceLfTags ¶
func NewLakeformationResourceLfTags(scope constructs.Construct, id *string, config *LakeformationResourceLfTagsConfig) LakeformationResourceLfTags
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags aws_lakeformation_resource_lf_tags} Resource.
type LakeformationResourceLfTagsConfig ¶
type LakeformationResourceLfTagsConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// lf_tag block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#lf_tag LakeformationResourceLfTags#lf_tag}
LfTag interface{} `field:"required" json:"lfTag" yaml:"lfTag"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#catalog_id LakeformationResourceLfTags#catalog_id}.
CatalogId *string `field:"optional" json:"catalogId" yaml:"catalogId"`
// database block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#database LakeformationResourceLfTags#database}
Database *LakeformationResourceLfTagsDatabase `field:"optional" json:"database" yaml:"database"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#id LakeformationResourceLfTags#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// table block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#table LakeformationResourceLfTags#table}
Table *LakeformationResourceLfTagsTable `field:"optional" json:"table" yaml:"table"`
// table_with_columns block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#table_with_columns LakeformationResourceLfTags#table_with_columns}
TableWithColumns *LakeformationResourceLfTagsTableWithColumns `field:"optional" json:"tableWithColumns" yaml:"tableWithColumns"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#timeouts LakeformationResourceLfTags#timeouts}
Timeouts *LakeformationResourceLfTagsTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type LakeformationResourceLfTagsDatabase ¶
type LakeformationResourceLfTagsDatabase struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#name LakeformationResourceLfTags#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#catalog_id LakeformationResourceLfTags#catalog_id}.
CatalogId *string `field:"optional" json:"catalogId" yaml:"catalogId"`
}
type LakeformationResourceLfTagsDatabaseOutputReference ¶
type LakeformationResourceLfTagsDatabaseOutputReference interface {
cdktf.ComplexObject
CatalogId() *string
SetCatalogId(val *string)
CatalogIdInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LakeformationResourceLfTagsDatabase
SetInternalValue(val *LakeformationResourceLfTagsDatabase)
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCatalogId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLakeformationResourceLfTagsDatabaseOutputReference ¶
func NewLakeformationResourceLfTagsDatabaseOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LakeformationResourceLfTagsDatabaseOutputReference
type LakeformationResourceLfTagsLfTag ¶
type LakeformationResourceLfTagsLfTag struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#key LakeformationResourceLfTags#key}.
Key *string `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#value LakeformationResourceLfTags#value}.
Value *string `field:"required" json:"value" yaml:"value"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#catalog_id LakeformationResourceLfTags#catalog_id}.
CatalogId *string `field:"optional" json:"catalogId" yaml:"catalogId"`
}
type LakeformationResourceLfTagsLfTagList ¶
type LakeformationResourceLfTagsLfTagList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) LakeformationResourceLfTagsLfTagOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLakeformationResourceLfTagsLfTagList ¶
func NewLakeformationResourceLfTagsLfTagList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) LakeformationResourceLfTagsLfTagList
type LakeformationResourceLfTagsLfTagOutputReference ¶
type LakeformationResourceLfTagsLfTagOutputReference interface {
cdktf.ComplexObject
CatalogId() *string
SetCatalogId(val *string)
CatalogIdInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCatalogId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLakeformationResourceLfTagsLfTagOutputReference ¶
func NewLakeformationResourceLfTagsLfTagOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) LakeformationResourceLfTagsLfTagOutputReference
type LakeformationResourceLfTagsTable ¶
type LakeformationResourceLfTagsTable struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#database_name LakeformationResourceLfTags#database_name}.
DatabaseName *string `field:"required" json:"databaseName" yaml:"databaseName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#catalog_id LakeformationResourceLfTags#catalog_id}.
CatalogId *string `field:"optional" json:"catalogId" yaml:"catalogId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#name LakeformationResourceLfTags#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#wildcard LakeformationResourceLfTags#wildcard}.
Wildcard interface{} `field:"optional" json:"wildcard" yaml:"wildcard"`
}
type LakeformationResourceLfTagsTableOutputReference ¶
type LakeformationResourceLfTagsTableOutputReference interface {
cdktf.ComplexObject
CatalogId() *string
SetCatalogId(val *string)
CatalogIdInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DatabaseName() *string
SetDatabaseName(val *string)
DatabaseNameInput() *string
// Experimental.
Fqn() *string
InternalValue() *LakeformationResourceLfTagsTable
SetInternalValue(val *LakeformationResourceLfTagsTable)
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Wildcard() interface{}
SetWildcard(val interface{})
WildcardInput() interface{}
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCatalogId()
ResetName()
ResetWildcard()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLakeformationResourceLfTagsTableOutputReference ¶
func NewLakeformationResourceLfTagsTableOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LakeformationResourceLfTagsTableOutputReference
type LakeformationResourceLfTagsTableWithColumns ¶
type LakeformationResourceLfTagsTableWithColumns struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#database_name LakeformationResourceLfTags#database_name}.
DatabaseName *string `field:"required" json:"databaseName" yaml:"databaseName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#name LakeformationResourceLfTags#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#catalog_id LakeformationResourceLfTags#catalog_id}.
CatalogId *string `field:"optional" json:"catalogId" yaml:"catalogId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#column_names LakeformationResourceLfTags#column_names}.
ColumnNames *[]*string `field:"optional" json:"columnNames" yaml:"columnNames"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#excluded_column_names LakeformationResourceLfTags#excluded_column_names}.
ExcludedColumnNames *[]*string `field:"optional" json:"excludedColumnNames" yaml:"excludedColumnNames"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#wildcard LakeformationResourceLfTags#wildcard}.
Wildcard interface{} `field:"optional" json:"wildcard" yaml:"wildcard"`
}
type LakeformationResourceLfTagsTableWithColumnsOutputReference ¶
type LakeformationResourceLfTagsTableWithColumnsOutputReference interface {
cdktf.ComplexObject
CatalogId() *string
SetCatalogId(val *string)
CatalogIdInput() *string
ColumnNames() *[]*string
SetColumnNames(val *[]*string)
ColumnNamesInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DatabaseName() *string
SetDatabaseName(val *string)
DatabaseNameInput() *string
ExcludedColumnNames() *[]*string
SetExcludedColumnNames(val *[]*string)
ExcludedColumnNamesInput() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LakeformationResourceLfTagsTableWithColumns
SetInternalValue(val *LakeformationResourceLfTagsTableWithColumns)
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Wildcard() interface{}
SetWildcard(val interface{})
WildcardInput() interface{}
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCatalogId()
ResetColumnNames()
ResetExcludedColumnNames()
ResetWildcard()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLakeformationResourceLfTagsTableWithColumnsOutputReference ¶
func NewLakeformationResourceLfTagsTableWithColumnsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LakeformationResourceLfTagsTableWithColumnsOutputReference
type LakeformationResourceLfTagsTimeouts ¶
type LakeformationResourceLfTagsTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#create LakeformationResourceLfTags#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lakeformation_resource_lf_tags#delete LakeformationResourceLfTags#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type LakeformationResourceLfTagsTimeoutsOutputReference ¶
type LakeformationResourceLfTagsTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLakeformationResourceLfTagsTimeoutsOutputReference ¶
func NewLakeformationResourceLfTagsTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LakeformationResourceLfTagsTimeoutsOutputReference
Source Files
¶
- LakeformationResourceLfTags.go
- LakeformationResourceLfTagsConfig.go
- LakeformationResourceLfTagsDatabase.go
- LakeformationResourceLfTagsDatabaseOutputReference.go
- LakeformationResourceLfTagsDatabaseOutputReference__checks.go
- LakeformationResourceLfTagsLfTag.go
- LakeformationResourceLfTagsLfTagList.go
- LakeformationResourceLfTagsLfTagList__checks.go
- LakeformationResourceLfTagsLfTagOutputReference.go
- LakeformationResourceLfTagsLfTagOutputReference__checks.go
- LakeformationResourceLfTagsTable.go
- LakeformationResourceLfTagsTableOutputReference.go
- LakeformationResourceLfTagsTableOutputReference__checks.go
- LakeformationResourceLfTagsTableWithColumns.go
- LakeformationResourceLfTagsTableWithColumnsOutputReference.go
- LakeformationResourceLfTagsTableWithColumnsOutputReference__checks.go
- LakeformationResourceLfTagsTimeouts.go
- LakeformationResourceLfTagsTimeoutsOutputReference.go
- LakeformationResourceLfTagsTimeoutsOutputReference__checks.go
- LakeformationResourceLfTags__checks.go
- main.go