Documentation
¶
Index ¶
- func LambdaLayerVersion_IsConstruct(x interface{}) *bool
- func LambdaLayerVersion_IsTerraformElement(x interface{}) *bool
- func LambdaLayerVersion_IsTerraformResource(x interface{}) *bool
- func LambdaLayerVersion_TfResourceType() *string
- func NewLambdaLayerVersion_Override(l LambdaLayerVersion, scope constructs.Construct, id *string, ...)
- type LambdaLayerVersion
- type LambdaLayerVersionConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LambdaLayerVersion_IsConstruct ¶
func LambdaLayerVersion_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func LambdaLayerVersion_IsTerraformElement ¶
func LambdaLayerVersion_IsTerraformElement(x interface{}) *bool
Experimental.
func LambdaLayerVersion_IsTerraformResource ¶
func LambdaLayerVersion_IsTerraformResource(x interface{}) *bool
Experimental.
func LambdaLayerVersion_TfResourceType ¶
func LambdaLayerVersion_TfResourceType() *string
func NewLambdaLayerVersion_Override ¶
func NewLambdaLayerVersion_Override(l LambdaLayerVersion, scope constructs.Construct, id *string, config *LambdaLayerVersionConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lambda_layer_version aws_lambda_layer_version} Resource.
Types ¶
type LambdaLayerVersion ¶
type LambdaLayerVersion interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CompatibleArchitectures() *[]*string
SetCompatibleArchitectures(val *[]*string)
CompatibleArchitecturesInput() *[]*string
CompatibleRuntimes() *[]*string
SetCompatibleRuntimes(val *[]*string)
CompatibleRuntimesInput() *[]*string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreatedDate() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Filename() *string
SetFilename(val *string)
FilenameInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
LayerArn() *string
LayerName() *string
SetLayerName(val *string)
LayerNameInput() *string
LicenseInfo() *string
SetLicenseInfo(val *string)
LicenseInfoInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
S3Bucket() *string
SetS3Bucket(val *string)
S3BucketInput() *string
S3Key() *string
SetS3Key(val *string)
S3KeyInput() *string
S3ObjectVersion() *string
SetS3ObjectVersion(val *string)
S3ObjectVersionInput() *string
SigningJobArn() *string
SigningProfileVersionArn() *string
SkipDestroy() interface{}
SetSkipDestroy(val interface{})
SkipDestroyInput() interface{}
SourceCodeHash() *string
SetSourceCodeHash(val *string)
SourceCodeHashInput() *string
SourceCodeSize() *float64
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Version() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetCompatibleArchitectures()
ResetCompatibleRuntimes()
ResetDescription()
ResetFilename()
ResetId()
ResetLicenseInfo()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetS3Bucket()
ResetS3Key()
ResetS3ObjectVersion()
ResetSkipDestroy()
ResetSourceCodeHash()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lambda_layer_version aws_lambda_layer_version}.
func NewLambdaLayerVersion ¶
func NewLambdaLayerVersion(scope constructs.Construct, id *string, config *LambdaLayerVersionConfig) LambdaLayerVersion
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lambda_layer_version aws_lambda_layer_version} Resource.
type LambdaLayerVersionConfig ¶
type LambdaLayerVersionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lambda_layer_version#layer_name LambdaLayerVersion#layer_name}.
LayerName *string `field:"required" json:"layerName" yaml:"layerName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lambda_layer_version#compatible_architectures LambdaLayerVersion#compatible_architectures}.
CompatibleArchitectures *[]*string `field:"optional" json:"compatibleArchitectures" yaml:"compatibleArchitectures"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lambda_layer_version#compatible_runtimes LambdaLayerVersion#compatible_runtimes}.
CompatibleRuntimes *[]*string `field:"optional" json:"compatibleRuntimes" yaml:"compatibleRuntimes"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lambda_layer_version#description LambdaLayerVersion#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lambda_layer_version#filename LambdaLayerVersion#filename}.
Filename *string `field:"optional" json:"filename" yaml:"filename"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lambda_layer_version#id LambdaLayerVersion#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lambda_layer_version#license_info LambdaLayerVersion#license_info}.
LicenseInfo *string `field:"optional" json:"licenseInfo" yaml:"licenseInfo"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lambda_layer_version#s3_bucket LambdaLayerVersion#s3_bucket}.
S3Bucket *string `field:"optional" json:"s3Bucket" yaml:"s3Bucket"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lambda_layer_version#s3_key LambdaLayerVersion#s3_key}.
S3Key *string `field:"optional" json:"s3Key" yaml:"s3Key"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lambda_layer_version#s3_object_version LambdaLayerVersion#s3_object_version}.
S3ObjectVersion *string `field:"optional" json:"s3ObjectVersion" yaml:"s3ObjectVersion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lambda_layer_version#skip_destroy LambdaLayerVersion#skip_destroy}.
SkipDestroy interface{} `field:"optional" json:"skipDestroy" yaml:"skipDestroy"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lambda_layer_version#source_code_hash LambdaLayerVersion#source_code_hash}.
SourceCodeHash *string `field:"optional" json:"sourceCodeHash" yaml:"sourceCodeHash"`
}