Documentation
¶
Index ¶
- func LbTargetGroup_IsConstruct(x interface{}) *bool
- func LbTargetGroup_IsTerraformElement(x interface{}) *bool
- func LbTargetGroup_IsTerraformResource(x interface{}) *bool
- func LbTargetGroup_TfResourceType() *string
- func NewLbTargetGroupHealthCheckOutputReference_Override(l LbTargetGroupHealthCheckOutputReference, ...)
- func NewLbTargetGroupStickinessOutputReference_Override(l LbTargetGroupStickinessOutputReference, ...)
- func NewLbTargetGroupTargetFailoverList_Override(l LbTargetGroupTargetFailoverList, ...)
- func NewLbTargetGroupTargetFailoverOutputReference_Override(l LbTargetGroupTargetFailoverOutputReference, ...)
- func NewLbTargetGroup_Override(l LbTargetGroup, scope constructs.Construct, id *string, ...)
- type LbTargetGroup
- type LbTargetGroupConfig
- type LbTargetGroupHealthCheck
- type LbTargetGroupHealthCheckOutputReference
- type LbTargetGroupStickiness
- type LbTargetGroupStickinessOutputReference
- type LbTargetGroupTargetFailover
- type LbTargetGroupTargetFailoverList
- type LbTargetGroupTargetFailoverOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LbTargetGroup_IsConstruct ¶
func LbTargetGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func LbTargetGroup_IsTerraformElement ¶
func LbTargetGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func LbTargetGroup_IsTerraformResource ¶
func LbTargetGroup_IsTerraformResource(x interface{}) *bool
Experimental.
func LbTargetGroup_TfResourceType ¶
func LbTargetGroup_TfResourceType() *string
func NewLbTargetGroupHealthCheckOutputReference_Override ¶
func NewLbTargetGroupHealthCheckOutputReference_Override(l LbTargetGroupHealthCheckOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLbTargetGroupStickinessOutputReference_Override ¶
func NewLbTargetGroupStickinessOutputReference_Override(l LbTargetGroupStickinessOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLbTargetGroupTargetFailoverList_Override ¶
func NewLbTargetGroupTargetFailoverList_Override(l LbTargetGroupTargetFailoverList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewLbTargetGroupTargetFailoverOutputReference_Override ¶
func NewLbTargetGroupTargetFailoverOutputReference_Override(l LbTargetGroupTargetFailoverOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewLbTargetGroup_Override ¶
func NewLbTargetGroup_Override(l LbTargetGroup, scope constructs.Construct, id *string, config *LbTargetGroupConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group aws_lb_target_group} Resource.
Types ¶
type LbTargetGroup ¶
type LbTargetGroup interface {
cdktf.TerraformResource
Arn() *string
ArnSuffix() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
ConnectionTermination() interface{}
SetConnectionTermination(val interface{})
ConnectionTerminationInput() interface{}
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeregistrationDelay() *string
SetDeregistrationDelay(val *string)
DeregistrationDelayInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HealthCheck() LbTargetGroupHealthCheckOutputReference
HealthCheckInput() *LbTargetGroupHealthCheck
Id() *string
SetId(val *string)
IdInput() *string
IpAddressType() *string
SetIpAddressType(val *string)
IpAddressTypeInput() *string
LambdaMultiValueHeadersEnabled() interface{}
SetLambdaMultiValueHeadersEnabled(val interface{})
LambdaMultiValueHeadersEnabledInput() interface{}
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LoadBalancingAlgorithmType() *string
SetLoadBalancingAlgorithmType(val *string)
LoadBalancingAlgorithmTypeInput() *string
LoadBalancingCrossZoneEnabled() *string
SetLoadBalancingCrossZoneEnabled(val *string)
LoadBalancingCrossZoneEnabledInput() *string
Name() *string
SetName(val *string)
NameInput() *string
NamePrefix() *string
SetNamePrefix(val *string)
NamePrefixInput() *string
// The tree node.
Node() constructs.Node
Port() *float64
SetPort(val *float64)
PortInput() *float64
PreserveClientIp() *string
SetPreserveClientIp(val *string)
PreserveClientIpInput() *string
Protocol() *string
SetProtocol(val *string)
ProtocolInput() *string
ProtocolVersion() *string
SetProtocolVersion(val *string)
ProtocolVersionInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
ProxyProtocolV2() interface{}
SetProxyProtocolV2(val interface{})
ProxyProtocolV2Input() interface{}
// Experimental.
RawOverrides() interface{}
SlowStart() *float64
SetSlowStart(val *float64)
SlowStartInput() *float64
Stickiness() LbTargetGroupStickinessOutputReference
StickinessInput() *LbTargetGroupStickiness
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
TargetFailover() LbTargetGroupTargetFailoverList
TargetFailoverInput() interface{}
TargetType() *string
SetTargetType(val *string)
TargetTypeInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
VpcId() *string
SetVpcId(val *string)
VpcIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutHealthCheck(value *LbTargetGroupHealthCheck)
PutStickiness(value *LbTargetGroupStickiness)
PutTargetFailover(value interface{})
ResetConnectionTermination()
ResetDeregistrationDelay()
ResetHealthCheck()
ResetId()
ResetIpAddressType()
ResetLambdaMultiValueHeadersEnabled()
ResetLoadBalancingAlgorithmType()
ResetLoadBalancingCrossZoneEnabled()
ResetName()
ResetNamePrefix()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPort()
ResetPreserveClientIp()
ResetProtocol()
ResetProtocolVersion()
ResetProxyProtocolV2()
ResetSlowStart()
ResetStickiness()
ResetTags()
ResetTagsAll()
ResetTargetFailover()
ResetTargetType()
ResetVpcId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group aws_lb_target_group}.
func NewLbTargetGroup ¶
func NewLbTargetGroup(scope constructs.Construct, id *string, config *LbTargetGroupConfig) LbTargetGroup
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group aws_lb_target_group} Resource.
type LbTargetGroupConfig ¶
type LbTargetGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#connection_termination LbTargetGroup#connection_termination}.
ConnectionTermination interface{} `field:"optional" json:"connectionTermination" yaml:"connectionTermination"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#deregistration_delay LbTargetGroup#deregistration_delay}.
DeregistrationDelay *string `field:"optional" json:"deregistrationDelay" yaml:"deregistrationDelay"`
// health_check block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#health_check LbTargetGroup#health_check}
HealthCheck *LbTargetGroupHealthCheck `field:"optional" json:"healthCheck" yaml:"healthCheck"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#id LbTargetGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#ip_address_type LbTargetGroup#ip_address_type}.
IpAddressType *string `field:"optional" json:"ipAddressType" yaml:"ipAddressType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#lambda_multi_value_headers_enabled LbTargetGroup#lambda_multi_value_headers_enabled}.
LambdaMultiValueHeadersEnabled interface{} `field:"optional" json:"lambdaMultiValueHeadersEnabled" yaml:"lambdaMultiValueHeadersEnabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#load_balancing_algorithm_type LbTargetGroup#load_balancing_algorithm_type}.
LoadBalancingAlgorithmType *string `field:"optional" json:"loadBalancingAlgorithmType" yaml:"loadBalancingAlgorithmType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#load_balancing_cross_zone_enabled LbTargetGroup#load_balancing_cross_zone_enabled}.
LoadBalancingCrossZoneEnabled *string `field:"optional" json:"loadBalancingCrossZoneEnabled" yaml:"loadBalancingCrossZoneEnabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#name LbTargetGroup#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#name_prefix LbTargetGroup#name_prefix}.
NamePrefix *string `field:"optional" json:"namePrefix" yaml:"namePrefix"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#port LbTargetGroup#port}.
Port *float64 `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#preserve_client_ip LbTargetGroup#preserve_client_ip}.
PreserveClientIp *string `field:"optional" json:"preserveClientIp" yaml:"preserveClientIp"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#protocol LbTargetGroup#protocol}.
Protocol *string `field:"optional" json:"protocol" yaml:"protocol"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#protocol_version LbTargetGroup#protocol_version}.
ProtocolVersion *string `field:"optional" json:"protocolVersion" yaml:"protocolVersion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#proxy_protocol_v2 LbTargetGroup#proxy_protocol_v2}.
ProxyProtocolV2 interface{} `field:"optional" json:"proxyProtocolV2" yaml:"proxyProtocolV2"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#slow_start LbTargetGroup#slow_start}.
SlowStart *float64 `field:"optional" json:"slowStart" yaml:"slowStart"`
// stickiness block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#stickiness LbTargetGroup#stickiness}
Stickiness *LbTargetGroupStickiness `field:"optional" json:"stickiness" yaml:"stickiness"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#tags LbTargetGroup#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#tags_all LbTargetGroup#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// target_failover block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#target_failover LbTargetGroup#target_failover}
TargetFailover interface{} `field:"optional" json:"targetFailover" yaml:"targetFailover"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#target_type LbTargetGroup#target_type}.
TargetType *string `field:"optional" json:"targetType" yaml:"targetType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#vpc_id LbTargetGroup#vpc_id}.
VpcId *string `field:"optional" json:"vpcId" yaml:"vpcId"`
}
type LbTargetGroupHealthCheck ¶
type LbTargetGroupHealthCheck struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#enabled LbTargetGroup#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#healthy_threshold LbTargetGroup#healthy_threshold}.
HealthyThreshold *float64 `field:"optional" json:"healthyThreshold" yaml:"healthyThreshold"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#interval LbTargetGroup#interval}.
Interval *float64 `field:"optional" json:"interval" yaml:"interval"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#matcher LbTargetGroup#matcher}.
Matcher *string `field:"optional" json:"matcher" yaml:"matcher"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#path LbTargetGroup#path}.
Path *string `field:"optional" json:"path" yaml:"path"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#port LbTargetGroup#port}.
Port *string `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#protocol LbTargetGroup#protocol}.
Protocol *string `field:"optional" json:"protocol" yaml:"protocol"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#timeout LbTargetGroup#timeout}.
Timeout *float64 `field:"optional" json:"timeout" yaml:"timeout"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#unhealthy_threshold LbTargetGroup#unhealthy_threshold}.
UnhealthyThreshold *float64 `field:"optional" json:"unhealthyThreshold" yaml:"unhealthyThreshold"`
}
type LbTargetGroupHealthCheckOutputReference ¶
type LbTargetGroupHealthCheckOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
HealthyThreshold() *float64
SetHealthyThreshold(val *float64)
HealthyThresholdInput() *float64
InternalValue() *LbTargetGroupHealthCheck
SetInternalValue(val *LbTargetGroupHealthCheck)
Interval() *float64
SetInterval(val *float64)
IntervalInput() *float64
Matcher() *string
SetMatcher(val *string)
MatcherInput() *string
Path() *string
SetPath(val *string)
PathInput() *string
Port() *string
SetPort(val *string)
PortInput() *string
Protocol() *string
SetProtocol(val *string)
ProtocolInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Timeout() *float64
SetTimeout(val *float64)
TimeoutInput() *float64
UnhealthyThreshold() *float64
SetUnhealthyThreshold(val *float64)
UnhealthyThresholdInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnabled()
ResetHealthyThreshold()
ResetInterval()
ResetMatcher()
ResetPath()
ResetPort()
ResetProtocol()
ResetTimeout()
ResetUnhealthyThreshold()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLbTargetGroupHealthCheckOutputReference ¶
func NewLbTargetGroupHealthCheckOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LbTargetGroupHealthCheckOutputReference
type LbTargetGroupStickiness ¶
type LbTargetGroupStickiness struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#type LbTargetGroup#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#cookie_duration LbTargetGroup#cookie_duration}.
CookieDuration *float64 `field:"optional" json:"cookieDuration" yaml:"cookieDuration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#cookie_name LbTargetGroup#cookie_name}.
CookieName *string `field:"optional" json:"cookieName" yaml:"cookieName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#enabled LbTargetGroup#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
}
type LbTargetGroupStickinessOutputReference ¶
type LbTargetGroupStickinessOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CookieDuration() *float64
SetCookieDuration(val *float64)
CookieDurationInput() *float64
CookieName() *string
SetCookieName(val *string)
CookieNameInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *LbTargetGroupStickiness
SetInternalValue(val *LbTargetGroupStickiness)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCookieDuration()
ResetCookieName()
ResetEnabled()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLbTargetGroupStickinessOutputReference ¶
func NewLbTargetGroupStickinessOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LbTargetGroupStickinessOutputReference
type LbTargetGroupTargetFailover ¶
type LbTargetGroupTargetFailover struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#on_deregistration LbTargetGroup#on_deregistration}.
OnDeregistration *string `field:"required" json:"onDeregistration" yaml:"onDeregistration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lb_target_group#on_unhealthy LbTargetGroup#on_unhealthy}.
OnUnhealthy *string `field:"required" json:"onUnhealthy" yaml:"onUnhealthy"`
}
type LbTargetGroupTargetFailoverList ¶
type LbTargetGroupTargetFailoverList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) LbTargetGroupTargetFailoverOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLbTargetGroupTargetFailoverList ¶
func NewLbTargetGroupTargetFailoverList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) LbTargetGroupTargetFailoverList
type LbTargetGroupTargetFailoverOutputReference ¶
type LbTargetGroupTargetFailoverOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
OnDeregistration() *string
SetOnDeregistration(val *string)
OnDeregistrationInput() *string
OnUnhealthy() *string
SetOnUnhealthy(val *string)
OnUnhealthyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLbTargetGroupTargetFailoverOutputReference ¶
func NewLbTargetGroupTargetFailoverOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) LbTargetGroupTargetFailoverOutputReference
Source Files
¶
- LbTargetGroup.go
- LbTargetGroupConfig.go
- LbTargetGroupHealthCheck.go
- LbTargetGroupHealthCheckOutputReference.go
- LbTargetGroupHealthCheckOutputReference__checks.go
- LbTargetGroupStickiness.go
- LbTargetGroupStickinessOutputReference.go
- LbTargetGroupStickinessOutputReference__checks.go
- LbTargetGroupTargetFailover.go
- LbTargetGroupTargetFailoverList.go
- LbTargetGroupTargetFailoverList__checks.go
- LbTargetGroupTargetFailoverOutputReference.go
- LbTargetGroupTargetFailoverOutputReference__checks.go
- LbTargetGroup__checks.go
- main.go