Documentation
¶
Index ¶
- func LexBot_IsConstruct(x interface{}) *bool
- func LexBot_IsTerraformElement(x interface{}) *bool
- func LexBot_IsTerraformResource(x interface{}) *bool
- func LexBot_TfResourceType() *string
- func NewLexBotAbortStatementMessageList_Override(l LexBotAbortStatementMessageList, ...)
- func NewLexBotAbortStatementMessageOutputReference_Override(l LexBotAbortStatementMessageOutputReference, ...)
- func NewLexBotAbortStatementOutputReference_Override(l LexBotAbortStatementOutputReference, ...)
- func NewLexBotClarificationPromptMessageList_Override(l LexBotClarificationPromptMessageList, ...)
- func NewLexBotClarificationPromptMessageOutputReference_Override(l LexBotClarificationPromptMessageOutputReference, ...)
- func NewLexBotClarificationPromptOutputReference_Override(l LexBotClarificationPromptOutputReference, ...)
- func NewLexBotIntentList_Override(l LexBotIntentList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewLexBotIntentOutputReference_Override(l LexBotIntentOutputReference, terraformResource cdktf.IInterpolatingParent, ...)
- func NewLexBotTimeoutsOutputReference_Override(l LexBotTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, ...)
- func NewLexBot_Override(l LexBot, scope constructs.Construct, id *string, config *LexBotConfig)
- type LexBot
- type LexBotAbortStatement
- type LexBotAbortStatementMessage
- type LexBotAbortStatementMessageList
- type LexBotAbortStatementMessageOutputReference
- type LexBotAbortStatementOutputReference
- type LexBotClarificationPrompt
- type LexBotClarificationPromptMessage
- type LexBotClarificationPromptMessageList
- type LexBotClarificationPromptMessageOutputReference
- type LexBotClarificationPromptOutputReference
- type LexBotConfig
- type LexBotIntent
- type LexBotIntentList
- type LexBotIntentOutputReference
- type LexBotTimeouts
- type LexBotTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LexBot_IsConstruct ¶
func LexBot_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func LexBot_IsTerraformResource ¶
func LexBot_IsTerraformResource(x interface{}) *bool
Experimental.
func LexBot_TfResourceType ¶
func LexBot_TfResourceType() *string
func NewLexBotAbortStatementMessageList_Override ¶
func NewLexBotAbortStatementMessageList_Override(l LexBotAbortStatementMessageList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewLexBotAbortStatementMessageOutputReference_Override ¶
func NewLexBotAbortStatementMessageOutputReference_Override(l LexBotAbortStatementMessageOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewLexBotAbortStatementOutputReference_Override ¶
func NewLexBotAbortStatementOutputReference_Override(l LexBotAbortStatementOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLexBotClarificationPromptMessageList_Override ¶
func NewLexBotClarificationPromptMessageList_Override(l LexBotClarificationPromptMessageList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewLexBotClarificationPromptMessageOutputReference_Override ¶
func NewLexBotClarificationPromptMessageOutputReference_Override(l LexBotClarificationPromptMessageOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewLexBotClarificationPromptOutputReference_Override ¶
func NewLexBotClarificationPromptOutputReference_Override(l LexBotClarificationPromptOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLexBotIntentList_Override ¶
func NewLexBotIntentList_Override(l LexBotIntentList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewLexBotIntentOutputReference_Override ¶
func NewLexBotIntentOutputReference_Override(l LexBotIntentOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewLexBotTimeoutsOutputReference_Override ¶
func NewLexBotTimeoutsOutputReference_Override(l LexBotTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLexBot_Override ¶
func NewLexBot_Override(l LexBot, scope constructs.Construct, id *string, config *LexBotConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot aws_lex_bot} Resource.
Types ¶
type LexBot ¶
type LexBot interface {
cdktf.TerraformResource
AbortStatement() LexBotAbortStatementOutputReference
AbortStatementInput() *LexBotAbortStatement
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
Checksum() *string
ChildDirected() interface{}
SetChildDirected(val interface{})
ChildDirectedInput() interface{}
ClarificationPrompt() LexBotClarificationPromptOutputReference
ClarificationPromptInput() *LexBotClarificationPrompt
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreatedDate() *string
CreateVersion() interface{}
SetCreateVersion(val interface{})
CreateVersionInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DetectSentiment() interface{}
SetDetectSentiment(val interface{})
DetectSentimentInput() interface{}
EnableModelImprovements() interface{}
SetEnableModelImprovements(val interface{})
EnableModelImprovementsInput() interface{}
FailureReason() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IdleSessionTtlInSeconds() *float64
SetIdleSessionTtlInSeconds(val *float64)
IdleSessionTtlInSecondsInput() *float64
Intent() LexBotIntentList
IntentInput() interface{}
LastUpdatedDate() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Locale() *string
SetLocale(val *string)
LocaleInput() *string
Name() *string
SetName(val *string)
NameInput() *string
NluIntentConfidenceThreshold() *float64
SetNluIntentConfidenceThreshold(val *float64)
NluIntentConfidenceThresholdInput() *float64
// The tree node.
Node() constructs.Node
ProcessBehavior() *string
SetProcessBehavior(val *string)
ProcessBehaviorInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Status() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() LexBotTimeoutsOutputReference
TimeoutsInput() interface{}
Version() *string
VoiceId() *string
SetVoiceId(val *string)
VoiceIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAbortStatement(value *LexBotAbortStatement)
PutClarificationPrompt(value *LexBotClarificationPrompt)
PutIntent(value interface{})
PutTimeouts(value *LexBotTimeouts)
ResetClarificationPrompt()
ResetCreateVersion()
ResetDescription()
ResetDetectSentiment()
ResetEnableModelImprovements()
ResetId()
ResetIdleSessionTtlInSeconds()
ResetLocale()
ResetNluIntentConfidenceThreshold()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProcessBehavior()
ResetTimeouts()
ResetVoiceId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot aws_lex_bot}.
func NewLexBot ¶
func NewLexBot(scope constructs.Construct, id *string, config *LexBotConfig) LexBot
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot aws_lex_bot} Resource.
type LexBotAbortStatement ¶
type LexBotAbortStatement struct {
// message block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#message LexBot#message}
Message interface{} `field:"required" json:"message" yaml:"message"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#response_card LexBot#response_card}.
ResponseCard *string `field:"optional" json:"responseCard" yaml:"responseCard"`
}
type LexBotAbortStatementMessage ¶
type LexBotAbortStatementMessage struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#content LexBot#content}.
Content *string `field:"required" json:"content" yaml:"content"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#content_type LexBot#content_type}.
ContentType *string `field:"required" json:"contentType" yaml:"contentType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#group_number LexBot#group_number}.
GroupNumber *float64 `field:"optional" json:"groupNumber" yaml:"groupNumber"`
}
type LexBotAbortStatementMessageList ¶
type LexBotAbortStatementMessageList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) LexBotAbortStatementMessageOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLexBotAbortStatementMessageList ¶
func NewLexBotAbortStatementMessageList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) LexBotAbortStatementMessageList
type LexBotAbortStatementMessageOutputReference ¶
type LexBotAbortStatementMessageOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Content() *string
SetContent(val *string)
ContentInput() *string
ContentType() *string
SetContentType(val *string)
ContentTypeInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
GroupNumber() *float64
SetGroupNumber(val *float64)
GroupNumberInput() *float64
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetGroupNumber()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLexBotAbortStatementMessageOutputReference ¶
func NewLexBotAbortStatementMessageOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) LexBotAbortStatementMessageOutputReference
type LexBotAbortStatementOutputReference ¶
type LexBotAbortStatementOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LexBotAbortStatement
SetInternalValue(val *LexBotAbortStatement)
Message() LexBotAbortStatementMessageList
MessageInput() interface{}
ResponseCard() *string
SetResponseCard(val *string)
ResponseCardInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutMessage(value interface{})
ResetResponseCard()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLexBotAbortStatementOutputReference ¶
func NewLexBotAbortStatementOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LexBotAbortStatementOutputReference
type LexBotClarificationPrompt ¶
type LexBotClarificationPrompt struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#max_attempts LexBot#max_attempts}.
MaxAttempts *float64 `field:"required" json:"maxAttempts" yaml:"maxAttempts"`
// message block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#message LexBot#message}
Message interface{} `field:"required" json:"message" yaml:"message"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#response_card LexBot#response_card}.
ResponseCard *string `field:"optional" json:"responseCard" yaml:"responseCard"`
}
type LexBotClarificationPromptMessage ¶
type LexBotClarificationPromptMessage struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#content LexBot#content}.
Content *string `field:"required" json:"content" yaml:"content"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#content_type LexBot#content_type}.
ContentType *string `field:"required" json:"contentType" yaml:"contentType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#group_number LexBot#group_number}.
GroupNumber *float64 `field:"optional" json:"groupNumber" yaml:"groupNumber"`
}
type LexBotClarificationPromptMessageList ¶
type LexBotClarificationPromptMessageList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) LexBotClarificationPromptMessageOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLexBotClarificationPromptMessageList ¶
func NewLexBotClarificationPromptMessageList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) LexBotClarificationPromptMessageList
type LexBotClarificationPromptMessageOutputReference ¶
type LexBotClarificationPromptMessageOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Content() *string
SetContent(val *string)
ContentInput() *string
ContentType() *string
SetContentType(val *string)
ContentTypeInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
GroupNumber() *float64
SetGroupNumber(val *float64)
GroupNumberInput() *float64
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetGroupNumber()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLexBotClarificationPromptMessageOutputReference ¶
func NewLexBotClarificationPromptMessageOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) LexBotClarificationPromptMessageOutputReference
type LexBotClarificationPromptOutputReference ¶
type LexBotClarificationPromptOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LexBotClarificationPrompt
SetInternalValue(val *LexBotClarificationPrompt)
MaxAttempts() *float64
SetMaxAttempts(val *float64)
MaxAttemptsInput() *float64
Message() LexBotClarificationPromptMessageList
MessageInput() interface{}
ResponseCard() *string
SetResponseCard(val *string)
ResponseCardInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutMessage(value interface{})
ResetResponseCard()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLexBotClarificationPromptOutputReference ¶
func NewLexBotClarificationPromptOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LexBotClarificationPromptOutputReference
type LexBotConfig ¶
type LexBotConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// abort_statement block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#abort_statement LexBot#abort_statement}
AbortStatement *LexBotAbortStatement `field:"required" json:"abortStatement" yaml:"abortStatement"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#child_directed LexBot#child_directed}.
ChildDirected interface{} `field:"required" json:"childDirected" yaml:"childDirected"`
// intent block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#intent LexBot#intent}
Intent interface{} `field:"required" json:"intent" yaml:"intent"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#name LexBot#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// clarification_prompt block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#clarification_prompt LexBot#clarification_prompt}
ClarificationPrompt *LexBotClarificationPrompt `field:"optional" json:"clarificationPrompt" yaml:"clarificationPrompt"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#create_version LexBot#create_version}.
CreateVersion interface{} `field:"optional" json:"createVersion" yaml:"createVersion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#description LexBot#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#detect_sentiment LexBot#detect_sentiment}.
DetectSentiment interface{} `field:"optional" json:"detectSentiment" yaml:"detectSentiment"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#enable_model_improvements LexBot#enable_model_improvements}.
EnableModelImprovements interface{} `field:"optional" json:"enableModelImprovements" yaml:"enableModelImprovements"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#id LexBot#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#idle_session_ttl_in_seconds LexBot#idle_session_ttl_in_seconds}.
IdleSessionTtlInSeconds *float64 `field:"optional" json:"idleSessionTtlInSeconds" yaml:"idleSessionTtlInSeconds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#locale LexBot#locale}.
Locale *string `field:"optional" json:"locale" yaml:"locale"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#nlu_intent_confidence_threshold LexBot#nlu_intent_confidence_threshold}.
NluIntentConfidenceThreshold *float64 `field:"optional" json:"nluIntentConfidenceThreshold" yaml:"nluIntentConfidenceThreshold"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#process_behavior LexBot#process_behavior}.
ProcessBehavior *string `field:"optional" json:"processBehavior" yaml:"processBehavior"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#timeouts LexBot#timeouts}
Timeouts *LexBotTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#voice_id LexBot#voice_id}.
VoiceId *string `field:"optional" json:"voiceId" yaml:"voiceId"`
}
type LexBotIntent ¶
type LexBotIntent struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#intent_name LexBot#intent_name}.
IntentName *string `field:"required" json:"intentName" yaml:"intentName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#intent_version LexBot#intent_version}.
IntentVersion *string `field:"required" json:"intentVersion" yaml:"intentVersion"`
}
type LexBotIntentList ¶
type LexBotIntentList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) LexBotIntentOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLexBotIntentList ¶
func NewLexBotIntentList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) LexBotIntentList
type LexBotIntentOutputReference ¶
type LexBotIntentOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IntentName() *string
SetIntentName(val *string)
IntentNameInput() *string
IntentVersion() *string
SetIntentVersion(val *string)
IntentVersionInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLexBotIntentOutputReference ¶
func NewLexBotIntentOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) LexBotIntentOutputReference
type LexBotTimeouts ¶
type LexBotTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#create LexBot#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#delete LexBot#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lex_bot#update LexBot#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type LexBotTimeoutsOutputReference ¶
type LexBotTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLexBotTimeoutsOutputReference ¶
func NewLexBotTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LexBotTimeoutsOutputReference
Source Files
¶
- LexBot.go
- LexBotAbortStatement.go
- LexBotAbortStatementMessage.go
- LexBotAbortStatementMessageList.go
- LexBotAbortStatementMessageList__checks.go
- LexBotAbortStatementMessageOutputReference.go
- LexBotAbortStatementMessageOutputReference__checks.go
- LexBotAbortStatementOutputReference.go
- LexBotAbortStatementOutputReference__checks.go
- LexBotClarificationPrompt.go
- LexBotClarificationPromptMessage.go
- LexBotClarificationPromptMessageList.go
- LexBotClarificationPromptMessageList__checks.go
- LexBotClarificationPromptMessageOutputReference.go
- LexBotClarificationPromptMessageOutputReference__checks.go
- LexBotClarificationPromptOutputReference.go
- LexBotClarificationPromptOutputReference__checks.go
- LexBotConfig.go
- LexBotIntent.go
- LexBotIntentList.go
- LexBotIntentList__checks.go
- LexBotIntentOutputReference.go
- LexBotIntentOutputReference__checks.go
- LexBotTimeouts.go
- LexBotTimeoutsOutputReference.go
- LexBotTimeoutsOutputReference__checks.go
- LexBot__checks.go
- main.go