Documentation
¶
Index ¶
- func LightsailDistribution_IsConstruct(x interface{}) *bool
- func LightsailDistribution_IsTerraformElement(x interface{}) *bool
- func LightsailDistribution_IsTerraformResource(x interface{}) *bool
- func LightsailDistribution_TfResourceType() *string
- func NewLightsailDistributionCacheBehaviorList_Override(l LightsailDistributionCacheBehaviorList, ...)
- func NewLightsailDistributionCacheBehaviorOutputReference_Override(l LightsailDistributionCacheBehaviorOutputReference, ...)
- func NewLightsailDistributionCacheBehaviorSettingsForwardedCookiesOutputReference_Override(l LightsailDistributionCacheBehaviorSettingsForwardedCookiesOutputReference, ...)
- func NewLightsailDistributionCacheBehaviorSettingsForwardedHeadersOutputReference_Override(l LightsailDistributionCacheBehaviorSettingsForwardedHeadersOutputReference, ...)
- func NewLightsailDistributionCacheBehaviorSettingsForwardedQueryStringsOutputReference_Override(...)
- func NewLightsailDistributionCacheBehaviorSettingsOutputReference_Override(l LightsailDistributionCacheBehaviorSettingsOutputReference, ...)
- func NewLightsailDistributionDefaultCacheBehaviorOutputReference_Override(l LightsailDistributionDefaultCacheBehaviorOutputReference, ...)
- func NewLightsailDistributionLocationList_Override(l LightsailDistributionLocationList, ...)
- func NewLightsailDistributionLocationOutputReference_Override(l LightsailDistributionLocationOutputReference, ...)
- func NewLightsailDistributionOriginOutputReference_Override(l LightsailDistributionOriginOutputReference, ...)
- func NewLightsailDistributionTimeoutsOutputReference_Override(l LightsailDistributionTimeoutsOutputReference, ...)
- func NewLightsailDistribution_Override(l LightsailDistribution, scope constructs.Construct, id *string, ...)
- type LightsailDistribution
- type LightsailDistributionCacheBehavior
- type LightsailDistributionCacheBehaviorList
- type LightsailDistributionCacheBehaviorOutputReference
- type LightsailDistributionCacheBehaviorSettings
- type LightsailDistributionCacheBehaviorSettingsForwardedCookies
- type LightsailDistributionCacheBehaviorSettingsForwardedCookiesOutputReference
- type LightsailDistributionCacheBehaviorSettingsForwardedHeaders
- type LightsailDistributionCacheBehaviorSettingsForwardedHeadersOutputReference
- type LightsailDistributionCacheBehaviorSettingsForwardedQueryStrings
- type LightsailDistributionCacheBehaviorSettingsForwardedQueryStringsOutputReference
- type LightsailDistributionCacheBehaviorSettingsOutputReference
- type LightsailDistributionConfig
- type LightsailDistributionDefaultCacheBehavior
- type LightsailDistributionDefaultCacheBehaviorOutputReference
- type LightsailDistributionLocation
- type LightsailDistributionLocationList
- type LightsailDistributionLocationOutputReference
- type LightsailDistributionOrigin
- type LightsailDistributionOriginOutputReference
- type LightsailDistributionTimeouts
- type LightsailDistributionTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LightsailDistribution_IsConstruct ¶
func LightsailDistribution_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func LightsailDistribution_IsTerraformElement ¶
func LightsailDistribution_IsTerraformElement(x interface{}) *bool
Experimental.
func LightsailDistribution_IsTerraformResource ¶
func LightsailDistribution_IsTerraformResource(x interface{}) *bool
Experimental.
func LightsailDistribution_TfResourceType ¶
func LightsailDistribution_TfResourceType() *string
func NewLightsailDistributionCacheBehaviorList_Override ¶
func NewLightsailDistributionCacheBehaviorList_Override(l LightsailDistributionCacheBehaviorList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewLightsailDistributionCacheBehaviorOutputReference_Override ¶
func NewLightsailDistributionCacheBehaviorOutputReference_Override(l LightsailDistributionCacheBehaviorOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewLightsailDistributionCacheBehaviorSettingsForwardedCookiesOutputReference_Override ¶
func NewLightsailDistributionCacheBehaviorSettingsForwardedCookiesOutputReference_Override(l LightsailDistributionCacheBehaviorSettingsForwardedCookiesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLightsailDistributionCacheBehaviorSettingsForwardedHeadersOutputReference_Override ¶
func NewLightsailDistributionCacheBehaviorSettingsForwardedHeadersOutputReference_Override(l LightsailDistributionCacheBehaviorSettingsForwardedHeadersOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLightsailDistributionCacheBehaviorSettingsForwardedQueryStringsOutputReference_Override ¶
func NewLightsailDistributionCacheBehaviorSettingsForwardedQueryStringsOutputReference_Override(l LightsailDistributionCacheBehaviorSettingsForwardedQueryStringsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLightsailDistributionCacheBehaviorSettingsOutputReference_Override ¶
func NewLightsailDistributionCacheBehaviorSettingsOutputReference_Override(l LightsailDistributionCacheBehaviorSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLightsailDistributionDefaultCacheBehaviorOutputReference_Override ¶
func NewLightsailDistributionDefaultCacheBehaviorOutputReference_Override(l LightsailDistributionDefaultCacheBehaviorOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLightsailDistributionLocationList_Override ¶
func NewLightsailDistributionLocationList_Override(l LightsailDistributionLocationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewLightsailDistributionLocationOutputReference_Override ¶
func NewLightsailDistributionLocationOutputReference_Override(l LightsailDistributionLocationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewLightsailDistributionOriginOutputReference_Override ¶
func NewLightsailDistributionOriginOutputReference_Override(l LightsailDistributionOriginOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLightsailDistributionTimeoutsOutputReference_Override ¶
func NewLightsailDistributionTimeoutsOutputReference_Override(l LightsailDistributionTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLightsailDistribution_Override ¶
func NewLightsailDistribution_Override(l LightsailDistribution, scope constructs.Construct, id *string, config *LightsailDistributionConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution aws_lightsail_distribution} Resource.
Types ¶
type LightsailDistribution ¶
type LightsailDistribution interface {
cdktf.TerraformResource
AlternativeDomainNames() *[]*string
Arn() *string
BundleId() *string
SetBundleId(val *string)
BundleIdInput() *string
CacheBehavior() LightsailDistributionCacheBehaviorList
CacheBehaviorInput() interface{}
CacheBehaviorSettings() LightsailDistributionCacheBehaviorSettingsOutputReference
CacheBehaviorSettingsInput() *LightsailDistributionCacheBehaviorSettings
// Experimental.
CdktfStack() cdktf.TerraformStack
CertificateName() *string
SetCertificateName(val *string)
CertificateNameInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreatedAt() *string
DefaultCacheBehavior() LightsailDistributionDefaultCacheBehaviorOutputReference
DefaultCacheBehaviorInput() *LightsailDistributionDefaultCacheBehavior
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DomainName() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IpAddressType() *string
SetIpAddressType(val *string)
IpAddressTypeInput() *string
IsEnabled() interface{}
SetIsEnabled(val interface{})
IsEnabledInput() interface{}
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() LightsailDistributionLocationList
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Origin() LightsailDistributionOriginOutputReference
OriginInput() *LightsailDistributionOrigin
OriginPublicDns() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ResourceType() *string
Status() *string
SupportCode() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() LightsailDistributionTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCacheBehavior(value interface{})
PutCacheBehaviorSettings(value *LightsailDistributionCacheBehaviorSettings)
PutDefaultCacheBehavior(value *LightsailDistributionDefaultCacheBehavior)
PutOrigin(value *LightsailDistributionOrigin)
PutTimeouts(value *LightsailDistributionTimeouts)
ResetCacheBehavior()
ResetCacheBehaviorSettings()
ResetCertificateName()
ResetId()
ResetIpAddressType()
ResetIsEnabled()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution aws_lightsail_distribution}.
func NewLightsailDistribution ¶
func NewLightsailDistribution(scope constructs.Construct, id *string, config *LightsailDistributionConfig) LightsailDistribution
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution aws_lightsail_distribution} Resource.
type LightsailDistributionCacheBehavior ¶
type LightsailDistributionCacheBehavior struct {
// The cache behavior for the specified path.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#behavior LightsailDistribution#behavior}
Behavior *string `field:"required" json:"behavior" yaml:"behavior"`
// The path to a directory or file to cached, or not cache.
//
// Use an asterisk symbol to specify wildcard directories (path/to/assets/*), and file types (*.html, *jpg, *js). Directories and file paths are case-sensitive.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#path LightsailDistribution#path}
Path *string `field:"required" json:"path" yaml:"path"`
}
type LightsailDistributionCacheBehaviorList ¶
type LightsailDistributionCacheBehaviorList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) LightsailDistributionCacheBehaviorOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailDistributionCacheBehaviorList ¶
func NewLightsailDistributionCacheBehaviorList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) LightsailDistributionCacheBehaviorList
type LightsailDistributionCacheBehaviorOutputReference ¶
type LightsailDistributionCacheBehaviorOutputReference interface {
cdktf.ComplexObject
Behavior() *string
SetBehavior(val *string)
BehaviorInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Path() *string
SetPath(val *string)
PathInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailDistributionCacheBehaviorOutputReference ¶
func NewLightsailDistributionCacheBehaviorOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) LightsailDistributionCacheBehaviorOutputReference
type LightsailDistributionCacheBehaviorSettings ¶
type LightsailDistributionCacheBehaviorSettings struct {
// The HTTP methods that are processed and forwarded to the distribution's origin.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#allowed_http_methods LightsailDistribution#allowed_http_methods}
AllowedHttpMethods *string `field:"optional" json:"allowedHttpMethods" yaml:"allowedHttpMethods"`
// The HTTP method responses that are cached by your distribution.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#cached_http_methods LightsailDistribution#cached_http_methods}
CachedHttpMethods *string `field:"optional" json:"cachedHttpMethods" yaml:"cachedHttpMethods"`
// The default amount of time that objects stay in the distribution's cache before the distribution forwards another request to the origin to determine whether the content has been updated.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#default_ttl LightsailDistribution#default_ttl}
DefaultTtl *float64 `field:"optional" json:"defaultTtl" yaml:"defaultTtl"`
// forwarded_cookies block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#forwarded_cookies LightsailDistribution#forwarded_cookies}
ForwardedCookies *LightsailDistributionCacheBehaviorSettingsForwardedCookies `field:"optional" json:"forwardedCookies" yaml:"forwardedCookies"`
// forwarded_headers block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#forwarded_headers LightsailDistribution#forwarded_headers}
ForwardedHeaders *LightsailDistributionCacheBehaviorSettingsForwardedHeaders `field:"optional" json:"forwardedHeaders" yaml:"forwardedHeaders"`
// forwarded_query_strings block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#forwarded_query_strings LightsailDistribution#forwarded_query_strings}
ForwardedQueryStrings *LightsailDistributionCacheBehaviorSettingsForwardedQueryStrings `field:"optional" json:"forwardedQueryStrings" yaml:"forwardedQueryStrings"`
// The maximum amount of time that objects stay in the distribution's cache before the distribution forwards another request to the origin to determine whether the object has been updated.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#maximum_ttl LightsailDistribution#maximum_ttl}
MaximumTtl *float64 `field:"optional" json:"maximumTtl" yaml:"maximumTtl"`
// The minimum amount of time that objects stay in the distribution's cache before the distribution forwards another request to the origin to determine whether the object has been updated.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#minimum_ttl LightsailDistribution#minimum_ttl}
MinimumTtl *float64 `field:"optional" json:"minimumTtl" yaml:"minimumTtl"`
}
type LightsailDistributionCacheBehaviorSettingsForwardedCookies ¶
type LightsailDistributionCacheBehaviorSettingsForwardedCookies struct {
// The specific cookies to forward to your distribution's origin.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#cookies_allow_list LightsailDistribution#cookies_allow_list}
CookiesAllowList *[]*string `field:"optional" json:"cookiesAllowList" yaml:"cookiesAllowList"`
// Specifies which cookies to forward to the distribution's origin for a cache behavior: all, none, or allow-list to forward only the cookies specified in the cookiesAllowList parameter.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#option LightsailDistribution#option}
Option *string `field:"optional" json:"option" yaml:"option"`
}
type LightsailDistributionCacheBehaviorSettingsForwardedCookiesOutputReference ¶
type LightsailDistributionCacheBehaviorSettingsForwardedCookiesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CookiesAllowList() *[]*string
SetCookiesAllowList(val *[]*string)
CookiesAllowListInput() *[]*string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LightsailDistributionCacheBehaviorSettingsForwardedCookies
SetInternalValue(val *LightsailDistributionCacheBehaviorSettingsForwardedCookies)
Option() *string
SetOption(val *string)
OptionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCookiesAllowList()
ResetOption()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailDistributionCacheBehaviorSettingsForwardedCookiesOutputReference ¶
func NewLightsailDistributionCacheBehaviorSettingsForwardedCookiesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LightsailDistributionCacheBehaviorSettingsForwardedCookiesOutputReference
type LightsailDistributionCacheBehaviorSettingsForwardedHeaders ¶
type LightsailDistributionCacheBehaviorSettingsForwardedHeaders struct {
// The specific headers to forward to your distribution's origin.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#headers_allow_list LightsailDistribution#headers_allow_list}
HeadersAllowList *[]*string `field:"optional" json:"headersAllowList" yaml:"headersAllowList"`
// The headers that you want your distribution to forward to your origin and base caching on.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#option LightsailDistribution#option}
Option *string `field:"optional" json:"option" yaml:"option"`
}
type LightsailDistributionCacheBehaviorSettingsForwardedHeadersOutputReference ¶
type LightsailDistributionCacheBehaviorSettingsForwardedHeadersOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HeadersAllowList() *[]*string
SetHeadersAllowList(val *[]*string)
HeadersAllowListInput() *[]*string
InternalValue() *LightsailDistributionCacheBehaviorSettingsForwardedHeaders
SetInternalValue(val *LightsailDistributionCacheBehaviorSettingsForwardedHeaders)
Option() *string
SetOption(val *string)
OptionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetHeadersAllowList()
ResetOption()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailDistributionCacheBehaviorSettingsForwardedHeadersOutputReference ¶
func NewLightsailDistributionCacheBehaviorSettingsForwardedHeadersOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LightsailDistributionCacheBehaviorSettingsForwardedHeadersOutputReference
type LightsailDistributionCacheBehaviorSettingsForwardedQueryStrings ¶
type LightsailDistributionCacheBehaviorSettingsForwardedQueryStrings struct {
// Indicates whether the distribution forwards and caches based on query strings.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#option LightsailDistribution#option}
Option interface{} `field:"optional" json:"option" yaml:"option"`
// The specific query strings that the distribution forwards to the origin.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#query_strings_allowed_list LightsailDistribution#query_strings_allowed_list}
QueryStringsAllowedList *[]*string `field:"optional" json:"queryStringsAllowedList" yaml:"queryStringsAllowedList"`
}
type LightsailDistributionCacheBehaviorSettingsForwardedQueryStringsOutputReference ¶
type LightsailDistributionCacheBehaviorSettingsForwardedQueryStringsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LightsailDistributionCacheBehaviorSettingsForwardedQueryStrings
SetInternalValue(val *LightsailDistributionCacheBehaviorSettingsForwardedQueryStrings)
Option() interface{}
SetOption(val interface{})
OptionInput() interface{}
QueryStringsAllowedList() *[]*string
SetQueryStringsAllowedList(val *[]*string)
QueryStringsAllowedListInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetOption()
ResetQueryStringsAllowedList()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailDistributionCacheBehaviorSettingsForwardedQueryStringsOutputReference ¶
func NewLightsailDistributionCacheBehaviorSettingsForwardedQueryStringsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LightsailDistributionCacheBehaviorSettingsForwardedQueryStringsOutputReference
type LightsailDistributionCacheBehaviorSettingsOutputReference ¶
type LightsailDistributionCacheBehaviorSettingsOutputReference interface {
cdktf.ComplexObject
AllowedHttpMethods() *string
SetAllowedHttpMethods(val *string)
AllowedHttpMethodsInput() *string
CachedHttpMethods() *string
SetCachedHttpMethods(val *string)
CachedHttpMethodsInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DefaultTtl() *float64
SetDefaultTtl(val *float64)
DefaultTtlInput() *float64
ForwardedCookies() LightsailDistributionCacheBehaviorSettingsForwardedCookiesOutputReference
ForwardedCookiesInput() *LightsailDistributionCacheBehaviorSettingsForwardedCookies
ForwardedHeaders() LightsailDistributionCacheBehaviorSettingsForwardedHeadersOutputReference
ForwardedHeadersInput() *LightsailDistributionCacheBehaviorSettingsForwardedHeaders
ForwardedQueryStrings() LightsailDistributionCacheBehaviorSettingsForwardedQueryStringsOutputReference
ForwardedQueryStringsInput() *LightsailDistributionCacheBehaviorSettingsForwardedQueryStrings
// Experimental.
Fqn() *string
InternalValue() *LightsailDistributionCacheBehaviorSettings
SetInternalValue(val *LightsailDistributionCacheBehaviorSettings)
MaximumTtl() *float64
SetMaximumTtl(val *float64)
MaximumTtlInput() *float64
MinimumTtl() *float64
SetMinimumTtl(val *float64)
MinimumTtlInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutForwardedCookies(value *LightsailDistributionCacheBehaviorSettingsForwardedCookies)
PutForwardedHeaders(value *LightsailDistributionCacheBehaviorSettingsForwardedHeaders)
PutForwardedQueryStrings(value *LightsailDistributionCacheBehaviorSettingsForwardedQueryStrings)
ResetAllowedHttpMethods()
ResetCachedHttpMethods()
ResetDefaultTtl()
ResetForwardedCookies()
ResetForwardedHeaders()
ResetForwardedQueryStrings()
ResetMaximumTtl()
ResetMinimumTtl()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailDistributionCacheBehaviorSettingsOutputReference ¶
func NewLightsailDistributionCacheBehaviorSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LightsailDistributionCacheBehaviorSettingsOutputReference
type LightsailDistributionConfig ¶
type LightsailDistributionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The bundle ID to use for the distribution.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#bundle_id LightsailDistribution#bundle_id}
BundleId *string `field:"required" json:"bundleId" yaml:"bundleId"`
// default_cache_behavior block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#default_cache_behavior LightsailDistribution#default_cache_behavior}
DefaultCacheBehavior *LightsailDistributionDefaultCacheBehavior `field:"required" json:"defaultCacheBehavior" yaml:"defaultCacheBehavior"`
// The name of the distribution.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#name LightsailDistribution#name}
Name *string `field:"required" json:"name" yaml:"name"`
// origin block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#origin LightsailDistribution#origin}
Origin *LightsailDistributionOrigin `field:"required" json:"origin" yaml:"origin"`
// cache_behavior block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#cache_behavior LightsailDistribution#cache_behavior}
CacheBehavior interface{} `field:"optional" json:"cacheBehavior" yaml:"cacheBehavior"`
// cache_behavior_settings block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#cache_behavior_settings LightsailDistribution#cache_behavior_settings}
CacheBehaviorSettings *LightsailDistributionCacheBehaviorSettings `field:"optional" json:"cacheBehaviorSettings" yaml:"cacheBehaviorSettings"`
// The name of the SSL/TLS certificate attached to the distribution, if any.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#certificate_name LightsailDistribution#certificate_name}
CertificateName *string `field:"optional" json:"certificateName" yaml:"certificateName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#id LightsailDistribution#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// The IP address type of the distribution.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#ip_address_type LightsailDistribution#ip_address_type}
IpAddressType *string `field:"optional" json:"ipAddressType" yaml:"ipAddressType"`
// Indicates whether the distribution is enabled.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#is_enabled LightsailDistribution#is_enabled}
IsEnabled interface{} `field:"optional" json:"isEnabled" yaml:"isEnabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#tags LightsailDistribution#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#tags_all LightsailDistribution#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#timeouts LightsailDistribution#timeouts}
Timeouts *LightsailDistributionTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type LightsailDistributionDefaultCacheBehavior ¶
type LightsailDistributionDefaultCacheBehavior struct {
// The cache behavior of the distribution.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#behavior LightsailDistribution#behavior}
Behavior *string `field:"required" json:"behavior" yaml:"behavior"`
}
type LightsailDistributionDefaultCacheBehaviorOutputReference ¶
type LightsailDistributionDefaultCacheBehaviorOutputReference interface {
cdktf.ComplexObject
Behavior() *string
SetBehavior(val *string)
BehaviorInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LightsailDistributionDefaultCacheBehavior
SetInternalValue(val *LightsailDistributionDefaultCacheBehavior)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailDistributionDefaultCacheBehaviorOutputReference ¶
func NewLightsailDistributionDefaultCacheBehaviorOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LightsailDistributionDefaultCacheBehaviorOutputReference
type LightsailDistributionLocation ¶
type LightsailDistributionLocation struct {
}
type LightsailDistributionLocationList ¶
type LightsailDistributionLocationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) LightsailDistributionLocationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailDistributionLocationList ¶
func NewLightsailDistributionLocationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) LightsailDistributionLocationList
type LightsailDistributionLocationOutputReference ¶
type LightsailDistributionLocationOutputReference interface {
cdktf.ComplexObject
AvailabilityZone() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LightsailDistributionLocation
SetInternalValue(val *LightsailDistributionLocation)
RegionName() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailDistributionLocationOutputReference ¶
func NewLightsailDistributionLocationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) LightsailDistributionLocationOutputReference
type LightsailDistributionOrigin ¶
type LightsailDistributionOrigin struct {
// The name of the origin resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#name LightsailDistribution#name}
Name *string `field:"required" json:"name" yaml:"name"`
// The AWS Region name of the origin resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#region_name LightsailDistribution#region_name}
RegionName *string `field:"required" json:"regionName" yaml:"regionName"`
// The protocol that your Amazon Lightsail distribution uses when establishing a connection with your origin to pull content.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#protocol_policy LightsailDistribution#protocol_policy}
ProtocolPolicy *string `field:"optional" json:"protocolPolicy" yaml:"protocolPolicy"`
}
type LightsailDistributionOriginOutputReference ¶
type LightsailDistributionOriginOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LightsailDistributionOrigin
SetInternalValue(val *LightsailDistributionOrigin)
Name() *string
SetName(val *string)
NameInput() *string
ProtocolPolicy() *string
SetProtocolPolicy(val *string)
ProtocolPolicyInput() *string
RegionName() *string
SetRegionName(val *string)
RegionNameInput() *string
ResourceType() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetProtocolPolicy()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailDistributionOriginOutputReference ¶
func NewLightsailDistributionOriginOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LightsailDistributionOriginOutputReference
type LightsailDistributionTimeouts ¶
type LightsailDistributionTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#create LightsailDistribution#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#delete LightsailDistribution#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_distribution#update LightsailDistribution#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type LightsailDistributionTimeoutsOutputReference ¶
type LightsailDistributionTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailDistributionTimeoutsOutputReference ¶
func NewLightsailDistributionTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LightsailDistributionTimeoutsOutputReference
Source Files
¶
- LightsailDistribution.go
- LightsailDistributionCacheBehavior.go
- LightsailDistributionCacheBehaviorList.go
- LightsailDistributionCacheBehaviorList__checks.go
- LightsailDistributionCacheBehaviorOutputReference.go
- LightsailDistributionCacheBehaviorOutputReference__checks.go
- LightsailDistributionCacheBehaviorSettings.go
- LightsailDistributionCacheBehaviorSettingsForwardedCookies.go
- LightsailDistributionCacheBehaviorSettingsForwardedCookiesOutputReference.go
- LightsailDistributionCacheBehaviorSettingsForwardedCookiesOutputReference__checks.go
- LightsailDistributionCacheBehaviorSettingsForwardedHeaders.go
- LightsailDistributionCacheBehaviorSettingsForwardedHeadersOutputReference.go
- LightsailDistributionCacheBehaviorSettingsForwardedHeadersOutputReference__checks.go
- LightsailDistributionCacheBehaviorSettingsForwardedQueryStrings.go
- LightsailDistributionCacheBehaviorSettingsForwardedQueryStringsOutputReference.go
- LightsailDistributionCacheBehaviorSettingsForwardedQueryStringsOutputReference__checks.go
- LightsailDistributionCacheBehaviorSettingsOutputReference.go
- LightsailDistributionCacheBehaviorSettingsOutputReference__checks.go
- LightsailDistributionConfig.go
- LightsailDistributionDefaultCacheBehavior.go
- LightsailDistributionDefaultCacheBehaviorOutputReference.go
- LightsailDistributionDefaultCacheBehaviorOutputReference__checks.go
- LightsailDistributionLocation.go
- LightsailDistributionLocationList.go
- LightsailDistributionLocationList__checks.go
- LightsailDistributionLocationOutputReference.go
- LightsailDistributionLocationOutputReference__checks.go
- LightsailDistributionOrigin.go
- LightsailDistributionOriginOutputReference.go
- LightsailDistributionOriginOutputReference__checks.go
- LightsailDistributionTimeouts.go
- LightsailDistributionTimeoutsOutputReference.go
- LightsailDistributionTimeoutsOutputReference__checks.go
- LightsailDistribution__checks.go
- main.go