Documentation
¶
Index ¶
- func LightsailInstancePublicPorts_IsConstruct(x interface{}) *bool
- func LightsailInstancePublicPorts_IsTerraformElement(x interface{}) *bool
- func LightsailInstancePublicPorts_IsTerraformResource(x interface{}) *bool
- func LightsailInstancePublicPorts_TfResourceType() *string
- func NewLightsailInstancePublicPortsPortInfoList_Override(l LightsailInstancePublicPortsPortInfoList, ...)
- func NewLightsailInstancePublicPortsPortInfoOutputReference_Override(l LightsailInstancePublicPortsPortInfoOutputReference, ...)
- func NewLightsailInstancePublicPorts_Override(l LightsailInstancePublicPorts, scope constructs.Construct, id *string, ...)
- type LightsailInstancePublicPorts
- type LightsailInstancePublicPortsConfig
- type LightsailInstancePublicPortsPortInfo
- type LightsailInstancePublicPortsPortInfoList
- type LightsailInstancePublicPortsPortInfoOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LightsailInstancePublicPorts_IsConstruct ¶
func LightsailInstancePublicPorts_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func LightsailInstancePublicPorts_IsTerraformElement ¶
func LightsailInstancePublicPorts_IsTerraformElement(x interface{}) *bool
Experimental.
func LightsailInstancePublicPorts_IsTerraformResource ¶
func LightsailInstancePublicPorts_IsTerraformResource(x interface{}) *bool
Experimental.
func LightsailInstancePublicPorts_TfResourceType ¶
func LightsailInstancePublicPorts_TfResourceType() *string
func NewLightsailInstancePublicPortsPortInfoList_Override ¶
func NewLightsailInstancePublicPortsPortInfoList_Override(l LightsailInstancePublicPortsPortInfoList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewLightsailInstancePublicPortsPortInfoOutputReference_Override ¶
func NewLightsailInstancePublicPortsPortInfoOutputReference_Override(l LightsailInstancePublicPortsPortInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewLightsailInstancePublicPorts_Override ¶
func NewLightsailInstancePublicPorts_Override(l LightsailInstancePublicPorts, scope constructs.Construct, id *string, config *LightsailInstancePublicPortsConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_instance_public_ports aws_lightsail_instance_public_ports} Resource.
Types ¶
type LightsailInstancePublicPorts ¶
type LightsailInstancePublicPorts interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InstanceName() *string
SetInstanceName(val *string)
InstanceNameInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
PortInfo() LightsailInstancePublicPortsPortInfoList
PortInfoInput() interface{}
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutPortInfo(value interface{})
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_instance_public_ports aws_lightsail_instance_public_ports}.
func NewLightsailInstancePublicPorts ¶
func NewLightsailInstancePublicPorts(scope constructs.Construct, id *string, config *LightsailInstancePublicPortsConfig) LightsailInstancePublicPorts
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_instance_public_ports aws_lightsail_instance_public_ports} Resource.
type LightsailInstancePublicPortsConfig ¶
type LightsailInstancePublicPortsConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_instance_public_ports#instance_name LightsailInstancePublicPorts#instance_name}.
InstanceName *string `field:"required" json:"instanceName" yaml:"instanceName"`
// port_info block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_instance_public_ports#port_info LightsailInstancePublicPorts#port_info}
PortInfo interface{} `field:"required" json:"portInfo" yaml:"portInfo"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_instance_public_ports#id LightsailInstancePublicPorts#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type LightsailInstancePublicPortsPortInfo ¶
type LightsailInstancePublicPortsPortInfo struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_instance_public_ports#from_port LightsailInstancePublicPorts#from_port}.
FromPort *float64 `field:"required" json:"fromPort" yaml:"fromPort"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_instance_public_ports#protocol LightsailInstancePublicPorts#protocol}.
Protocol *string `field:"required" json:"protocol" yaml:"protocol"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_instance_public_ports#to_port LightsailInstancePublicPorts#to_port}.
ToPort *float64 `field:"required" json:"toPort" yaml:"toPort"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_instance_public_ports#cidr_list_aliases LightsailInstancePublicPorts#cidr_list_aliases}.
CidrListAliases *[]*string `field:"optional" json:"cidrListAliases" yaml:"cidrListAliases"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_instance_public_ports#cidrs LightsailInstancePublicPorts#cidrs}.
Cidrs *[]*string `field:"optional" json:"cidrs" yaml:"cidrs"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/lightsail_instance_public_ports#ipv6_cidrs LightsailInstancePublicPorts#ipv6_cidrs}.
Ipv6Cidrs *[]*string `field:"optional" json:"ipv6Cidrs" yaml:"ipv6Cidrs"`
}
type LightsailInstancePublicPortsPortInfoList ¶
type LightsailInstancePublicPortsPortInfoList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) LightsailInstancePublicPortsPortInfoOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailInstancePublicPortsPortInfoList ¶
func NewLightsailInstancePublicPortsPortInfoList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) LightsailInstancePublicPortsPortInfoList
type LightsailInstancePublicPortsPortInfoOutputReference ¶
type LightsailInstancePublicPortsPortInfoOutputReference interface {
cdktf.ComplexObject
CidrListAliases() *[]*string
SetCidrListAliases(val *[]*string)
CidrListAliasesInput() *[]*string
Cidrs() *[]*string
SetCidrs(val *[]*string)
CidrsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
FromPort() *float64
SetFromPort(val *float64)
FromPortInput() *float64
InternalValue() interface{}
SetInternalValue(val interface{})
Ipv6Cidrs() *[]*string
SetIpv6Cidrs(val *[]*string)
Ipv6CidrsInput() *[]*string
Protocol() *string
SetProtocol(val *string)
ProtocolInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ToPort() *float64
SetToPort(val *float64)
ToPortInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCidrListAliases()
ResetCidrs()
ResetIpv6Cidrs()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLightsailInstancePublicPortsPortInfoOutputReference ¶
func NewLightsailInstancePublicPortsPortInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) LightsailInstancePublicPortsPortInfoOutputReference
Source Files
¶
- LightsailInstancePublicPorts.go
- LightsailInstancePublicPortsConfig.go
- LightsailInstancePublicPortsPortInfo.go
- LightsailInstancePublicPortsPortInfoList.go
- LightsailInstancePublicPortsPortInfoList__checks.go
- LightsailInstancePublicPortsPortInfoOutputReference.go
- LightsailInstancePublicPortsPortInfoOutputReference__checks.go
- LightsailInstancePublicPorts__checks.go
- main.go