Documentation
¶
Index ¶
- func NewOpensearchOutboundConnectionLocalDomainInfoOutputReference_Override(o OpensearchOutboundConnectionLocalDomainInfoOutputReference, ...)
- func NewOpensearchOutboundConnectionRemoteDomainInfoOutputReference_Override(o OpensearchOutboundConnectionRemoteDomainInfoOutputReference, ...)
- func NewOpensearchOutboundConnectionTimeoutsOutputReference_Override(o OpensearchOutboundConnectionTimeoutsOutputReference, ...)
- func NewOpensearchOutboundConnection_Override(o OpensearchOutboundConnection, scope constructs.Construct, id *string, ...)
- func OpensearchOutboundConnection_IsConstruct(x interface{}) *bool
- func OpensearchOutboundConnection_IsTerraformElement(x interface{}) *bool
- func OpensearchOutboundConnection_IsTerraformResource(x interface{}) *bool
- func OpensearchOutboundConnection_TfResourceType() *string
- type OpensearchOutboundConnection
- type OpensearchOutboundConnectionConfig
- type OpensearchOutboundConnectionLocalDomainInfo
- type OpensearchOutboundConnectionLocalDomainInfoOutputReference
- type OpensearchOutboundConnectionRemoteDomainInfo
- type OpensearchOutboundConnectionRemoteDomainInfoOutputReference
- type OpensearchOutboundConnectionTimeouts
- type OpensearchOutboundConnectionTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewOpensearchOutboundConnectionLocalDomainInfoOutputReference_Override ¶
func NewOpensearchOutboundConnectionLocalDomainInfoOutputReference_Override(o OpensearchOutboundConnectionLocalDomainInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpensearchOutboundConnectionRemoteDomainInfoOutputReference_Override ¶
func NewOpensearchOutboundConnectionRemoteDomainInfoOutputReference_Override(o OpensearchOutboundConnectionRemoteDomainInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpensearchOutboundConnectionTimeoutsOutputReference_Override ¶
func NewOpensearchOutboundConnectionTimeoutsOutputReference_Override(o OpensearchOutboundConnectionTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewOpensearchOutboundConnection_Override ¶
func NewOpensearchOutboundConnection_Override(o OpensearchOutboundConnection, scope constructs.Construct, id *string, config *OpensearchOutboundConnectionConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/opensearch_outbound_connection aws_opensearch_outbound_connection} Resource.
func OpensearchOutboundConnection_IsConstruct ¶
func OpensearchOutboundConnection_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func OpensearchOutboundConnection_IsTerraformElement ¶
func OpensearchOutboundConnection_IsTerraformElement(x interface{}) *bool
Experimental.
func OpensearchOutboundConnection_IsTerraformResource ¶
func OpensearchOutboundConnection_IsTerraformResource(x interface{}) *bool
Experimental.
func OpensearchOutboundConnection_TfResourceType ¶
func OpensearchOutboundConnection_TfResourceType() *string
Types ¶
type OpensearchOutboundConnection ¶
type OpensearchOutboundConnection interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
ConnectionAlias() *string
SetConnectionAlias(val *string)
ConnectionAliasInput() *string
ConnectionStatus() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LocalDomainInfo() OpensearchOutboundConnectionLocalDomainInfoOutputReference
LocalDomainInfoInput() *OpensearchOutboundConnectionLocalDomainInfo
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RemoteDomainInfo() OpensearchOutboundConnectionRemoteDomainInfoOutputReference
RemoteDomainInfoInput() *OpensearchOutboundConnectionRemoteDomainInfo
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() OpensearchOutboundConnectionTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutLocalDomainInfo(value *OpensearchOutboundConnectionLocalDomainInfo)
PutRemoteDomainInfo(value *OpensearchOutboundConnectionRemoteDomainInfo)
PutTimeouts(value *OpensearchOutboundConnectionTimeouts)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/opensearch_outbound_connection aws_opensearch_outbound_connection}.
func NewOpensearchOutboundConnection ¶
func NewOpensearchOutboundConnection(scope constructs.Construct, id *string, config *OpensearchOutboundConnectionConfig) OpensearchOutboundConnection
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/opensearch_outbound_connection aws_opensearch_outbound_connection} Resource.
type OpensearchOutboundConnectionConfig ¶
type OpensearchOutboundConnectionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/opensearch_outbound_connection#connection_alias OpensearchOutboundConnection#connection_alias}.
ConnectionAlias *string `field:"required" json:"connectionAlias" yaml:"connectionAlias"`
// local_domain_info block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/opensearch_outbound_connection#local_domain_info OpensearchOutboundConnection#local_domain_info}
LocalDomainInfo *OpensearchOutboundConnectionLocalDomainInfo `field:"required" json:"localDomainInfo" yaml:"localDomainInfo"`
// remote_domain_info block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/opensearch_outbound_connection#remote_domain_info OpensearchOutboundConnection#remote_domain_info}
RemoteDomainInfo *OpensearchOutboundConnectionRemoteDomainInfo `field:"required" json:"remoteDomainInfo" yaml:"remoteDomainInfo"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/opensearch_outbound_connection#id OpensearchOutboundConnection#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/opensearch_outbound_connection#timeouts OpensearchOutboundConnection#timeouts}
Timeouts *OpensearchOutboundConnectionTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type OpensearchOutboundConnectionLocalDomainInfo ¶
type OpensearchOutboundConnectionLocalDomainInfo struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/opensearch_outbound_connection#domain_name OpensearchOutboundConnection#domain_name}.
DomainName *string `field:"required" json:"domainName" yaml:"domainName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/opensearch_outbound_connection#owner_id OpensearchOutboundConnection#owner_id}.
OwnerId *string `field:"required" json:"ownerId" yaml:"ownerId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/opensearch_outbound_connection#region OpensearchOutboundConnection#region}.
Region *string `field:"required" json:"region" yaml:"region"`
}
type OpensearchOutboundConnectionLocalDomainInfoOutputReference ¶
type OpensearchOutboundConnectionLocalDomainInfoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DomainName() *string
SetDomainName(val *string)
DomainNameInput() *string
// Experimental.
Fqn() *string
InternalValue() *OpensearchOutboundConnectionLocalDomainInfo
SetInternalValue(val *OpensearchOutboundConnectionLocalDomainInfo)
OwnerId() *string
SetOwnerId(val *string)
OwnerIdInput() *string
Region() *string
SetRegion(val *string)
RegionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpensearchOutboundConnectionLocalDomainInfoOutputReference ¶
func NewOpensearchOutboundConnectionLocalDomainInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpensearchOutboundConnectionLocalDomainInfoOutputReference
type OpensearchOutboundConnectionRemoteDomainInfo ¶
type OpensearchOutboundConnectionRemoteDomainInfo struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/opensearch_outbound_connection#domain_name OpensearchOutboundConnection#domain_name}.
DomainName *string `field:"required" json:"domainName" yaml:"domainName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/opensearch_outbound_connection#owner_id OpensearchOutboundConnection#owner_id}.
OwnerId *string `field:"required" json:"ownerId" yaml:"ownerId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/opensearch_outbound_connection#region OpensearchOutboundConnection#region}.
Region *string `field:"required" json:"region" yaml:"region"`
}
type OpensearchOutboundConnectionRemoteDomainInfoOutputReference ¶
type OpensearchOutboundConnectionRemoteDomainInfoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DomainName() *string
SetDomainName(val *string)
DomainNameInput() *string
// Experimental.
Fqn() *string
InternalValue() *OpensearchOutboundConnectionRemoteDomainInfo
SetInternalValue(val *OpensearchOutboundConnectionRemoteDomainInfo)
OwnerId() *string
SetOwnerId(val *string)
OwnerIdInput() *string
Region() *string
SetRegion(val *string)
RegionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpensearchOutboundConnectionRemoteDomainInfoOutputReference ¶
func NewOpensearchOutboundConnectionRemoteDomainInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpensearchOutboundConnectionRemoteDomainInfoOutputReference
type OpensearchOutboundConnectionTimeouts ¶
type OpensearchOutboundConnectionTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/opensearch_outbound_connection#create OpensearchOutboundConnection#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/opensearch_outbound_connection#delete OpensearchOutboundConnection#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type OpensearchOutboundConnectionTimeoutsOutputReference ¶
type OpensearchOutboundConnectionTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewOpensearchOutboundConnectionTimeoutsOutputReference ¶
func NewOpensearchOutboundConnectionTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) OpensearchOutboundConnectionTimeoutsOutputReference
Source Files
¶
- OpensearchOutboundConnection.go
- OpensearchOutboundConnectionConfig.go
- OpensearchOutboundConnectionLocalDomainInfo.go
- OpensearchOutboundConnectionLocalDomainInfoOutputReference.go
- OpensearchOutboundConnectionLocalDomainInfoOutputReference__checks.go
- OpensearchOutboundConnectionRemoteDomainInfo.go
- OpensearchOutboundConnectionRemoteDomainInfoOutputReference.go
- OpensearchOutboundConnectionRemoteDomainInfoOutputReference__checks.go
- OpensearchOutboundConnectionTimeouts.go
- OpensearchOutboundConnectionTimeoutsOutputReference.go
- OpensearchOutboundConnectionTimeoutsOutputReference__checks.go
- OpensearchOutboundConnection__checks.go
- main.go