Documentation
¶
Index ¶
- func NewQuicksightRefreshScheduleScheduleList_Override(q QuicksightRefreshScheduleScheduleList, ...)
- func NewQuicksightRefreshScheduleScheduleOutputReference_Override(q QuicksightRefreshScheduleScheduleOutputReference, ...)
- func NewQuicksightRefreshScheduleScheduleScheduleFrequencyList_Override(q QuicksightRefreshScheduleScheduleScheduleFrequencyList, ...)
- func NewQuicksightRefreshScheduleScheduleScheduleFrequencyOutputReference_Override(q QuicksightRefreshScheduleScheduleScheduleFrequencyOutputReference, ...)
- func NewQuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayList_Override(q QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayList, ...)
- func NewQuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayOutputReference_Override(...)
- func NewQuicksightRefreshSchedule_Override(q QuicksightRefreshSchedule, scope constructs.Construct, id *string, ...)
- func QuicksightRefreshSchedule_IsConstruct(x interface{}) *bool
- func QuicksightRefreshSchedule_IsTerraformElement(x interface{}) *bool
- func QuicksightRefreshSchedule_IsTerraformResource(x interface{}) *bool
- func QuicksightRefreshSchedule_TfResourceType() *string
- type QuicksightRefreshSchedule
- type QuicksightRefreshScheduleConfig
- type QuicksightRefreshScheduleSchedule
- type QuicksightRefreshScheduleScheduleList
- type QuicksightRefreshScheduleScheduleOutputReference
- type QuicksightRefreshScheduleScheduleScheduleFrequency
- type QuicksightRefreshScheduleScheduleScheduleFrequencyList
- type QuicksightRefreshScheduleScheduleScheduleFrequencyOutputReference
- type QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDay
- type QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayList
- type QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewQuicksightRefreshScheduleScheduleList_Override ¶
func NewQuicksightRefreshScheduleScheduleList_Override(q QuicksightRefreshScheduleScheduleList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewQuicksightRefreshScheduleScheduleOutputReference_Override ¶
func NewQuicksightRefreshScheduleScheduleOutputReference_Override(q QuicksightRefreshScheduleScheduleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewQuicksightRefreshScheduleScheduleScheduleFrequencyList_Override ¶
func NewQuicksightRefreshScheduleScheduleScheduleFrequencyList_Override(q QuicksightRefreshScheduleScheduleScheduleFrequencyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewQuicksightRefreshScheduleScheduleScheduleFrequencyOutputReference_Override ¶
func NewQuicksightRefreshScheduleScheduleScheduleFrequencyOutputReference_Override(q QuicksightRefreshScheduleScheduleScheduleFrequencyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewQuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayList_Override ¶
func NewQuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayList_Override(q QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewQuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayOutputReference_Override ¶
func NewQuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayOutputReference_Override(q QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewQuicksightRefreshSchedule_Override ¶
func NewQuicksightRefreshSchedule_Override(q QuicksightRefreshSchedule, scope constructs.Construct, id *string, config *QuicksightRefreshScheduleConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/quicksight_refresh_schedule aws_quicksight_refresh_schedule} Resource.
func QuicksightRefreshSchedule_IsConstruct ¶
func QuicksightRefreshSchedule_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func QuicksightRefreshSchedule_IsTerraformElement ¶
func QuicksightRefreshSchedule_IsTerraformElement(x interface{}) *bool
Experimental.
func QuicksightRefreshSchedule_IsTerraformResource ¶
func QuicksightRefreshSchedule_IsTerraformResource(x interface{}) *bool
Experimental.
func QuicksightRefreshSchedule_TfResourceType ¶
func QuicksightRefreshSchedule_TfResourceType() *string
Types ¶
type QuicksightRefreshSchedule ¶
type QuicksightRefreshSchedule interface {
cdktf.TerraformResource
Arn() *string
AwsAccountId() *string
SetAwsAccountId(val *string)
AwsAccountIdInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DataSetId() *string
SetDataSetId(val *string)
DataSetIdInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Schedule() QuicksightRefreshScheduleScheduleList
ScheduleId() *string
SetScheduleId(val *string)
ScheduleIdInput() *string
ScheduleInput() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutSchedule(value interface{})
ResetAwsAccountId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSchedule()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/quicksight_refresh_schedule aws_quicksight_refresh_schedule}.
func NewQuicksightRefreshSchedule ¶
func NewQuicksightRefreshSchedule(scope constructs.Construct, id *string, config *QuicksightRefreshScheduleConfig) QuicksightRefreshSchedule
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/quicksight_refresh_schedule aws_quicksight_refresh_schedule} Resource.
type QuicksightRefreshScheduleConfig ¶
type QuicksightRefreshScheduleConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/quicksight_refresh_schedule#data_set_id QuicksightRefreshSchedule#data_set_id}.
DataSetId *string `field:"required" json:"dataSetId" yaml:"dataSetId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/quicksight_refresh_schedule#schedule_id QuicksightRefreshSchedule#schedule_id}.
ScheduleId *string `field:"required" json:"scheduleId" yaml:"scheduleId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/quicksight_refresh_schedule#aws_account_id QuicksightRefreshSchedule#aws_account_id}.
AwsAccountId *string `field:"optional" json:"awsAccountId" yaml:"awsAccountId"`
// schedule block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/quicksight_refresh_schedule#schedule QuicksightRefreshSchedule#schedule}
Schedule interface{} `field:"optional" json:"schedule" yaml:"schedule"`
}
type QuicksightRefreshScheduleSchedule ¶
type QuicksightRefreshScheduleSchedule struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/quicksight_refresh_schedule#refresh_type QuicksightRefreshSchedule#refresh_type}.
RefreshType *string `field:"required" json:"refreshType" yaml:"refreshType"`
// schedule_frequency block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/quicksight_refresh_schedule#schedule_frequency QuicksightRefreshSchedule#schedule_frequency}
ScheduleFrequency interface{} `field:"optional" json:"scheduleFrequency" yaml:"scheduleFrequency"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/quicksight_refresh_schedule#start_after_date_time QuicksightRefreshSchedule#start_after_date_time}.
StartAfterDateTime *string `field:"optional" json:"startAfterDateTime" yaml:"startAfterDateTime"`
}
type QuicksightRefreshScheduleScheduleList ¶
type QuicksightRefreshScheduleScheduleList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) QuicksightRefreshScheduleScheduleOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewQuicksightRefreshScheduleScheduleList ¶
func NewQuicksightRefreshScheduleScheduleList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) QuicksightRefreshScheduleScheduleList
type QuicksightRefreshScheduleScheduleOutputReference ¶
type QuicksightRefreshScheduleScheduleOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
RefreshType() *string
SetRefreshType(val *string)
RefreshTypeInput() *string
ScheduleFrequency() QuicksightRefreshScheduleScheduleScheduleFrequencyList
ScheduleFrequencyInput() interface{}
StartAfterDateTime() *string
SetStartAfterDateTime(val *string)
StartAfterDateTimeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutScheduleFrequency(value interface{})
ResetScheduleFrequency()
ResetStartAfterDateTime()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewQuicksightRefreshScheduleScheduleOutputReference ¶
func NewQuicksightRefreshScheduleScheduleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) QuicksightRefreshScheduleScheduleOutputReference
type QuicksightRefreshScheduleScheduleScheduleFrequency ¶
type QuicksightRefreshScheduleScheduleScheduleFrequency struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/quicksight_refresh_schedule#interval QuicksightRefreshSchedule#interval}.
Interval *string `field:"required" json:"interval" yaml:"interval"`
// refresh_on_day block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/quicksight_refresh_schedule#refresh_on_day QuicksightRefreshSchedule#refresh_on_day}
RefreshOnDay interface{} `field:"optional" json:"refreshOnDay" yaml:"refreshOnDay"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/quicksight_refresh_schedule#time_of_the_day QuicksightRefreshSchedule#time_of_the_day}.
TimeOfTheDay *string `field:"optional" json:"timeOfTheDay" yaml:"timeOfTheDay"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/quicksight_refresh_schedule#timezone QuicksightRefreshSchedule#timezone}.
Timezone *string `field:"optional" json:"timezone" yaml:"timezone"`
}
type QuicksightRefreshScheduleScheduleScheduleFrequencyList ¶
type QuicksightRefreshScheduleScheduleScheduleFrequencyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) QuicksightRefreshScheduleScheduleScheduleFrequencyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewQuicksightRefreshScheduleScheduleScheduleFrequencyList ¶
func NewQuicksightRefreshScheduleScheduleScheduleFrequencyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) QuicksightRefreshScheduleScheduleScheduleFrequencyList
type QuicksightRefreshScheduleScheduleScheduleFrequencyOutputReference ¶
type QuicksightRefreshScheduleScheduleScheduleFrequencyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Interval() *string
SetInterval(val *string)
IntervalInput() *string
RefreshOnDay() QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayList
RefreshOnDayInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TimeOfTheDay() *string
SetTimeOfTheDay(val *string)
TimeOfTheDayInput() *string
Timezone() *string
SetTimezone(val *string)
TimezoneInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutRefreshOnDay(value interface{})
ResetRefreshOnDay()
ResetTimeOfTheDay()
ResetTimezone()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewQuicksightRefreshScheduleScheduleScheduleFrequencyOutputReference ¶
func NewQuicksightRefreshScheduleScheduleScheduleFrequencyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) QuicksightRefreshScheduleScheduleScheduleFrequencyOutputReference
type QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDay ¶
type QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDay struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/quicksight_refresh_schedule#day_of_month QuicksightRefreshSchedule#day_of_month}.
DayOfMonth *string `field:"optional" json:"dayOfMonth" yaml:"dayOfMonth"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/quicksight_refresh_schedule#day_of_week QuicksightRefreshSchedule#day_of_week}.
DayOfWeek *string `field:"optional" json:"dayOfWeek" yaml:"dayOfWeek"`
}
type QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayList ¶
type QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewQuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayList ¶
func NewQuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayList
type QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayOutputReference ¶
type QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DayOfMonth() *string
SetDayOfMonth(val *string)
DayOfMonthInput() *string
DayOfWeek() *string
SetDayOfWeek(val *string)
DayOfWeekInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDayOfMonth()
ResetDayOfWeek()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewQuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayOutputReference ¶
func NewQuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayOutputReference
Source Files
¶
- QuicksightRefreshSchedule.go
- QuicksightRefreshScheduleConfig.go
- QuicksightRefreshScheduleSchedule.go
- QuicksightRefreshScheduleScheduleList.go
- QuicksightRefreshScheduleScheduleList__checks.go
- QuicksightRefreshScheduleScheduleOutputReference.go
- QuicksightRefreshScheduleScheduleOutputReference__checks.go
- QuicksightRefreshScheduleScheduleScheduleFrequency.go
- QuicksightRefreshScheduleScheduleScheduleFrequencyList.go
- QuicksightRefreshScheduleScheduleScheduleFrequencyList__checks.go
- QuicksightRefreshScheduleScheduleScheduleFrequencyOutputReference.go
- QuicksightRefreshScheduleScheduleScheduleFrequencyOutputReference__checks.go
- QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDay.go
- QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayList.go
- QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayList__checks.go
- QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayOutputReference.go
- QuicksightRefreshScheduleScheduleScheduleFrequencyRefreshOnDayOutputReference__checks.go
- QuicksightRefreshSchedule__checks.go
- main.go