Documentation
¶
Index ¶
- func NewRdsClusterActivityStream_Override(r RdsClusterActivityStream, scope constructs.Construct, id *string, ...)
- func RdsClusterActivityStream_IsConstruct(x interface{}) *bool
- func RdsClusterActivityStream_IsTerraformElement(x interface{}) *bool
- func RdsClusterActivityStream_IsTerraformResource(x interface{}) *bool
- func RdsClusterActivityStream_TfResourceType() *string
- type RdsClusterActivityStream
- type RdsClusterActivityStreamConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRdsClusterActivityStream_Override ¶
func NewRdsClusterActivityStream_Override(r RdsClusterActivityStream, scope constructs.Construct, id *string, config *RdsClusterActivityStreamConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/rds_cluster_activity_stream aws_rds_cluster_activity_stream} Resource.
func RdsClusterActivityStream_IsConstruct ¶
func RdsClusterActivityStream_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func RdsClusterActivityStream_IsTerraformElement ¶
func RdsClusterActivityStream_IsTerraformElement(x interface{}) *bool
Experimental.
func RdsClusterActivityStream_IsTerraformResource ¶
func RdsClusterActivityStream_IsTerraformResource(x interface{}) *bool
Experimental.
func RdsClusterActivityStream_TfResourceType ¶
func RdsClusterActivityStream_TfResourceType() *string
Types ¶
type RdsClusterActivityStream ¶
type RdsClusterActivityStream interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EngineNativeAuditFieldsIncluded() interface{}
SetEngineNativeAuditFieldsIncluded(val interface{})
EngineNativeAuditFieldsIncludedInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
KinesisStreamName() *string
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Mode() *string
SetMode(val *string)
ModeInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ResourceArn() *string
SetResourceArn(val *string)
ResourceArnInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetEngineNativeAuditFieldsIncluded()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/rds_cluster_activity_stream aws_rds_cluster_activity_stream}.
func NewRdsClusterActivityStream ¶
func NewRdsClusterActivityStream(scope constructs.Construct, id *string, config *RdsClusterActivityStreamConfig) RdsClusterActivityStream
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/rds_cluster_activity_stream aws_rds_cluster_activity_stream} Resource.
type RdsClusterActivityStreamConfig ¶
type RdsClusterActivityStreamConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/rds_cluster_activity_stream#kms_key_id RdsClusterActivityStream#kms_key_id}.
KmsKeyId *string `field:"required" json:"kmsKeyId" yaml:"kmsKeyId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/rds_cluster_activity_stream#mode RdsClusterActivityStream#mode}.
Mode *string `field:"required" json:"mode" yaml:"mode"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/rds_cluster_activity_stream#resource_arn RdsClusterActivityStream#resource_arn}.
ResourceArn *string `field:"required" json:"resourceArn" yaml:"resourceArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/rds_cluster_activity_stream#engine_native_audit_fields_included RdsClusterActivityStream#engine_native_audit_fields_included}.
EngineNativeAuditFieldsIncluded interface{} `field:"optional" json:"engineNativeAuditFieldsIncluded" yaml:"engineNativeAuditFieldsIncluded"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/rds_cluster_activity_stream#id RdsClusterActivityStream#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}