Documentation
¶
Index ¶
- func NewRedshiftClusterClusterNodesList_Override(r RedshiftClusterClusterNodesList, ...)
- func NewRedshiftClusterClusterNodesOutputReference_Override(r RedshiftClusterClusterNodesOutputReference, ...)
- func NewRedshiftClusterLoggingOutputReference_Override(r RedshiftClusterLoggingOutputReference, ...)
- func NewRedshiftClusterSnapshotCopyOutputReference_Override(r RedshiftClusterSnapshotCopyOutputReference, ...)
- func NewRedshiftClusterTimeoutsOutputReference_Override(r RedshiftClusterTimeoutsOutputReference, ...)
- func NewRedshiftCluster_Override(r RedshiftCluster, scope constructs.Construct, id *string, ...)
- func RedshiftCluster_IsConstruct(x interface{}) *bool
- func RedshiftCluster_IsTerraformElement(x interface{}) *bool
- func RedshiftCluster_IsTerraformResource(x interface{}) *bool
- func RedshiftCluster_TfResourceType() *string
- type RedshiftCluster
- type RedshiftClusterClusterNodes
- type RedshiftClusterClusterNodesList
- type RedshiftClusterClusterNodesOutputReference
- type RedshiftClusterConfig
- type RedshiftClusterLogging
- type RedshiftClusterLoggingOutputReference
- type RedshiftClusterSnapshotCopy
- type RedshiftClusterSnapshotCopyOutputReference
- type RedshiftClusterTimeouts
- type RedshiftClusterTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRedshiftClusterClusterNodesList_Override ¶
func NewRedshiftClusterClusterNodesList_Override(r RedshiftClusterClusterNodesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewRedshiftClusterClusterNodesOutputReference_Override ¶
func NewRedshiftClusterClusterNodesOutputReference_Override(r RedshiftClusterClusterNodesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewRedshiftClusterLoggingOutputReference_Override ¶
func NewRedshiftClusterLoggingOutputReference_Override(r RedshiftClusterLoggingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewRedshiftClusterSnapshotCopyOutputReference_Override ¶
func NewRedshiftClusterSnapshotCopyOutputReference_Override(r RedshiftClusterSnapshotCopyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewRedshiftClusterTimeoutsOutputReference_Override ¶
func NewRedshiftClusterTimeoutsOutputReference_Override(r RedshiftClusterTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewRedshiftCluster_Override ¶
func NewRedshiftCluster_Override(r RedshiftCluster, scope constructs.Construct, id *string, config *RedshiftClusterConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster aws_redshift_cluster} Resource.
func RedshiftCluster_IsConstruct ¶
func RedshiftCluster_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func RedshiftCluster_IsTerraformElement ¶
func RedshiftCluster_IsTerraformElement(x interface{}) *bool
Experimental.
func RedshiftCluster_IsTerraformResource ¶
func RedshiftCluster_IsTerraformResource(x interface{}) *bool
Experimental.
func RedshiftCluster_TfResourceType ¶
func RedshiftCluster_TfResourceType() *string
Types ¶
type RedshiftCluster ¶
type RedshiftCluster interface {
cdktf.TerraformResource
AllowVersionUpgrade() interface{}
SetAllowVersionUpgrade(val interface{})
AllowVersionUpgradeInput() interface{}
ApplyImmediately() interface{}
SetApplyImmediately(val interface{})
ApplyImmediatelyInput() interface{}
AquaConfigurationStatus() *string
SetAquaConfigurationStatus(val *string)
AquaConfigurationStatusInput() *string
Arn() *string
AutomatedSnapshotRetentionPeriod() *float64
SetAutomatedSnapshotRetentionPeriod(val *float64)
AutomatedSnapshotRetentionPeriodInput() *float64
AvailabilityZone() *string
SetAvailabilityZone(val *string)
AvailabilityZoneInput() *string
AvailabilityZoneRelocationEnabled() interface{}
SetAvailabilityZoneRelocationEnabled(val interface{})
AvailabilityZoneRelocationEnabledInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterIdentifier() *string
SetClusterIdentifier(val *string)
ClusterIdentifierInput() *string
ClusterNodes() RedshiftClusterClusterNodesList
ClusterParameterGroupName() *string
SetClusterParameterGroupName(val *string)
ClusterParameterGroupNameInput() *string
ClusterPublicKey() *string
SetClusterPublicKey(val *string)
ClusterPublicKeyInput() *string
ClusterRevisionNumber() *string
SetClusterRevisionNumber(val *string)
ClusterRevisionNumberInput() *string
ClusterSecurityGroups() *[]*string
SetClusterSecurityGroups(val *[]*string)
ClusterSecurityGroupsInput() *[]*string
ClusterSubnetGroupName() *string
SetClusterSubnetGroupName(val *string)
ClusterSubnetGroupNameInput() *string
ClusterType() *string
SetClusterType(val *string)
ClusterTypeInput() *string
ClusterVersion() *string
SetClusterVersion(val *string)
ClusterVersionInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DatabaseName() *string
SetDatabaseName(val *string)
DatabaseNameInput() *string
DefaultIamRoleArn() *string
SetDefaultIamRoleArn(val *string)
DefaultIamRoleArnInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DnsName() *string
ElasticIp() *string
SetElasticIp(val *string)
ElasticIpInput() *string
Encrypted() interface{}
SetEncrypted(val interface{})
EncryptedInput() interface{}
Endpoint() *string
SetEndpoint(val *string)
EndpointInput() *string
EnhancedVpcRouting() interface{}
SetEnhancedVpcRouting(val interface{})
EnhancedVpcRoutingInput() interface{}
FinalSnapshotIdentifier() *string
SetFinalSnapshotIdentifier(val *string)
FinalSnapshotIdentifierInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
IamRoles() *[]*string
SetIamRoles(val *[]*string)
IamRolesInput() *[]*string
Id() *string
SetId(val *string)
IdInput() *string
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Logging() RedshiftClusterLoggingOutputReference
LoggingInput() *RedshiftClusterLogging
MaintenanceTrackName() *string
SetMaintenanceTrackName(val *string)
MaintenanceTrackNameInput() *string
ManualSnapshotRetentionPeriod() *float64
SetManualSnapshotRetentionPeriod(val *float64)
ManualSnapshotRetentionPeriodInput() *float64
MasterPassword() *string
SetMasterPassword(val *string)
MasterPasswordInput() *string
MasterUsername() *string
SetMasterUsername(val *string)
MasterUsernameInput() *string
// The tree node.
Node() constructs.Node
NodeType() *string
SetNodeType(val *string)
NodeTypeInput() *string
NumberOfNodes() *float64
SetNumberOfNodes(val *float64)
NumberOfNodesInput() *float64
OwnerAccount() *string
SetOwnerAccount(val *string)
OwnerAccountInput() *string
Port() *float64
SetPort(val *float64)
PortInput() *float64
PreferredMaintenanceWindow() *string
SetPreferredMaintenanceWindow(val *string)
PreferredMaintenanceWindowInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
PubliclyAccessible() interface{}
SetPubliclyAccessible(val interface{})
PubliclyAccessibleInput() interface{}
// Experimental.
RawOverrides() interface{}
SkipFinalSnapshot() interface{}
SetSkipFinalSnapshot(val interface{})
SkipFinalSnapshotInput() interface{}
SnapshotClusterIdentifier() *string
SetSnapshotClusterIdentifier(val *string)
SnapshotClusterIdentifierInput() *string
SnapshotCopy() RedshiftClusterSnapshotCopyOutputReference
SnapshotCopyInput() *RedshiftClusterSnapshotCopy
SnapshotIdentifier() *string
SetSnapshotIdentifier(val *string)
SnapshotIdentifierInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() RedshiftClusterTimeoutsOutputReference
TimeoutsInput() interface{}
VpcSecurityGroupIds() *[]*string
SetVpcSecurityGroupIds(val *[]*string)
VpcSecurityGroupIdsInput() *[]*string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutLogging(value *RedshiftClusterLogging)
PutSnapshotCopy(value *RedshiftClusterSnapshotCopy)
PutTimeouts(value *RedshiftClusterTimeouts)
ResetAllowVersionUpgrade()
ResetApplyImmediately()
ResetAquaConfigurationStatus()
ResetAutomatedSnapshotRetentionPeriod()
ResetAvailabilityZone()
ResetAvailabilityZoneRelocationEnabled()
ResetClusterParameterGroupName()
ResetClusterPublicKey()
ResetClusterRevisionNumber()
ResetClusterSecurityGroups()
ResetClusterSubnetGroupName()
ResetClusterType()
ResetClusterVersion()
ResetDatabaseName()
ResetDefaultIamRoleArn()
ResetElasticIp()
ResetEncrypted()
ResetEndpoint()
ResetEnhancedVpcRouting()
ResetFinalSnapshotIdentifier()
ResetIamRoles()
ResetId()
ResetKmsKeyId()
ResetLogging()
ResetMaintenanceTrackName()
ResetManualSnapshotRetentionPeriod()
ResetMasterPassword()
ResetMasterUsername()
ResetNumberOfNodes()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetOwnerAccount()
ResetPort()
ResetPreferredMaintenanceWindow()
ResetPubliclyAccessible()
ResetSkipFinalSnapshot()
ResetSnapshotClusterIdentifier()
ResetSnapshotCopy()
ResetSnapshotIdentifier()
ResetTags()
ResetTagsAll()
ResetTimeouts()
ResetVpcSecurityGroupIds()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster aws_redshift_cluster}.
func NewRedshiftCluster ¶
func NewRedshiftCluster(scope constructs.Construct, id *string, config *RedshiftClusterConfig) RedshiftCluster
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster aws_redshift_cluster} Resource.
type RedshiftClusterClusterNodes ¶
type RedshiftClusterClusterNodes struct {
}
type RedshiftClusterClusterNodesList ¶
type RedshiftClusterClusterNodesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) RedshiftClusterClusterNodesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRedshiftClusterClusterNodesList ¶
func NewRedshiftClusterClusterNodesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) RedshiftClusterClusterNodesList
type RedshiftClusterClusterNodesOutputReference ¶
type RedshiftClusterClusterNodesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *RedshiftClusterClusterNodes
SetInternalValue(val *RedshiftClusterClusterNodes)
NodeRole() *string
PrivateIpAddress() *string
PublicIpAddress() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRedshiftClusterClusterNodesOutputReference ¶
func NewRedshiftClusterClusterNodesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) RedshiftClusterClusterNodesOutputReference
type RedshiftClusterConfig ¶
type RedshiftClusterConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#cluster_identifier RedshiftCluster#cluster_identifier}.
ClusterIdentifier *string `field:"required" json:"clusterIdentifier" yaml:"clusterIdentifier"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#node_type RedshiftCluster#node_type}.
NodeType *string `field:"required" json:"nodeType" yaml:"nodeType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#allow_version_upgrade RedshiftCluster#allow_version_upgrade}.
AllowVersionUpgrade interface{} `field:"optional" json:"allowVersionUpgrade" yaml:"allowVersionUpgrade"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#apply_immediately RedshiftCluster#apply_immediately}.
ApplyImmediately interface{} `field:"optional" json:"applyImmediately" yaml:"applyImmediately"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#aqua_configuration_status RedshiftCluster#aqua_configuration_status}.
AquaConfigurationStatus *string `field:"optional" json:"aquaConfigurationStatus" yaml:"aquaConfigurationStatus"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#automated_snapshot_retention_period RedshiftCluster#automated_snapshot_retention_period}.
AutomatedSnapshotRetentionPeriod *float64 `field:"optional" json:"automatedSnapshotRetentionPeriod" yaml:"automatedSnapshotRetentionPeriod"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#availability_zone RedshiftCluster#availability_zone}.
AvailabilityZone *string `field:"optional" json:"availabilityZone" yaml:"availabilityZone"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#availability_zone_relocation_enabled RedshiftCluster#availability_zone_relocation_enabled}.
AvailabilityZoneRelocationEnabled interface{} `field:"optional" json:"availabilityZoneRelocationEnabled" yaml:"availabilityZoneRelocationEnabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#cluster_parameter_group_name RedshiftCluster#cluster_parameter_group_name}.
ClusterParameterGroupName *string `field:"optional" json:"clusterParameterGroupName" yaml:"clusterParameterGroupName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#cluster_public_key RedshiftCluster#cluster_public_key}.
ClusterPublicKey *string `field:"optional" json:"clusterPublicKey" yaml:"clusterPublicKey"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#cluster_revision_number RedshiftCluster#cluster_revision_number}.
ClusterRevisionNumber *string `field:"optional" json:"clusterRevisionNumber" yaml:"clusterRevisionNumber"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#cluster_security_groups RedshiftCluster#cluster_security_groups}.
ClusterSecurityGroups *[]*string `field:"optional" json:"clusterSecurityGroups" yaml:"clusterSecurityGroups"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#cluster_subnet_group_name RedshiftCluster#cluster_subnet_group_name}.
ClusterSubnetGroupName *string `field:"optional" json:"clusterSubnetGroupName" yaml:"clusterSubnetGroupName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#cluster_type RedshiftCluster#cluster_type}.
ClusterType *string `field:"optional" json:"clusterType" yaml:"clusterType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#cluster_version RedshiftCluster#cluster_version}.
ClusterVersion *string `field:"optional" json:"clusterVersion" yaml:"clusterVersion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#database_name RedshiftCluster#database_name}.
DatabaseName *string `field:"optional" json:"databaseName" yaml:"databaseName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#default_iam_role_arn RedshiftCluster#default_iam_role_arn}.
DefaultIamRoleArn *string `field:"optional" json:"defaultIamRoleArn" yaml:"defaultIamRoleArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#elastic_ip RedshiftCluster#elastic_ip}.
ElasticIp *string `field:"optional" json:"elasticIp" yaml:"elasticIp"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#encrypted RedshiftCluster#encrypted}.
Encrypted interface{} `field:"optional" json:"encrypted" yaml:"encrypted"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#endpoint RedshiftCluster#endpoint}.
Endpoint *string `field:"optional" json:"endpoint" yaml:"endpoint"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#enhanced_vpc_routing RedshiftCluster#enhanced_vpc_routing}.
EnhancedVpcRouting interface{} `field:"optional" json:"enhancedVpcRouting" yaml:"enhancedVpcRouting"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#final_snapshot_identifier RedshiftCluster#final_snapshot_identifier}.
FinalSnapshotIdentifier *string `field:"optional" json:"finalSnapshotIdentifier" yaml:"finalSnapshotIdentifier"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#iam_roles RedshiftCluster#iam_roles}.
IamRoles *[]*string `field:"optional" json:"iamRoles" yaml:"iamRoles"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#id RedshiftCluster#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#kms_key_id RedshiftCluster#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
// logging block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#logging RedshiftCluster#logging}
Logging *RedshiftClusterLogging `field:"optional" json:"logging" yaml:"logging"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#maintenance_track_name RedshiftCluster#maintenance_track_name}.
MaintenanceTrackName *string `field:"optional" json:"maintenanceTrackName" yaml:"maintenanceTrackName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#manual_snapshot_retention_period RedshiftCluster#manual_snapshot_retention_period}.
ManualSnapshotRetentionPeriod *float64 `field:"optional" json:"manualSnapshotRetentionPeriod" yaml:"manualSnapshotRetentionPeriod"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#master_password RedshiftCluster#master_password}.
MasterPassword *string `field:"optional" json:"masterPassword" yaml:"masterPassword"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#master_username RedshiftCluster#master_username}.
MasterUsername *string `field:"optional" json:"masterUsername" yaml:"masterUsername"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#number_of_nodes RedshiftCluster#number_of_nodes}.
NumberOfNodes *float64 `field:"optional" json:"numberOfNodes" yaml:"numberOfNodes"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#owner_account RedshiftCluster#owner_account}.
OwnerAccount *string `field:"optional" json:"ownerAccount" yaml:"ownerAccount"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#port RedshiftCluster#port}.
Port *float64 `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#preferred_maintenance_window RedshiftCluster#preferred_maintenance_window}.
PreferredMaintenanceWindow *string `field:"optional" json:"preferredMaintenanceWindow" yaml:"preferredMaintenanceWindow"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#publicly_accessible RedshiftCluster#publicly_accessible}.
PubliclyAccessible interface{} `field:"optional" json:"publiclyAccessible" yaml:"publiclyAccessible"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#skip_final_snapshot RedshiftCluster#skip_final_snapshot}.
SkipFinalSnapshot interface{} `field:"optional" json:"skipFinalSnapshot" yaml:"skipFinalSnapshot"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#snapshot_cluster_identifier RedshiftCluster#snapshot_cluster_identifier}.
SnapshotClusterIdentifier *string `field:"optional" json:"snapshotClusterIdentifier" yaml:"snapshotClusterIdentifier"`
// snapshot_copy block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#snapshot_copy RedshiftCluster#snapshot_copy}
SnapshotCopy *RedshiftClusterSnapshotCopy `field:"optional" json:"snapshotCopy" yaml:"snapshotCopy"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#snapshot_identifier RedshiftCluster#snapshot_identifier}.
SnapshotIdentifier *string `field:"optional" json:"snapshotIdentifier" yaml:"snapshotIdentifier"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#tags RedshiftCluster#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#tags_all RedshiftCluster#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#timeouts RedshiftCluster#timeouts}
Timeouts *RedshiftClusterTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#vpc_security_group_ids RedshiftCluster#vpc_security_group_ids}.
VpcSecurityGroupIds *[]*string `field:"optional" json:"vpcSecurityGroupIds" yaml:"vpcSecurityGroupIds"`
}
type RedshiftClusterLogging ¶
type RedshiftClusterLogging struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#enable RedshiftCluster#enable}.
Enable interface{} `field:"required" json:"enable" yaml:"enable"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#bucket_name RedshiftCluster#bucket_name}.
BucketName *string `field:"optional" json:"bucketName" yaml:"bucketName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#log_destination_type RedshiftCluster#log_destination_type}.
LogDestinationType *string `field:"optional" json:"logDestinationType" yaml:"logDestinationType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#log_exports RedshiftCluster#log_exports}.
LogExports *[]*string `field:"optional" json:"logExports" yaml:"logExports"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#s3_key_prefix RedshiftCluster#s3_key_prefix}.
S3KeyPrefix *string `field:"optional" json:"s3KeyPrefix" yaml:"s3KeyPrefix"`
}
type RedshiftClusterLoggingOutputReference ¶
type RedshiftClusterLoggingOutputReference interface {
cdktf.ComplexObject
BucketName() *string
SetBucketName(val *string)
BucketNameInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enable() interface{}
SetEnable(val interface{})
EnableInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *RedshiftClusterLogging
SetInternalValue(val *RedshiftClusterLogging)
LogDestinationType() *string
SetLogDestinationType(val *string)
LogDestinationTypeInput() *string
LogExports() *[]*string
SetLogExports(val *[]*string)
LogExportsInput() *[]*string
S3KeyPrefix() *string
SetS3KeyPrefix(val *string)
S3KeyPrefixInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBucketName()
ResetLogDestinationType()
ResetLogExports()
ResetS3KeyPrefix()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRedshiftClusterLoggingOutputReference ¶
func NewRedshiftClusterLoggingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) RedshiftClusterLoggingOutputReference
type RedshiftClusterSnapshotCopy ¶
type RedshiftClusterSnapshotCopy struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#destination_region RedshiftCluster#destination_region}.
DestinationRegion *string `field:"required" json:"destinationRegion" yaml:"destinationRegion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#grant_name RedshiftCluster#grant_name}.
GrantName *string `field:"optional" json:"grantName" yaml:"grantName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#retention_period RedshiftCluster#retention_period}.
RetentionPeriod *float64 `field:"optional" json:"retentionPeriod" yaml:"retentionPeriod"`
}
type RedshiftClusterSnapshotCopyOutputReference ¶
type RedshiftClusterSnapshotCopyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DestinationRegion() *string
SetDestinationRegion(val *string)
DestinationRegionInput() *string
// Experimental.
Fqn() *string
GrantName() *string
SetGrantName(val *string)
GrantNameInput() *string
InternalValue() *RedshiftClusterSnapshotCopy
SetInternalValue(val *RedshiftClusterSnapshotCopy)
RetentionPeriod() *float64
SetRetentionPeriod(val *float64)
RetentionPeriodInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetGrantName()
ResetRetentionPeriod()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRedshiftClusterSnapshotCopyOutputReference ¶
func NewRedshiftClusterSnapshotCopyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) RedshiftClusterSnapshotCopyOutputReference
type RedshiftClusterTimeouts ¶
type RedshiftClusterTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#create RedshiftCluster#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#delete RedshiftCluster#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_cluster#update RedshiftCluster#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type RedshiftClusterTimeoutsOutputReference ¶
type RedshiftClusterTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRedshiftClusterTimeoutsOutputReference ¶
func NewRedshiftClusterTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) RedshiftClusterTimeoutsOutputReference
Source Files
¶
- RedshiftCluster.go
- RedshiftClusterClusterNodes.go
- RedshiftClusterClusterNodesList.go
- RedshiftClusterClusterNodesList__checks.go
- RedshiftClusterClusterNodesOutputReference.go
- RedshiftClusterClusterNodesOutputReference__checks.go
- RedshiftClusterConfig.go
- RedshiftClusterLogging.go
- RedshiftClusterLoggingOutputReference.go
- RedshiftClusterLoggingOutputReference__checks.go
- RedshiftClusterSnapshotCopy.go
- RedshiftClusterSnapshotCopyOutputReference.go
- RedshiftClusterSnapshotCopyOutputReference__checks.go
- RedshiftClusterTimeouts.go
- RedshiftClusterTimeoutsOutputReference.go
- RedshiftClusterTimeoutsOutputReference__checks.go
- RedshiftCluster__checks.go
- main.go