Documentation
¶
Index ¶
- func NewRedshiftdataStatementParametersList_Override(r RedshiftdataStatementParametersList, ...)
- func NewRedshiftdataStatementParametersOutputReference_Override(r RedshiftdataStatementParametersOutputReference, ...)
- func NewRedshiftdataStatementTimeoutsOutputReference_Override(r RedshiftdataStatementTimeoutsOutputReference, ...)
- func NewRedshiftdataStatement_Override(r RedshiftdataStatement, scope constructs.Construct, id *string, ...)
- func RedshiftdataStatement_IsConstruct(x interface{}) *bool
- func RedshiftdataStatement_IsTerraformElement(x interface{}) *bool
- func RedshiftdataStatement_IsTerraformResource(x interface{}) *bool
- func RedshiftdataStatement_TfResourceType() *string
- type RedshiftdataStatement
- type RedshiftdataStatementConfig
- type RedshiftdataStatementParameters
- type RedshiftdataStatementParametersList
- type RedshiftdataStatementParametersOutputReference
- type RedshiftdataStatementTimeouts
- type RedshiftdataStatementTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRedshiftdataStatementParametersList_Override ¶
func NewRedshiftdataStatementParametersList_Override(r RedshiftdataStatementParametersList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewRedshiftdataStatementParametersOutputReference_Override ¶
func NewRedshiftdataStatementParametersOutputReference_Override(r RedshiftdataStatementParametersOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewRedshiftdataStatementTimeoutsOutputReference_Override ¶
func NewRedshiftdataStatementTimeoutsOutputReference_Override(r RedshiftdataStatementTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewRedshiftdataStatement_Override ¶
func NewRedshiftdataStatement_Override(r RedshiftdataStatement, scope constructs.Construct, id *string, config *RedshiftdataStatementConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshiftdata_statement aws_redshiftdata_statement} Resource.
func RedshiftdataStatement_IsConstruct ¶
func RedshiftdataStatement_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func RedshiftdataStatement_IsTerraformElement ¶
func RedshiftdataStatement_IsTerraformElement(x interface{}) *bool
Experimental.
func RedshiftdataStatement_IsTerraformResource ¶
func RedshiftdataStatement_IsTerraformResource(x interface{}) *bool
Experimental.
func RedshiftdataStatement_TfResourceType ¶
func RedshiftdataStatement_TfResourceType() *string
Types ¶
type RedshiftdataStatement ¶
type RedshiftdataStatement interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterIdentifier() *string
SetClusterIdentifier(val *string)
ClusterIdentifierInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
Database() *string
SetDatabase(val *string)
DatabaseInput() *string
DbUser() *string
SetDbUser(val *string)
DbUserInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
Parameters() RedshiftdataStatementParametersList
ParametersInput() interface{}
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SecretArn() *string
SetSecretArn(val *string)
SecretArnInput() *string
Sql() *string
SetSql(val *string)
SqlInput() *string
StatementName() *string
SetStatementName(val *string)
StatementNameInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() RedshiftdataStatementTimeoutsOutputReference
TimeoutsInput() interface{}
WithEvent() interface{}
SetWithEvent(val interface{})
WithEventInput() interface{}
WorkgroupName() *string
SetWorkgroupName(val *string)
WorkgroupNameInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutParameters(value interface{})
PutTimeouts(value *RedshiftdataStatementTimeouts)
ResetClusterIdentifier()
ResetDbUser()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetParameters()
ResetSecretArn()
ResetStatementName()
ResetTimeouts()
ResetWithEvent()
ResetWorkgroupName()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshiftdata_statement aws_redshiftdata_statement}.
func NewRedshiftdataStatement ¶
func NewRedshiftdataStatement(scope constructs.Construct, id *string, config *RedshiftdataStatementConfig) RedshiftdataStatement
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshiftdata_statement aws_redshiftdata_statement} Resource.
type RedshiftdataStatementConfig ¶
type RedshiftdataStatementConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshiftdata_statement#database RedshiftdataStatement#database}.
Database *string `field:"required" json:"database" yaml:"database"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshiftdata_statement#sql RedshiftdataStatement#sql}.
Sql *string `field:"required" json:"sql" yaml:"sql"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshiftdata_statement#cluster_identifier RedshiftdataStatement#cluster_identifier}.
ClusterIdentifier *string `field:"optional" json:"clusterIdentifier" yaml:"clusterIdentifier"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshiftdata_statement#db_user RedshiftdataStatement#db_user}.
DbUser *string `field:"optional" json:"dbUser" yaml:"dbUser"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshiftdata_statement#id RedshiftdataStatement#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// parameters block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshiftdata_statement#parameters RedshiftdataStatement#parameters}
Parameters interface{} `field:"optional" json:"parameters" yaml:"parameters"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshiftdata_statement#secret_arn RedshiftdataStatement#secret_arn}.
SecretArn *string `field:"optional" json:"secretArn" yaml:"secretArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshiftdata_statement#statement_name RedshiftdataStatement#statement_name}.
StatementName *string `field:"optional" json:"statementName" yaml:"statementName"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshiftdata_statement#timeouts RedshiftdataStatement#timeouts}
Timeouts *RedshiftdataStatementTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshiftdata_statement#with_event RedshiftdataStatement#with_event}.
WithEvent interface{} `field:"optional" json:"withEvent" yaml:"withEvent"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshiftdata_statement#workgroup_name RedshiftdataStatement#workgroup_name}.
WorkgroupName *string `field:"optional" json:"workgroupName" yaml:"workgroupName"`
}
type RedshiftdataStatementParameters ¶
type RedshiftdataStatementParameters struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshiftdata_statement#name RedshiftdataStatement#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshiftdata_statement#value RedshiftdataStatement#value}.
Value *string `field:"required" json:"value" yaml:"value"`
}
type RedshiftdataStatementParametersList ¶
type RedshiftdataStatementParametersList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) RedshiftdataStatementParametersOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRedshiftdataStatementParametersList ¶
func NewRedshiftdataStatementParametersList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) RedshiftdataStatementParametersList
type RedshiftdataStatementParametersOutputReference ¶
type RedshiftdataStatementParametersOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRedshiftdataStatementParametersOutputReference ¶
func NewRedshiftdataStatementParametersOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) RedshiftdataStatementParametersOutputReference
type RedshiftdataStatementTimeouts ¶
type RedshiftdataStatementTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshiftdata_statement#create RedshiftdataStatement#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
}
type RedshiftdataStatementTimeoutsOutputReference ¶
type RedshiftdataStatementTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRedshiftdataStatementTimeoutsOutputReference ¶
func NewRedshiftdataStatementTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) RedshiftdataStatementTimeoutsOutputReference
Source Files
¶
- RedshiftdataStatement.go
- RedshiftdataStatementConfig.go
- RedshiftdataStatementParameters.go
- RedshiftdataStatementParametersList.go
- RedshiftdataStatementParametersList__checks.go
- RedshiftdataStatementParametersOutputReference.go
- RedshiftdataStatementParametersOutputReference__checks.go
- RedshiftdataStatementTimeouts.go
- RedshiftdataStatementTimeoutsOutputReference.go
- RedshiftdataStatementTimeoutsOutputReference__checks.go
- RedshiftdataStatement__checks.go
- main.go