Documentation
¶
Index ¶
- func NewRedshiftEndpointAccessVpcEndpointList_Override(r RedshiftEndpointAccessVpcEndpointList, ...)
- func NewRedshiftEndpointAccessVpcEndpointNetworkInterfaceList_Override(r RedshiftEndpointAccessVpcEndpointNetworkInterfaceList, ...)
- func NewRedshiftEndpointAccessVpcEndpointNetworkInterfaceOutputReference_Override(r RedshiftEndpointAccessVpcEndpointNetworkInterfaceOutputReference, ...)
- func NewRedshiftEndpointAccessVpcEndpointOutputReference_Override(r RedshiftEndpointAccessVpcEndpointOutputReference, ...)
- func NewRedshiftEndpointAccess_Override(r RedshiftEndpointAccess, scope constructs.Construct, id *string, ...)
- func RedshiftEndpointAccess_IsConstruct(x interface{}) *bool
- func RedshiftEndpointAccess_IsTerraformElement(x interface{}) *bool
- func RedshiftEndpointAccess_IsTerraformResource(x interface{}) *bool
- func RedshiftEndpointAccess_TfResourceType() *string
- type RedshiftEndpointAccess
- type RedshiftEndpointAccessConfig
- type RedshiftEndpointAccessVpcEndpoint
- type RedshiftEndpointAccessVpcEndpointList
- type RedshiftEndpointAccessVpcEndpointNetworkInterface
- type RedshiftEndpointAccessVpcEndpointNetworkInterfaceList
- type RedshiftEndpointAccessVpcEndpointNetworkInterfaceOutputReference
- type RedshiftEndpointAccessVpcEndpointOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRedshiftEndpointAccessVpcEndpointList_Override ¶
func NewRedshiftEndpointAccessVpcEndpointList_Override(r RedshiftEndpointAccessVpcEndpointList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewRedshiftEndpointAccessVpcEndpointNetworkInterfaceList_Override ¶
func NewRedshiftEndpointAccessVpcEndpointNetworkInterfaceList_Override(r RedshiftEndpointAccessVpcEndpointNetworkInterfaceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewRedshiftEndpointAccessVpcEndpointNetworkInterfaceOutputReference_Override ¶
func NewRedshiftEndpointAccessVpcEndpointNetworkInterfaceOutputReference_Override(r RedshiftEndpointAccessVpcEndpointNetworkInterfaceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewRedshiftEndpointAccessVpcEndpointOutputReference_Override ¶
func NewRedshiftEndpointAccessVpcEndpointOutputReference_Override(r RedshiftEndpointAccessVpcEndpointOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewRedshiftEndpointAccess_Override ¶
func NewRedshiftEndpointAccess_Override(r RedshiftEndpointAccess, scope constructs.Construct, id *string, config *RedshiftEndpointAccessConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_endpoint_access aws_redshift_endpoint_access} Resource.
func RedshiftEndpointAccess_IsConstruct ¶
func RedshiftEndpointAccess_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func RedshiftEndpointAccess_IsTerraformElement ¶
func RedshiftEndpointAccess_IsTerraformElement(x interface{}) *bool
Experimental.
func RedshiftEndpointAccess_IsTerraformResource ¶
func RedshiftEndpointAccess_IsTerraformResource(x interface{}) *bool
Experimental.
func RedshiftEndpointAccess_TfResourceType ¶
func RedshiftEndpointAccess_TfResourceType() *string
Types ¶
type RedshiftEndpointAccess ¶
type RedshiftEndpointAccess interface {
cdktf.TerraformResource
Address() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterIdentifier() *string
SetClusterIdentifier(val *string)
ClusterIdentifierInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EndpointName() *string
SetEndpointName(val *string)
EndpointNameInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
Port() *float64
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ResourceOwner() *string
SetResourceOwner(val *string)
ResourceOwnerInput() *string
SubnetGroupName() *string
SetSubnetGroupName(val *string)
SubnetGroupNameInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
VpcEndpoint() RedshiftEndpointAccessVpcEndpointList
VpcSecurityGroupIds() *[]*string
SetVpcSecurityGroupIds(val *[]*string)
VpcSecurityGroupIdsInput() *[]*string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetResourceOwner()
ResetVpcSecurityGroupIds()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_endpoint_access aws_redshift_endpoint_access}.
func NewRedshiftEndpointAccess ¶
func NewRedshiftEndpointAccess(scope constructs.Construct, id *string, config *RedshiftEndpointAccessConfig) RedshiftEndpointAccess
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_endpoint_access aws_redshift_endpoint_access} Resource.
type RedshiftEndpointAccessConfig ¶
type RedshiftEndpointAccessConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_endpoint_access#cluster_identifier RedshiftEndpointAccess#cluster_identifier}.
ClusterIdentifier *string `field:"required" json:"clusterIdentifier" yaml:"clusterIdentifier"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_endpoint_access#endpoint_name RedshiftEndpointAccess#endpoint_name}.
EndpointName *string `field:"required" json:"endpointName" yaml:"endpointName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_endpoint_access#subnet_group_name RedshiftEndpointAccess#subnet_group_name}.
SubnetGroupName *string `field:"required" json:"subnetGroupName" yaml:"subnetGroupName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_endpoint_access#id RedshiftEndpointAccess#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_endpoint_access#resource_owner RedshiftEndpointAccess#resource_owner}.
ResourceOwner *string `field:"optional" json:"resourceOwner" yaml:"resourceOwner"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/redshift_endpoint_access#vpc_security_group_ids RedshiftEndpointAccess#vpc_security_group_ids}.
VpcSecurityGroupIds *[]*string `field:"optional" json:"vpcSecurityGroupIds" yaml:"vpcSecurityGroupIds"`
}
type RedshiftEndpointAccessVpcEndpoint ¶
type RedshiftEndpointAccessVpcEndpoint struct {
}
type RedshiftEndpointAccessVpcEndpointList ¶
type RedshiftEndpointAccessVpcEndpointList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) RedshiftEndpointAccessVpcEndpointOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRedshiftEndpointAccessVpcEndpointList ¶
func NewRedshiftEndpointAccessVpcEndpointList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) RedshiftEndpointAccessVpcEndpointList
type RedshiftEndpointAccessVpcEndpointNetworkInterface ¶
type RedshiftEndpointAccessVpcEndpointNetworkInterface struct {
}
type RedshiftEndpointAccessVpcEndpointNetworkInterfaceList ¶
type RedshiftEndpointAccessVpcEndpointNetworkInterfaceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) RedshiftEndpointAccessVpcEndpointNetworkInterfaceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRedshiftEndpointAccessVpcEndpointNetworkInterfaceList ¶
func NewRedshiftEndpointAccessVpcEndpointNetworkInterfaceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) RedshiftEndpointAccessVpcEndpointNetworkInterfaceList
type RedshiftEndpointAccessVpcEndpointNetworkInterfaceOutputReference ¶
type RedshiftEndpointAccessVpcEndpointNetworkInterfaceOutputReference interface {
cdktf.ComplexObject
AvailabilityZone() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *RedshiftEndpointAccessVpcEndpointNetworkInterface
SetInternalValue(val *RedshiftEndpointAccessVpcEndpointNetworkInterface)
NetworkInterfaceId() *string
PrivateIpAddress() *string
SubnetId() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRedshiftEndpointAccessVpcEndpointNetworkInterfaceOutputReference ¶
func NewRedshiftEndpointAccessVpcEndpointNetworkInterfaceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) RedshiftEndpointAccessVpcEndpointNetworkInterfaceOutputReference
type RedshiftEndpointAccessVpcEndpointOutputReference ¶
type RedshiftEndpointAccessVpcEndpointOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *RedshiftEndpointAccessVpcEndpoint
SetInternalValue(val *RedshiftEndpointAccessVpcEndpoint)
NetworkInterface() RedshiftEndpointAccessVpcEndpointNetworkInterfaceList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VpcEndpointId() *string
VpcId() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRedshiftEndpointAccessVpcEndpointOutputReference ¶
func NewRedshiftEndpointAccessVpcEndpointOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) RedshiftEndpointAccessVpcEndpointOutputReference
Source Files
¶
- RedshiftEndpointAccess.go
- RedshiftEndpointAccessConfig.go
- RedshiftEndpointAccessVpcEndpoint.go
- RedshiftEndpointAccessVpcEndpointList.go
- RedshiftEndpointAccessVpcEndpointList__checks.go
- RedshiftEndpointAccessVpcEndpointNetworkInterface.go
- RedshiftEndpointAccessVpcEndpointNetworkInterfaceList.go
- RedshiftEndpointAccessVpcEndpointNetworkInterfaceList__checks.go
- RedshiftEndpointAccessVpcEndpointNetworkInterfaceOutputReference.go
- RedshiftEndpointAccessVpcEndpointNetworkInterfaceOutputReference__checks.go
- RedshiftEndpointAccessVpcEndpointOutputReference.go
- RedshiftEndpointAccessVpcEndpointOutputReference__checks.go
- RedshiftEndpointAccess__checks.go
- main.go