Documentation
¶
Index ¶
- func NewResourcegroupsGroupConfigurationList_Override(r ResourcegroupsGroupConfigurationList, ...)
- func NewResourcegroupsGroupConfigurationOutputReference_Override(r ResourcegroupsGroupConfigurationOutputReference, ...)
- func NewResourcegroupsGroupConfigurationParametersList_Override(r ResourcegroupsGroupConfigurationParametersList, ...)
- func NewResourcegroupsGroupConfigurationParametersOutputReference_Override(r ResourcegroupsGroupConfigurationParametersOutputReference, ...)
- func NewResourcegroupsGroupResourceQueryOutputReference_Override(r ResourcegroupsGroupResourceQueryOutputReference, ...)
- func NewResourcegroupsGroupTimeoutsOutputReference_Override(r ResourcegroupsGroupTimeoutsOutputReference, ...)
- func NewResourcegroupsGroup_Override(r ResourcegroupsGroup, scope constructs.Construct, id *string, ...)
- func ResourcegroupsGroup_IsConstruct(x interface{}) *bool
- func ResourcegroupsGroup_IsTerraformElement(x interface{}) *bool
- func ResourcegroupsGroup_IsTerraformResource(x interface{}) *bool
- func ResourcegroupsGroup_TfResourceType() *string
- type ResourcegroupsGroup
- type ResourcegroupsGroupConfig
- type ResourcegroupsGroupConfiguration
- type ResourcegroupsGroupConfigurationList
- type ResourcegroupsGroupConfigurationOutputReference
- type ResourcegroupsGroupConfigurationParameters
- type ResourcegroupsGroupConfigurationParametersList
- type ResourcegroupsGroupConfigurationParametersOutputReference
- type ResourcegroupsGroupResourceQuery
- type ResourcegroupsGroupResourceQueryOutputReference
- type ResourcegroupsGroupTimeouts
- type ResourcegroupsGroupTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewResourcegroupsGroupConfigurationList_Override ¶
func NewResourcegroupsGroupConfigurationList_Override(r ResourcegroupsGroupConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewResourcegroupsGroupConfigurationOutputReference_Override ¶
func NewResourcegroupsGroupConfigurationOutputReference_Override(r ResourcegroupsGroupConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewResourcegroupsGroupConfigurationParametersList_Override ¶
func NewResourcegroupsGroupConfigurationParametersList_Override(r ResourcegroupsGroupConfigurationParametersList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewResourcegroupsGroupConfigurationParametersOutputReference_Override ¶
func NewResourcegroupsGroupConfigurationParametersOutputReference_Override(r ResourcegroupsGroupConfigurationParametersOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewResourcegroupsGroupResourceQueryOutputReference_Override ¶
func NewResourcegroupsGroupResourceQueryOutputReference_Override(r ResourcegroupsGroupResourceQueryOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewResourcegroupsGroupTimeoutsOutputReference_Override ¶
func NewResourcegroupsGroupTimeoutsOutputReference_Override(r ResourcegroupsGroupTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewResourcegroupsGroup_Override ¶
func NewResourcegroupsGroup_Override(r ResourcegroupsGroup, scope constructs.Construct, id *string, config *ResourcegroupsGroupConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/resourcegroups_group aws_resourcegroups_group} Resource.
func ResourcegroupsGroup_IsConstruct ¶
func ResourcegroupsGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ResourcegroupsGroup_IsTerraformElement ¶
func ResourcegroupsGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func ResourcegroupsGroup_IsTerraformResource ¶
func ResourcegroupsGroup_IsTerraformResource(x interface{}) *bool
Experimental.
func ResourcegroupsGroup_TfResourceType ¶
func ResourcegroupsGroup_TfResourceType() *string
Types ¶
type ResourcegroupsGroup ¶
type ResourcegroupsGroup interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
Configuration() ResourcegroupsGroupConfigurationList
ConfigurationInput() interface{}
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ResourceQuery() ResourcegroupsGroupResourceQueryOutputReference
ResourceQueryInput() *ResourcegroupsGroupResourceQuery
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() ResourcegroupsGroupTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutConfiguration(value interface{})
PutResourceQuery(value *ResourcegroupsGroupResourceQuery)
PutTimeouts(value *ResourcegroupsGroupTimeouts)
ResetConfiguration()
ResetDescription()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetResourceQuery()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/resourcegroups_group aws_resourcegroups_group}.
func NewResourcegroupsGroup ¶
func NewResourcegroupsGroup(scope constructs.Construct, id *string, config *ResourcegroupsGroupConfig) ResourcegroupsGroup
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/resourcegroups_group aws_resourcegroups_group} Resource.
type ResourcegroupsGroupConfig ¶
type ResourcegroupsGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/resourcegroups_group#name ResourcegroupsGroup#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/resourcegroups_group#configuration ResourcegroupsGroup#configuration}
Configuration interface{} `field:"optional" json:"configuration" yaml:"configuration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/resourcegroups_group#description ResourcegroupsGroup#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/resourcegroups_group#id ResourcegroupsGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// resource_query block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/resourcegroups_group#resource_query ResourcegroupsGroup#resource_query}
ResourceQuery *ResourcegroupsGroupResourceQuery `field:"optional" json:"resourceQuery" yaml:"resourceQuery"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/resourcegroups_group#tags ResourcegroupsGroup#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/resourcegroups_group#tags_all ResourcegroupsGroup#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/resourcegroups_group#timeouts ResourcegroupsGroup#timeouts}
Timeouts *ResourcegroupsGroupTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type ResourcegroupsGroupConfiguration ¶
type ResourcegroupsGroupConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/resourcegroups_group#type ResourcegroupsGroup#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// parameters block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/resourcegroups_group#parameters ResourcegroupsGroup#parameters}
Parameters interface{} `field:"optional" json:"parameters" yaml:"parameters"`
}
type ResourcegroupsGroupConfigurationList ¶
type ResourcegroupsGroupConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ResourcegroupsGroupConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewResourcegroupsGroupConfigurationList ¶
func NewResourcegroupsGroupConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ResourcegroupsGroupConfigurationList
type ResourcegroupsGroupConfigurationOutputReference ¶
type ResourcegroupsGroupConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Parameters() ResourcegroupsGroupConfigurationParametersList
ParametersInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutParameters(value interface{})
ResetParameters()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewResourcegroupsGroupConfigurationOutputReference ¶
func NewResourcegroupsGroupConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ResourcegroupsGroupConfigurationOutputReference
type ResourcegroupsGroupConfigurationParameters ¶
type ResourcegroupsGroupConfigurationParameters struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/resourcegroups_group#name ResourcegroupsGroup#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/resourcegroups_group#values ResourcegroupsGroup#values}.
Values *[]*string `field:"required" json:"values" yaml:"values"`
}
type ResourcegroupsGroupConfigurationParametersList ¶
type ResourcegroupsGroupConfigurationParametersList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) ResourcegroupsGroupConfigurationParametersOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewResourcegroupsGroupConfigurationParametersList ¶
func NewResourcegroupsGroupConfigurationParametersList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ResourcegroupsGroupConfigurationParametersList
type ResourcegroupsGroupConfigurationParametersOutputReference ¶
type ResourcegroupsGroupConfigurationParametersOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
SetValues(val *[]*string)
ValuesInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewResourcegroupsGroupConfigurationParametersOutputReference ¶
func NewResourcegroupsGroupConfigurationParametersOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ResourcegroupsGroupConfigurationParametersOutputReference
type ResourcegroupsGroupResourceQuery ¶
type ResourcegroupsGroupResourceQuery struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/resourcegroups_group#query ResourcegroupsGroup#query}.
Query *string `field:"required" json:"query" yaml:"query"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/resourcegroups_group#type ResourcegroupsGroup#type}.
Type *string `field:"optional" json:"type" yaml:"type"`
}
type ResourcegroupsGroupResourceQueryOutputReference ¶
type ResourcegroupsGroupResourceQueryOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ResourcegroupsGroupResourceQuery
SetInternalValue(val *ResourcegroupsGroupResourceQuery)
Query() *string
SetQuery(val *string)
QueryInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewResourcegroupsGroupResourceQueryOutputReference ¶
func NewResourcegroupsGroupResourceQueryOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ResourcegroupsGroupResourceQueryOutputReference
type ResourcegroupsGroupTimeouts ¶
type ResourcegroupsGroupTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/resourcegroups_group#create ResourcegroupsGroup#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/resourcegroups_group#update ResourcegroupsGroup#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type ResourcegroupsGroupTimeoutsOutputReference ¶
type ResourcegroupsGroupTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewResourcegroupsGroupTimeoutsOutputReference ¶
func NewResourcegroupsGroupTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ResourcegroupsGroupTimeoutsOutputReference
Source Files
¶
- ResourcegroupsGroup.go
- ResourcegroupsGroupConfig.go
- ResourcegroupsGroupConfiguration.go
- ResourcegroupsGroupConfigurationList.go
- ResourcegroupsGroupConfigurationList__checks.go
- ResourcegroupsGroupConfigurationOutputReference.go
- ResourcegroupsGroupConfigurationOutputReference__checks.go
- ResourcegroupsGroupConfigurationParameters.go
- ResourcegroupsGroupConfigurationParametersList.go
- ResourcegroupsGroupConfigurationParametersList__checks.go
- ResourcegroupsGroupConfigurationParametersOutputReference.go
- ResourcegroupsGroupConfigurationParametersOutputReference__checks.go
- ResourcegroupsGroupResourceQuery.go
- ResourcegroupsGroupResourceQueryOutputReference.go
- ResourcegroupsGroupResourceQueryOutputReference__checks.go
- ResourcegroupsGroupTimeouts.go
- ResourcegroupsGroupTimeoutsOutputReference.go
- ResourcegroupsGroupTimeoutsOutputReference__checks.go
- ResourcegroupsGroup__checks.go
- main.go