Documentation
¶
Index ¶
- func NewRouteTimeoutsOutputReference_Override(r RouteTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, ...)
- func NewRoute_Override(r Route, scope constructs.Construct, id *string, config *RouteConfig)
- func Route_IsConstruct(x interface{}) *bool
- func Route_IsTerraformElement(x interface{}) *bool
- func Route_IsTerraformResource(x interface{}) *bool
- func Route_TfResourceType() *string
- type Route
- type RouteConfig
- type RouteTimeouts
- type RouteTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRouteTimeoutsOutputReference_Override ¶
func NewRouteTimeoutsOutputReference_Override(r RouteTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewRoute_Override ¶
func NewRoute_Override(r Route, scope constructs.Construct, id *string, config *RouteConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route aws_route} Resource.
func Route_IsConstruct ¶
func Route_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func Route_TfResourceType ¶
func Route_TfResourceType() *string
Types ¶
type Route ¶
type Route interface {
cdktf.TerraformResource
CarrierGatewayId() *string
SetCarrierGatewayId(val *string)
CarrierGatewayIdInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
CoreNetworkArn() *string
SetCoreNetworkArn(val *string)
CoreNetworkArnInput() *string
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DestinationCidrBlock() *string
SetDestinationCidrBlock(val *string)
DestinationCidrBlockInput() *string
DestinationIpv6CidrBlock() *string
SetDestinationIpv6CidrBlock(val *string)
DestinationIpv6CidrBlockInput() *string
DestinationPrefixListId() *string
SetDestinationPrefixListId(val *string)
DestinationPrefixListIdInput() *string
EgressOnlyGatewayId() *string
SetEgressOnlyGatewayId(val *string)
EgressOnlyGatewayIdInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GatewayId() *string
SetGatewayId(val *string)
GatewayIdInput() *string
Id() *string
SetId(val *string)
IdInput() *string
InstanceId() *string
SetInstanceId(val *string)
InstanceIdInput() *string
InstanceOwnerId() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LocalGatewayId() *string
SetLocalGatewayId(val *string)
LocalGatewayIdInput() *string
NatGatewayId() *string
SetNatGatewayId(val *string)
NatGatewayIdInput() *string
NetworkInterfaceId() *string
SetNetworkInterfaceId(val *string)
NetworkInterfaceIdInput() *string
// The tree node.
Node() constructs.Node
Origin() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RouteTableId() *string
SetRouteTableId(val *string)
RouteTableIdInput() *string
State() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() RouteTimeoutsOutputReference
TimeoutsInput() interface{}
TransitGatewayId() *string
SetTransitGatewayId(val *string)
TransitGatewayIdInput() *string
VpcEndpointId() *string
SetVpcEndpointId(val *string)
VpcEndpointIdInput() *string
VpcPeeringConnectionId() *string
SetVpcPeeringConnectionId(val *string)
VpcPeeringConnectionIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *RouteTimeouts)
ResetCarrierGatewayId()
ResetCoreNetworkArn()
ResetDestinationCidrBlock()
ResetDestinationIpv6CidrBlock()
ResetDestinationPrefixListId()
ResetEgressOnlyGatewayId()
ResetGatewayId()
ResetId()
ResetInstanceId()
ResetLocalGatewayId()
ResetNatGatewayId()
ResetNetworkInterfaceId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
ResetTransitGatewayId()
ResetVpcEndpointId()
ResetVpcPeeringConnectionId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route aws_route}.
func NewRoute ¶
func NewRoute(scope constructs.Construct, id *string, config *RouteConfig) Route
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route aws_route} Resource.
type RouteConfig ¶
type RouteConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#route_table_id Route#route_table_id}.
RouteTableId *string `field:"required" json:"routeTableId" yaml:"routeTableId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#carrier_gateway_id Route#carrier_gateway_id}.
CarrierGatewayId *string `field:"optional" json:"carrierGatewayId" yaml:"carrierGatewayId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#core_network_arn Route#core_network_arn}.
CoreNetworkArn *string `field:"optional" json:"coreNetworkArn" yaml:"coreNetworkArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#destination_cidr_block Route#destination_cidr_block}.
DestinationCidrBlock *string `field:"optional" json:"destinationCidrBlock" yaml:"destinationCidrBlock"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#destination_ipv6_cidr_block Route#destination_ipv6_cidr_block}.
DestinationIpv6CidrBlock *string `field:"optional" json:"destinationIpv6CidrBlock" yaml:"destinationIpv6CidrBlock"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#destination_prefix_list_id Route#destination_prefix_list_id}.
DestinationPrefixListId *string `field:"optional" json:"destinationPrefixListId" yaml:"destinationPrefixListId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#egress_only_gateway_id Route#egress_only_gateway_id}.
EgressOnlyGatewayId *string `field:"optional" json:"egressOnlyGatewayId" yaml:"egressOnlyGatewayId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#gateway_id Route#gateway_id}.
GatewayId *string `field:"optional" json:"gatewayId" yaml:"gatewayId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#id Route#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#instance_id Route#instance_id}.
InstanceId *string `field:"optional" json:"instanceId" yaml:"instanceId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#local_gateway_id Route#local_gateway_id}.
LocalGatewayId *string `field:"optional" json:"localGatewayId" yaml:"localGatewayId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#nat_gateway_id Route#nat_gateway_id}.
NatGatewayId *string `field:"optional" json:"natGatewayId" yaml:"natGatewayId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#network_interface_id Route#network_interface_id}.
NetworkInterfaceId *string `field:"optional" json:"networkInterfaceId" yaml:"networkInterfaceId"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#timeouts Route#timeouts}
Timeouts *RouteTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#transit_gateway_id Route#transit_gateway_id}.
TransitGatewayId *string `field:"optional" json:"transitGatewayId" yaml:"transitGatewayId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#vpc_endpoint_id Route#vpc_endpoint_id}.
VpcEndpointId *string `field:"optional" json:"vpcEndpointId" yaml:"vpcEndpointId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#vpc_peering_connection_id Route#vpc_peering_connection_id}.
VpcPeeringConnectionId *string `field:"optional" json:"vpcPeeringConnectionId" yaml:"vpcPeeringConnectionId"`
}
type RouteTimeouts ¶
type RouteTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#create Route#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#delete Route#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route#update Route#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type RouteTimeoutsOutputReference ¶
type RouteTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRouteTimeoutsOutputReference ¶
func NewRouteTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) RouteTimeoutsOutputReference