Documentation
¶
Index ¶
- func NewRouteTableRouteList_Override(r RouteTableRouteList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewRouteTableRouteOutputReference_Override(r RouteTableRouteOutputReference, terraformResource cdktf.IInterpolatingParent, ...)
- func NewRouteTableTimeoutsOutputReference_Override(r RouteTableTimeoutsOutputReference, ...)
- func NewRouteTable_Override(r RouteTable, scope constructs.Construct, id *string, config *RouteTableConfig)
- func RouteTable_IsConstruct(x interface{}) *bool
- func RouteTable_IsTerraformElement(x interface{}) *bool
- func RouteTable_IsTerraformResource(x interface{}) *bool
- func RouteTable_TfResourceType() *string
- type RouteTable
- type RouteTableConfig
- type RouteTableRoute
- type RouteTableRouteList
- type RouteTableRouteOutputReference
- type RouteTableTimeouts
- type RouteTableTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRouteTableRouteList_Override ¶
func NewRouteTableRouteList_Override(r RouteTableRouteList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewRouteTableRouteOutputReference_Override ¶
func NewRouteTableRouteOutputReference_Override(r RouteTableRouteOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewRouteTableTimeoutsOutputReference_Override ¶
func NewRouteTableTimeoutsOutputReference_Override(r RouteTableTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewRouteTable_Override ¶
func NewRouteTable_Override(r RouteTable, scope constructs.Construct, id *string, config *RouteTableConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table aws_route_table} Resource.
func RouteTable_IsConstruct ¶
func RouteTable_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func RouteTable_IsTerraformElement ¶
func RouteTable_IsTerraformElement(x interface{}) *bool
Experimental.
func RouteTable_IsTerraformResource ¶
func RouteTable_IsTerraformResource(x interface{}) *bool
Experimental.
func RouteTable_TfResourceType ¶
func RouteTable_TfResourceType() *string
Types ¶
type RouteTable ¶
type RouteTable interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
OwnerId() *string
PropagatingVgws() *[]*string
SetPropagatingVgws(val *[]*string)
PropagatingVgwsInput() *[]*string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Route() RouteTableRouteList
RouteInput() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() RouteTableTimeoutsOutputReference
TimeoutsInput() interface{}
VpcId() *string
SetVpcId(val *string)
VpcIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutRoute(value interface{})
PutTimeouts(value *RouteTableTimeouts)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPropagatingVgws()
ResetRoute()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table aws_route_table}.
func NewRouteTable ¶
func NewRouteTable(scope constructs.Construct, id *string, config *RouteTableConfig) RouteTable
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table aws_route_table} Resource.
type RouteTableConfig ¶
type RouteTableConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#vpc_id RouteTable#vpc_id}.
VpcId *string `field:"required" json:"vpcId" yaml:"vpcId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#id RouteTable#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#propagating_vgws RouteTable#propagating_vgws}.
PropagatingVgws *[]*string `field:"optional" json:"propagatingVgws" yaml:"propagatingVgws"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#route RouteTable#route}.
Route interface{} `field:"optional" json:"route" yaml:"route"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#tags RouteTable#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#tags_all RouteTable#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#timeouts RouteTable#timeouts}
Timeouts *RouteTableTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type RouteTableRoute ¶
type RouteTableRoute struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#carrier_gateway_id RouteTable#carrier_gateway_id}.
CarrierGatewayId *string `field:"optional" json:"carrierGatewayId" yaml:"carrierGatewayId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#cidr_block RouteTable#cidr_block}.
CidrBlock *string `field:"optional" json:"cidrBlock" yaml:"cidrBlock"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#core_network_arn RouteTable#core_network_arn}.
CoreNetworkArn *string `field:"optional" json:"coreNetworkArn" yaml:"coreNetworkArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#destination_prefix_list_id RouteTable#destination_prefix_list_id}.
DestinationPrefixListId *string `field:"optional" json:"destinationPrefixListId" yaml:"destinationPrefixListId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#egress_only_gateway_id RouteTable#egress_only_gateway_id}.
EgressOnlyGatewayId *string `field:"optional" json:"egressOnlyGatewayId" yaml:"egressOnlyGatewayId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#gateway_id RouteTable#gateway_id}.
GatewayId *string `field:"optional" json:"gatewayId" yaml:"gatewayId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#instance_id RouteTable#instance_id}.
InstanceId *string `field:"optional" json:"instanceId" yaml:"instanceId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#ipv6_cidr_block RouteTable#ipv6_cidr_block}.
Ipv6CidrBlock *string `field:"optional" json:"ipv6CidrBlock" yaml:"ipv6CidrBlock"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#local_gateway_id RouteTable#local_gateway_id}.
LocalGatewayId *string `field:"optional" json:"localGatewayId" yaml:"localGatewayId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#nat_gateway_id RouteTable#nat_gateway_id}.
NatGatewayId *string `field:"optional" json:"natGatewayId" yaml:"natGatewayId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#network_interface_id RouteTable#network_interface_id}.
NetworkInterfaceId *string `field:"optional" json:"networkInterfaceId" yaml:"networkInterfaceId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#transit_gateway_id RouteTable#transit_gateway_id}.
TransitGatewayId *string `field:"optional" json:"transitGatewayId" yaml:"transitGatewayId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#vpc_endpoint_id RouteTable#vpc_endpoint_id}.
VpcEndpointId *string `field:"optional" json:"vpcEndpointId" yaml:"vpcEndpointId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#vpc_peering_connection_id RouteTable#vpc_peering_connection_id}.
VpcPeeringConnectionId *string `field:"optional" json:"vpcPeeringConnectionId" yaml:"vpcPeeringConnectionId"`
}
type RouteTableRouteList ¶
type RouteTableRouteList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) RouteTableRouteOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRouteTableRouteList ¶
func NewRouteTableRouteList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) RouteTableRouteList
type RouteTableRouteOutputReference ¶
type RouteTableRouteOutputReference interface {
cdktf.ComplexObject
CarrierGatewayId() *string
SetCarrierGatewayId(val *string)
CarrierGatewayIdInput() *string
CidrBlock() *string
SetCidrBlock(val *string)
CidrBlockInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CoreNetworkArn() *string
SetCoreNetworkArn(val *string)
CoreNetworkArnInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DestinationPrefixListId() *string
SetDestinationPrefixListId(val *string)
DestinationPrefixListIdInput() *string
EgressOnlyGatewayId() *string
SetEgressOnlyGatewayId(val *string)
EgressOnlyGatewayIdInput() *string
// Experimental.
Fqn() *string
GatewayId() *string
SetGatewayId(val *string)
GatewayIdInput() *string
InstanceId() *string
SetInstanceId(val *string)
InstanceIdInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Ipv6CidrBlock() *string
SetIpv6CidrBlock(val *string)
Ipv6CidrBlockInput() *string
LocalGatewayId() *string
SetLocalGatewayId(val *string)
LocalGatewayIdInput() *string
NatGatewayId() *string
SetNatGatewayId(val *string)
NatGatewayIdInput() *string
NetworkInterfaceId() *string
SetNetworkInterfaceId(val *string)
NetworkInterfaceIdInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TransitGatewayId() *string
SetTransitGatewayId(val *string)
TransitGatewayIdInput() *string
VpcEndpointId() *string
SetVpcEndpointId(val *string)
VpcEndpointIdInput() *string
VpcPeeringConnectionId() *string
SetVpcPeeringConnectionId(val *string)
VpcPeeringConnectionIdInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCarrierGatewayId()
ResetCidrBlock()
ResetCoreNetworkArn()
ResetDestinationPrefixListId()
ResetEgressOnlyGatewayId()
ResetGatewayId()
ResetInstanceId()
ResetIpv6CidrBlock()
ResetLocalGatewayId()
ResetNatGatewayId()
ResetNetworkInterfaceId()
ResetTransitGatewayId()
ResetVpcEndpointId()
ResetVpcPeeringConnectionId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRouteTableRouteOutputReference ¶
func NewRouteTableRouteOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) RouteTableRouteOutputReference
type RouteTableTimeouts ¶
type RouteTableTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#create RouteTable#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#delete RouteTable#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/route_table#update RouteTable#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type RouteTableTimeoutsOutputReference ¶
type RouteTableTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewRouteTableTimeoutsOutputReference ¶
func NewRouteTableTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) RouteTableTimeoutsOutputReference
Source Files
¶
- RouteTable.go
- RouteTableConfig.go
- RouteTableRoute.go
- RouteTableRouteList.go
- RouteTableRouteList__checks.go
- RouteTableRouteOutputReference.go
- RouteTableRouteOutputReference__checks.go
- RouteTableTimeouts.go
- RouteTableTimeoutsOutputReference.go
- RouteTableTimeoutsOutputReference__checks.go
- RouteTable__checks.go
- main.go