Documentation
¶
Index ¶
- func NewSagemakerFeatureGroupFeatureDefinitionList_Override(s SagemakerFeatureGroupFeatureDefinitionList, ...)
- func NewSagemakerFeatureGroupFeatureDefinitionOutputReference_Override(s SagemakerFeatureGroupFeatureDefinitionOutputReference, ...)
- func NewSagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference_Override(s SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference, ...)
- func NewSagemakerFeatureGroupOfflineStoreConfigOutputReference_Override(s SagemakerFeatureGroupOfflineStoreConfigOutputReference, ...)
- func NewSagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference_Override(s SagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference, ...)
- func NewSagemakerFeatureGroupOnlineStoreConfigOutputReference_Override(s SagemakerFeatureGroupOnlineStoreConfigOutputReference, ...)
- func NewSagemakerFeatureGroupOnlineStoreConfigSecurityConfigOutputReference_Override(s SagemakerFeatureGroupOnlineStoreConfigSecurityConfigOutputReference, ...)
- func NewSagemakerFeatureGroup_Override(s SagemakerFeatureGroup, scope constructs.Construct, id *string, ...)
- func SagemakerFeatureGroup_IsConstruct(x interface{}) *bool
- func SagemakerFeatureGroup_IsTerraformElement(x interface{}) *bool
- func SagemakerFeatureGroup_IsTerraformResource(x interface{}) *bool
- func SagemakerFeatureGroup_TfResourceType() *string
- type SagemakerFeatureGroup
- type SagemakerFeatureGroupConfig
- type SagemakerFeatureGroupFeatureDefinition
- type SagemakerFeatureGroupFeatureDefinitionList
- type SagemakerFeatureGroupFeatureDefinitionOutputReference
- type SagemakerFeatureGroupOfflineStoreConfig
- type SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfig
- type SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference
- type SagemakerFeatureGroupOfflineStoreConfigOutputReference
- type SagemakerFeatureGroupOfflineStoreConfigS3StorageConfig
- type SagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference
- type SagemakerFeatureGroupOnlineStoreConfig
- type SagemakerFeatureGroupOnlineStoreConfigOutputReference
- type SagemakerFeatureGroupOnlineStoreConfigSecurityConfig
- type SagemakerFeatureGroupOnlineStoreConfigSecurityConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSagemakerFeatureGroupFeatureDefinitionList_Override ¶
func NewSagemakerFeatureGroupFeatureDefinitionList_Override(s SagemakerFeatureGroupFeatureDefinitionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSagemakerFeatureGroupFeatureDefinitionOutputReference_Override ¶
func NewSagemakerFeatureGroupFeatureDefinitionOutputReference_Override(s SagemakerFeatureGroupFeatureDefinitionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference_Override ¶
func NewSagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference_Override(s SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerFeatureGroupOfflineStoreConfigOutputReference_Override ¶
func NewSagemakerFeatureGroupOfflineStoreConfigOutputReference_Override(s SagemakerFeatureGroupOfflineStoreConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference_Override ¶
func NewSagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference_Override(s SagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerFeatureGroupOnlineStoreConfigOutputReference_Override ¶
func NewSagemakerFeatureGroupOnlineStoreConfigOutputReference_Override(s SagemakerFeatureGroupOnlineStoreConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerFeatureGroupOnlineStoreConfigSecurityConfigOutputReference_Override ¶
func NewSagemakerFeatureGroupOnlineStoreConfigSecurityConfigOutputReference_Override(s SagemakerFeatureGroupOnlineStoreConfigSecurityConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerFeatureGroup_Override ¶
func NewSagemakerFeatureGroup_Override(s SagemakerFeatureGroup, scope constructs.Construct, id *string, config *SagemakerFeatureGroupConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group aws_sagemaker_feature_group} Resource.
func SagemakerFeatureGroup_IsConstruct ¶
func SagemakerFeatureGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SagemakerFeatureGroup_IsTerraformElement ¶
func SagemakerFeatureGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func SagemakerFeatureGroup_IsTerraformResource ¶
func SagemakerFeatureGroup_IsTerraformResource(x interface{}) *bool
Experimental.
func SagemakerFeatureGroup_TfResourceType ¶
func SagemakerFeatureGroup_TfResourceType() *string
Types ¶
type SagemakerFeatureGroup ¶
type SagemakerFeatureGroup interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
EventTimeFeatureName() *string
SetEventTimeFeatureName(val *string)
EventTimeFeatureNameInput() *string
FeatureDefinition() SagemakerFeatureGroupFeatureDefinitionList
FeatureDefinitionInput() interface{}
FeatureGroupName() *string
SetFeatureGroupName(val *string)
FeatureGroupNameInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
OfflineStoreConfig() SagemakerFeatureGroupOfflineStoreConfigOutputReference
OfflineStoreConfigInput() *SagemakerFeatureGroupOfflineStoreConfig
OnlineStoreConfig() SagemakerFeatureGroupOnlineStoreConfigOutputReference
OnlineStoreConfigInput() *SagemakerFeatureGroupOnlineStoreConfig
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RecordIdentifierFeatureName() *string
SetRecordIdentifierFeatureName(val *string)
RecordIdentifierFeatureNameInput() *string
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutFeatureDefinition(value interface{})
PutOfflineStoreConfig(value *SagemakerFeatureGroupOfflineStoreConfig)
PutOnlineStoreConfig(value *SagemakerFeatureGroupOnlineStoreConfig)
ResetDescription()
ResetId()
ResetOfflineStoreConfig()
ResetOnlineStoreConfig()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group aws_sagemaker_feature_group}.
func NewSagemakerFeatureGroup ¶
func NewSagemakerFeatureGroup(scope constructs.Construct, id *string, config *SagemakerFeatureGroupConfig) SagemakerFeatureGroup
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group aws_sagemaker_feature_group} Resource.
type SagemakerFeatureGroupConfig ¶
type SagemakerFeatureGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#event_time_feature_name SagemakerFeatureGroup#event_time_feature_name}.
EventTimeFeatureName *string `field:"required" json:"eventTimeFeatureName" yaml:"eventTimeFeatureName"`
// feature_definition block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#feature_definition SagemakerFeatureGroup#feature_definition}
FeatureDefinition interface{} `field:"required" json:"featureDefinition" yaml:"featureDefinition"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#feature_group_name SagemakerFeatureGroup#feature_group_name}.
FeatureGroupName *string `field:"required" json:"featureGroupName" yaml:"featureGroupName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#record_identifier_feature_name SagemakerFeatureGroup#record_identifier_feature_name}.
RecordIdentifierFeatureName *string `field:"required" json:"recordIdentifierFeatureName" yaml:"recordIdentifierFeatureName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#role_arn SagemakerFeatureGroup#role_arn}.
RoleArn *string `field:"required" json:"roleArn" yaml:"roleArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#description SagemakerFeatureGroup#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#id SagemakerFeatureGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// offline_store_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#offline_store_config SagemakerFeatureGroup#offline_store_config}
OfflineStoreConfig *SagemakerFeatureGroupOfflineStoreConfig `field:"optional" json:"offlineStoreConfig" yaml:"offlineStoreConfig"`
// online_store_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#online_store_config SagemakerFeatureGroup#online_store_config}
OnlineStoreConfig *SagemakerFeatureGroupOnlineStoreConfig `field:"optional" json:"onlineStoreConfig" yaml:"onlineStoreConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#tags SagemakerFeatureGroup#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#tags_all SagemakerFeatureGroup#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type SagemakerFeatureGroupFeatureDefinition ¶
type SagemakerFeatureGroupFeatureDefinition struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#feature_name SagemakerFeatureGroup#feature_name}.
FeatureName *string `field:"optional" json:"featureName" yaml:"featureName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#feature_type SagemakerFeatureGroup#feature_type}.
FeatureType *string `field:"optional" json:"featureType" yaml:"featureType"`
}
type SagemakerFeatureGroupFeatureDefinitionList ¶
type SagemakerFeatureGroupFeatureDefinitionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SagemakerFeatureGroupFeatureDefinitionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerFeatureGroupFeatureDefinitionList ¶
func NewSagemakerFeatureGroupFeatureDefinitionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SagemakerFeatureGroupFeatureDefinitionList
type SagemakerFeatureGroupFeatureDefinitionOutputReference ¶
type SagemakerFeatureGroupFeatureDefinitionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FeatureName() *string
SetFeatureName(val *string)
FeatureNameInput() *string
FeatureType() *string
SetFeatureType(val *string)
FeatureTypeInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetFeatureName()
ResetFeatureType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerFeatureGroupFeatureDefinitionOutputReference ¶
func NewSagemakerFeatureGroupFeatureDefinitionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SagemakerFeatureGroupFeatureDefinitionOutputReference
type SagemakerFeatureGroupOfflineStoreConfig ¶
type SagemakerFeatureGroupOfflineStoreConfig struct {
// s3_storage_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#s3_storage_config SagemakerFeatureGroup#s3_storage_config}
S3StorageConfig *SagemakerFeatureGroupOfflineStoreConfigS3StorageConfig `field:"required" json:"s3StorageConfig" yaml:"s3StorageConfig"`
// data_catalog_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#data_catalog_config SagemakerFeatureGroup#data_catalog_config}
DataCatalogConfig *SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfig `field:"optional" json:"dataCatalogConfig" yaml:"dataCatalogConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#disable_glue_table_creation SagemakerFeatureGroup#disable_glue_table_creation}.
DisableGlueTableCreation interface{} `field:"optional" json:"disableGlueTableCreation" yaml:"disableGlueTableCreation"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#table_format SagemakerFeatureGroup#table_format}.
TableFormat *string `field:"optional" json:"tableFormat" yaml:"tableFormat"`
}
type SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfig ¶
type SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfig struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#catalog SagemakerFeatureGroup#catalog}.
Catalog *string `field:"optional" json:"catalog" yaml:"catalog"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#database SagemakerFeatureGroup#database}.
Database *string `field:"optional" json:"database" yaml:"database"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#table_name SagemakerFeatureGroup#table_name}.
TableName *string `field:"optional" json:"tableName" yaml:"tableName"`
}
type SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference ¶
type SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference interface {
cdktf.ComplexObject
Catalog() *string
SetCatalog(val *string)
CatalogInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Database() *string
SetDatabase(val *string)
DatabaseInput() *string
// Experimental.
Fqn() *string
InternalValue() *SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfig
SetInternalValue(val *SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfig)
TableName() *string
SetTableName(val *string)
TableNameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCatalog()
ResetDatabase()
ResetTableName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference ¶
func NewSagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference
type SagemakerFeatureGroupOfflineStoreConfigOutputReference ¶
type SagemakerFeatureGroupOfflineStoreConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DataCatalogConfig() SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference
DataCatalogConfigInput() *SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfig
DisableGlueTableCreation() interface{}
SetDisableGlueTableCreation(val interface{})
DisableGlueTableCreationInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *SagemakerFeatureGroupOfflineStoreConfig
SetInternalValue(val *SagemakerFeatureGroupOfflineStoreConfig)
S3StorageConfig() SagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference
S3StorageConfigInput() *SagemakerFeatureGroupOfflineStoreConfigS3StorageConfig
TableFormat() *string
SetTableFormat(val *string)
TableFormatInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutDataCatalogConfig(value *SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfig)
PutS3StorageConfig(value *SagemakerFeatureGroupOfflineStoreConfigS3StorageConfig)
ResetDataCatalogConfig()
ResetDisableGlueTableCreation()
ResetTableFormat()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerFeatureGroupOfflineStoreConfigOutputReference ¶
func NewSagemakerFeatureGroupOfflineStoreConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerFeatureGroupOfflineStoreConfigOutputReference
type SagemakerFeatureGroupOfflineStoreConfigS3StorageConfig ¶
type SagemakerFeatureGroupOfflineStoreConfigS3StorageConfig struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#s3_uri SagemakerFeatureGroup#s3_uri}.
S3Uri *string `field:"required" json:"s3Uri" yaml:"s3Uri"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#kms_key_id SagemakerFeatureGroup#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
}
type SagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference ¶
type SagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SagemakerFeatureGroupOfflineStoreConfigS3StorageConfig
SetInternalValue(val *SagemakerFeatureGroupOfflineStoreConfigS3StorageConfig)
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
S3Uri() *string
SetS3Uri(val *string)
S3UriInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetKmsKeyId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference ¶
func NewSagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference
type SagemakerFeatureGroupOnlineStoreConfig ¶
type SagemakerFeatureGroupOnlineStoreConfig struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#enable_online_store SagemakerFeatureGroup#enable_online_store}.
EnableOnlineStore interface{} `field:"optional" json:"enableOnlineStore" yaml:"enableOnlineStore"`
// security_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#security_config SagemakerFeatureGroup#security_config}
SecurityConfig *SagemakerFeatureGroupOnlineStoreConfigSecurityConfig `field:"optional" json:"securityConfig" yaml:"securityConfig"`
}
type SagemakerFeatureGroupOnlineStoreConfigOutputReference ¶
type SagemakerFeatureGroupOnlineStoreConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EnableOnlineStore() interface{}
SetEnableOnlineStore(val interface{})
EnableOnlineStoreInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *SagemakerFeatureGroupOnlineStoreConfig
SetInternalValue(val *SagemakerFeatureGroupOnlineStoreConfig)
SecurityConfig() SagemakerFeatureGroupOnlineStoreConfigSecurityConfigOutputReference
SecurityConfigInput() *SagemakerFeatureGroupOnlineStoreConfigSecurityConfig
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutSecurityConfig(value *SagemakerFeatureGroupOnlineStoreConfigSecurityConfig)
ResetEnableOnlineStore()
ResetSecurityConfig()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerFeatureGroupOnlineStoreConfigOutputReference ¶
func NewSagemakerFeatureGroupOnlineStoreConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerFeatureGroupOnlineStoreConfigOutputReference
type SagemakerFeatureGroupOnlineStoreConfigSecurityConfig ¶
type SagemakerFeatureGroupOnlineStoreConfigSecurityConfig struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_feature_group#kms_key_id SagemakerFeatureGroup#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
}
type SagemakerFeatureGroupOnlineStoreConfigSecurityConfigOutputReference ¶
type SagemakerFeatureGroupOnlineStoreConfigSecurityConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SagemakerFeatureGroupOnlineStoreConfigSecurityConfig
SetInternalValue(val *SagemakerFeatureGroupOnlineStoreConfigSecurityConfig)
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetKmsKeyId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerFeatureGroupOnlineStoreConfigSecurityConfigOutputReference ¶
func NewSagemakerFeatureGroupOnlineStoreConfigSecurityConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerFeatureGroupOnlineStoreConfigSecurityConfigOutputReference
Source Files
¶
- SagemakerFeatureGroup.go
- SagemakerFeatureGroupConfig.go
- SagemakerFeatureGroupFeatureDefinition.go
- SagemakerFeatureGroupFeatureDefinitionList.go
- SagemakerFeatureGroupFeatureDefinitionList__checks.go
- SagemakerFeatureGroupFeatureDefinitionOutputReference.go
- SagemakerFeatureGroupFeatureDefinitionOutputReference__checks.go
- SagemakerFeatureGroupOfflineStoreConfig.go
- SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfig.go
- SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference.go
- SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference__checks.go
- SagemakerFeatureGroupOfflineStoreConfigOutputReference.go
- SagemakerFeatureGroupOfflineStoreConfigOutputReference__checks.go
- SagemakerFeatureGroupOfflineStoreConfigS3StorageConfig.go
- SagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference.go
- SagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference__checks.go
- SagemakerFeatureGroupOnlineStoreConfig.go
- SagemakerFeatureGroupOnlineStoreConfigOutputReference.go
- SagemakerFeatureGroupOnlineStoreConfigOutputReference__checks.go
- SagemakerFeatureGroupOnlineStoreConfigSecurityConfig.go
- SagemakerFeatureGroupOnlineStoreConfigSecurityConfigOutputReference.go
- SagemakerFeatureGroupOnlineStoreConfigSecurityConfigOutputReference__checks.go
- SagemakerFeatureGroup__checks.go
- main.go