Documentation
¶
Index ¶
- func NewSagemakerProjectServiceCatalogProvisioningDetailsOutputReference_Override(s SagemakerProjectServiceCatalogProvisioningDetailsOutputReference, ...)
- func NewSagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterList_Override(s SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterList, ...)
- func NewSagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterOutputReference_Override(...)
- func NewSagemakerProject_Override(s SagemakerProject, scope constructs.Construct, id *string, ...)
- func SagemakerProject_IsConstruct(x interface{}) *bool
- func SagemakerProject_IsTerraformElement(x interface{}) *bool
- func SagemakerProject_IsTerraformResource(x interface{}) *bool
- func SagemakerProject_TfResourceType() *string
- type SagemakerProject
- type SagemakerProjectConfig
- type SagemakerProjectServiceCatalogProvisioningDetails
- type SagemakerProjectServiceCatalogProvisioningDetailsOutputReference
- type SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameter
- type SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterList
- type SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSagemakerProjectServiceCatalogProvisioningDetailsOutputReference_Override ¶
func NewSagemakerProjectServiceCatalogProvisioningDetailsOutputReference_Override(s SagemakerProjectServiceCatalogProvisioningDetailsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterList_Override ¶
func NewSagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterList_Override(s SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterOutputReference_Override ¶
func NewSagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterOutputReference_Override(s SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSagemakerProject_Override ¶
func NewSagemakerProject_Override(s SagemakerProject, scope constructs.Construct, id *string, config *SagemakerProjectConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_project aws_sagemaker_project} Resource.
func SagemakerProject_IsConstruct ¶
func SagemakerProject_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SagemakerProject_IsTerraformElement ¶
func SagemakerProject_IsTerraformElement(x interface{}) *bool
Experimental.
func SagemakerProject_IsTerraformResource ¶
func SagemakerProject_IsTerraformResource(x interface{}) *bool
Experimental.
func SagemakerProject_TfResourceType ¶
func SagemakerProject_TfResourceType() *string
Types ¶
type SagemakerProject ¶
type SagemakerProject interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
ProjectDescription() *string
SetProjectDescription(val *string)
ProjectDescriptionInput() *string
ProjectId() *string
ProjectName() *string
SetProjectName(val *string)
ProjectNameInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ServiceCatalogProvisioningDetails() SagemakerProjectServiceCatalogProvisioningDetailsOutputReference
ServiceCatalogProvisioningDetailsInput() *SagemakerProjectServiceCatalogProvisioningDetails
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutServiceCatalogProvisioningDetails(value *SagemakerProjectServiceCatalogProvisioningDetails)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProjectDescription()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_project aws_sagemaker_project}.
func NewSagemakerProject ¶
func NewSagemakerProject(scope constructs.Construct, id *string, config *SagemakerProjectConfig) SagemakerProject
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_project aws_sagemaker_project} Resource.
type SagemakerProjectConfig ¶
type SagemakerProjectConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_project#project_name SagemakerProject#project_name}.
ProjectName *string `field:"required" json:"projectName" yaml:"projectName"`
// service_catalog_provisioning_details block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_project#service_catalog_provisioning_details SagemakerProject#service_catalog_provisioning_details}
ServiceCatalogProvisioningDetails *SagemakerProjectServiceCatalogProvisioningDetails `field:"required" json:"serviceCatalogProvisioningDetails" yaml:"serviceCatalogProvisioningDetails"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_project#id SagemakerProject#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_project#project_description SagemakerProject#project_description}.
ProjectDescription *string `field:"optional" json:"projectDescription" yaml:"projectDescription"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_project#tags SagemakerProject#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_project#tags_all SagemakerProject#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type SagemakerProjectServiceCatalogProvisioningDetails ¶
type SagemakerProjectServiceCatalogProvisioningDetails struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_project#product_id SagemakerProject#product_id}.
ProductId *string `field:"required" json:"productId" yaml:"productId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_project#path_id SagemakerProject#path_id}.
PathId *string `field:"optional" json:"pathId" yaml:"pathId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_project#provisioning_artifact_id SagemakerProject#provisioning_artifact_id}.
ProvisioningArtifactId *string `field:"optional" json:"provisioningArtifactId" yaml:"provisioningArtifactId"`
// provisioning_parameter block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_project#provisioning_parameter SagemakerProject#provisioning_parameter}
ProvisioningParameter interface{} `field:"optional" json:"provisioningParameter" yaml:"provisioningParameter"`
}
type SagemakerProjectServiceCatalogProvisioningDetailsOutputReference ¶
type SagemakerProjectServiceCatalogProvisioningDetailsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SagemakerProjectServiceCatalogProvisioningDetails
SetInternalValue(val *SagemakerProjectServiceCatalogProvisioningDetails)
PathId() *string
SetPathId(val *string)
PathIdInput() *string
ProductId() *string
SetProductId(val *string)
ProductIdInput() *string
ProvisioningArtifactId() *string
SetProvisioningArtifactId(val *string)
ProvisioningArtifactIdInput() *string
ProvisioningParameter() SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterList
ProvisioningParameterInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutProvisioningParameter(value interface{})
ResetPathId()
ResetProvisioningArtifactId()
ResetProvisioningParameter()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerProjectServiceCatalogProvisioningDetailsOutputReference ¶
func NewSagemakerProjectServiceCatalogProvisioningDetailsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SagemakerProjectServiceCatalogProvisioningDetailsOutputReference
type SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameter ¶
type SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameter struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_project#key SagemakerProject#key}.
Key *string `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sagemaker_project#value SagemakerProject#value}.
Value *string `field:"optional" json:"value" yaml:"value"`
}
type SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterList ¶
type SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterList ¶
func NewSagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterList
type SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterOutputReference ¶
type SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetValue()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterOutputReference ¶
func NewSagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterOutputReference
Source Files
¶
- SagemakerProject.go
- SagemakerProjectConfig.go
- SagemakerProjectServiceCatalogProvisioningDetails.go
- SagemakerProjectServiceCatalogProvisioningDetailsOutputReference.go
- SagemakerProjectServiceCatalogProvisioningDetailsOutputReference__checks.go
- SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameter.go
- SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterList.go
- SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterList__checks.go
- SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterOutputReference.go
- SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterOutputReference__checks.go
- SagemakerProject__checks.go
- main.go