Documentation
¶
Index ¶
- func NewSesReceiptRuleAddHeaderActionList_Override(s SesReceiptRuleAddHeaderActionList, ...)
- func NewSesReceiptRuleAddHeaderActionOutputReference_Override(s SesReceiptRuleAddHeaderActionOutputReference, ...)
- func NewSesReceiptRuleBounceActionList_Override(s SesReceiptRuleBounceActionList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewSesReceiptRuleBounceActionOutputReference_Override(s SesReceiptRuleBounceActionOutputReference, ...)
- func NewSesReceiptRuleLambdaActionList_Override(s SesReceiptRuleLambdaActionList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewSesReceiptRuleLambdaActionOutputReference_Override(s SesReceiptRuleLambdaActionOutputReference, ...)
- func NewSesReceiptRuleS3ActionList_Override(s SesReceiptRuleS3ActionList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewSesReceiptRuleS3ActionOutputReference_Override(s SesReceiptRuleS3ActionOutputReference, ...)
- func NewSesReceiptRuleSnsActionList_Override(s SesReceiptRuleSnsActionList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewSesReceiptRuleSnsActionOutputReference_Override(s SesReceiptRuleSnsActionOutputReference, ...)
- func NewSesReceiptRuleStopActionList_Override(s SesReceiptRuleStopActionList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewSesReceiptRuleStopActionOutputReference_Override(s SesReceiptRuleStopActionOutputReference, ...)
- func NewSesReceiptRuleWorkmailActionList_Override(s SesReceiptRuleWorkmailActionList, ...)
- func NewSesReceiptRuleWorkmailActionOutputReference_Override(s SesReceiptRuleWorkmailActionOutputReference, ...)
- func NewSesReceiptRule_Override(s SesReceiptRule, scope constructs.Construct, id *string, ...)
- func SesReceiptRule_IsConstruct(x interface{}) *bool
- func SesReceiptRule_IsTerraformElement(x interface{}) *bool
- func SesReceiptRule_IsTerraformResource(x interface{}) *bool
- func SesReceiptRule_TfResourceType() *string
- type SesReceiptRule
- type SesReceiptRuleAddHeaderAction
- type SesReceiptRuleAddHeaderActionList
- type SesReceiptRuleAddHeaderActionOutputReference
- type SesReceiptRuleBounceAction
- type SesReceiptRuleBounceActionList
- type SesReceiptRuleBounceActionOutputReference
- type SesReceiptRuleConfig
- type SesReceiptRuleLambdaAction
- type SesReceiptRuleLambdaActionList
- type SesReceiptRuleLambdaActionOutputReference
- type SesReceiptRuleS3Action
- type SesReceiptRuleS3ActionList
- type SesReceiptRuleS3ActionOutputReference
- type SesReceiptRuleSnsAction
- type SesReceiptRuleSnsActionList
- type SesReceiptRuleSnsActionOutputReference
- type SesReceiptRuleStopAction
- type SesReceiptRuleStopActionList
- type SesReceiptRuleStopActionOutputReference
- type SesReceiptRuleWorkmailAction
- type SesReceiptRuleWorkmailActionList
- type SesReceiptRuleWorkmailActionOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSesReceiptRuleAddHeaderActionList_Override ¶
func NewSesReceiptRuleAddHeaderActionList_Override(s SesReceiptRuleAddHeaderActionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSesReceiptRuleAddHeaderActionOutputReference_Override ¶
func NewSesReceiptRuleAddHeaderActionOutputReference_Override(s SesReceiptRuleAddHeaderActionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSesReceiptRuleBounceActionList_Override ¶
func NewSesReceiptRuleBounceActionList_Override(s SesReceiptRuleBounceActionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSesReceiptRuleBounceActionOutputReference_Override ¶
func NewSesReceiptRuleBounceActionOutputReference_Override(s SesReceiptRuleBounceActionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSesReceiptRuleLambdaActionList_Override ¶
func NewSesReceiptRuleLambdaActionList_Override(s SesReceiptRuleLambdaActionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSesReceiptRuleLambdaActionOutputReference_Override ¶
func NewSesReceiptRuleLambdaActionOutputReference_Override(s SesReceiptRuleLambdaActionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSesReceiptRuleS3ActionList_Override ¶
func NewSesReceiptRuleS3ActionList_Override(s SesReceiptRuleS3ActionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSesReceiptRuleS3ActionOutputReference_Override ¶
func NewSesReceiptRuleS3ActionOutputReference_Override(s SesReceiptRuleS3ActionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSesReceiptRuleSnsActionList_Override ¶
func NewSesReceiptRuleSnsActionList_Override(s SesReceiptRuleSnsActionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSesReceiptRuleSnsActionOutputReference_Override ¶
func NewSesReceiptRuleSnsActionOutputReference_Override(s SesReceiptRuleSnsActionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSesReceiptRuleStopActionList_Override ¶
func NewSesReceiptRuleStopActionList_Override(s SesReceiptRuleStopActionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSesReceiptRuleStopActionOutputReference_Override ¶
func NewSesReceiptRuleStopActionOutputReference_Override(s SesReceiptRuleStopActionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSesReceiptRuleWorkmailActionList_Override ¶
func NewSesReceiptRuleWorkmailActionList_Override(s SesReceiptRuleWorkmailActionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSesReceiptRuleWorkmailActionOutputReference_Override ¶
func NewSesReceiptRuleWorkmailActionOutputReference_Override(s SesReceiptRuleWorkmailActionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSesReceiptRule_Override ¶
func NewSesReceiptRule_Override(s SesReceiptRule, scope constructs.Construct, id *string, config *SesReceiptRuleConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule aws_ses_receipt_rule} Resource.
func SesReceiptRule_IsConstruct ¶
func SesReceiptRule_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SesReceiptRule_IsTerraformElement ¶
func SesReceiptRule_IsTerraformElement(x interface{}) *bool
Experimental.
func SesReceiptRule_IsTerraformResource ¶
func SesReceiptRule_IsTerraformResource(x interface{}) *bool
Experimental.
func SesReceiptRule_TfResourceType ¶
func SesReceiptRule_TfResourceType() *string
Types ¶
type SesReceiptRule ¶
type SesReceiptRule interface {
cdktf.TerraformResource
AddHeaderAction() SesReceiptRuleAddHeaderActionList
AddHeaderActionInput() interface{}
After() *string
SetAfter(val *string)
AfterInput() *string
Arn() *string
BounceAction() SesReceiptRuleBounceActionList
BounceActionInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
LambdaAction() SesReceiptRuleLambdaActionList
LambdaActionInput() interface{}
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Recipients() *[]*string
SetRecipients(val *[]*string)
RecipientsInput() *[]*string
RuleSetName() *string
SetRuleSetName(val *string)
RuleSetNameInput() *string
S3Action() SesReceiptRuleS3ActionList
S3ActionInput() interface{}
ScanEnabled() interface{}
SetScanEnabled(val interface{})
ScanEnabledInput() interface{}
SnsAction() SesReceiptRuleSnsActionList
SnsActionInput() interface{}
StopAction() SesReceiptRuleStopActionList
StopActionInput() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
TlsPolicy() *string
SetTlsPolicy(val *string)
TlsPolicyInput() *string
WorkmailAction() SesReceiptRuleWorkmailActionList
WorkmailActionInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAddHeaderAction(value interface{})
PutBounceAction(value interface{})
PutLambdaAction(value interface{})
PutS3Action(value interface{})
PutSnsAction(value interface{})
PutStopAction(value interface{})
PutWorkmailAction(value interface{})
ResetAddHeaderAction()
ResetAfter()
ResetBounceAction()
ResetEnabled()
ResetId()
ResetLambdaAction()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRecipients()
ResetS3Action()
ResetScanEnabled()
ResetSnsAction()
ResetStopAction()
ResetTlsPolicy()
ResetWorkmailAction()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule aws_ses_receipt_rule}.
func NewSesReceiptRule ¶
func NewSesReceiptRule(scope constructs.Construct, id *string, config *SesReceiptRuleConfig) SesReceiptRule
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule aws_ses_receipt_rule} Resource.
type SesReceiptRuleAddHeaderAction ¶
type SesReceiptRuleAddHeaderAction struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#header_name SesReceiptRule#header_name}.
HeaderName *string `field:"required" json:"headerName" yaml:"headerName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#header_value SesReceiptRule#header_value}.
HeaderValue *string `field:"required" json:"headerValue" yaml:"headerValue"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#position SesReceiptRule#position}.
Position *float64 `field:"required" json:"position" yaml:"position"`
}
type SesReceiptRuleAddHeaderActionList ¶
type SesReceiptRuleAddHeaderActionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SesReceiptRuleAddHeaderActionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesReceiptRuleAddHeaderActionList ¶
func NewSesReceiptRuleAddHeaderActionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SesReceiptRuleAddHeaderActionList
type SesReceiptRuleAddHeaderActionOutputReference ¶
type SesReceiptRuleAddHeaderActionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HeaderName() *string
SetHeaderName(val *string)
HeaderNameInput() *string
HeaderValue() *string
SetHeaderValue(val *string)
HeaderValueInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Position() *float64
SetPosition(val *float64)
PositionInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesReceiptRuleAddHeaderActionOutputReference ¶
func NewSesReceiptRuleAddHeaderActionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SesReceiptRuleAddHeaderActionOutputReference
type SesReceiptRuleBounceAction ¶
type SesReceiptRuleBounceAction struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#message SesReceiptRule#message}.
Message *string `field:"required" json:"message" yaml:"message"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#position SesReceiptRule#position}.
Position *float64 `field:"required" json:"position" yaml:"position"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#sender SesReceiptRule#sender}.
Sender *string `field:"required" json:"sender" yaml:"sender"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#smtp_reply_code SesReceiptRule#smtp_reply_code}.
SmtpReplyCode *string `field:"required" json:"smtpReplyCode" yaml:"smtpReplyCode"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#status_code SesReceiptRule#status_code}.
StatusCode *string `field:"optional" json:"statusCode" yaml:"statusCode"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#topic_arn SesReceiptRule#topic_arn}.
TopicArn *string `field:"optional" json:"topicArn" yaml:"topicArn"`
}
type SesReceiptRuleBounceActionList ¶
type SesReceiptRuleBounceActionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SesReceiptRuleBounceActionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesReceiptRuleBounceActionList ¶
func NewSesReceiptRuleBounceActionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SesReceiptRuleBounceActionList
type SesReceiptRuleBounceActionOutputReference ¶
type SesReceiptRuleBounceActionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Message() *string
SetMessage(val *string)
MessageInput() *string
Position() *float64
SetPosition(val *float64)
PositionInput() *float64
Sender() *string
SetSender(val *string)
SenderInput() *string
SmtpReplyCode() *string
SetSmtpReplyCode(val *string)
SmtpReplyCodeInput() *string
StatusCode() *string
SetStatusCode(val *string)
StatusCodeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TopicArn() *string
SetTopicArn(val *string)
TopicArnInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetStatusCode()
ResetTopicArn()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesReceiptRuleBounceActionOutputReference ¶
func NewSesReceiptRuleBounceActionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SesReceiptRuleBounceActionOutputReference
type SesReceiptRuleConfig ¶
type SesReceiptRuleConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#name SesReceiptRule#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#rule_set_name SesReceiptRule#rule_set_name}.
RuleSetName *string `field:"required" json:"ruleSetName" yaml:"ruleSetName"`
// add_header_action block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#add_header_action SesReceiptRule#add_header_action}
AddHeaderAction interface{} `field:"optional" json:"addHeaderAction" yaml:"addHeaderAction"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#after SesReceiptRule#after}.
After *string `field:"optional" json:"after" yaml:"after"`
// bounce_action block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#bounce_action SesReceiptRule#bounce_action}
BounceAction interface{} `field:"optional" json:"bounceAction" yaml:"bounceAction"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#enabled SesReceiptRule#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#id SesReceiptRule#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// lambda_action block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#lambda_action SesReceiptRule#lambda_action}
LambdaAction interface{} `field:"optional" json:"lambdaAction" yaml:"lambdaAction"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#recipients SesReceiptRule#recipients}.
Recipients *[]*string `field:"optional" json:"recipients" yaml:"recipients"`
// s3_action block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#s3_action SesReceiptRule#s3_action}
S3Action interface{} `field:"optional" json:"s3Action" yaml:"s3Action"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#scan_enabled SesReceiptRule#scan_enabled}.
ScanEnabled interface{} `field:"optional" json:"scanEnabled" yaml:"scanEnabled"`
// sns_action block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#sns_action SesReceiptRule#sns_action}
SnsAction interface{} `field:"optional" json:"snsAction" yaml:"snsAction"`
// stop_action block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#stop_action SesReceiptRule#stop_action}
StopAction interface{} `field:"optional" json:"stopAction" yaml:"stopAction"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#tls_policy SesReceiptRule#tls_policy}.
TlsPolicy *string `field:"optional" json:"tlsPolicy" yaml:"tlsPolicy"`
// workmail_action block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#workmail_action SesReceiptRule#workmail_action}
WorkmailAction interface{} `field:"optional" json:"workmailAction" yaml:"workmailAction"`
}
type SesReceiptRuleLambdaAction ¶
type SesReceiptRuleLambdaAction struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#function_arn SesReceiptRule#function_arn}.
FunctionArn *string `field:"required" json:"functionArn" yaml:"functionArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#position SesReceiptRule#position}.
Position *float64 `field:"required" json:"position" yaml:"position"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#invocation_type SesReceiptRule#invocation_type}.
InvocationType *string `field:"optional" json:"invocationType" yaml:"invocationType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#topic_arn SesReceiptRule#topic_arn}.
TopicArn *string `field:"optional" json:"topicArn" yaml:"topicArn"`
}
type SesReceiptRuleLambdaActionList ¶
type SesReceiptRuleLambdaActionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SesReceiptRuleLambdaActionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesReceiptRuleLambdaActionList ¶
func NewSesReceiptRuleLambdaActionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SesReceiptRuleLambdaActionList
type SesReceiptRuleLambdaActionOutputReference ¶
type SesReceiptRuleLambdaActionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
FunctionArn() *string
SetFunctionArn(val *string)
FunctionArnInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
InvocationType() *string
SetInvocationType(val *string)
InvocationTypeInput() *string
Position() *float64
SetPosition(val *float64)
PositionInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TopicArn() *string
SetTopicArn(val *string)
TopicArnInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetInvocationType()
ResetTopicArn()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesReceiptRuleLambdaActionOutputReference ¶
func NewSesReceiptRuleLambdaActionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SesReceiptRuleLambdaActionOutputReference
type SesReceiptRuleS3Action ¶
type SesReceiptRuleS3Action struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#bucket_name SesReceiptRule#bucket_name}.
BucketName *string `field:"required" json:"bucketName" yaml:"bucketName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#position SesReceiptRule#position}.
Position *float64 `field:"required" json:"position" yaml:"position"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#kms_key_arn SesReceiptRule#kms_key_arn}.
KmsKeyArn *string `field:"optional" json:"kmsKeyArn" yaml:"kmsKeyArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#object_key_prefix SesReceiptRule#object_key_prefix}.
ObjectKeyPrefix *string `field:"optional" json:"objectKeyPrefix" yaml:"objectKeyPrefix"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#topic_arn SesReceiptRule#topic_arn}.
TopicArn *string `field:"optional" json:"topicArn" yaml:"topicArn"`
}
type SesReceiptRuleS3ActionList ¶
type SesReceiptRuleS3ActionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SesReceiptRuleS3ActionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesReceiptRuleS3ActionList ¶
func NewSesReceiptRuleS3ActionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SesReceiptRuleS3ActionList
type SesReceiptRuleS3ActionOutputReference ¶
type SesReceiptRuleS3ActionOutputReference interface {
cdktf.ComplexObject
BucketName() *string
SetBucketName(val *string)
BucketNameInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
KmsKeyArn() *string
SetKmsKeyArn(val *string)
KmsKeyArnInput() *string
ObjectKeyPrefix() *string
SetObjectKeyPrefix(val *string)
ObjectKeyPrefixInput() *string
Position() *float64
SetPosition(val *float64)
PositionInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TopicArn() *string
SetTopicArn(val *string)
TopicArnInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetKmsKeyArn()
ResetObjectKeyPrefix()
ResetTopicArn()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesReceiptRuleS3ActionOutputReference ¶
func NewSesReceiptRuleS3ActionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SesReceiptRuleS3ActionOutputReference
type SesReceiptRuleSnsAction ¶
type SesReceiptRuleSnsAction struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#position SesReceiptRule#position}.
Position *float64 `field:"required" json:"position" yaml:"position"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#topic_arn SesReceiptRule#topic_arn}.
TopicArn *string `field:"required" json:"topicArn" yaml:"topicArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#encoding SesReceiptRule#encoding}.
Encoding *string `field:"optional" json:"encoding" yaml:"encoding"`
}
type SesReceiptRuleSnsActionList ¶
type SesReceiptRuleSnsActionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SesReceiptRuleSnsActionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesReceiptRuleSnsActionList ¶
func NewSesReceiptRuleSnsActionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SesReceiptRuleSnsActionList
type SesReceiptRuleSnsActionOutputReference ¶
type SesReceiptRuleSnsActionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Encoding() *string
SetEncoding(val *string)
EncodingInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Position() *float64
SetPosition(val *float64)
PositionInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TopicArn() *string
SetTopicArn(val *string)
TopicArnInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEncoding()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesReceiptRuleSnsActionOutputReference ¶
func NewSesReceiptRuleSnsActionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SesReceiptRuleSnsActionOutputReference
type SesReceiptRuleStopAction ¶
type SesReceiptRuleStopAction struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#position SesReceiptRule#position}.
Position *float64 `field:"required" json:"position" yaml:"position"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#scope SesReceiptRule#scope}.
Scope *string `field:"required" json:"scope" yaml:"scope"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#topic_arn SesReceiptRule#topic_arn}.
TopicArn *string `field:"optional" json:"topicArn" yaml:"topicArn"`
}
type SesReceiptRuleStopActionList ¶
type SesReceiptRuleStopActionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SesReceiptRuleStopActionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesReceiptRuleStopActionList ¶
func NewSesReceiptRuleStopActionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SesReceiptRuleStopActionList
type SesReceiptRuleStopActionOutputReference ¶
type SesReceiptRuleStopActionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Position() *float64
SetPosition(val *float64)
PositionInput() *float64
Scope() *string
SetScope(val *string)
ScopeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TopicArn() *string
SetTopicArn(val *string)
TopicArnInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetTopicArn()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesReceiptRuleStopActionOutputReference ¶
func NewSesReceiptRuleStopActionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SesReceiptRuleStopActionOutputReference
type SesReceiptRuleWorkmailAction ¶
type SesReceiptRuleWorkmailAction struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#organization_arn SesReceiptRule#organization_arn}.
OrganizationArn *string `field:"required" json:"organizationArn" yaml:"organizationArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#position SesReceiptRule#position}.
Position *float64 `field:"required" json:"position" yaml:"position"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ses_receipt_rule#topic_arn SesReceiptRule#topic_arn}.
TopicArn *string `field:"optional" json:"topicArn" yaml:"topicArn"`
}
type SesReceiptRuleWorkmailActionList ¶
type SesReceiptRuleWorkmailActionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SesReceiptRuleWorkmailActionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesReceiptRuleWorkmailActionList ¶
func NewSesReceiptRuleWorkmailActionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SesReceiptRuleWorkmailActionList
type SesReceiptRuleWorkmailActionOutputReference ¶
type SesReceiptRuleWorkmailActionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
OrganizationArn() *string
SetOrganizationArn(val *string)
OrganizationArnInput() *string
Position() *float64
SetPosition(val *float64)
PositionInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TopicArn() *string
SetTopicArn(val *string)
TopicArnInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetTopicArn()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesReceiptRuleWorkmailActionOutputReference ¶
func NewSesReceiptRuleWorkmailActionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SesReceiptRuleWorkmailActionOutputReference
Source Files
¶
- SesReceiptRule.go
- SesReceiptRuleAddHeaderAction.go
- SesReceiptRuleAddHeaderActionList.go
- SesReceiptRuleAddHeaderActionList__checks.go
- SesReceiptRuleAddHeaderActionOutputReference.go
- SesReceiptRuleAddHeaderActionOutputReference__checks.go
- SesReceiptRuleBounceAction.go
- SesReceiptRuleBounceActionList.go
- SesReceiptRuleBounceActionList__checks.go
- SesReceiptRuleBounceActionOutputReference.go
- SesReceiptRuleBounceActionOutputReference__checks.go
- SesReceiptRuleConfig.go
- SesReceiptRuleLambdaAction.go
- SesReceiptRuleLambdaActionList.go
- SesReceiptRuleLambdaActionList__checks.go
- SesReceiptRuleLambdaActionOutputReference.go
- SesReceiptRuleLambdaActionOutputReference__checks.go
- SesReceiptRuleS3Action.go
- SesReceiptRuleS3ActionList.go
- SesReceiptRuleS3ActionList__checks.go
- SesReceiptRuleS3ActionOutputReference.go
- SesReceiptRuleS3ActionOutputReference__checks.go
- SesReceiptRuleSnsAction.go
- SesReceiptRuleSnsActionList.go
- SesReceiptRuleSnsActionList__checks.go
- SesReceiptRuleSnsActionOutputReference.go
- SesReceiptRuleSnsActionOutputReference__checks.go
- SesReceiptRuleStopAction.go
- SesReceiptRuleStopActionList.go
- SesReceiptRuleStopActionList__checks.go
- SesReceiptRuleStopActionOutputReference.go
- SesReceiptRuleStopActionOutputReference__checks.go
- SesReceiptRuleWorkmailAction.go
- SesReceiptRuleWorkmailActionList.go
- SesReceiptRuleWorkmailActionList__checks.go
- SesReceiptRuleWorkmailActionOutputReference.go
- SesReceiptRuleWorkmailActionOutputReference__checks.go
- SesReceiptRule__checks.go
- main.go