Documentation
¶
Index ¶
- func NewSesv2ConfigurationSetDeliveryOptionsOutputReference_Override(s Sesv2ConfigurationSetDeliveryOptionsOutputReference, ...)
- func NewSesv2ConfigurationSetReputationOptionsOutputReference_Override(s Sesv2ConfigurationSetReputationOptionsOutputReference, ...)
- func NewSesv2ConfigurationSetSendingOptionsOutputReference_Override(s Sesv2ConfigurationSetSendingOptionsOutputReference, ...)
- func NewSesv2ConfigurationSetSuppressionOptionsOutputReference_Override(s Sesv2ConfigurationSetSuppressionOptionsOutputReference, ...)
- func NewSesv2ConfigurationSetTrackingOptionsOutputReference_Override(s Sesv2ConfigurationSetTrackingOptionsOutputReference, ...)
- func NewSesv2ConfigurationSetVdmOptionsDashboardOptionsOutputReference_Override(s Sesv2ConfigurationSetVdmOptionsDashboardOptionsOutputReference, ...)
- func NewSesv2ConfigurationSetVdmOptionsGuardianOptionsOutputReference_Override(s Sesv2ConfigurationSetVdmOptionsGuardianOptionsOutputReference, ...)
- func NewSesv2ConfigurationSetVdmOptionsOutputReference_Override(s Sesv2ConfigurationSetVdmOptionsOutputReference, ...)
- func NewSesv2ConfigurationSet_Override(s Sesv2ConfigurationSet, scope constructs.Construct, id *string, ...)
- func Sesv2ConfigurationSet_IsConstruct(x interface{}) *bool
- func Sesv2ConfigurationSet_IsTerraformElement(x interface{}) *bool
- func Sesv2ConfigurationSet_IsTerraformResource(x interface{}) *bool
- func Sesv2ConfigurationSet_TfResourceType() *string
- type Sesv2ConfigurationSet
- type Sesv2ConfigurationSetConfig
- type Sesv2ConfigurationSetDeliveryOptions
- type Sesv2ConfigurationSetDeliveryOptionsOutputReference
- type Sesv2ConfigurationSetReputationOptions
- type Sesv2ConfigurationSetReputationOptionsOutputReference
- type Sesv2ConfigurationSetSendingOptions
- type Sesv2ConfigurationSetSendingOptionsOutputReference
- type Sesv2ConfigurationSetSuppressionOptions
- type Sesv2ConfigurationSetSuppressionOptionsOutputReference
- type Sesv2ConfigurationSetTrackingOptions
- type Sesv2ConfigurationSetTrackingOptionsOutputReference
- type Sesv2ConfigurationSetVdmOptions
- type Sesv2ConfigurationSetVdmOptionsDashboardOptions
- type Sesv2ConfigurationSetVdmOptionsDashboardOptionsOutputReference
- type Sesv2ConfigurationSetVdmOptionsGuardianOptions
- type Sesv2ConfigurationSetVdmOptionsGuardianOptionsOutputReference
- type Sesv2ConfigurationSetVdmOptionsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSesv2ConfigurationSetDeliveryOptionsOutputReference_Override ¶
func NewSesv2ConfigurationSetDeliveryOptionsOutputReference_Override(s Sesv2ConfigurationSetDeliveryOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSesv2ConfigurationSetReputationOptionsOutputReference_Override ¶
func NewSesv2ConfigurationSetReputationOptionsOutputReference_Override(s Sesv2ConfigurationSetReputationOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSesv2ConfigurationSetSendingOptionsOutputReference_Override ¶
func NewSesv2ConfigurationSetSendingOptionsOutputReference_Override(s Sesv2ConfigurationSetSendingOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSesv2ConfigurationSetSuppressionOptionsOutputReference_Override ¶
func NewSesv2ConfigurationSetSuppressionOptionsOutputReference_Override(s Sesv2ConfigurationSetSuppressionOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSesv2ConfigurationSetTrackingOptionsOutputReference_Override ¶
func NewSesv2ConfigurationSetTrackingOptionsOutputReference_Override(s Sesv2ConfigurationSetTrackingOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSesv2ConfigurationSetVdmOptionsDashboardOptionsOutputReference_Override ¶
func NewSesv2ConfigurationSetVdmOptionsDashboardOptionsOutputReference_Override(s Sesv2ConfigurationSetVdmOptionsDashboardOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSesv2ConfigurationSetVdmOptionsGuardianOptionsOutputReference_Override ¶
func NewSesv2ConfigurationSetVdmOptionsGuardianOptionsOutputReference_Override(s Sesv2ConfigurationSetVdmOptionsGuardianOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSesv2ConfigurationSetVdmOptionsOutputReference_Override ¶
func NewSesv2ConfigurationSetVdmOptionsOutputReference_Override(s Sesv2ConfigurationSetVdmOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSesv2ConfigurationSet_Override ¶
func NewSesv2ConfigurationSet_Override(s Sesv2ConfigurationSet, scope constructs.Construct, id *string, config *Sesv2ConfigurationSetConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set aws_sesv2_configuration_set} Resource.
func Sesv2ConfigurationSet_IsConstruct ¶
func Sesv2ConfigurationSet_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func Sesv2ConfigurationSet_IsTerraformElement ¶
func Sesv2ConfigurationSet_IsTerraformElement(x interface{}) *bool
Experimental.
func Sesv2ConfigurationSet_IsTerraformResource ¶
func Sesv2ConfigurationSet_IsTerraformResource(x interface{}) *bool
Experimental.
func Sesv2ConfigurationSet_TfResourceType ¶
func Sesv2ConfigurationSet_TfResourceType() *string
Types ¶
type Sesv2ConfigurationSet ¶
type Sesv2ConfigurationSet interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ConfigurationSetName() *string
SetConfigurationSetName(val *string)
ConfigurationSetNameInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DeliveryOptions() Sesv2ConfigurationSetDeliveryOptionsOutputReference
DeliveryOptionsInput() *Sesv2ConfigurationSetDeliveryOptions
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ReputationOptions() Sesv2ConfigurationSetReputationOptionsOutputReference
ReputationOptionsInput() *Sesv2ConfigurationSetReputationOptions
SendingOptions() Sesv2ConfigurationSetSendingOptionsOutputReference
SendingOptionsInput() *Sesv2ConfigurationSetSendingOptions
SuppressionOptions() Sesv2ConfigurationSetSuppressionOptionsOutputReference
SuppressionOptionsInput() *Sesv2ConfigurationSetSuppressionOptions
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
TrackingOptions() Sesv2ConfigurationSetTrackingOptionsOutputReference
TrackingOptionsInput() *Sesv2ConfigurationSetTrackingOptions
VdmOptions() Sesv2ConfigurationSetVdmOptionsOutputReference
VdmOptionsInput() *Sesv2ConfigurationSetVdmOptions
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDeliveryOptions(value *Sesv2ConfigurationSetDeliveryOptions)
PutReputationOptions(value *Sesv2ConfigurationSetReputationOptions)
PutSendingOptions(value *Sesv2ConfigurationSetSendingOptions)
PutSuppressionOptions(value *Sesv2ConfigurationSetSuppressionOptions)
PutTrackingOptions(value *Sesv2ConfigurationSetTrackingOptions)
PutVdmOptions(value *Sesv2ConfigurationSetVdmOptions)
ResetDeliveryOptions()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetReputationOptions()
ResetSendingOptions()
ResetSuppressionOptions()
ResetTags()
ResetTagsAll()
ResetTrackingOptions()
ResetVdmOptions()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set aws_sesv2_configuration_set}.
func NewSesv2ConfigurationSet ¶
func NewSesv2ConfigurationSet(scope constructs.Construct, id *string, config *Sesv2ConfigurationSetConfig) Sesv2ConfigurationSet
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set aws_sesv2_configuration_set} Resource.
type Sesv2ConfigurationSetConfig ¶
type Sesv2ConfigurationSetConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set#configuration_set_name Sesv2ConfigurationSet#configuration_set_name}.
ConfigurationSetName *string `field:"required" json:"configurationSetName" yaml:"configurationSetName"`
// delivery_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set#delivery_options Sesv2ConfigurationSet#delivery_options}
DeliveryOptions *Sesv2ConfigurationSetDeliveryOptions `field:"optional" json:"deliveryOptions" yaml:"deliveryOptions"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set#id Sesv2ConfigurationSet#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// reputation_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set#reputation_options Sesv2ConfigurationSet#reputation_options}
ReputationOptions *Sesv2ConfigurationSetReputationOptions `field:"optional" json:"reputationOptions" yaml:"reputationOptions"`
// sending_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set#sending_options Sesv2ConfigurationSet#sending_options}
SendingOptions *Sesv2ConfigurationSetSendingOptions `field:"optional" json:"sendingOptions" yaml:"sendingOptions"`
// suppression_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set#suppression_options Sesv2ConfigurationSet#suppression_options}
SuppressionOptions *Sesv2ConfigurationSetSuppressionOptions `field:"optional" json:"suppressionOptions" yaml:"suppressionOptions"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set#tags Sesv2ConfigurationSet#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set#tags_all Sesv2ConfigurationSet#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// tracking_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set#tracking_options Sesv2ConfigurationSet#tracking_options}
TrackingOptions *Sesv2ConfigurationSetTrackingOptions `field:"optional" json:"trackingOptions" yaml:"trackingOptions"`
// vdm_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set#vdm_options Sesv2ConfigurationSet#vdm_options}
VdmOptions *Sesv2ConfigurationSetVdmOptions `field:"optional" json:"vdmOptions" yaml:"vdmOptions"`
}
type Sesv2ConfigurationSetDeliveryOptions ¶
type Sesv2ConfigurationSetDeliveryOptions struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set#sending_pool_name Sesv2ConfigurationSet#sending_pool_name}.
SendingPoolName *string `field:"optional" json:"sendingPoolName" yaml:"sendingPoolName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set#tls_policy Sesv2ConfigurationSet#tls_policy}.
TlsPolicy *string `field:"optional" json:"tlsPolicy" yaml:"tlsPolicy"`
}
type Sesv2ConfigurationSetDeliveryOptionsOutputReference ¶
type Sesv2ConfigurationSetDeliveryOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *Sesv2ConfigurationSetDeliveryOptions
SetInternalValue(val *Sesv2ConfigurationSetDeliveryOptions)
SendingPoolName() *string
SetSendingPoolName(val *string)
SendingPoolNameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TlsPolicy() *string
SetTlsPolicy(val *string)
TlsPolicyInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetSendingPoolName()
ResetTlsPolicy()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesv2ConfigurationSetDeliveryOptionsOutputReference ¶
func NewSesv2ConfigurationSetDeliveryOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Sesv2ConfigurationSetDeliveryOptionsOutputReference
type Sesv2ConfigurationSetReputationOptions ¶
type Sesv2ConfigurationSetReputationOptions struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set#reputation_metrics_enabled Sesv2ConfigurationSet#reputation_metrics_enabled}.
ReputationMetricsEnabled interface{} `field:"optional" json:"reputationMetricsEnabled" yaml:"reputationMetricsEnabled"`
}
type Sesv2ConfigurationSetReputationOptionsOutputReference ¶
type Sesv2ConfigurationSetReputationOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *Sesv2ConfigurationSetReputationOptions
SetInternalValue(val *Sesv2ConfigurationSetReputationOptions)
LastFreshStart() *string
ReputationMetricsEnabled() interface{}
SetReputationMetricsEnabled(val interface{})
ReputationMetricsEnabledInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetReputationMetricsEnabled()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesv2ConfigurationSetReputationOptionsOutputReference ¶
func NewSesv2ConfigurationSetReputationOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Sesv2ConfigurationSetReputationOptionsOutputReference
type Sesv2ConfigurationSetSendingOptions ¶
type Sesv2ConfigurationSetSendingOptions struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set#sending_enabled Sesv2ConfigurationSet#sending_enabled}.
SendingEnabled interface{} `field:"optional" json:"sendingEnabled" yaml:"sendingEnabled"`
}
type Sesv2ConfigurationSetSendingOptionsOutputReference ¶
type Sesv2ConfigurationSetSendingOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *Sesv2ConfigurationSetSendingOptions
SetInternalValue(val *Sesv2ConfigurationSetSendingOptions)
SendingEnabled() interface{}
SetSendingEnabled(val interface{})
SendingEnabledInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetSendingEnabled()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesv2ConfigurationSetSendingOptionsOutputReference ¶
func NewSesv2ConfigurationSetSendingOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Sesv2ConfigurationSetSendingOptionsOutputReference
type Sesv2ConfigurationSetSuppressionOptions ¶
type Sesv2ConfigurationSetSuppressionOptions struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set#suppressed_reasons Sesv2ConfigurationSet#suppressed_reasons}.
SuppressedReasons *[]*string `field:"optional" json:"suppressedReasons" yaml:"suppressedReasons"`
}
type Sesv2ConfigurationSetSuppressionOptionsOutputReference ¶
type Sesv2ConfigurationSetSuppressionOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *Sesv2ConfigurationSetSuppressionOptions
SetInternalValue(val *Sesv2ConfigurationSetSuppressionOptions)
SuppressedReasons() *[]*string
SetSuppressedReasons(val *[]*string)
SuppressedReasonsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetSuppressedReasons()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesv2ConfigurationSetSuppressionOptionsOutputReference ¶
func NewSesv2ConfigurationSetSuppressionOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Sesv2ConfigurationSetSuppressionOptionsOutputReference
type Sesv2ConfigurationSetTrackingOptions ¶
type Sesv2ConfigurationSetTrackingOptions struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set#custom_redirect_domain Sesv2ConfigurationSet#custom_redirect_domain}.
CustomRedirectDomain *string `field:"required" json:"customRedirectDomain" yaml:"customRedirectDomain"`
}
type Sesv2ConfigurationSetTrackingOptionsOutputReference ¶
type Sesv2ConfigurationSetTrackingOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
CustomRedirectDomain() *string
SetCustomRedirectDomain(val *string)
CustomRedirectDomainInput() *string
// Experimental.
Fqn() *string
InternalValue() *Sesv2ConfigurationSetTrackingOptions
SetInternalValue(val *Sesv2ConfigurationSetTrackingOptions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesv2ConfigurationSetTrackingOptionsOutputReference ¶
func NewSesv2ConfigurationSetTrackingOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Sesv2ConfigurationSetTrackingOptionsOutputReference
type Sesv2ConfigurationSetVdmOptions ¶
type Sesv2ConfigurationSetVdmOptions struct {
// dashboard_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set#dashboard_options Sesv2ConfigurationSet#dashboard_options}
DashboardOptions *Sesv2ConfigurationSetVdmOptionsDashboardOptions `field:"optional" json:"dashboardOptions" yaml:"dashboardOptions"`
// guardian_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set#guardian_options Sesv2ConfigurationSet#guardian_options}
GuardianOptions *Sesv2ConfigurationSetVdmOptionsGuardianOptions `field:"optional" json:"guardianOptions" yaml:"guardianOptions"`
}
type Sesv2ConfigurationSetVdmOptionsDashboardOptions ¶
type Sesv2ConfigurationSetVdmOptionsDashboardOptions struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set#engagement_metrics Sesv2ConfigurationSet#engagement_metrics}.
EngagementMetrics *string `field:"optional" json:"engagementMetrics" yaml:"engagementMetrics"`
}
type Sesv2ConfigurationSetVdmOptionsDashboardOptionsOutputReference ¶
type Sesv2ConfigurationSetVdmOptionsDashboardOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EngagementMetrics() *string
SetEngagementMetrics(val *string)
EngagementMetricsInput() *string
// Experimental.
Fqn() *string
InternalValue() *Sesv2ConfigurationSetVdmOptionsDashboardOptions
SetInternalValue(val *Sesv2ConfigurationSetVdmOptionsDashboardOptions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEngagementMetrics()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesv2ConfigurationSetVdmOptionsDashboardOptionsOutputReference ¶
func NewSesv2ConfigurationSetVdmOptionsDashboardOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Sesv2ConfigurationSetVdmOptionsDashboardOptionsOutputReference
type Sesv2ConfigurationSetVdmOptionsGuardianOptions ¶
type Sesv2ConfigurationSetVdmOptionsGuardianOptions struct {
OptimizedSharedDelivery *string `field:"optional" json:"optimizedSharedDelivery" yaml:"optimizedSharedDelivery"`
}
type Sesv2ConfigurationSetVdmOptionsGuardianOptionsOutputReference ¶
type Sesv2ConfigurationSetVdmOptionsGuardianOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *Sesv2ConfigurationSetVdmOptionsGuardianOptions
SetInternalValue(val *Sesv2ConfigurationSetVdmOptionsGuardianOptions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesv2ConfigurationSetVdmOptionsGuardianOptionsOutputReference ¶
func NewSesv2ConfigurationSetVdmOptionsGuardianOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Sesv2ConfigurationSetVdmOptionsGuardianOptionsOutputReference
type Sesv2ConfigurationSetVdmOptionsOutputReference ¶
type Sesv2ConfigurationSetVdmOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DashboardOptions() Sesv2ConfigurationSetVdmOptionsDashboardOptionsOutputReference
DashboardOptionsInput() *Sesv2ConfigurationSetVdmOptionsDashboardOptions
// Experimental.
Fqn() *string
GuardianOptions() Sesv2ConfigurationSetVdmOptionsGuardianOptionsOutputReference
GuardianOptionsInput() *Sesv2ConfigurationSetVdmOptionsGuardianOptions
InternalValue() *Sesv2ConfigurationSetVdmOptions
SetInternalValue(val *Sesv2ConfigurationSetVdmOptions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutDashboardOptions(value *Sesv2ConfigurationSetVdmOptionsDashboardOptions)
PutGuardianOptions(value *Sesv2ConfigurationSetVdmOptionsGuardianOptions)
ResetDashboardOptions()
ResetGuardianOptions()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesv2ConfigurationSetVdmOptionsOutputReference ¶
func NewSesv2ConfigurationSetVdmOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Sesv2ConfigurationSetVdmOptionsOutputReference
Source Files
¶
- Sesv2ConfigurationSet.go
- Sesv2ConfigurationSetConfig.go
- Sesv2ConfigurationSetDeliveryOptions.go
- Sesv2ConfigurationSetDeliveryOptionsOutputReference.go
- Sesv2ConfigurationSetDeliveryOptionsOutputReference__checks.go
- Sesv2ConfigurationSetReputationOptions.go
- Sesv2ConfigurationSetReputationOptionsOutputReference.go
- Sesv2ConfigurationSetReputationOptionsOutputReference__checks.go
- Sesv2ConfigurationSetSendingOptions.go
- Sesv2ConfigurationSetSendingOptionsOutputReference.go
- Sesv2ConfigurationSetSendingOptionsOutputReference__checks.go
- Sesv2ConfigurationSetSuppressionOptions.go
- Sesv2ConfigurationSetSuppressionOptionsOutputReference.go
- Sesv2ConfigurationSetSuppressionOptionsOutputReference__checks.go
- Sesv2ConfigurationSetTrackingOptions.go
- Sesv2ConfigurationSetTrackingOptionsOutputReference.go
- Sesv2ConfigurationSetTrackingOptionsOutputReference__checks.go
- Sesv2ConfigurationSetVdmOptions.go
- Sesv2ConfigurationSetVdmOptionsDashboardOptions.go
- Sesv2ConfigurationSetVdmOptionsDashboardOptionsOutputReference.go
- Sesv2ConfigurationSetVdmOptionsDashboardOptionsOutputReference__checks.go
- Sesv2ConfigurationSetVdmOptionsGuardianOptions.go
- Sesv2ConfigurationSetVdmOptionsGuardianOptionsOutputReference.go
- Sesv2ConfigurationSetVdmOptionsGuardianOptionsOutputReference__checks.go
- Sesv2ConfigurationSetVdmOptionsOutputReference.go
- Sesv2ConfigurationSetVdmOptionsOutputReference__checks.go
- Sesv2ConfigurationSet__checks.go
- main.go