Documentation
¶
Index ¶
- func NewSesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationList_Override(...)
- func NewSesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationOutputReference_Override(...)
- func NewSesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationOutputReference_Override(...)
- func NewSesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestinationOutputReference_Override(...)
- func NewSesv2ConfigurationSetEventDestinationEventDestinationOutputReference_Override(s Sesv2ConfigurationSetEventDestinationEventDestinationOutputReference, ...)
- func NewSesv2ConfigurationSetEventDestinationEventDestinationPinpointDestinationOutputReference_Override(...)
- func NewSesv2ConfigurationSetEventDestinationEventDestinationSnsDestinationOutputReference_Override(...)
- func NewSesv2ConfigurationSetEventDestination_Override(s Sesv2ConfigurationSetEventDestination, scope constructs.Construct, ...)
- func Sesv2ConfigurationSetEventDestination_IsConstruct(x interface{}) *bool
- func Sesv2ConfigurationSetEventDestination_IsTerraformElement(x interface{}) *bool
- func Sesv2ConfigurationSetEventDestination_IsTerraformResource(x interface{}) *bool
- func Sesv2ConfigurationSetEventDestination_TfResourceType() *string
- type Sesv2ConfigurationSetEventDestination
- type Sesv2ConfigurationSetEventDestinationConfig
- type Sesv2ConfigurationSetEventDestinationEventDestination
- type Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestination
- type Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfiguration
- type Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationList
- type Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationOutputReference
- type Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationOutputReference
- type Sesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestination
- type Sesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestinationOutputReference
- type Sesv2ConfigurationSetEventDestinationEventDestinationOutputReference
- type Sesv2ConfigurationSetEventDestinationEventDestinationPinpointDestination
- type Sesv2ConfigurationSetEventDestinationEventDestinationPinpointDestinationOutputReference
- type Sesv2ConfigurationSetEventDestinationEventDestinationSnsDestination
- type Sesv2ConfigurationSetEventDestinationEventDestinationSnsDestinationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationList_Override ¶
func NewSesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationList_Override(s Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationOutputReference_Override ¶
func NewSesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationOutputReference_Override(s Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationOutputReference_Override ¶
func NewSesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationOutputReference_Override(s Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestinationOutputReference_Override ¶
func NewSesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestinationOutputReference_Override(s Sesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestinationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSesv2ConfigurationSetEventDestinationEventDestinationOutputReference_Override ¶
func NewSesv2ConfigurationSetEventDestinationEventDestinationOutputReference_Override(s Sesv2ConfigurationSetEventDestinationEventDestinationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSesv2ConfigurationSetEventDestinationEventDestinationPinpointDestinationOutputReference_Override ¶
func NewSesv2ConfigurationSetEventDestinationEventDestinationPinpointDestinationOutputReference_Override(s Sesv2ConfigurationSetEventDestinationEventDestinationPinpointDestinationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSesv2ConfigurationSetEventDestinationEventDestinationSnsDestinationOutputReference_Override ¶
func NewSesv2ConfigurationSetEventDestinationEventDestinationSnsDestinationOutputReference_Override(s Sesv2ConfigurationSetEventDestinationEventDestinationSnsDestinationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSesv2ConfigurationSetEventDestination_Override ¶
func NewSesv2ConfigurationSetEventDestination_Override(s Sesv2ConfigurationSetEventDestination, scope constructs.Construct, id *string, config *Sesv2ConfigurationSetEventDestinationConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination aws_sesv2_configuration_set_event_destination} Resource.
func Sesv2ConfigurationSetEventDestination_IsConstruct ¶
func Sesv2ConfigurationSetEventDestination_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func Sesv2ConfigurationSetEventDestination_IsTerraformElement ¶
func Sesv2ConfigurationSetEventDestination_IsTerraformElement(x interface{}) *bool
Experimental.
func Sesv2ConfigurationSetEventDestination_IsTerraformResource ¶
func Sesv2ConfigurationSetEventDestination_IsTerraformResource(x interface{}) *bool
Experimental.
func Sesv2ConfigurationSetEventDestination_TfResourceType ¶
func Sesv2ConfigurationSetEventDestination_TfResourceType() *string
Types ¶
type Sesv2ConfigurationSetEventDestination ¶
type Sesv2ConfigurationSetEventDestination interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
ConfigurationSetName() *string
SetConfigurationSetName(val *string)
ConfigurationSetNameInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EventDestination() Sesv2ConfigurationSetEventDestinationEventDestinationOutputReference
EventDestinationInput() *Sesv2ConfigurationSetEventDestinationEventDestination
EventDestinationName() *string
SetEventDestinationName(val *string)
EventDestinationNameInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutEventDestination(value *Sesv2ConfigurationSetEventDestinationEventDestination)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination aws_sesv2_configuration_set_event_destination}.
func NewSesv2ConfigurationSetEventDestination ¶
func NewSesv2ConfigurationSetEventDestination(scope constructs.Construct, id *string, config *Sesv2ConfigurationSetEventDestinationConfig) Sesv2ConfigurationSetEventDestination
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination aws_sesv2_configuration_set_event_destination} Resource.
type Sesv2ConfigurationSetEventDestinationConfig ¶
type Sesv2ConfigurationSetEventDestinationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination#configuration_set_name Sesv2ConfigurationSetEventDestination#configuration_set_name}.
ConfigurationSetName *string `field:"required" json:"configurationSetName" yaml:"configurationSetName"`
// event_destination block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination#event_destination Sesv2ConfigurationSetEventDestination#event_destination}
EventDestination *Sesv2ConfigurationSetEventDestinationEventDestination `field:"required" json:"eventDestination" yaml:"eventDestination"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination#event_destination_name Sesv2ConfigurationSetEventDestination#event_destination_name}.
EventDestinationName *string `field:"required" json:"eventDestinationName" yaml:"eventDestinationName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination#id Sesv2ConfigurationSetEventDestination#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type Sesv2ConfigurationSetEventDestinationEventDestination ¶
type Sesv2ConfigurationSetEventDestinationEventDestination struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination#matching_event_types Sesv2ConfigurationSetEventDestination#matching_event_types}.
MatchingEventTypes *[]*string `field:"required" json:"matchingEventTypes" yaml:"matchingEventTypes"`
// cloud_watch_destination block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination#cloud_watch_destination Sesv2ConfigurationSetEventDestination#cloud_watch_destination}
CloudWatchDestination *Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestination `field:"optional" json:"cloudWatchDestination" yaml:"cloudWatchDestination"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination#enabled Sesv2ConfigurationSetEventDestination#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// kinesis_firehose_destination block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination#kinesis_firehose_destination Sesv2ConfigurationSetEventDestination#kinesis_firehose_destination}
KinesisFirehoseDestination *Sesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestination `field:"optional" json:"kinesisFirehoseDestination" yaml:"kinesisFirehoseDestination"`
// pinpoint_destination block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination#pinpoint_destination Sesv2ConfigurationSetEventDestination#pinpoint_destination}
PinpointDestination *Sesv2ConfigurationSetEventDestinationEventDestinationPinpointDestination `field:"optional" json:"pinpointDestination" yaml:"pinpointDestination"`
// sns_destination block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination#sns_destination Sesv2ConfigurationSetEventDestination#sns_destination}
SnsDestination *Sesv2ConfigurationSetEventDestinationEventDestinationSnsDestination `field:"optional" json:"snsDestination" yaml:"snsDestination"`
}
type Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestination ¶
type Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestination struct {
// dimension_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination#dimension_configuration Sesv2ConfigurationSetEventDestination#dimension_configuration}
DimensionConfiguration interface{} `field:"required" json:"dimensionConfiguration" yaml:"dimensionConfiguration"`
}
type Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfiguration ¶
type Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination#default_dimension_value Sesv2ConfigurationSetEventDestination#default_dimension_value}.
DefaultDimensionValue *string `field:"required" json:"defaultDimensionValue" yaml:"defaultDimensionValue"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination#dimension_name Sesv2ConfigurationSetEventDestination#dimension_name}.
DimensionName *string `field:"required" json:"dimensionName" yaml:"dimensionName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination#dimension_value_source Sesv2ConfigurationSetEventDestination#dimension_value_source}.
DimensionValueSource *string `field:"required" json:"dimensionValueSource" yaml:"dimensionValueSource"`
}
type Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationList ¶
type Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationList ¶
func NewSesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationList
type Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationOutputReference ¶
type Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DefaultDimensionValue() *string
SetDefaultDimensionValue(val *string)
DefaultDimensionValueInput() *string
DimensionName() *string
SetDimensionName(val *string)
DimensionNameInput() *string
DimensionValueSource() *string
SetDimensionValueSource(val *string)
DimensionValueSourceInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationOutputReference ¶
func NewSesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationOutputReference
type Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationOutputReference ¶
type Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DimensionConfiguration() Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationList
DimensionConfigurationInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestination
SetInternalValue(val *Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestination)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutDimensionConfiguration(value interface{})
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationOutputReference ¶
func NewSesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationOutputReference
type Sesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestination ¶
type Sesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestination struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination#delivery_stream_arn Sesv2ConfigurationSetEventDestination#delivery_stream_arn}.
DeliveryStreamArn *string `field:"required" json:"deliveryStreamArn" yaml:"deliveryStreamArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination#iam_role_arn Sesv2ConfigurationSetEventDestination#iam_role_arn}.
IamRoleArn *string `field:"required" json:"iamRoleArn" yaml:"iamRoleArn"`
}
type Sesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestinationOutputReference ¶
type Sesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestinationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeliveryStreamArn() *string
SetDeliveryStreamArn(val *string)
DeliveryStreamArnInput() *string
// Experimental.
Fqn() *string
IamRoleArn() *string
SetIamRoleArn(val *string)
IamRoleArnInput() *string
InternalValue() *Sesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestination
SetInternalValue(val *Sesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestination)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestinationOutputReference ¶
func NewSesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestinationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Sesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestinationOutputReference
type Sesv2ConfigurationSetEventDestinationEventDestinationOutputReference ¶
type Sesv2ConfigurationSetEventDestinationEventDestinationOutputReference interface {
cdktf.ComplexObject
CloudWatchDestination() Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationOutputReference
CloudWatchDestinationInput() *Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestination
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *Sesv2ConfigurationSetEventDestinationEventDestination
SetInternalValue(val *Sesv2ConfigurationSetEventDestinationEventDestination)
KinesisFirehoseDestination() Sesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestinationOutputReference
KinesisFirehoseDestinationInput() *Sesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestination
MatchingEventTypes() *[]*string
SetMatchingEventTypes(val *[]*string)
MatchingEventTypesInput() *[]*string
PinpointDestination() Sesv2ConfigurationSetEventDestinationEventDestinationPinpointDestinationOutputReference
PinpointDestinationInput() *Sesv2ConfigurationSetEventDestinationEventDestinationPinpointDestination
SnsDestination() Sesv2ConfigurationSetEventDestinationEventDestinationSnsDestinationOutputReference
SnsDestinationInput() *Sesv2ConfigurationSetEventDestinationEventDestinationSnsDestination
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutCloudWatchDestination(value *Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestination)
PutKinesisFirehoseDestination(value *Sesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestination)
PutPinpointDestination(value *Sesv2ConfigurationSetEventDestinationEventDestinationPinpointDestination)
PutSnsDestination(value *Sesv2ConfigurationSetEventDestinationEventDestinationSnsDestination)
ResetCloudWatchDestination()
ResetEnabled()
ResetKinesisFirehoseDestination()
ResetPinpointDestination()
ResetSnsDestination()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesv2ConfigurationSetEventDestinationEventDestinationOutputReference ¶
func NewSesv2ConfigurationSetEventDestinationEventDestinationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Sesv2ConfigurationSetEventDestinationEventDestinationOutputReference
type Sesv2ConfigurationSetEventDestinationEventDestinationPinpointDestination ¶
type Sesv2ConfigurationSetEventDestinationEventDestinationPinpointDestination struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination#application_arn Sesv2ConfigurationSetEventDestination#application_arn}.
ApplicationArn *string `field:"required" json:"applicationArn" yaml:"applicationArn"`
}
type Sesv2ConfigurationSetEventDestinationEventDestinationPinpointDestinationOutputReference ¶
type Sesv2ConfigurationSetEventDestinationEventDestinationPinpointDestinationOutputReference interface {
cdktf.ComplexObject
ApplicationArn() *string
SetApplicationArn(val *string)
ApplicationArnInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *Sesv2ConfigurationSetEventDestinationEventDestinationPinpointDestination
SetInternalValue(val *Sesv2ConfigurationSetEventDestinationEventDestinationPinpointDestination)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesv2ConfigurationSetEventDestinationEventDestinationPinpointDestinationOutputReference ¶
func NewSesv2ConfigurationSetEventDestinationEventDestinationPinpointDestinationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Sesv2ConfigurationSetEventDestinationEventDestinationPinpointDestinationOutputReference
type Sesv2ConfigurationSetEventDestinationEventDestinationSnsDestination ¶
type Sesv2ConfigurationSetEventDestinationEventDestinationSnsDestination struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/sesv2_configuration_set_event_destination#topic_arn Sesv2ConfigurationSetEventDestination#topic_arn}.
TopicArn *string `field:"required" json:"topicArn" yaml:"topicArn"`
}
type Sesv2ConfigurationSetEventDestinationEventDestinationSnsDestinationOutputReference ¶
type Sesv2ConfigurationSetEventDestinationEventDestinationSnsDestinationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *Sesv2ConfigurationSetEventDestinationEventDestinationSnsDestination
SetInternalValue(val *Sesv2ConfigurationSetEventDestinationEventDestinationSnsDestination)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TopicArn() *string
SetTopicArn(val *string)
TopicArnInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSesv2ConfigurationSetEventDestinationEventDestinationSnsDestinationOutputReference ¶
func NewSesv2ConfigurationSetEventDestinationEventDestinationSnsDestinationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Sesv2ConfigurationSetEventDestinationEventDestinationSnsDestinationOutputReference
Source Files
¶
- Sesv2ConfigurationSetEventDestination.go
- Sesv2ConfigurationSetEventDestinationConfig.go
- Sesv2ConfigurationSetEventDestinationEventDestination.go
- Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestination.go
- Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfiguration.go
- Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationList.go
- Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationList__checks.go
- Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationOutputReference.go
- Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationDimensionConfigurationOutputReference__checks.go
- Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationOutputReference.go
- Sesv2ConfigurationSetEventDestinationEventDestinationCloudWatchDestinationOutputReference__checks.go
- Sesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestination.go
- Sesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestinationOutputReference.go
- Sesv2ConfigurationSetEventDestinationEventDestinationKinesisFirehoseDestinationOutputReference__checks.go
- Sesv2ConfigurationSetEventDestinationEventDestinationOutputReference.go
- Sesv2ConfigurationSetEventDestinationEventDestinationOutputReference__checks.go
- Sesv2ConfigurationSetEventDestinationEventDestinationPinpointDestination.go
- Sesv2ConfigurationSetEventDestinationEventDestinationPinpointDestinationOutputReference.go
- Sesv2ConfigurationSetEventDestinationEventDestinationPinpointDestinationOutputReference__checks.go
- Sesv2ConfigurationSetEventDestinationEventDestinationSnsDestination.go
- Sesv2ConfigurationSetEventDestinationEventDestinationSnsDestinationOutputReference.go
- Sesv2ConfigurationSetEventDestinationEventDestinationSnsDestinationOutputReference__checks.go
- Sesv2ConfigurationSetEventDestination__checks.go
- main.go