Documentation
¶
Index ¶
- func NewSsmAssociationOutputLocationOutputReference_Override(s SsmAssociationOutputLocationOutputReference, ...)
- func NewSsmAssociationTargetsList_Override(s SsmAssociationTargetsList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewSsmAssociationTargetsOutputReference_Override(s SsmAssociationTargetsOutputReference, ...)
- func NewSsmAssociation_Override(s SsmAssociation, scope constructs.Construct, id *string, ...)
- func SsmAssociation_IsConstruct(x interface{}) *bool
- func SsmAssociation_IsTerraformElement(x interface{}) *bool
- func SsmAssociation_IsTerraformResource(x interface{}) *bool
- func SsmAssociation_TfResourceType() *string
- type SsmAssociation
- type SsmAssociationConfig
- type SsmAssociationOutputLocation
- type SsmAssociationOutputLocationOutputReference
- type SsmAssociationTargets
- type SsmAssociationTargetsList
- type SsmAssociationTargetsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSsmAssociationOutputLocationOutputReference_Override ¶
func NewSsmAssociationOutputLocationOutputReference_Override(s SsmAssociationOutputLocationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSsmAssociationTargetsList_Override ¶
func NewSsmAssociationTargetsList_Override(s SsmAssociationTargetsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSsmAssociationTargetsOutputReference_Override ¶
func NewSsmAssociationTargetsOutputReference_Override(s SsmAssociationTargetsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSsmAssociation_Override ¶
func NewSsmAssociation_Override(s SsmAssociation, scope constructs.Construct, id *string, config *SsmAssociationConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association aws_ssm_association} Resource.
func SsmAssociation_IsConstruct ¶
func SsmAssociation_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SsmAssociation_IsTerraformElement ¶
func SsmAssociation_IsTerraformElement(x interface{}) *bool
Experimental.
func SsmAssociation_IsTerraformResource ¶
func SsmAssociation_IsTerraformResource(x interface{}) *bool
Experimental.
func SsmAssociation_TfResourceType ¶
func SsmAssociation_TfResourceType() *string
Types ¶
type SsmAssociation ¶
type SsmAssociation interface {
cdktf.TerraformResource
ApplyOnlyAtCronInterval() interface{}
SetApplyOnlyAtCronInterval(val interface{})
ApplyOnlyAtCronIntervalInput() interface{}
Arn() *string
AssociationId() *string
AssociationName() *string
SetAssociationName(val *string)
AssociationNameInput() *string
AutomationTargetParameterName() *string
SetAutomationTargetParameterName(val *string)
AutomationTargetParameterNameInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ComplianceSeverity() *string
SetComplianceSeverity(val *string)
ComplianceSeverityInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DocumentVersion() *string
SetDocumentVersion(val *string)
DocumentVersionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InstanceId() *string
SetInstanceId(val *string)
InstanceIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaxConcurrency() *string
SetMaxConcurrency(val *string)
MaxConcurrencyInput() *string
MaxErrors() *string
SetMaxErrors(val *string)
MaxErrorsInput() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
OutputLocation() SsmAssociationOutputLocationOutputReference
OutputLocationInput() *SsmAssociationOutputLocation
Parameters() *map[string]*string
SetParameters(val *map[string]*string)
ParametersInput() *map[string]*string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ScheduleExpression() *string
SetScheduleExpression(val *string)
ScheduleExpressionInput() *string
Targets() SsmAssociationTargetsList
TargetsInput() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
WaitForSuccessTimeoutSeconds() *float64
SetWaitForSuccessTimeoutSeconds(val *float64)
WaitForSuccessTimeoutSecondsInput() *float64
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutOutputLocation(value *SsmAssociationOutputLocation)
PutTargets(value interface{})
ResetApplyOnlyAtCronInterval()
ResetAssociationName()
ResetAutomationTargetParameterName()
ResetComplianceSeverity()
ResetDocumentVersion()
ResetId()
ResetInstanceId()
ResetMaxConcurrency()
ResetMaxErrors()
ResetOutputLocation()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetParameters()
ResetScheduleExpression()
ResetTargets()
ResetWaitForSuccessTimeoutSeconds()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association aws_ssm_association}.
func NewSsmAssociation ¶
func NewSsmAssociation(scope constructs.Construct, id *string, config *SsmAssociationConfig) SsmAssociation
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association aws_ssm_association} Resource.
type SsmAssociationConfig ¶
type SsmAssociationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#name SsmAssociation#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#apply_only_at_cron_interval SsmAssociation#apply_only_at_cron_interval}.
ApplyOnlyAtCronInterval interface{} `field:"optional" json:"applyOnlyAtCronInterval" yaml:"applyOnlyAtCronInterval"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#association_name SsmAssociation#association_name}.
AssociationName *string `field:"optional" json:"associationName" yaml:"associationName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#automation_target_parameter_name SsmAssociation#automation_target_parameter_name}.
AutomationTargetParameterName *string `field:"optional" json:"automationTargetParameterName" yaml:"automationTargetParameterName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#compliance_severity SsmAssociation#compliance_severity}.
ComplianceSeverity *string `field:"optional" json:"complianceSeverity" yaml:"complianceSeverity"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#document_version SsmAssociation#document_version}.
DocumentVersion *string `field:"optional" json:"documentVersion" yaml:"documentVersion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#id SsmAssociation#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#instance_id SsmAssociation#instance_id}.
InstanceId *string `field:"optional" json:"instanceId" yaml:"instanceId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#max_concurrency SsmAssociation#max_concurrency}.
MaxConcurrency *string `field:"optional" json:"maxConcurrency" yaml:"maxConcurrency"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#max_errors SsmAssociation#max_errors}.
MaxErrors *string `field:"optional" json:"maxErrors" yaml:"maxErrors"`
// output_location block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#output_location SsmAssociation#output_location}
OutputLocation *SsmAssociationOutputLocation `field:"optional" json:"outputLocation" yaml:"outputLocation"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#parameters SsmAssociation#parameters}.
Parameters *map[string]*string `field:"optional" json:"parameters" yaml:"parameters"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#schedule_expression SsmAssociation#schedule_expression}.
ScheduleExpression *string `field:"optional" json:"scheduleExpression" yaml:"scheduleExpression"`
// targets block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#targets SsmAssociation#targets}
Targets interface{} `field:"optional" json:"targets" yaml:"targets"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#wait_for_success_timeout_seconds SsmAssociation#wait_for_success_timeout_seconds}.
WaitForSuccessTimeoutSeconds *float64 `field:"optional" json:"waitForSuccessTimeoutSeconds" yaml:"waitForSuccessTimeoutSeconds"`
}
type SsmAssociationOutputLocation ¶
type SsmAssociationOutputLocation struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#s3_bucket_name SsmAssociation#s3_bucket_name}.
S3BucketName *string `field:"required" json:"s3BucketName" yaml:"s3BucketName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#s3_key_prefix SsmAssociation#s3_key_prefix}.
S3KeyPrefix *string `field:"optional" json:"s3KeyPrefix" yaml:"s3KeyPrefix"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#s3_region SsmAssociation#s3_region}.
S3Region *string `field:"optional" json:"s3Region" yaml:"s3Region"`
}
type SsmAssociationOutputLocationOutputReference ¶
type SsmAssociationOutputLocationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SsmAssociationOutputLocation
SetInternalValue(val *SsmAssociationOutputLocation)
S3BucketName() *string
SetS3BucketName(val *string)
S3BucketNameInput() *string
S3KeyPrefix() *string
SetS3KeyPrefix(val *string)
S3KeyPrefixInput() *string
S3Region() *string
SetS3Region(val *string)
S3RegionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetS3KeyPrefix()
ResetS3Region()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmAssociationOutputLocationOutputReference ¶
func NewSsmAssociationOutputLocationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SsmAssociationOutputLocationOutputReference
type SsmAssociationTargets ¶
type SsmAssociationTargets struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#key SsmAssociation#key}.
Key *string `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_association#values SsmAssociation#values}.
Values *[]*string `field:"required" json:"values" yaml:"values"`
}
type SsmAssociationTargetsList ¶
type SsmAssociationTargetsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SsmAssociationTargetsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmAssociationTargetsList ¶
func NewSsmAssociationTargetsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SsmAssociationTargetsList
type SsmAssociationTargetsOutputReference ¶
type SsmAssociationTargetsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
SetValues(val *[]*string)
ValuesInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmAssociationTargetsOutputReference ¶
func NewSsmAssociationTargetsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SsmAssociationTargetsOutputReference
Source Files
¶
- SsmAssociation.go
- SsmAssociationConfig.go
- SsmAssociationOutputLocation.go
- SsmAssociationOutputLocationOutputReference.go
- SsmAssociationOutputLocationOutputReference__checks.go
- SsmAssociationTargets.go
- SsmAssociationTargetsList.go
- SsmAssociationTargetsList__checks.go
- SsmAssociationTargetsOutputReference.go
- SsmAssociationTargetsOutputReference__checks.go
- SsmAssociation__checks.go
- main.go