Documentation
¶
Index ¶
- func NewSsmcontactsPlanStageList_Override(s SsmcontactsPlanStageList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewSsmcontactsPlanStageOutputReference_Override(s SsmcontactsPlanStageOutputReference, ...)
- func NewSsmcontactsPlanStageTargetChannelTargetInfoOutputReference_Override(s SsmcontactsPlanStageTargetChannelTargetInfoOutputReference, ...)
- func NewSsmcontactsPlanStageTargetContactTargetInfoOutputReference_Override(s SsmcontactsPlanStageTargetContactTargetInfoOutputReference, ...)
- func NewSsmcontactsPlanStageTargetList_Override(s SsmcontactsPlanStageTargetList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewSsmcontactsPlanStageTargetOutputReference_Override(s SsmcontactsPlanStageTargetOutputReference, ...)
- func NewSsmcontactsPlan_Override(s SsmcontactsPlan, scope constructs.Construct, id *string, ...)
- func SsmcontactsPlan_IsConstruct(x interface{}) *bool
- func SsmcontactsPlan_IsTerraformElement(x interface{}) *bool
- func SsmcontactsPlan_IsTerraformResource(x interface{}) *bool
- func SsmcontactsPlan_TfResourceType() *string
- type SsmcontactsPlan
- type SsmcontactsPlanConfig
- type SsmcontactsPlanStage
- type SsmcontactsPlanStageList
- type SsmcontactsPlanStageOutputReference
- type SsmcontactsPlanStageTarget
- type SsmcontactsPlanStageTargetChannelTargetInfo
- type SsmcontactsPlanStageTargetChannelTargetInfoOutputReference
- type SsmcontactsPlanStageTargetContactTargetInfo
- type SsmcontactsPlanStageTargetContactTargetInfoOutputReference
- type SsmcontactsPlanStageTargetList
- type SsmcontactsPlanStageTargetOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSsmcontactsPlanStageList_Override ¶
func NewSsmcontactsPlanStageList_Override(s SsmcontactsPlanStageList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSsmcontactsPlanStageOutputReference_Override ¶
func NewSsmcontactsPlanStageOutputReference_Override(s SsmcontactsPlanStageOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSsmcontactsPlanStageTargetChannelTargetInfoOutputReference_Override ¶
func NewSsmcontactsPlanStageTargetChannelTargetInfoOutputReference_Override(s SsmcontactsPlanStageTargetChannelTargetInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSsmcontactsPlanStageTargetContactTargetInfoOutputReference_Override ¶
func NewSsmcontactsPlanStageTargetContactTargetInfoOutputReference_Override(s SsmcontactsPlanStageTargetContactTargetInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSsmcontactsPlanStageTargetList_Override ¶
func NewSsmcontactsPlanStageTargetList_Override(s SsmcontactsPlanStageTargetList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSsmcontactsPlanStageTargetOutputReference_Override ¶
func NewSsmcontactsPlanStageTargetOutputReference_Override(s SsmcontactsPlanStageTargetOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSsmcontactsPlan_Override ¶
func NewSsmcontactsPlan_Override(s SsmcontactsPlan, scope constructs.Construct, id *string, config *SsmcontactsPlanConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmcontacts_plan aws_ssmcontacts_plan} Resource.
func SsmcontactsPlan_IsConstruct ¶
func SsmcontactsPlan_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SsmcontactsPlan_IsTerraformElement ¶
func SsmcontactsPlan_IsTerraformElement(x interface{}) *bool
Experimental.
func SsmcontactsPlan_IsTerraformResource ¶
func SsmcontactsPlan_IsTerraformResource(x interface{}) *bool
Experimental.
func SsmcontactsPlan_TfResourceType ¶
func SsmcontactsPlan_TfResourceType() *string
Types ¶
type SsmcontactsPlan ¶
type SsmcontactsPlan interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ContactId() *string
SetContactId(val *string)
ContactIdInput() *string
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Stage() SsmcontactsPlanStageList
StageInput() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutStage(value interface{})
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmcontacts_plan aws_ssmcontacts_plan}.
func NewSsmcontactsPlan ¶
func NewSsmcontactsPlan(scope constructs.Construct, id *string, config *SsmcontactsPlanConfig) SsmcontactsPlan
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmcontacts_plan aws_ssmcontacts_plan} Resource.
type SsmcontactsPlanConfig ¶
type SsmcontactsPlanConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmcontacts_plan#contact_id SsmcontactsPlan#contact_id}.
ContactId *string `field:"required" json:"contactId" yaml:"contactId"`
// stage block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmcontacts_plan#stage SsmcontactsPlan#stage}
Stage interface{} `field:"required" json:"stage" yaml:"stage"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmcontacts_plan#id SsmcontactsPlan#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type SsmcontactsPlanStage ¶
type SsmcontactsPlanStage struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmcontacts_plan#duration_in_minutes SsmcontactsPlan#duration_in_minutes}.
DurationInMinutes *float64 `field:"required" json:"durationInMinutes" yaml:"durationInMinutes"`
// target block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmcontacts_plan#target SsmcontactsPlan#target}
Target interface{} `field:"optional" json:"target" yaml:"target"`
}
type SsmcontactsPlanStageList ¶
type SsmcontactsPlanStageList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SsmcontactsPlanStageOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmcontactsPlanStageList ¶
func NewSsmcontactsPlanStageList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SsmcontactsPlanStageList
type SsmcontactsPlanStageOutputReference ¶
type SsmcontactsPlanStageOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DurationInMinutes() *float64
SetDurationInMinutes(val *float64)
DurationInMinutesInput() *float64
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Target() SsmcontactsPlanStageTargetList
TargetInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutTarget(value interface{})
ResetTarget()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmcontactsPlanStageOutputReference ¶
func NewSsmcontactsPlanStageOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SsmcontactsPlanStageOutputReference
type SsmcontactsPlanStageTarget ¶
type SsmcontactsPlanStageTarget struct {
// channel_target_info block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmcontacts_plan#channel_target_info SsmcontactsPlan#channel_target_info}
ChannelTargetInfo *SsmcontactsPlanStageTargetChannelTargetInfo `field:"optional" json:"channelTargetInfo" yaml:"channelTargetInfo"`
// contact_target_info block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmcontacts_plan#contact_target_info SsmcontactsPlan#contact_target_info}
ContactTargetInfo *SsmcontactsPlanStageTargetContactTargetInfo `field:"optional" json:"contactTargetInfo" yaml:"contactTargetInfo"`
}
type SsmcontactsPlanStageTargetChannelTargetInfo ¶
type SsmcontactsPlanStageTargetChannelTargetInfo struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmcontacts_plan#contact_channel_id SsmcontactsPlan#contact_channel_id}.
ContactChannelId *string `field:"required" json:"contactChannelId" yaml:"contactChannelId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmcontacts_plan#retry_interval_in_minutes SsmcontactsPlan#retry_interval_in_minutes}.
RetryIntervalInMinutes *float64 `field:"optional" json:"retryIntervalInMinutes" yaml:"retryIntervalInMinutes"`
}
type SsmcontactsPlanStageTargetChannelTargetInfoOutputReference ¶
type SsmcontactsPlanStageTargetChannelTargetInfoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ContactChannelId() *string
SetContactChannelId(val *string)
ContactChannelIdInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SsmcontactsPlanStageTargetChannelTargetInfo
SetInternalValue(val *SsmcontactsPlanStageTargetChannelTargetInfo)
RetryIntervalInMinutes() *float64
SetRetryIntervalInMinutes(val *float64)
RetryIntervalInMinutesInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetRetryIntervalInMinutes()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmcontactsPlanStageTargetChannelTargetInfoOutputReference ¶
func NewSsmcontactsPlanStageTargetChannelTargetInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SsmcontactsPlanStageTargetChannelTargetInfoOutputReference
type SsmcontactsPlanStageTargetContactTargetInfo ¶
type SsmcontactsPlanStageTargetContactTargetInfo struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmcontacts_plan#is_essential SsmcontactsPlan#is_essential}.
IsEssential interface{} `field:"required" json:"isEssential" yaml:"isEssential"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmcontacts_plan#contact_id SsmcontactsPlan#contact_id}.
ContactId *string `field:"optional" json:"contactId" yaml:"contactId"`
}
type SsmcontactsPlanStageTargetContactTargetInfoOutputReference ¶
type SsmcontactsPlanStageTargetContactTargetInfoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ContactId() *string
SetContactId(val *string)
ContactIdInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SsmcontactsPlanStageTargetContactTargetInfo
SetInternalValue(val *SsmcontactsPlanStageTargetContactTargetInfo)
IsEssential() interface{}
SetIsEssential(val interface{})
IsEssentialInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetContactId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmcontactsPlanStageTargetContactTargetInfoOutputReference ¶
func NewSsmcontactsPlanStageTargetContactTargetInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SsmcontactsPlanStageTargetContactTargetInfoOutputReference
type SsmcontactsPlanStageTargetList ¶
type SsmcontactsPlanStageTargetList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SsmcontactsPlanStageTargetOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmcontactsPlanStageTargetList ¶
func NewSsmcontactsPlanStageTargetList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SsmcontactsPlanStageTargetList
type SsmcontactsPlanStageTargetOutputReference ¶
type SsmcontactsPlanStageTargetOutputReference interface {
cdktf.ComplexObject
ChannelTargetInfo() SsmcontactsPlanStageTargetChannelTargetInfoOutputReference
ChannelTargetInfoInput() *SsmcontactsPlanStageTargetChannelTargetInfo
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ContactTargetInfo() SsmcontactsPlanStageTargetContactTargetInfoOutputReference
ContactTargetInfoInput() *SsmcontactsPlanStageTargetContactTargetInfo
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutChannelTargetInfo(value *SsmcontactsPlanStageTargetChannelTargetInfo)
PutContactTargetInfo(value *SsmcontactsPlanStageTargetContactTargetInfo)
ResetChannelTargetInfo()
ResetContactTargetInfo()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmcontactsPlanStageTargetOutputReference ¶
func NewSsmcontactsPlanStageTargetOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SsmcontactsPlanStageTargetOutputReference
Source Files
¶
- SsmcontactsPlan.go
- SsmcontactsPlanConfig.go
- SsmcontactsPlanStage.go
- SsmcontactsPlanStageList.go
- SsmcontactsPlanStageList__checks.go
- SsmcontactsPlanStageOutputReference.go
- SsmcontactsPlanStageOutputReference__checks.go
- SsmcontactsPlanStageTarget.go
- SsmcontactsPlanStageTargetChannelTargetInfo.go
- SsmcontactsPlanStageTargetChannelTargetInfoOutputReference.go
- SsmcontactsPlanStageTargetChannelTargetInfoOutputReference__checks.go
- SsmcontactsPlanStageTargetContactTargetInfo.go
- SsmcontactsPlanStageTargetContactTargetInfoOutputReference.go
- SsmcontactsPlanStageTargetContactTargetInfoOutputReference__checks.go
- SsmcontactsPlanStageTargetList.go
- SsmcontactsPlanStageTargetList__checks.go
- SsmcontactsPlanStageTargetOutputReference.go
- SsmcontactsPlanStageTargetOutputReference__checks.go
- SsmcontactsPlan__checks.go
- main.go