Documentation
¶
Index ¶
- func NewSsmincidentsResponsePlanActionOutputReference_Override(s SsmincidentsResponsePlanActionOutputReference, ...)
- func NewSsmincidentsResponsePlanActionSsmAutomationList_Override(s SsmincidentsResponsePlanActionSsmAutomationList, ...)
- func NewSsmincidentsResponsePlanActionSsmAutomationOutputReference_Override(s SsmincidentsResponsePlanActionSsmAutomationOutputReference, ...)
- func NewSsmincidentsResponsePlanActionSsmAutomationParameterList_Override(s SsmincidentsResponsePlanActionSsmAutomationParameterList, ...)
- func NewSsmincidentsResponsePlanActionSsmAutomationParameterOutputReference_Override(s SsmincidentsResponsePlanActionSsmAutomationParameterOutputReference, ...)
- func NewSsmincidentsResponsePlanIncidentTemplateNotificationTargetList_Override(s SsmincidentsResponsePlanIncidentTemplateNotificationTargetList, ...)
- func NewSsmincidentsResponsePlanIncidentTemplateNotificationTargetOutputReference_Override(s SsmincidentsResponsePlanIncidentTemplateNotificationTargetOutputReference, ...)
- func NewSsmincidentsResponsePlanIncidentTemplateOutputReference_Override(s SsmincidentsResponsePlanIncidentTemplateOutputReference, ...)
- func NewSsmincidentsResponsePlanIntegrationOutputReference_Override(s SsmincidentsResponsePlanIntegrationOutputReference, ...)
- func NewSsmincidentsResponsePlanIntegrationPagerdutyList_Override(s SsmincidentsResponsePlanIntegrationPagerdutyList, ...)
- func NewSsmincidentsResponsePlanIntegrationPagerdutyOutputReference_Override(s SsmincidentsResponsePlanIntegrationPagerdutyOutputReference, ...)
- func NewSsmincidentsResponsePlan_Override(s SsmincidentsResponsePlan, scope constructs.Construct, id *string, ...)
- func SsmincidentsResponsePlan_IsConstruct(x interface{}) *bool
- func SsmincidentsResponsePlan_IsTerraformElement(x interface{}) *bool
- func SsmincidentsResponsePlan_IsTerraformResource(x interface{}) *bool
- func SsmincidentsResponsePlan_TfResourceType() *string
- type SsmincidentsResponsePlan
- type SsmincidentsResponsePlanAction
- type SsmincidentsResponsePlanActionOutputReference
- type SsmincidentsResponsePlanActionSsmAutomation
- type SsmincidentsResponsePlanActionSsmAutomationList
- type SsmincidentsResponsePlanActionSsmAutomationOutputReference
- type SsmincidentsResponsePlanActionSsmAutomationParameter
- type SsmincidentsResponsePlanActionSsmAutomationParameterList
- type SsmincidentsResponsePlanActionSsmAutomationParameterOutputReference
- type SsmincidentsResponsePlanConfig
- type SsmincidentsResponsePlanIncidentTemplate
- type SsmincidentsResponsePlanIncidentTemplateNotificationTarget
- type SsmincidentsResponsePlanIncidentTemplateNotificationTargetList
- type SsmincidentsResponsePlanIncidentTemplateNotificationTargetOutputReference
- type SsmincidentsResponsePlanIncidentTemplateOutputReference
- type SsmincidentsResponsePlanIntegration
- type SsmincidentsResponsePlanIntegrationOutputReference
- type SsmincidentsResponsePlanIntegrationPagerduty
- type SsmincidentsResponsePlanIntegrationPagerdutyList
- type SsmincidentsResponsePlanIntegrationPagerdutyOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSsmincidentsResponsePlanActionOutputReference_Override ¶
func NewSsmincidentsResponsePlanActionOutputReference_Override(s SsmincidentsResponsePlanActionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSsmincidentsResponsePlanActionSsmAutomationList_Override ¶
func NewSsmincidentsResponsePlanActionSsmAutomationList_Override(s SsmincidentsResponsePlanActionSsmAutomationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSsmincidentsResponsePlanActionSsmAutomationOutputReference_Override ¶
func NewSsmincidentsResponsePlanActionSsmAutomationOutputReference_Override(s SsmincidentsResponsePlanActionSsmAutomationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSsmincidentsResponsePlanActionSsmAutomationParameterList_Override ¶
func NewSsmincidentsResponsePlanActionSsmAutomationParameterList_Override(s SsmincidentsResponsePlanActionSsmAutomationParameterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSsmincidentsResponsePlanActionSsmAutomationParameterOutputReference_Override ¶
func NewSsmincidentsResponsePlanActionSsmAutomationParameterOutputReference_Override(s SsmincidentsResponsePlanActionSsmAutomationParameterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSsmincidentsResponsePlanIncidentTemplateNotificationTargetList_Override ¶
func NewSsmincidentsResponsePlanIncidentTemplateNotificationTargetList_Override(s SsmincidentsResponsePlanIncidentTemplateNotificationTargetList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSsmincidentsResponsePlanIncidentTemplateNotificationTargetOutputReference_Override ¶
func NewSsmincidentsResponsePlanIncidentTemplateNotificationTargetOutputReference_Override(s SsmincidentsResponsePlanIncidentTemplateNotificationTargetOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSsmincidentsResponsePlanIncidentTemplateOutputReference_Override ¶
func NewSsmincidentsResponsePlanIncidentTemplateOutputReference_Override(s SsmincidentsResponsePlanIncidentTemplateOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSsmincidentsResponsePlanIntegrationOutputReference_Override ¶
func NewSsmincidentsResponsePlanIntegrationOutputReference_Override(s SsmincidentsResponsePlanIntegrationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewSsmincidentsResponsePlanIntegrationPagerdutyList_Override ¶
func NewSsmincidentsResponsePlanIntegrationPagerdutyList_Override(s SsmincidentsResponsePlanIntegrationPagerdutyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSsmincidentsResponsePlanIntegrationPagerdutyOutputReference_Override ¶
func NewSsmincidentsResponsePlanIntegrationPagerdutyOutputReference_Override(s SsmincidentsResponsePlanIntegrationPagerdutyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSsmincidentsResponsePlan_Override ¶
func NewSsmincidentsResponsePlan_Override(s SsmincidentsResponsePlan, scope constructs.Construct, id *string, config *SsmincidentsResponsePlanConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan aws_ssmincidents_response_plan} Resource.
func SsmincidentsResponsePlan_IsConstruct ¶
func SsmincidentsResponsePlan_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SsmincidentsResponsePlan_IsTerraformElement ¶
func SsmincidentsResponsePlan_IsTerraformElement(x interface{}) *bool
Experimental.
func SsmincidentsResponsePlan_IsTerraformResource ¶
func SsmincidentsResponsePlan_IsTerraformResource(x interface{}) *bool
Experimental.
func SsmincidentsResponsePlan_TfResourceType ¶
func SsmincidentsResponsePlan_TfResourceType() *string
Types ¶
type SsmincidentsResponsePlan ¶
type SsmincidentsResponsePlan interface {
cdktf.TerraformResource
Action() SsmincidentsResponsePlanActionOutputReference
ActionInput() *SsmincidentsResponsePlanAction
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ChatChannel() *[]*string
SetChatChannel(val *[]*string)
ChatChannelInput() *[]*string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
Engagements() *[]*string
SetEngagements(val *[]*string)
EngagementsInput() *[]*string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IncidentTemplate() SsmincidentsResponsePlanIncidentTemplateOutputReference
IncidentTemplateInput() *SsmincidentsResponsePlanIncidentTemplate
Integration() SsmincidentsResponsePlanIntegrationOutputReference
IntegrationInput() *SsmincidentsResponsePlanIntegration
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAction(value *SsmincidentsResponsePlanAction)
PutIncidentTemplate(value *SsmincidentsResponsePlanIncidentTemplate)
PutIntegration(value *SsmincidentsResponsePlanIntegration)
ResetAction()
ResetChatChannel()
ResetDisplayName()
ResetEngagements()
ResetId()
ResetIntegration()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan aws_ssmincidents_response_plan}.
func NewSsmincidentsResponsePlan ¶
func NewSsmincidentsResponsePlan(scope constructs.Construct, id *string, config *SsmincidentsResponsePlanConfig) SsmincidentsResponsePlan
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan aws_ssmincidents_response_plan} Resource.
type SsmincidentsResponsePlanAction ¶
type SsmincidentsResponsePlanAction struct {
// ssm_automation block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#ssm_automation SsmincidentsResponsePlan#ssm_automation}
SsmAutomation interface{} `field:"optional" json:"ssmAutomation" yaml:"ssmAutomation"`
}
type SsmincidentsResponsePlanActionOutputReference ¶
type SsmincidentsResponsePlanActionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SsmincidentsResponsePlanAction
SetInternalValue(val *SsmincidentsResponsePlanAction)
SsmAutomation() SsmincidentsResponsePlanActionSsmAutomationList
SsmAutomationInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutSsmAutomation(value interface{})
ResetSsmAutomation()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmincidentsResponsePlanActionOutputReference ¶
func NewSsmincidentsResponsePlanActionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SsmincidentsResponsePlanActionOutputReference
type SsmincidentsResponsePlanActionSsmAutomation ¶
type SsmincidentsResponsePlanActionSsmAutomation struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#document_name SsmincidentsResponsePlan#document_name}.
DocumentName *string `field:"required" json:"documentName" yaml:"documentName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#role_arn SsmincidentsResponsePlan#role_arn}.
RoleArn *string `field:"required" json:"roleArn" yaml:"roleArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#document_version SsmincidentsResponsePlan#document_version}.
DocumentVersion *string `field:"optional" json:"documentVersion" yaml:"documentVersion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#dynamic_parameters SsmincidentsResponsePlan#dynamic_parameters}.
DynamicParameters *map[string]*string `field:"optional" json:"dynamicParameters" yaml:"dynamicParameters"`
// parameter block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#parameter SsmincidentsResponsePlan#parameter}
Parameter interface{} `field:"optional" json:"parameter" yaml:"parameter"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#target_account SsmincidentsResponsePlan#target_account}.
TargetAccount *string `field:"optional" json:"targetAccount" yaml:"targetAccount"`
}
type SsmincidentsResponsePlanActionSsmAutomationList ¶
type SsmincidentsResponsePlanActionSsmAutomationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SsmincidentsResponsePlanActionSsmAutomationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmincidentsResponsePlanActionSsmAutomationList ¶
func NewSsmincidentsResponsePlanActionSsmAutomationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SsmincidentsResponsePlanActionSsmAutomationList
type SsmincidentsResponsePlanActionSsmAutomationOutputReference ¶
type SsmincidentsResponsePlanActionSsmAutomationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DocumentName() *string
SetDocumentName(val *string)
DocumentNameInput() *string
DocumentVersion() *string
SetDocumentVersion(val *string)
DocumentVersionInput() *string
DynamicParameters() *map[string]*string
SetDynamicParameters(val *map[string]*string)
DynamicParametersInput() *map[string]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Parameter() SsmincidentsResponsePlanActionSsmAutomationParameterList
ParameterInput() interface{}
RoleArn() *string
SetRoleArn(val *string)
RoleArnInput() *string
TargetAccount() *string
SetTargetAccount(val *string)
TargetAccountInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutParameter(value interface{})
ResetDocumentVersion()
ResetDynamicParameters()
ResetParameter()
ResetTargetAccount()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmincidentsResponsePlanActionSsmAutomationOutputReference ¶
func NewSsmincidentsResponsePlanActionSsmAutomationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SsmincidentsResponsePlanActionSsmAutomationOutputReference
type SsmincidentsResponsePlanActionSsmAutomationParameter ¶
type SsmincidentsResponsePlanActionSsmAutomationParameter struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#name SsmincidentsResponsePlan#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#values SsmincidentsResponsePlan#values}.
Values *[]*string `field:"required" json:"values" yaml:"values"`
}
type SsmincidentsResponsePlanActionSsmAutomationParameterList ¶
type SsmincidentsResponsePlanActionSsmAutomationParameterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SsmincidentsResponsePlanActionSsmAutomationParameterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmincidentsResponsePlanActionSsmAutomationParameterList ¶
func NewSsmincidentsResponsePlanActionSsmAutomationParameterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SsmincidentsResponsePlanActionSsmAutomationParameterList
type SsmincidentsResponsePlanActionSsmAutomationParameterOutputReference ¶
type SsmincidentsResponsePlanActionSsmAutomationParameterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
SetValues(val *[]*string)
ValuesInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmincidentsResponsePlanActionSsmAutomationParameterOutputReference ¶
func NewSsmincidentsResponsePlanActionSsmAutomationParameterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SsmincidentsResponsePlanActionSsmAutomationParameterOutputReference
type SsmincidentsResponsePlanConfig ¶
type SsmincidentsResponsePlanConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// incident_template block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#incident_template SsmincidentsResponsePlan#incident_template}
IncidentTemplate *SsmincidentsResponsePlanIncidentTemplate `field:"required" json:"incidentTemplate" yaml:"incidentTemplate"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#name SsmincidentsResponsePlan#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// action block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#action SsmincidentsResponsePlan#action}
Action *SsmincidentsResponsePlanAction `field:"optional" json:"action" yaml:"action"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#chat_channel SsmincidentsResponsePlan#chat_channel}.
ChatChannel *[]*string `field:"optional" json:"chatChannel" yaml:"chatChannel"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#display_name SsmincidentsResponsePlan#display_name}.
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#engagements SsmincidentsResponsePlan#engagements}.
Engagements *[]*string `field:"optional" json:"engagements" yaml:"engagements"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#id SsmincidentsResponsePlan#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// integration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#integration SsmincidentsResponsePlan#integration}
Integration *SsmincidentsResponsePlanIntegration `field:"optional" json:"integration" yaml:"integration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#tags SsmincidentsResponsePlan#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#tags_all SsmincidentsResponsePlan#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type SsmincidentsResponsePlanIncidentTemplate ¶
type SsmincidentsResponsePlanIncidentTemplate struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#impact SsmincidentsResponsePlan#impact}.
Impact *float64 `field:"required" json:"impact" yaml:"impact"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#title SsmincidentsResponsePlan#title}.
Title *string `field:"required" json:"title" yaml:"title"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#dedupe_string SsmincidentsResponsePlan#dedupe_string}.
DedupeString *string `field:"optional" json:"dedupeString" yaml:"dedupeString"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#incident_tags SsmincidentsResponsePlan#incident_tags}.
IncidentTags *map[string]*string `field:"optional" json:"incidentTags" yaml:"incidentTags"`
// notification_target block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#notification_target SsmincidentsResponsePlan#notification_target}
NotificationTarget interface{} `field:"optional" json:"notificationTarget" yaml:"notificationTarget"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#summary SsmincidentsResponsePlan#summary}.
Summary *string `field:"optional" json:"summary" yaml:"summary"`
}
type SsmincidentsResponsePlanIncidentTemplateNotificationTarget ¶
type SsmincidentsResponsePlanIncidentTemplateNotificationTarget struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#sns_topic_arn SsmincidentsResponsePlan#sns_topic_arn}.
SnsTopicArn *string `field:"required" json:"snsTopicArn" yaml:"snsTopicArn"`
}
type SsmincidentsResponsePlanIncidentTemplateNotificationTargetList ¶
type SsmincidentsResponsePlanIncidentTemplateNotificationTargetList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SsmincidentsResponsePlanIncidentTemplateNotificationTargetOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmincidentsResponsePlanIncidentTemplateNotificationTargetList ¶
func NewSsmincidentsResponsePlanIncidentTemplateNotificationTargetList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SsmincidentsResponsePlanIncidentTemplateNotificationTargetList
type SsmincidentsResponsePlanIncidentTemplateNotificationTargetOutputReference ¶
type SsmincidentsResponsePlanIncidentTemplateNotificationTargetOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
SnsTopicArn() *string
SetSnsTopicArn(val *string)
SnsTopicArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmincidentsResponsePlanIncidentTemplateNotificationTargetOutputReference ¶
func NewSsmincidentsResponsePlanIncidentTemplateNotificationTargetOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SsmincidentsResponsePlanIncidentTemplateNotificationTargetOutputReference
type SsmincidentsResponsePlanIncidentTemplateOutputReference ¶
type SsmincidentsResponsePlanIncidentTemplateOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DedupeString() *string
SetDedupeString(val *string)
DedupeStringInput() *string
// Experimental.
Fqn() *string
Impact() *float64
SetImpact(val *float64)
ImpactInput() *float64
IncidentTags() *map[string]*string
SetIncidentTags(val *map[string]*string)
IncidentTagsInput() *map[string]*string
InternalValue() *SsmincidentsResponsePlanIncidentTemplate
SetInternalValue(val *SsmincidentsResponsePlanIncidentTemplate)
NotificationTarget() SsmincidentsResponsePlanIncidentTemplateNotificationTargetList
NotificationTargetInput() interface{}
Summary() *string
SetSummary(val *string)
SummaryInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Title() *string
SetTitle(val *string)
TitleInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutNotificationTarget(value interface{})
ResetDedupeString()
ResetIncidentTags()
ResetNotificationTarget()
ResetSummary()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmincidentsResponsePlanIncidentTemplateOutputReference ¶
func NewSsmincidentsResponsePlanIncidentTemplateOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SsmincidentsResponsePlanIncidentTemplateOutputReference
type SsmincidentsResponsePlanIntegration ¶
type SsmincidentsResponsePlanIntegration struct {
// pagerduty block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#pagerduty SsmincidentsResponsePlan#pagerduty}
Pagerduty interface{} `field:"optional" json:"pagerduty" yaml:"pagerduty"`
}
type SsmincidentsResponsePlanIntegrationOutputReference ¶
type SsmincidentsResponsePlanIntegrationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *SsmincidentsResponsePlanIntegration
SetInternalValue(val *SsmincidentsResponsePlanIntegration)
Pagerduty() SsmincidentsResponsePlanIntegrationPagerdutyList
PagerdutyInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutPagerduty(value interface{})
ResetPagerduty()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmincidentsResponsePlanIntegrationOutputReference ¶
func NewSsmincidentsResponsePlanIntegrationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) SsmincidentsResponsePlanIntegrationOutputReference
type SsmincidentsResponsePlanIntegrationPagerduty ¶
type SsmincidentsResponsePlanIntegrationPagerduty struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#name SsmincidentsResponsePlan#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#secret_id SsmincidentsResponsePlan#secret_id}.
SecretId *string `field:"required" json:"secretId" yaml:"secretId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssmincidents_response_plan#service_id SsmincidentsResponsePlan#service_id}.
ServiceId *string `field:"required" json:"serviceId" yaml:"serviceId"`
}
type SsmincidentsResponsePlanIntegrationPagerdutyList ¶
type SsmincidentsResponsePlanIntegrationPagerdutyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SsmincidentsResponsePlanIntegrationPagerdutyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmincidentsResponsePlanIntegrationPagerdutyList ¶
func NewSsmincidentsResponsePlanIntegrationPagerdutyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SsmincidentsResponsePlanIntegrationPagerdutyList
type SsmincidentsResponsePlanIntegrationPagerdutyOutputReference ¶
type SsmincidentsResponsePlanIntegrationPagerdutyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
SecretId() *string
SetSecretId(val *string)
SecretIdInput() *string
ServiceId() *string
SetServiceId(val *string)
ServiceIdInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmincidentsResponsePlanIntegrationPagerdutyOutputReference ¶
func NewSsmincidentsResponsePlanIntegrationPagerdutyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SsmincidentsResponsePlanIntegrationPagerdutyOutputReference
Source Files
¶
- SsmincidentsResponsePlan.go
- SsmincidentsResponsePlanAction.go
- SsmincidentsResponsePlanActionOutputReference.go
- SsmincidentsResponsePlanActionOutputReference__checks.go
- SsmincidentsResponsePlanActionSsmAutomation.go
- SsmincidentsResponsePlanActionSsmAutomationList.go
- SsmincidentsResponsePlanActionSsmAutomationList__checks.go
- SsmincidentsResponsePlanActionSsmAutomationOutputReference.go
- SsmincidentsResponsePlanActionSsmAutomationOutputReference__checks.go
- SsmincidentsResponsePlanActionSsmAutomationParameter.go
- SsmincidentsResponsePlanActionSsmAutomationParameterList.go
- SsmincidentsResponsePlanActionSsmAutomationParameterList__checks.go
- SsmincidentsResponsePlanActionSsmAutomationParameterOutputReference.go
- SsmincidentsResponsePlanActionSsmAutomationParameterOutputReference__checks.go
- SsmincidentsResponsePlanConfig.go
- SsmincidentsResponsePlanIncidentTemplate.go
- SsmincidentsResponsePlanIncidentTemplateNotificationTarget.go
- SsmincidentsResponsePlanIncidentTemplateNotificationTargetList.go
- SsmincidentsResponsePlanIncidentTemplateNotificationTargetList__checks.go
- SsmincidentsResponsePlanIncidentTemplateNotificationTargetOutputReference.go
- SsmincidentsResponsePlanIncidentTemplateNotificationTargetOutputReference__checks.go
- SsmincidentsResponsePlanIncidentTemplateOutputReference.go
- SsmincidentsResponsePlanIncidentTemplateOutputReference__checks.go
- SsmincidentsResponsePlanIntegration.go
- SsmincidentsResponsePlanIntegrationOutputReference.go
- SsmincidentsResponsePlanIntegrationOutputReference__checks.go
- SsmincidentsResponsePlanIntegrationPagerduty.go
- SsmincidentsResponsePlanIntegrationPagerdutyList.go
- SsmincidentsResponsePlanIntegrationPagerdutyList__checks.go
- SsmincidentsResponsePlanIntegrationPagerdutyOutputReference.go
- SsmincidentsResponsePlanIntegrationPagerdutyOutputReference__checks.go
- SsmincidentsResponsePlan__checks.go
- main.go