Documentation
¶
Index ¶
- func NewSsmParameter_Override(s SsmParameter, scope constructs.Construct, id *string, ...)
- func SsmParameter_IsConstruct(x interface{}) *bool
- func SsmParameter_IsTerraformElement(x interface{}) *bool
- func SsmParameter_IsTerraformResource(x interface{}) *bool
- func SsmParameter_TfResourceType() *string
- type SsmParameter
- type SsmParameterConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSsmParameter_Override ¶
func NewSsmParameter_Override(s SsmParameter, scope constructs.Construct, id *string, config *SsmParameterConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_parameter aws_ssm_parameter} Resource.
func SsmParameter_IsConstruct ¶
func SsmParameter_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SsmParameter_IsTerraformElement ¶
func SsmParameter_IsTerraformElement(x interface{}) *bool
Experimental.
func SsmParameter_IsTerraformResource ¶
func SsmParameter_IsTerraformResource(x interface{}) *bool
Experimental.
func SsmParameter_TfResourceType ¶
func SsmParameter_TfResourceType() *string
Types ¶
type SsmParameter ¶
type SsmParameter interface {
cdktf.TerraformResource
AllowedPattern() *string
SetAllowedPattern(val *string)
AllowedPatternInput() *string
Arn() *string
SetArn(val *string)
ArnInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DataType() *string
SetDataType(val *string)
DataTypeInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InsecureValue() *string
SetInsecureValue(val *string)
InsecureValueInput() *string
KeyId() *string
SetKeyId(val *string)
KeyIdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Overwrite() interface{}
SetOverwrite(val interface{})
OverwriteInput() interface{}
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Tier() *string
SetTier(val *string)
TierInput() *string
Type() *string
SetType(val *string)
TypeInput() *string
Value() *string
SetValue(val *string)
ValueInput() *string
Version() *float64
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetAllowedPattern()
ResetArn()
ResetDataType()
ResetDescription()
ResetId()
ResetInsecureValue()
ResetKeyId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetOverwrite()
ResetTags()
ResetTagsAll()
ResetTier()
ResetValue()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_parameter aws_ssm_parameter}.
func NewSsmParameter ¶
func NewSsmParameter(scope constructs.Construct, id *string, config *SsmParameterConfig) SsmParameter
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_parameter aws_ssm_parameter} Resource.
type SsmParameterConfig ¶
type SsmParameterConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_parameter#name SsmParameter#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_parameter#type SsmParameter#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_parameter#allowed_pattern SsmParameter#allowed_pattern}.
AllowedPattern *string `field:"optional" json:"allowedPattern" yaml:"allowedPattern"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_parameter#arn SsmParameter#arn}.
Arn *string `field:"optional" json:"arn" yaml:"arn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_parameter#data_type SsmParameter#data_type}.
DataType *string `field:"optional" json:"dataType" yaml:"dataType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_parameter#description SsmParameter#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_parameter#id SsmParameter#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_parameter#insecure_value SsmParameter#insecure_value}.
InsecureValue *string `field:"optional" json:"insecureValue" yaml:"insecureValue"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_parameter#key_id SsmParameter#key_id}.
KeyId *string `field:"optional" json:"keyId" yaml:"keyId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_parameter#overwrite SsmParameter#overwrite}.
Overwrite interface{} `field:"optional" json:"overwrite" yaml:"overwrite"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_parameter#tags SsmParameter#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_parameter#tags_all SsmParameter#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_parameter#tier SsmParameter#tier}.
Tier *string `field:"optional" json:"tier" yaml:"tier"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_parameter#value SsmParameter#value}.
Value *string `field:"optional" json:"value" yaml:"value"`
}