Documentation
¶
Index ¶
- func NewSsmPatchBaselineApprovalRuleList_Override(s SsmPatchBaselineApprovalRuleList, ...)
- func NewSsmPatchBaselineApprovalRuleOutputReference_Override(s SsmPatchBaselineApprovalRuleOutputReference, ...)
- func NewSsmPatchBaselineApprovalRulePatchFilterList_Override(s SsmPatchBaselineApprovalRulePatchFilterList, ...)
- func NewSsmPatchBaselineApprovalRulePatchFilterOutputReference_Override(s SsmPatchBaselineApprovalRulePatchFilterOutputReference, ...)
- func NewSsmPatchBaselineGlobalFilterList_Override(s SsmPatchBaselineGlobalFilterList, ...)
- func NewSsmPatchBaselineGlobalFilterOutputReference_Override(s SsmPatchBaselineGlobalFilterOutputReference, ...)
- func NewSsmPatchBaselineSourceList_Override(s SsmPatchBaselineSourceList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewSsmPatchBaselineSourceOutputReference_Override(s SsmPatchBaselineSourceOutputReference, ...)
- func NewSsmPatchBaseline_Override(s SsmPatchBaseline, scope constructs.Construct, id *string, ...)
- func SsmPatchBaseline_IsConstruct(x interface{}) *bool
- func SsmPatchBaseline_IsTerraformElement(x interface{}) *bool
- func SsmPatchBaseline_IsTerraformResource(x interface{}) *bool
- func SsmPatchBaseline_TfResourceType() *string
- type SsmPatchBaseline
- type SsmPatchBaselineApprovalRule
- type SsmPatchBaselineApprovalRuleList
- type SsmPatchBaselineApprovalRuleOutputReference
- type SsmPatchBaselineApprovalRulePatchFilter
- type SsmPatchBaselineApprovalRulePatchFilterList
- type SsmPatchBaselineApprovalRulePatchFilterOutputReference
- type SsmPatchBaselineConfig
- type SsmPatchBaselineGlobalFilter
- type SsmPatchBaselineGlobalFilterList
- type SsmPatchBaselineGlobalFilterOutputReference
- type SsmPatchBaselineSource
- type SsmPatchBaselineSourceList
- type SsmPatchBaselineSourceOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSsmPatchBaselineApprovalRuleList_Override ¶
func NewSsmPatchBaselineApprovalRuleList_Override(s SsmPatchBaselineApprovalRuleList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSsmPatchBaselineApprovalRuleOutputReference_Override ¶
func NewSsmPatchBaselineApprovalRuleOutputReference_Override(s SsmPatchBaselineApprovalRuleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSsmPatchBaselineApprovalRulePatchFilterList_Override ¶
func NewSsmPatchBaselineApprovalRulePatchFilterList_Override(s SsmPatchBaselineApprovalRulePatchFilterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSsmPatchBaselineApprovalRulePatchFilterOutputReference_Override ¶
func NewSsmPatchBaselineApprovalRulePatchFilterOutputReference_Override(s SsmPatchBaselineApprovalRulePatchFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSsmPatchBaselineGlobalFilterList_Override ¶
func NewSsmPatchBaselineGlobalFilterList_Override(s SsmPatchBaselineGlobalFilterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSsmPatchBaselineGlobalFilterOutputReference_Override ¶
func NewSsmPatchBaselineGlobalFilterOutputReference_Override(s SsmPatchBaselineGlobalFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSsmPatchBaselineSourceList_Override ¶
func NewSsmPatchBaselineSourceList_Override(s SsmPatchBaselineSourceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewSsmPatchBaselineSourceOutputReference_Override ¶
func NewSsmPatchBaselineSourceOutputReference_Override(s SsmPatchBaselineSourceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewSsmPatchBaseline_Override ¶
func NewSsmPatchBaseline_Override(s SsmPatchBaseline, scope constructs.Construct, id *string, config *SsmPatchBaselineConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline aws_ssm_patch_baseline} Resource.
func SsmPatchBaseline_IsConstruct ¶
func SsmPatchBaseline_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func SsmPatchBaseline_IsTerraformElement ¶
func SsmPatchBaseline_IsTerraformElement(x interface{}) *bool
Experimental.
func SsmPatchBaseline_IsTerraformResource ¶
func SsmPatchBaseline_IsTerraformResource(x interface{}) *bool
Experimental.
func SsmPatchBaseline_TfResourceType ¶
func SsmPatchBaseline_TfResourceType() *string
Types ¶
type SsmPatchBaseline ¶
type SsmPatchBaseline interface {
cdktf.TerraformResource
ApprovalRule() SsmPatchBaselineApprovalRuleList
ApprovalRuleInput() interface{}
ApprovedPatches() *[]*string
SetApprovedPatches(val *[]*string)
ApprovedPatchesComplianceLevel() *string
SetApprovedPatchesComplianceLevel(val *string)
ApprovedPatchesComplianceLevelInput() *string
ApprovedPatchesEnableNonSecurity() interface{}
SetApprovedPatchesEnableNonSecurity(val interface{})
ApprovedPatchesEnableNonSecurityInput() interface{}
ApprovedPatchesInput() *[]*string
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GlobalFilter() SsmPatchBaselineGlobalFilterList
GlobalFilterInput() interface{}
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
OperatingSystem() *string
SetOperatingSystem(val *string)
OperatingSystemInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RejectedPatches() *[]*string
SetRejectedPatches(val *[]*string)
RejectedPatchesAction() *string
SetRejectedPatchesAction(val *string)
RejectedPatchesActionInput() *string
RejectedPatchesInput() *[]*string
Source() SsmPatchBaselineSourceList
SourceInput() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutApprovalRule(value interface{})
PutGlobalFilter(value interface{})
PutSource(value interface{})
ResetApprovalRule()
ResetApprovedPatches()
ResetApprovedPatchesComplianceLevel()
ResetApprovedPatchesEnableNonSecurity()
ResetDescription()
ResetGlobalFilter()
ResetId()
ResetOperatingSystem()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRejectedPatches()
ResetRejectedPatchesAction()
ResetSource()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline aws_ssm_patch_baseline}.
func NewSsmPatchBaseline ¶
func NewSsmPatchBaseline(scope constructs.Construct, id *string, config *SsmPatchBaselineConfig) SsmPatchBaseline
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline aws_ssm_patch_baseline} Resource.
type SsmPatchBaselineApprovalRule ¶
type SsmPatchBaselineApprovalRule struct {
// patch_filter block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#patch_filter SsmPatchBaseline#patch_filter}
PatchFilter interface{} `field:"required" json:"patchFilter" yaml:"patchFilter"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#approve_after_days SsmPatchBaseline#approve_after_days}.
ApproveAfterDays *float64 `field:"optional" json:"approveAfterDays" yaml:"approveAfterDays"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#approve_until_date SsmPatchBaseline#approve_until_date}.
ApproveUntilDate *string `field:"optional" json:"approveUntilDate" yaml:"approveUntilDate"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#compliance_level SsmPatchBaseline#compliance_level}.
ComplianceLevel *string `field:"optional" json:"complianceLevel" yaml:"complianceLevel"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#enable_non_security SsmPatchBaseline#enable_non_security}.
EnableNonSecurity interface{} `field:"optional" json:"enableNonSecurity" yaml:"enableNonSecurity"`
}
type SsmPatchBaselineApprovalRuleList ¶
type SsmPatchBaselineApprovalRuleList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SsmPatchBaselineApprovalRuleOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmPatchBaselineApprovalRuleList ¶
func NewSsmPatchBaselineApprovalRuleList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SsmPatchBaselineApprovalRuleList
type SsmPatchBaselineApprovalRuleOutputReference ¶
type SsmPatchBaselineApprovalRuleOutputReference interface {
cdktf.ComplexObject
ApproveAfterDays() *float64
SetApproveAfterDays(val *float64)
ApproveAfterDaysInput() *float64
ApproveUntilDate() *string
SetApproveUntilDate(val *string)
ApproveUntilDateInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ComplianceLevel() *string
SetComplianceLevel(val *string)
ComplianceLevelInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EnableNonSecurity() interface{}
SetEnableNonSecurity(val interface{})
EnableNonSecurityInput() interface{}
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
PatchFilter() SsmPatchBaselineApprovalRulePatchFilterList
PatchFilterInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutPatchFilter(value interface{})
ResetApproveAfterDays()
ResetApproveUntilDate()
ResetComplianceLevel()
ResetEnableNonSecurity()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmPatchBaselineApprovalRuleOutputReference ¶
func NewSsmPatchBaselineApprovalRuleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SsmPatchBaselineApprovalRuleOutputReference
type SsmPatchBaselineApprovalRulePatchFilter ¶
type SsmPatchBaselineApprovalRulePatchFilter struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#key SsmPatchBaseline#key}.
Key *string `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#values SsmPatchBaseline#values}.
Values *[]*string `field:"required" json:"values" yaml:"values"`
}
type SsmPatchBaselineApprovalRulePatchFilterList ¶
type SsmPatchBaselineApprovalRulePatchFilterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SsmPatchBaselineApprovalRulePatchFilterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmPatchBaselineApprovalRulePatchFilterList ¶
func NewSsmPatchBaselineApprovalRulePatchFilterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SsmPatchBaselineApprovalRulePatchFilterList
type SsmPatchBaselineApprovalRulePatchFilterOutputReference ¶
type SsmPatchBaselineApprovalRulePatchFilterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
SetValues(val *[]*string)
ValuesInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmPatchBaselineApprovalRulePatchFilterOutputReference ¶
func NewSsmPatchBaselineApprovalRulePatchFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SsmPatchBaselineApprovalRulePatchFilterOutputReference
type SsmPatchBaselineConfig ¶
type SsmPatchBaselineConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#name SsmPatchBaseline#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// approval_rule block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#approval_rule SsmPatchBaseline#approval_rule}
ApprovalRule interface{} `field:"optional" json:"approvalRule" yaml:"approvalRule"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#approved_patches SsmPatchBaseline#approved_patches}.
ApprovedPatches *[]*string `field:"optional" json:"approvedPatches" yaml:"approvedPatches"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#approved_patches_compliance_level SsmPatchBaseline#approved_patches_compliance_level}.
ApprovedPatchesComplianceLevel *string `field:"optional" json:"approvedPatchesComplianceLevel" yaml:"approvedPatchesComplianceLevel"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#approved_patches_enable_non_security SsmPatchBaseline#approved_patches_enable_non_security}.
ApprovedPatchesEnableNonSecurity interface{} `field:"optional" json:"approvedPatchesEnableNonSecurity" yaml:"approvedPatchesEnableNonSecurity"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#description SsmPatchBaseline#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// global_filter block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#global_filter SsmPatchBaseline#global_filter}
GlobalFilter interface{} `field:"optional" json:"globalFilter" yaml:"globalFilter"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#id SsmPatchBaseline#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#operating_system SsmPatchBaseline#operating_system}.
OperatingSystem *string `field:"optional" json:"operatingSystem" yaml:"operatingSystem"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#rejected_patches SsmPatchBaseline#rejected_patches}.
RejectedPatches *[]*string `field:"optional" json:"rejectedPatches" yaml:"rejectedPatches"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#rejected_patches_action SsmPatchBaseline#rejected_patches_action}.
RejectedPatchesAction *string `field:"optional" json:"rejectedPatchesAction" yaml:"rejectedPatchesAction"`
// source block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#source SsmPatchBaseline#source}
Source interface{} `field:"optional" json:"source" yaml:"source"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#tags SsmPatchBaseline#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#tags_all SsmPatchBaseline#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type SsmPatchBaselineGlobalFilter ¶
type SsmPatchBaselineGlobalFilter struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#key SsmPatchBaseline#key}.
Key *string `field:"required" json:"key" yaml:"key"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#values SsmPatchBaseline#values}.
Values *[]*string `field:"required" json:"values" yaml:"values"`
}
type SsmPatchBaselineGlobalFilterList ¶
type SsmPatchBaselineGlobalFilterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SsmPatchBaselineGlobalFilterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmPatchBaselineGlobalFilterList ¶
func NewSsmPatchBaselineGlobalFilterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SsmPatchBaselineGlobalFilterList
type SsmPatchBaselineGlobalFilterOutputReference ¶
type SsmPatchBaselineGlobalFilterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
SetValues(val *[]*string)
ValuesInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmPatchBaselineGlobalFilterOutputReference ¶
func NewSsmPatchBaselineGlobalFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SsmPatchBaselineGlobalFilterOutputReference
type SsmPatchBaselineSource ¶
type SsmPatchBaselineSource struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#configuration SsmPatchBaseline#configuration}.
Configuration *string `field:"required" json:"configuration" yaml:"configuration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#name SsmPatchBaseline#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/ssm_patch_baseline#products SsmPatchBaseline#products}.
Products *[]*string `field:"required" json:"products" yaml:"products"`
}
type SsmPatchBaselineSourceList ¶
type SsmPatchBaselineSourceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) SsmPatchBaselineSourceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmPatchBaselineSourceList ¶
func NewSsmPatchBaselineSourceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) SsmPatchBaselineSourceList
type SsmPatchBaselineSourceOutputReference ¶
type SsmPatchBaselineSourceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Configuration() *string
SetConfiguration(val *string)
ConfigurationInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
Products() *[]*string
SetProducts(val *[]*string)
ProductsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewSsmPatchBaselineSourceOutputReference ¶
func NewSsmPatchBaselineSourceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) SsmPatchBaselineSourceOutputReference
Source Files
¶
- SsmPatchBaseline.go
- SsmPatchBaselineApprovalRule.go
- SsmPatchBaselineApprovalRuleList.go
- SsmPatchBaselineApprovalRuleList__checks.go
- SsmPatchBaselineApprovalRuleOutputReference.go
- SsmPatchBaselineApprovalRuleOutputReference__checks.go
- SsmPatchBaselineApprovalRulePatchFilter.go
- SsmPatchBaselineApprovalRulePatchFilterList.go
- SsmPatchBaselineApprovalRulePatchFilterList__checks.go
- SsmPatchBaselineApprovalRulePatchFilterOutputReference.go
- SsmPatchBaselineApprovalRulePatchFilterOutputReference__checks.go
- SsmPatchBaselineConfig.go
- SsmPatchBaselineGlobalFilter.go
- SsmPatchBaselineGlobalFilterList.go
- SsmPatchBaselineGlobalFilterList__checks.go
- SsmPatchBaselineGlobalFilterOutputReference.go
- SsmPatchBaselineGlobalFilterOutputReference__checks.go
- SsmPatchBaselineSource.go
- SsmPatchBaselineSourceList.go
- SsmPatchBaselineSourceList__checks.go
- SsmPatchBaselineSourceOutputReference.go
- SsmPatchBaselineSourceOutputReference__checks.go
- SsmPatchBaseline__checks.go
- main.go