Documentation
¶
Index ¶
- func NewStoragegatewayGatewayGatewayNetworkInterfaceList_Override(s StoragegatewayGatewayGatewayNetworkInterfaceList, ...)
- func NewStoragegatewayGatewayGatewayNetworkInterfaceOutputReference_Override(s StoragegatewayGatewayGatewayNetworkInterfaceOutputReference, ...)
- func NewStoragegatewayGatewayMaintenanceStartTimeOutputReference_Override(s StoragegatewayGatewayMaintenanceStartTimeOutputReference, ...)
- func NewStoragegatewayGatewaySmbActiveDirectorySettingsOutputReference_Override(s StoragegatewayGatewaySmbActiveDirectorySettingsOutputReference, ...)
- func NewStoragegatewayGatewayTimeoutsOutputReference_Override(s StoragegatewayGatewayTimeoutsOutputReference, ...)
- func NewStoragegatewayGateway_Override(s StoragegatewayGateway, scope constructs.Construct, id *string, ...)
- func StoragegatewayGateway_IsConstruct(x interface{}) *bool
- func StoragegatewayGateway_IsTerraformElement(x interface{}) *bool
- func StoragegatewayGateway_IsTerraformResource(x interface{}) *bool
- func StoragegatewayGateway_TfResourceType() *string
- type StoragegatewayGateway
- type StoragegatewayGatewayConfig
- type StoragegatewayGatewayGatewayNetworkInterface
- type StoragegatewayGatewayGatewayNetworkInterfaceList
- type StoragegatewayGatewayGatewayNetworkInterfaceOutputReference
- type StoragegatewayGatewayMaintenanceStartTime
- type StoragegatewayGatewayMaintenanceStartTimeOutputReference
- type StoragegatewayGatewaySmbActiveDirectorySettings
- type StoragegatewayGatewaySmbActiveDirectorySettingsOutputReference
- type StoragegatewayGatewayTimeouts
- type StoragegatewayGatewayTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewStoragegatewayGatewayGatewayNetworkInterfaceList_Override ¶
func NewStoragegatewayGatewayGatewayNetworkInterfaceList_Override(s StoragegatewayGatewayGatewayNetworkInterfaceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewStoragegatewayGatewayGatewayNetworkInterfaceOutputReference_Override ¶
func NewStoragegatewayGatewayGatewayNetworkInterfaceOutputReference_Override(s StoragegatewayGatewayGatewayNetworkInterfaceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewStoragegatewayGatewayMaintenanceStartTimeOutputReference_Override ¶
func NewStoragegatewayGatewayMaintenanceStartTimeOutputReference_Override(s StoragegatewayGatewayMaintenanceStartTimeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewStoragegatewayGatewaySmbActiveDirectorySettingsOutputReference_Override ¶
func NewStoragegatewayGatewaySmbActiveDirectorySettingsOutputReference_Override(s StoragegatewayGatewaySmbActiveDirectorySettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewStoragegatewayGatewayTimeoutsOutputReference_Override ¶
func NewStoragegatewayGatewayTimeoutsOutputReference_Override(s StoragegatewayGatewayTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewStoragegatewayGateway_Override ¶
func NewStoragegatewayGateway_Override(s StoragegatewayGateway, scope constructs.Construct, id *string, config *StoragegatewayGatewayConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway aws_storagegateway_gateway} Resource.
func StoragegatewayGateway_IsConstruct ¶
func StoragegatewayGateway_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func StoragegatewayGateway_IsTerraformElement ¶
func StoragegatewayGateway_IsTerraformElement(x interface{}) *bool
Experimental.
func StoragegatewayGateway_IsTerraformResource ¶
func StoragegatewayGateway_IsTerraformResource(x interface{}) *bool
Experimental.
func StoragegatewayGateway_TfResourceType ¶
func StoragegatewayGateway_TfResourceType() *string
Types ¶
type StoragegatewayGateway ¶
type StoragegatewayGateway interface {
cdktf.TerraformResource
ActivationKey() *string
SetActivationKey(val *string)
ActivationKeyInput() *string
Arn() *string
AverageDownloadRateLimitInBitsPerSec() *float64
SetAverageDownloadRateLimitInBitsPerSec(val *float64)
AverageDownloadRateLimitInBitsPerSecInput() *float64
AverageUploadRateLimitInBitsPerSec() *float64
SetAverageUploadRateLimitInBitsPerSec(val *float64)
AverageUploadRateLimitInBitsPerSecInput() *float64
// Experimental.
CdktfStack() cdktf.TerraformStack
CloudwatchLogGroupArn() *string
SetCloudwatchLogGroupArn(val *string)
CloudwatchLogGroupArnInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Ec2InstanceId() *string
EndpointType() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GatewayId() *string
GatewayIpAddress() *string
SetGatewayIpAddress(val *string)
GatewayIpAddressInput() *string
GatewayName() *string
SetGatewayName(val *string)
GatewayNameInput() *string
GatewayNetworkInterface() StoragegatewayGatewayGatewayNetworkInterfaceList
GatewayTimezone() *string
SetGatewayTimezone(val *string)
GatewayTimezoneInput() *string
GatewayType() *string
SetGatewayType(val *string)
GatewayTypeInput() *string
GatewayVpcEndpoint() *string
SetGatewayVpcEndpoint(val *string)
GatewayVpcEndpointInput() *string
HostEnvironment() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaintenanceStartTime() StoragegatewayGatewayMaintenanceStartTimeOutputReference
MaintenanceStartTimeInput() *StoragegatewayGatewayMaintenanceStartTime
MediumChangerType() *string
SetMediumChangerType(val *string)
MediumChangerTypeInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SmbActiveDirectorySettings() StoragegatewayGatewaySmbActiveDirectorySettingsOutputReference
SmbActiveDirectorySettingsInput() *StoragegatewayGatewaySmbActiveDirectorySettings
SmbGuestPassword() *string
SetSmbGuestPassword(val *string)
SmbGuestPasswordInput() *string
SmbSecurityStrategy() *string
SetSmbSecurityStrategy(val *string)
SmbSecurityStrategyInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
TapeDriveType() *string
SetTapeDriveType(val *string)
TapeDriveTypeInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() StoragegatewayGatewayTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutMaintenanceStartTime(value *StoragegatewayGatewayMaintenanceStartTime)
PutSmbActiveDirectorySettings(value *StoragegatewayGatewaySmbActiveDirectorySettings)
PutTimeouts(value *StoragegatewayGatewayTimeouts)
ResetActivationKey()
ResetAverageDownloadRateLimitInBitsPerSec()
ResetAverageUploadRateLimitInBitsPerSec()
ResetCloudwatchLogGroupArn()
ResetGatewayIpAddress()
ResetGatewayType()
ResetGatewayVpcEndpoint()
ResetId()
ResetMaintenanceStartTime()
ResetMediumChangerType()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSmbActiveDirectorySettings()
ResetSmbGuestPassword()
ResetSmbSecurityStrategy()
ResetTags()
ResetTagsAll()
ResetTapeDriveType()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway aws_storagegateway_gateway}.
func NewStoragegatewayGateway ¶
func NewStoragegatewayGateway(scope constructs.Construct, id *string, config *StoragegatewayGatewayConfig) StoragegatewayGateway
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway aws_storagegateway_gateway} Resource.
type StoragegatewayGatewayConfig ¶
type StoragegatewayGatewayConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#gateway_name StoragegatewayGateway#gateway_name}.
GatewayName *string `field:"required" json:"gatewayName" yaml:"gatewayName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#gateway_timezone StoragegatewayGateway#gateway_timezone}.
GatewayTimezone *string `field:"required" json:"gatewayTimezone" yaml:"gatewayTimezone"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#activation_key StoragegatewayGateway#activation_key}.
ActivationKey *string `field:"optional" json:"activationKey" yaml:"activationKey"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#average_download_rate_limit_in_bits_per_sec StoragegatewayGateway#average_download_rate_limit_in_bits_per_sec}.
AverageDownloadRateLimitInBitsPerSec *float64 `field:"optional" json:"averageDownloadRateLimitInBitsPerSec" yaml:"averageDownloadRateLimitInBitsPerSec"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#average_upload_rate_limit_in_bits_per_sec StoragegatewayGateway#average_upload_rate_limit_in_bits_per_sec}.
AverageUploadRateLimitInBitsPerSec *float64 `field:"optional" json:"averageUploadRateLimitInBitsPerSec" yaml:"averageUploadRateLimitInBitsPerSec"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#cloudwatch_log_group_arn StoragegatewayGateway#cloudwatch_log_group_arn}.
CloudwatchLogGroupArn *string `field:"optional" json:"cloudwatchLogGroupArn" yaml:"cloudwatchLogGroupArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#gateway_ip_address StoragegatewayGateway#gateway_ip_address}.
GatewayIpAddress *string `field:"optional" json:"gatewayIpAddress" yaml:"gatewayIpAddress"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#gateway_type StoragegatewayGateway#gateway_type}.
GatewayType *string `field:"optional" json:"gatewayType" yaml:"gatewayType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#gateway_vpc_endpoint StoragegatewayGateway#gateway_vpc_endpoint}.
GatewayVpcEndpoint *string `field:"optional" json:"gatewayVpcEndpoint" yaml:"gatewayVpcEndpoint"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#id StoragegatewayGateway#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// maintenance_start_time block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#maintenance_start_time StoragegatewayGateway#maintenance_start_time}
MaintenanceStartTime *StoragegatewayGatewayMaintenanceStartTime `field:"optional" json:"maintenanceStartTime" yaml:"maintenanceStartTime"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#medium_changer_type StoragegatewayGateway#medium_changer_type}.
MediumChangerType *string `field:"optional" json:"mediumChangerType" yaml:"mediumChangerType"`
// smb_active_directory_settings block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#smb_active_directory_settings StoragegatewayGateway#smb_active_directory_settings}
SmbActiveDirectorySettings *StoragegatewayGatewaySmbActiveDirectorySettings `field:"optional" json:"smbActiveDirectorySettings" yaml:"smbActiveDirectorySettings"`
SmbFileShareVisibility interface{} `field:"optional" json:"smbFileShareVisibility" yaml:"smbFileShareVisibility"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#smb_guest_password StoragegatewayGateway#smb_guest_password}.
SmbGuestPassword *string `field:"optional" json:"smbGuestPassword" yaml:"smbGuestPassword"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#smb_security_strategy StoragegatewayGateway#smb_security_strategy}.
SmbSecurityStrategy *string `field:"optional" json:"smbSecurityStrategy" yaml:"smbSecurityStrategy"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#tags StoragegatewayGateway#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#tags_all StoragegatewayGateway#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#tape_drive_type StoragegatewayGateway#tape_drive_type}.
TapeDriveType *string `field:"optional" json:"tapeDriveType" yaml:"tapeDriveType"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#timeouts StoragegatewayGateway#timeouts}
Timeouts *StoragegatewayGatewayTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type StoragegatewayGatewayGatewayNetworkInterface ¶
type StoragegatewayGatewayGatewayNetworkInterface struct {
}
type StoragegatewayGatewayGatewayNetworkInterfaceList ¶
type StoragegatewayGatewayGatewayNetworkInterfaceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) StoragegatewayGatewayGatewayNetworkInterfaceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewStoragegatewayGatewayGatewayNetworkInterfaceList ¶
func NewStoragegatewayGatewayGatewayNetworkInterfaceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) StoragegatewayGatewayGatewayNetworkInterfaceList
type StoragegatewayGatewayGatewayNetworkInterfaceOutputReference ¶
type StoragegatewayGatewayGatewayNetworkInterfaceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *StoragegatewayGatewayGatewayNetworkInterface
SetInternalValue(val *StoragegatewayGatewayGatewayNetworkInterface)
Ipv4Address() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewStoragegatewayGatewayGatewayNetworkInterfaceOutputReference ¶
func NewStoragegatewayGatewayGatewayNetworkInterfaceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) StoragegatewayGatewayGatewayNetworkInterfaceOutputReference
type StoragegatewayGatewayMaintenanceStartTime ¶
type StoragegatewayGatewayMaintenanceStartTime struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#hour_of_day StoragegatewayGateway#hour_of_day}.
HourOfDay *float64 `field:"required" json:"hourOfDay" yaml:"hourOfDay"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#day_of_month StoragegatewayGateway#day_of_month}.
DayOfMonth *string `field:"optional" json:"dayOfMonth" yaml:"dayOfMonth"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#day_of_week StoragegatewayGateway#day_of_week}.
DayOfWeek *string `field:"optional" json:"dayOfWeek" yaml:"dayOfWeek"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#minute_of_hour StoragegatewayGateway#minute_of_hour}.
MinuteOfHour *float64 `field:"optional" json:"minuteOfHour" yaml:"minuteOfHour"`
}
type StoragegatewayGatewayMaintenanceStartTimeOutputReference ¶
type StoragegatewayGatewayMaintenanceStartTimeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DayOfMonth() *string
SetDayOfMonth(val *string)
DayOfMonthInput() *string
DayOfWeek() *string
SetDayOfWeek(val *string)
DayOfWeekInput() *string
// Experimental.
Fqn() *string
HourOfDay() *float64
SetHourOfDay(val *float64)
HourOfDayInput() *float64
InternalValue() *StoragegatewayGatewayMaintenanceStartTime
SetInternalValue(val *StoragegatewayGatewayMaintenanceStartTime)
MinuteOfHour() *float64
SetMinuteOfHour(val *float64)
MinuteOfHourInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDayOfMonth()
ResetDayOfWeek()
ResetMinuteOfHour()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewStoragegatewayGatewayMaintenanceStartTimeOutputReference ¶
func NewStoragegatewayGatewayMaintenanceStartTimeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) StoragegatewayGatewayMaintenanceStartTimeOutputReference
type StoragegatewayGatewaySmbActiveDirectorySettings ¶
type StoragegatewayGatewaySmbActiveDirectorySettings struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#domain_name StoragegatewayGateway#domain_name}.
DomainName *string `field:"required" json:"domainName" yaml:"domainName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#password StoragegatewayGateway#password}.
Password *string `field:"required" json:"password" yaml:"password"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#username StoragegatewayGateway#username}.
Username *string `field:"required" json:"username" yaml:"username"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#domain_controllers StoragegatewayGateway#domain_controllers}.
DomainControllers *[]*string `field:"optional" json:"domainControllers" yaml:"domainControllers"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#organizational_unit StoragegatewayGateway#organizational_unit}.
OrganizationalUnit *string `field:"optional" json:"organizationalUnit" yaml:"organizationalUnit"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#timeout_in_seconds StoragegatewayGateway#timeout_in_seconds}.
TimeoutInSeconds *float64 `field:"optional" json:"timeoutInSeconds" yaml:"timeoutInSeconds"`
}
type StoragegatewayGatewaySmbActiveDirectorySettingsOutputReference ¶
type StoragegatewayGatewaySmbActiveDirectorySettingsOutputReference interface {
cdktf.ComplexObject
ActiveDirectoryStatus() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DomainControllers() *[]*string
SetDomainControllers(val *[]*string)
DomainControllersInput() *[]*string
DomainName() *string
SetDomainName(val *string)
DomainNameInput() *string
// Experimental.
Fqn() *string
InternalValue() *StoragegatewayGatewaySmbActiveDirectorySettings
SetInternalValue(val *StoragegatewayGatewaySmbActiveDirectorySettings)
OrganizationalUnit() *string
SetOrganizationalUnit(val *string)
OrganizationalUnitInput() *string
Password() *string
SetPassword(val *string)
PasswordInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TimeoutInSeconds() *float64
SetTimeoutInSeconds(val *float64)
TimeoutInSecondsInput() *float64
Username() *string
SetUsername(val *string)
UsernameInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDomainControllers()
ResetOrganizationalUnit()
ResetTimeoutInSeconds()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewStoragegatewayGatewaySmbActiveDirectorySettingsOutputReference ¶
func NewStoragegatewayGatewaySmbActiveDirectorySettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) StoragegatewayGatewaySmbActiveDirectorySettingsOutputReference
type StoragegatewayGatewayTimeouts ¶
type StoragegatewayGatewayTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_gateway#create StoragegatewayGateway#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
}
type StoragegatewayGatewayTimeoutsOutputReference ¶
type StoragegatewayGatewayTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewStoragegatewayGatewayTimeoutsOutputReference ¶
func NewStoragegatewayGatewayTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) StoragegatewayGatewayTimeoutsOutputReference
Source Files
¶
- StoragegatewayGateway.go
- StoragegatewayGatewayConfig.go
- StoragegatewayGatewayGatewayNetworkInterface.go
- StoragegatewayGatewayGatewayNetworkInterfaceList.go
- StoragegatewayGatewayGatewayNetworkInterfaceList__checks.go
- StoragegatewayGatewayGatewayNetworkInterfaceOutputReference.go
- StoragegatewayGatewayGatewayNetworkInterfaceOutputReference__checks.go
- StoragegatewayGatewayMaintenanceStartTime.go
- StoragegatewayGatewayMaintenanceStartTimeOutputReference.go
- StoragegatewayGatewayMaintenanceStartTimeOutputReference__checks.go
- StoragegatewayGatewaySmbActiveDirectorySettings.go
- StoragegatewayGatewaySmbActiveDirectorySettingsOutputReference.go
- StoragegatewayGatewaySmbActiveDirectorySettingsOutputReference__checks.go
- StoragegatewayGatewayTimeouts.go
- StoragegatewayGatewayTimeoutsOutputReference.go
- StoragegatewayGatewayTimeoutsOutputReference__checks.go
- StoragegatewayGateway__checks.go
- main.go