Documentation
¶
Index ¶
- func NewStoragegatewayNfsFileShareCacheAttributesOutputReference_Override(s StoragegatewayNfsFileShareCacheAttributesOutputReference, ...)
- func NewStoragegatewayNfsFileShareNfsFileShareDefaultsOutputReference_Override(s StoragegatewayNfsFileShareNfsFileShareDefaultsOutputReference, ...)
- func NewStoragegatewayNfsFileShareTimeoutsOutputReference_Override(s StoragegatewayNfsFileShareTimeoutsOutputReference, ...)
- func NewStoragegatewayNfsFileShare_Override(s StoragegatewayNfsFileShare, scope constructs.Construct, id *string, ...)
- func StoragegatewayNfsFileShare_IsConstruct(x interface{}) *bool
- func StoragegatewayNfsFileShare_IsTerraformElement(x interface{}) *bool
- func StoragegatewayNfsFileShare_IsTerraformResource(x interface{}) *bool
- func StoragegatewayNfsFileShare_TfResourceType() *string
- type StoragegatewayNfsFileShare
- type StoragegatewayNfsFileShareCacheAttributes
- type StoragegatewayNfsFileShareCacheAttributesOutputReference
- type StoragegatewayNfsFileShareConfig
- type StoragegatewayNfsFileShareNfsFileShareDefaults
- type StoragegatewayNfsFileShareNfsFileShareDefaultsOutputReference
- type StoragegatewayNfsFileShareTimeouts
- type StoragegatewayNfsFileShareTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewStoragegatewayNfsFileShareCacheAttributesOutputReference_Override ¶
func NewStoragegatewayNfsFileShareCacheAttributesOutputReference_Override(s StoragegatewayNfsFileShareCacheAttributesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewStoragegatewayNfsFileShareNfsFileShareDefaultsOutputReference_Override ¶
func NewStoragegatewayNfsFileShareNfsFileShareDefaultsOutputReference_Override(s StoragegatewayNfsFileShareNfsFileShareDefaultsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewStoragegatewayNfsFileShareTimeoutsOutputReference_Override ¶
func NewStoragegatewayNfsFileShareTimeoutsOutputReference_Override(s StoragegatewayNfsFileShareTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewStoragegatewayNfsFileShare_Override ¶
func NewStoragegatewayNfsFileShare_Override(s StoragegatewayNfsFileShare, scope constructs.Construct, id *string, config *StoragegatewayNfsFileShareConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_nfs_file_share aws_storagegateway_nfs_file_share} Resource.
func StoragegatewayNfsFileShare_IsConstruct ¶
func StoragegatewayNfsFileShare_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func StoragegatewayNfsFileShare_IsTerraformElement ¶
func StoragegatewayNfsFileShare_IsTerraformElement(x interface{}) *bool
Experimental.
func StoragegatewayNfsFileShare_IsTerraformResource ¶
func StoragegatewayNfsFileShare_IsTerraformResource(x interface{}) *bool
Experimental.
func StoragegatewayNfsFileShare_TfResourceType ¶
func StoragegatewayNfsFileShare_TfResourceType() *string
Types ¶
type StoragegatewayNfsFileShare ¶
type StoragegatewayNfsFileShare interface {
cdktf.TerraformResource
// Experimental.
Connection() interface{}
SetConnection(val interface{})
ConstructNodeMetadata() *map[string]interface{}
Count() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
ForEach() cdktf.ITerraformIterator
SetForEach(val cdktf.ITerraformIterator)
Fqn() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
// The tree node.
Provider() cdktf.TerraformProvider
SetProvider(val cdktf.TerraformProvider)
Provisioners() *[]interface{}
SetProvisioners(val *[]interface{})
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformMetaArguments() *map[string]interface{}
// Experimental.
AddOverride(path *string, value interface{})
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ToMetadata() interface{}
ToString() *string
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_nfs_file_share aws_storagegateway_nfs_file_share}.
func NewStoragegatewayNfsFileShare ¶
func NewStoragegatewayNfsFileShare(scope constructs.Construct, id *string, config *StoragegatewayNfsFileShareConfig) StoragegatewayNfsFileShare
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_nfs_file_share aws_storagegateway_nfs_file_share} Resource.
type StoragegatewayNfsFileShareCacheAttributes ¶
type StoragegatewayNfsFileShareCacheAttributes struct {
CacheStaleTimeoutInSeconds *float64 `field:"optional" json:"cacheStaleTimeoutInSeconds" yaml:"cacheStaleTimeoutInSeconds"`
}
type StoragegatewayNfsFileShareCacheAttributesOutputReference ¶
type StoragegatewayNfsFileShareCacheAttributesOutputReference interface {
cdktf.ComplexObject
// Experimental.
ComplexObjectIndex() interface{}
SetComplexObjectIndex(val interface{})
// Experimental.
ComplexObjectIsFromSet() *bool
SetComplexObjectIsFromSet(val *bool)
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
ComputeFqn() *string
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationAsList() cdktf.IResolvable
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewStoragegatewayNfsFileShareCacheAttributesOutputReference ¶
func NewStoragegatewayNfsFileShareCacheAttributesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) StoragegatewayNfsFileShareCacheAttributesOutputReference
type StoragegatewayNfsFileShareConfig ¶
type StoragegatewayNfsFileShareConfig struct {
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
Count interface{} `field:"optional" json:"count" yaml:"count"`
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
ClientList *[]*string `field:"required" json:"clientList" yaml:"clientList"`
GatewayArn *string `field:"required" json:"gatewayArn" yaml:"gatewayArn"`
LocationArn *string `field:"required" json:"locationArn" yaml:"locationArn"`
RoleArn *string `field:"required" json:"roleArn" yaml:"roleArn"`
AuditDestinationArn *string `field:"optional" json:"auditDestinationArn" yaml:"auditDestinationArn"`
BucketRegion *string `field:"optional" json:"bucketRegion" yaml:"bucketRegion"`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_nfs_file_share#cache_attributes StoragegatewayNfsFileShare#cache_attributes}
CacheAttributes *StoragegatewayNfsFileShareCacheAttributes `field:"optional" json:"cacheAttributes" yaml:"cacheAttributes"`
DefaultStorageClass *string `field:"optional" json:"defaultStorageClass" yaml:"defaultStorageClass"`
FileShareName *string `field:"optional" json:"fileShareName" yaml:"fileShareName"`
GuessMimeTypeEnabled interface{} `field:"optional" json:"guessMimeTypeEnabled" yaml:"guessMimeTypeEnabled"`
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
KmsEncrypted interface{} `field:"optional" json:"kmsEncrypted" yaml:"kmsEncrypted"`
KmsKeyArn *string `field:"optional" json:"kmsKeyArn" yaml:"kmsKeyArn"`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_nfs_file_share#nfs_file_share_defaults StoragegatewayNfsFileShare#nfs_file_share_defaults}
NfsFileShareDefaults *StoragegatewayNfsFileShareNfsFileShareDefaults `field:"optional" json:"nfsFileShareDefaults" yaml:"nfsFileShareDefaults"`
NotificationPolicy *string `field:"optional" json:"notificationPolicy" yaml:"notificationPolicy"`
ObjectAcl *string `field:"optional" json:"objectAcl" yaml:"objectAcl"`
ReadOnly interface{} `field:"optional" json:"readOnly" yaml:"readOnly"`
RequesterPays interface{} `field:"optional" json:"requesterPays" yaml:"requesterPays"`
Squash *string `field:"optional" json:"squash" yaml:"squash"`
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/storagegateway_nfs_file_share#timeouts StoragegatewayNfsFileShare#timeouts}
Timeouts *StoragegatewayNfsFileShareTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
VpcEndpointDnsName *string `field:"optional" json:"vpcEndpointDnsName" yaml:"vpcEndpointDnsName"`
}
type StoragegatewayNfsFileShareNfsFileShareDefaults ¶
type StoragegatewayNfsFileShareNfsFileShareDefaults struct {
DirectoryMode *string `field:"optional" json:"directoryMode" yaml:"directoryMode"`
FileMode *string `field:"optional" json:"fileMode" yaml:"fileMode"`
GroupId *string `field:"optional" json:"groupId" yaml:"groupId"`
OwnerId *string `field:"optional" json:"ownerId" yaml:"ownerId"`
}
type StoragegatewayNfsFileShareNfsFileShareDefaultsOutputReference ¶
type StoragegatewayNfsFileShareNfsFileShareDefaultsOutputReference interface {
cdktf.ComplexObject
// Experimental.
ComplexObjectIndex() interface{}
SetComplexObjectIndex(val interface{})
// Experimental.
ComplexObjectIsFromSet() *bool
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
// Experimental.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
ComputeFqn() *string
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationAsList() cdktf.IResolvable
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewStoragegatewayNfsFileShareNfsFileShareDefaultsOutputReference ¶
func NewStoragegatewayNfsFileShareNfsFileShareDefaultsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) StoragegatewayNfsFileShareNfsFileShareDefaultsOutputReference
type StoragegatewayNfsFileShareTimeoutsOutputReference ¶
type StoragegatewayNfsFileShareTimeoutsOutputReference interface {
cdktf.ComplexObject
// Experimental.
ComplexObjectIndex() interface{}
SetComplexObjectIndex(val interface{})
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
// Experimental.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
ComputeFqn() *string
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationAsList() cdktf.IResolvable
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewStoragegatewayNfsFileShareTimeoutsOutputReference ¶
func NewStoragegatewayNfsFileShareTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) StoragegatewayNfsFileShareTimeoutsOutputReference
Source Files
¶
- StoragegatewayNfsFileShare.go
- StoragegatewayNfsFileShareCacheAttributes.go
- StoragegatewayNfsFileShareCacheAttributesOutputReference.go
- StoragegatewayNfsFileShareCacheAttributesOutputReference__checks.go
- StoragegatewayNfsFileShareConfig.go
- StoragegatewayNfsFileShareNfsFileShareDefaults.go
- StoragegatewayNfsFileShareNfsFileShareDefaultsOutputReference.go
- StoragegatewayNfsFileShareNfsFileShareDefaultsOutputReference__checks.go
- StoragegatewayNfsFileShareTimeouts.go
- StoragegatewayNfsFileShareTimeoutsOutputReference.go
- StoragegatewayNfsFileShareTimeoutsOutputReference__checks.go
- StoragegatewayNfsFileShare__checks.go
- main.go