Documentation
¶
Index ¶
- func NewTransferAccessHomeDirectoryMappingsList_Override(t TransferAccessHomeDirectoryMappingsList, ...)
- func NewTransferAccessHomeDirectoryMappingsOutputReference_Override(t TransferAccessHomeDirectoryMappingsOutputReference, ...)
- func NewTransferAccessPosixProfileOutputReference_Override(t TransferAccessPosixProfileOutputReference, ...)
- func NewTransferAccess_Override(t TransferAccess, scope constructs.Construct, id *string, ...)
- func TransferAccess_IsConstruct(x interface{}) *bool
- func TransferAccess_IsTerraformElement(x interface{}) *bool
- func TransferAccess_IsTerraformResource(x interface{}) *bool
- func TransferAccess_TfResourceType() *string
- type TransferAccess
- type TransferAccessConfig
- type TransferAccessHomeDirectoryMappings
- type TransferAccessHomeDirectoryMappingsList
- type TransferAccessHomeDirectoryMappingsOutputReference
- type TransferAccessPosixProfile
- type TransferAccessPosixProfileOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewTransferAccessHomeDirectoryMappingsList_Override ¶
func NewTransferAccessHomeDirectoryMappingsList_Override(t TransferAccessHomeDirectoryMappingsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewTransferAccessHomeDirectoryMappingsOutputReference_Override ¶
func NewTransferAccessHomeDirectoryMappingsOutputReference_Override(t TransferAccessHomeDirectoryMappingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewTransferAccessPosixProfileOutputReference_Override ¶
func NewTransferAccessPosixProfileOutputReference_Override(t TransferAccessPosixProfileOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewTransferAccess_Override ¶
func NewTransferAccess_Override(t TransferAccess, scope constructs.Construct, id *string, config *TransferAccessConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/transfer_access aws_transfer_access} Resource.
func TransferAccess_IsConstruct ¶
func TransferAccess_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func TransferAccess_IsTerraformElement ¶
func TransferAccess_IsTerraformElement(x interface{}) *bool
Experimental.
func TransferAccess_IsTerraformResource ¶
func TransferAccess_IsTerraformResource(x interface{}) *bool
Experimental.
func TransferAccess_TfResourceType ¶
func TransferAccess_TfResourceType() *string
Types ¶
type TransferAccess ¶
type TransferAccess interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
ExternalId() *string
SetExternalId(val *string)
ExternalIdInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HomeDirectory() *string
SetHomeDirectory(val *string)
HomeDirectoryInput() *string
HomeDirectoryMappings() TransferAccessHomeDirectoryMappingsList
HomeDirectoryMappingsInput() interface{}
HomeDirectoryType() *string
SetHomeDirectoryType(val *string)
HomeDirectoryTypeInput() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
Policy() *string
SetPolicy(val *string)
PolicyInput() *string
PosixProfile() TransferAccessPosixProfileOutputReference
PosixProfileInput() *TransferAccessPosixProfile
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Role() *string
SetRole(val *string)
RoleInput() *string
ServerId() *string
SetServerId(val *string)
ServerIdInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutHomeDirectoryMappings(value interface{})
PutPosixProfile(value *TransferAccessPosixProfile)
ResetHomeDirectory()
ResetHomeDirectoryMappings()
ResetHomeDirectoryType()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPolicy()
ResetPosixProfile()
ResetRole()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/transfer_access aws_transfer_access}.
func NewTransferAccess ¶
func NewTransferAccess(scope constructs.Construct, id *string, config *TransferAccessConfig) TransferAccess
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/transfer_access aws_transfer_access} Resource.
type TransferAccessConfig ¶
type TransferAccessConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/transfer_access#external_id TransferAccess#external_id}.
ExternalId *string `field:"required" json:"externalId" yaml:"externalId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/transfer_access#server_id TransferAccess#server_id}.
ServerId *string `field:"required" json:"serverId" yaml:"serverId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/transfer_access#home_directory TransferAccess#home_directory}.
HomeDirectory *string `field:"optional" json:"homeDirectory" yaml:"homeDirectory"`
// home_directory_mappings block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/transfer_access#home_directory_mappings TransferAccess#home_directory_mappings}
HomeDirectoryMappings interface{} `field:"optional" json:"homeDirectoryMappings" yaml:"homeDirectoryMappings"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/transfer_access#home_directory_type TransferAccess#home_directory_type}.
HomeDirectoryType *string `field:"optional" json:"homeDirectoryType" yaml:"homeDirectoryType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/transfer_access#id TransferAccess#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/transfer_access#policy TransferAccess#policy}.
Policy *string `field:"optional" json:"policy" yaml:"policy"`
// posix_profile block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/transfer_access#posix_profile TransferAccess#posix_profile}
PosixProfile *TransferAccessPosixProfile `field:"optional" json:"posixProfile" yaml:"posixProfile"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/transfer_access#role TransferAccess#role}.
Role *string `field:"optional" json:"role" yaml:"role"`
}
type TransferAccessHomeDirectoryMappings ¶
type TransferAccessHomeDirectoryMappings struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/transfer_access#entry TransferAccess#entry}.
Entry *string `field:"required" json:"entry" yaml:"entry"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/transfer_access#target TransferAccess#target}.
Target *string `field:"required" json:"target" yaml:"target"`
}
type TransferAccessHomeDirectoryMappingsList ¶
type TransferAccessHomeDirectoryMappingsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) TransferAccessHomeDirectoryMappingsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewTransferAccessHomeDirectoryMappingsList ¶
func NewTransferAccessHomeDirectoryMappingsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) TransferAccessHomeDirectoryMappingsList
type TransferAccessHomeDirectoryMappingsOutputReference ¶
type TransferAccessHomeDirectoryMappingsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Entry() *string
SetEntry(val *string)
EntryInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Target() *string
SetTarget(val *string)
TargetInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewTransferAccessHomeDirectoryMappingsOutputReference ¶
func NewTransferAccessHomeDirectoryMappingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) TransferAccessHomeDirectoryMappingsOutputReference
type TransferAccessPosixProfile ¶
type TransferAccessPosixProfile struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/transfer_access#gid TransferAccess#gid}.
Gid *float64 `field:"required" json:"gid" yaml:"gid"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/transfer_access#uid TransferAccess#uid}.
Uid *float64 `field:"required" json:"uid" yaml:"uid"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/transfer_access#secondary_gids TransferAccess#secondary_gids}.
SecondaryGids *[]*float64 `field:"optional" json:"secondaryGids" yaml:"secondaryGids"`
}
type TransferAccessPosixProfileOutputReference ¶
type TransferAccessPosixProfileOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Gid() *float64
SetGid(val *float64)
GidInput() *float64
InternalValue() *TransferAccessPosixProfile
SetInternalValue(val *TransferAccessPosixProfile)
SecondaryGids() *[]*float64
SetSecondaryGids(val *[]*float64)
SecondaryGidsInput() *[]*float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Uid() *float64
SetUid(val *float64)
UidInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetSecondaryGids()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewTransferAccessPosixProfileOutputReference ¶
func NewTransferAccessPosixProfileOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) TransferAccessPosixProfileOutputReference
Source Files
¶
- TransferAccess.go
- TransferAccessConfig.go
- TransferAccessHomeDirectoryMappings.go
- TransferAccessHomeDirectoryMappingsList.go
- TransferAccessHomeDirectoryMappingsList__checks.go
- TransferAccessHomeDirectoryMappingsOutputReference.go
- TransferAccessHomeDirectoryMappingsOutputReference__checks.go
- TransferAccessPosixProfile.go
- TransferAccessPosixProfileOutputReference.go
- TransferAccessPosixProfileOutputReference__checks.go
- TransferAccess__checks.go
- main.go