Documentation
¶
Index ¶
- func NewVpclatticeTargetGroupConfigAOutputReference_Override(v VpclatticeTargetGroupConfigAOutputReference, ...)
- func NewVpclatticeTargetGroupConfigHealthCheckMatcherOutputReference_Override(v VpclatticeTargetGroupConfigHealthCheckMatcherOutputReference, ...)
- func NewVpclatticeTargetGroupConfigHealthCheckOutputReference_Override(v VpclatticeTargetGroupConfigHealthCheckOutputReference, ...)
- func NewVpclatticeTargetGroupTimeoutsOutputReference_Override(v VpclatticeTargetGroupTimeoutsOutputReference, ...)
- func NewVpclatticeTargetGroup_Override(v VpclatticeTargetGroup, scope constructs.Construct, id *string, ...)
- func VpclatticeTargetGroup_IsConstruct(x interface{}) *bool
- func VpclatticeTargetGroup_IsTerraformElement(x interface{}) *bool
- func VpclatticeTargetGroup_IsTerraformResource(x interface{}) *bool
- func VpclatticeTargetGroup_TfResourceType() *string
- type VpclatticeTargetGroup
- type VpclatticeTargetGroupConfig
- type VpclatticeTargetGroupConfigA
- type VpclatticeTargetGroupConfigAOutputReference
- type VpclatticeTargetGroupConfigHealthCheck
- type VpclatticeTargetGroupConfigHealthCheckMatcher
- type VpclatticeTargetGroupConfigHealthCheckMatcherOutputReference
- type VpclatticeTargetGroupConfigHealthCheckOutputReference
- type VpclatticeTargetGroupTimeouts
- type VpclatticeTargetGroupTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewVpclatticeTargetGroupConfigAOutputReference_Override ¶
func NewVpclatticeTargetGroupConfigAOutputReference_Override(v VpclatticeTargetGroupConfigAOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVpclatticeTargetGroupConfigHealthCheckMatcherOutputReference_Override ¶
func NewVpclatticeTargetGroupConfigHealthCheckMatcherOutputReference_Override(v VpclatticeTargetGroupConfigHealthCheckMatcherOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVpclatticeTargetGroupConfigHealthCheckOutputReference_Override ¶
func NewVpclatticeTargetGroupConfigHealthCheckOutputReference_Override(v VpclatticeTargetGroupConfigHealthCheckOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVpclatticeTargetGroupTimeoutsOutputReference_Override ¶
func NewVpclatticeTargetGroupTimeoutsOutputReference_Override(v VpclatticeTargetGroupTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVpclatticeTargetGroup_Override ¶
func NewVpclatticeTargetGroup_Override(v VpclatticeTargetGroup, scope constructs.Construct, id *string, config *VpclatticeTargetGroupConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group aws_vpclattice_target_group} Resource.
func VpclatticeTargetGroup_IsConstruct ¶
func VpclatticeTargetGroup_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func VpclatticeTargetGroup_IsTerraformElement ¶
func VpclatticeTargetGroup_IsTerraformElement(x interface{}) *bool
Experimental.
func VpclatticeTargetGroup_IsTerraformResource ¶
func VpclatticeTargetGroup_IsTerraformResource(x interface{}) *bool
Experimental.
func VpclatticeTargetGroup_TfResourceType ¶
func VpclatticeTargetGroup_TfResourceType() *string
Types ¶
type VpclatticeTargetGroup ¶
type VpclatticeTargetGroup interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
Config() VpclatticeTargetGroupConfigAOutputReference
ConfigInput() *VpclatticeTargetGroupConfigA
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Status() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() VpclatticeTargetGroupTimeoutsOutputReference
TimeoutsInput() interface{}
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutConfig(value *VpclatticeTargetGroupConfigA)
PutTimeouts(value *VpclatticeTargetGroupTimeouts)
ResetConfig()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group aws_vpclattice_target_group}.
func NewVpclatticeTargetGroup ¶
func NewVpclatticeTargetGroup(scope constructs.Construct, id *string, config *VpclatticeTargetGroupConfig) VpclatticeTargetGroup
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group aws_vpclattice_target_group} Resource.
type VpclatticeTargetGroupConfig ¶
type VpclatticeTargetGroupConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#name VpclatticeTargetGroup#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#type VpclatticeTargetGroup#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#config VpclatticeTargetGroup#config}
Config *VpclatticeTargetGroupConfigA `field:"optional" json:"config" yaml:"config"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#id VpclatticeTargetGroup#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#tags VpclatticeTargetGroup#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#tags_all VpclatticeTargetGroup#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#timeouts VpclatticeTargetGroup#timeouts}
Timeouts *VpclatticeTargetGroupTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type VpclatticeTargetGroupConfigA ¶
type VpclatticeTargetGroupConfigA struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#port VpclatticeTargetGroup#port}.
Port *float64 `field:"required" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#protocol VpclatticeTargetGroup#protocol}.
Protocol *string `field:"required" json:"protocol" yaml:"protocol"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#vpc_identifier VpclatticeTargetGroup#vpc_identifier}.
VpcIdentifier *string `field:"required" json:"vpcIdentifier" yaml:"vpcIdentifier"`
// health_check block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#health_check VpclatticeTargetGroup#health_check}
HealthCheck *VpclatticeTargetGroupConfigHealthCheck `field:"optional" json:"healthCheck" yaml:"healthCheck"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#ip_address_type VpclatticeTargetGroup#ip_address_type}.
IpAddressType *string `field:"optional" json:"ipAddressType" yaml:"ipAddressType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#protocol_version VpclatticeTargetGroup#protocol_version}.
ProtocolVersion *string `field:"optional" json:"protocolVersion" yaml:"protocolVersion"`
}
type VpclatticeTargetGroupConfigAOutputReference ¶
type VpclatticeTargetGroupConfigAOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HealthCheck() VpclatticeTargetGroupConfigHealthCheckOutputReference
HealthCheckInput() *VpclatticeTargetGroupConfigHealthCheck
InternalValue() *VpclatticeTargetGroupConfigA
SetInternalValue(val *VpclatticeTargetGroupConfigA)
IpAddressType() *string
SetIpAddressType(val *string)
IpAddressTypeInput() *string
Port() *float64
SetPort(val *float64)
PortInput() *float64
Protocol() *string
SetProtocol(val *string)
ProtocolInput() *string
ProtocolVersion() *string
SetProtocolVersion(val *string)
ProtocolVersionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VpcIdentifier() *string
SetVpcIdentifier(val *string)
VpcIdentifierInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutHealthCheck(value *VpclatticeTargetGroupConfigHealthCheck)
ResetHealthCheck()
ResetIpAddressType()
ResetProtocolVersion()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpclatticeTargetGroupConfigAOutputReference ¶
func NewVpclatticeTargetGroupConfigAOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VpclatticeTargetGroupConfigAOutputReference
type VpclatticeTargetGroupConfigHealthCheck ¶
type VpclatticeTargetGroupConfigHealthCheck struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#enabled VpclatticeTargetGroup#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#health_check_interval_seconds VpclatticeTargetGroup#health_check_interval_seconds}.
HealthCheckIntervalSeconds *float64 `field:"optional" json:"healthCheckIntervalSeconds" yaml:"healthCheckIntervalSeconds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#health_check_timeout_seconds VpclatticeTargetGroup#health_check_timeout_seconds}.
HealthCheckTimeoutSeconds *float64 `field:"optional" json:"healthCheckTimeoutSeconds" yaml:"healthCheckTimeoutSeconds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#healthy_threshold_count VpclatticeTargetGroup#healthy_threshold_count}.
HealthyThresholdCount *float64 `field:"optional" json:"healthyThresholdCount" yaml:"healthyThresholdCount"`
// matcher block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#matcher VpclatticeTargetGroup#matcher}
Matcher *VpclatticeTargetGroupConfigHealthCheckMatcher `field:"optional" json:"matcher" yaml:"matcher"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#path VpclatticeTargetGroup#path}.
Path *string `field:"optional" json:"path" yaml:"path"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#port VpclatticeTargetGroup#port}.
Port *float64 `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#protocol VpclatticeTargetGroup#protocol}.
Protocol *string `field:"optional" json:"protocol" yaml:"protocol"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#protocol_version VpclatticeTargetGroup#protocol_version}.
ProtocolVersion *string `field:"optional" json:"protocolVersion" yaml:"protocolVersion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#unhealthy_threshold_count VpclatticeTargetGroup#unhealthy_threshold_count}.
UnhealthyThresholdCount *float64 `field:"optional" json:"unhealthyThresholdCount" yaml:"unhealthyThresholdCount"`
}
type VpclatticeTargetGroupConfigHealthCheckMatcher ¶
type VpclatticeTargetGroupConfigHealthCheckMatcher struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#value VpclatticeTargetGroup#value}.
Value *string `field:"optional" json:"value" yaml:"value"`
}
type VpclatticeTargetGroupConfigHealthCheckMatcherOutputReference ¶
type VpclatticeTargetGroupConfigHealthCheckMatcherOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *VpclatticeTargetGroupConfigHealthCheckMatcher
SetInternalValue(val *VpclatticeTargetGroupConfigHealthCheckMatcher)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetValue()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpclatticeTargetGroupConfigHealthCheckMatcherOutputReference ¶
func NewVpclatticeTargetGroupConfigHealthCheckMatcherOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VpclatticeTargetGroupConfigHealthCheckMatcherOutputReference
type VpclatticeTargetGroupConfigHealthCheckOutputReference ¶
type VpclatticeTargetGroupConfigHealthCheckOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
HealthCheckIntervalSeconds() *float64
SetHealthCheckIntervalSeconds(val *float64)
HealthCheckIntervalSecondsInput() *float64
HealthCheckTimeoutSeconds() *float64
SetHealthCheckTimeoutSeconds(val *float64)
HealthCheckTimeoutSecondsInput() *float64
HealthyThresholdCount() *float64
SetHealthyThresholdCount(val *float64)
HealthyThresholdCountInput() *float64
InternalValue() *VpclatticeTargetGroupConfigHealthCheck
SetInternalValue(val *VpclatticeTargetGroupConfigHealthCheck)
Matcher() VpclatticeTargetGroupConfigHealthCheckMatcherOutputReference
MatcherInput() *VpclatticeTargetGroupConfigHealthCheckMatcher
Path() *string
SetPath(val *string)
PathInput() *string
Port() *float64
SetPort(val *float64)
PortInput() *float64
Protocol() *string
SetProtocol(val *string)
ProtocolInput() *string
ProtocolVersion() *string
SetProtocolVersion(val *string)
ProtocolVersionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UnhealthyThresholdCount() *float64
SetUnhealthyThresholdCount(val *float64)
UnhealthyThresholdCountInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutMatcher(value *VpclatticeTargetGroupConfigHealthCheckMatcher)
ResetEnabled()
ResetHealthCheckIntervalSeconds()
ResetHealthCheckTimeoutSeconds()
ResetHealthyThresholdCount()
ResetMatcher()
ResetPath()
ResetPort()
ResetProtocol()
ResetProtocolVersion()
ResetUnhealthyThresholdCount()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpclatticeTargetGroupConfigHealthCheckOutputReference ¶
func NewVpclatticeTargetGroupConfigHealthCheckOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VpclatticeTargetGroupConfigHealthCheckOutputReference
type VpclatticeTargetGroupTimeouts ¶
type VpclatticeTargetGroupTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#create VpclatticeTargetGroup#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#delete VpclatticeTargetGroup#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpclattice_target_group#update VpclatticeTargetGroup#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type VpclatticeTargetGroupTimeoutsOutputReference ¶
type VpclatticeTargetGroupTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpclatticeTargetGroupTimeoutsOutputReference ¶
func NewVpclatticeTargetGroupTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VpclatticeTargetGroupTimeoutsOutputReference
Source Files
¶
- VpclatticeTargetGroup.go
- VpclatticeTargetGroupConfig.go
- VpclatticeTargetGroupConfigA.go
- VpclatticeTargetGroupConfigAOutputReference.go
- VpclatticeTargetGroupConfigAOutputReference__checks.go
- VpclatticeTargetGroupConfigHealthCheck.go
- VpclatticeTargetGroupConfigHealthCheckMatcher.go
- VpclatticeTargetGroupConfigHealthCheckMatcherOutputReference.go
- VpclatticeTargetGroupConfigHealthCheckMatcherOutputReference__checks.go
- VpclatticeTargetGroupConfigHealthCheckOutputReference.go
- VpclatticeTargetGroupConfigHealthCheckOutputReference__checks.go
- VpclatticeTargetGroupTimeouts.go
- VpclatticeTargetGroupTimeoutsOutputReference.go
- VpclatticeTargetGroupTimeoutsOutputReference__checks.go
- VpclatticeTargetGroup__checks.go
- main.go