Documentation
¶
Index ¶
- func NewVpnConnectionRoutesList_Override(v VpnConnectionRoutesList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewVpnConnectionRoutesOutputReference_Override(v VpnConnectionRoutesOutputReference, ...)
- func NewVpnConnectionTunnel1LogOptionsCloudwatchLogOptionsOutputReference_Override(v VpnConnectionTunnel1LogOptionsCloudwatchLogOptionsOutputReference, ...)
- func NewVpnConnectionTunnel1LogOptionsOutputReference_Override(v VpnConnectionTunnel1LogOptionsOutputReference, ...)
- func NewVpnConnectionTunnel2LogOptionsCloudwatchLogOptionsOutputReference_Override(v VpnConnectionTunnel2LogOptionsCloudwatchLogOptionsOutputReference, ...)
- func NewVpnConnectionTunnel2LogOptionsOutputReference_Override(v VpnConnectionTunnel2LogOptionsOutputReference, ...)
- func NewVpnConnectionVgwTelemetryList_Override(v VpnConnectionVgwTelemetryList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewVpnConnectionVgwTelemetryOutputReference_Override(v VpnConnectionVgwTelemetryOutputReference, ...)
- func NewVpnConnection_Override(v VpnConnection, scope constructs.Construct, id *string, ...)
- func VpnConnection_IsConstruct(x interface{}) *bool
- func VpnConnection_IsTerraformElement(x interface{}) *bool
- func VpnConnection_IsTerraformResource(x interface{}) *bool
- func VpnConnection_TfResourceType() *string
- type VpnConnection
- type VpnConnectionConfig
- type VpnConnectionRoutes
- type VpnConnectionRoutesList
- type VpnConnectionRoutesOutputReference
- type VpnConnectionTunnel1LogOptions
- type VpnConnectionTunnel1LogOptionsCloudwatchLogOptions
- type VpnConnectionTunnel1LogOptionsCloudwatchLogOptionsOutputReference
- type VpnConnectionTunnel1LogOptionsOutputReference
- type VpnConnectionTunnel2LogOptions
- type VpnConnectionTunnel2LogOptionsCloudwatchLogOptions
- type VpnConnectionTunnel2LogOptionsCloudwatchLogOptionsOutputReference
- type VpnConnectionTunnel2LogOptionsOutputReference
- type VpnConnectionVgwTelemetry
- type VpnConnectionVgwTelemetryList
- type VpnConnectionVgwTelemetryOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewVpnConnectionRoutesList_Override ¶
func NewVpnConnectionRoutesList_Override(v VpnConnectionRoutesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewVpnConnectionRoutesOutputReference_Override ¶
func NewVpnConnectionRoutesOutputReference_Override(v VpnConnectionRoutesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewVpnConnectionTunnel1LogOptionsCloudwatchLogOptionsOutputReference_Override ¶
func NewVpnConnectionTunnel1LogOptionsCloudwatchLogOptionsOutputReference_Override(v VpnConnectionTunnel1LogOptionsCloudwatchLogOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVpnConnectionTunnel1LogOptionsOutputReference_Override ¶
func NewVpnConnectionTunnel1LogOptionsOutputReference_Override(v VpnConnectionTunnel1LogOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVpnConnectionTunnel2LogOptionsCloudwatchLogOptionsOutputReference_Override ¶
func NewVpnConnectionTunnel2LogOptionsCloudwatchLogOptionsOutputReference_Override(v VpnConnectionTunnel2LogOptionsCloudwatchLogOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVpnConnectionTunnel2LogOptionsOutputReference_Override ¶
func NewVpnConnectionTunnel2LogOptionsOutputReference_Override(v VpnConnectionTunnel2LogOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewVpnConnectionVgwTelemetryList_Override ¶
func NewVpnConnectionVgwTelemetryList_Override(v VpnConnectionVgwTelemetryList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewVpnConnectionVgwTelemetryOutputReference_Override ¶
func NewVpnConnectionVgwTelemetryOutputReference_Override(v VpnConnectionVgwTelemetryOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewVpnConnection_Override ¶
func NewVpnConnection_Override(v VpnConnection, scope constructs.Construct, id *string, config *VpnConnectionConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection aws_vpn_connection} Resource.
func VpnConnection_IsConstruct ¶
func VpnConnection_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func VpnConnection_IsTerraformElement ¶
func VpnConnection_IsTerraformElement(x interface{}) *bool
Experimental.
func VpnConnection_IsTerraformResource ¶
func VpnConnection_IsTerraformResource(x interface{}) *bool
Experimental.
func VpnConnection_TfResourceType ¶
func VpnConnection_TfResourceType() *string
Types ¶
type VpnConnection ¶
type VpnConnection interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
CoreNetworkArn() *string
CoreNetworkAttachmentArn() *string
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CustomerGatewayConfiguration() *string
CustomerGatewayId() *string
SetCustomerGatewayId(val *string)
CustomerGatewayIdInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EnableAcceleration() interface{}
SetEnableAcceleration(val interface{})
EnableAccelerationInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LocalIpv4NetworkCidr() *string
SetLocalIpv4NetworkCidr(val *string)
LocalIpv4NetworkCidrInput() *string
LocalIpv6NetworkCidr() *string
SetLocalIpv6NetworkCidr(val *string)
LocalIpv6NetworkCidrInput() *string
// The tree node.
Node() constructs.Node
OutsideIpAddressType() *string
SetOutsideIpAddressType(val *string)
OutsideIpAddressTypeInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RemoteIpv4NetworkCidr() *string
SetRemoteIpv4NetworkCidr(val *string)
RemoteIpv4NetworkCidrInput() *string
RemoteIpv6NetworkCidr() *string
SetRemoteIpv6NetworkCidr(val *string)
RemoteIpv6NetworkCidrInput() *string
Routes() VpnConnectionRoutesList
StaticRoutesOnly() interface{}
SetStaticRoutesOnly(val interface{})
StaticRoutesOnlyInput() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
TransitGatewayAttachmentId() *string
TransitGatewayId() *string
SetTransitGatewayId(val *string)
TransitGatewayIdInput() *string
TransportTransitGatewayAttachmentId() *string
SetTransportTransitGatewayAttachmentId(val *string)
TransportTransitGatewayAttachmentIdInput() *string
Tunnel1Address() *string
Tunnel1BgpAsn() *string
Tunnel1BgpHoldtime() *float64
Tunnel1CgwInsideAddress() *string
Tunnel1DpdTimeoutAction() *string
SetTunnel1DpdTimeoutAction(val *string)
Tunnel1DpdTimeoutActionInput() *string
Tunnel1DpdTimeoutSeconds() *float64
SetTunnel1DpdTimeoutSeconds(val *float64)
Tunnel1DpdTimeoutSecondsInput() *float64
Tunnel1EnableTunnelLifecycleControl() interface{}
SetTunnel1EnableTunnelLifecycleControl(val interface{})
Tunnel1EnableTunnelLifecycleControlInput() interface{}
Tunnel1IkeVersions() *[]*string
SetTunnel1IkeVersions(val *[]*string)
Tunnel1IkeVersionsInput() *[]*string
Tunnel1InsideCidr() *string
SetTunnel1InsideCidr(val *string)
Tunnel1InsideCidrInput() *string
Tunnel1InsideIpv6Cidr() *string
SetTunnel1InsideIpv6Cidr(val *string)
Tunnel1InsideIpv6CidrInput() *string
Tunnel1LogOptions() VpnConnectionTunnel1LogOptionsOutputReference
Tunnel1LogOptionsInput() *VpnConnectionTunnel1LogOptions
Tunnel1Phase1DhGroupNumbers() *[]*float64
SetTunnel1Phase1DhGroupNumbers(val *[]*float64)
Tunnel1Phase1DhGroupNumbersInput() *[]*float64
Tunnel1Phase1EncryptionAlgorithms() *[]*string
SetTunnel1Phase1EncryptionAlgorithms(val *[]*string)
Tunnel1Phase1EncryptionAlgorithmsInput() *[]*string
Tunnel1Phase1IntegrityAlgorithms() *[]*string
SetTunnel1Phase1IntegrityAlgorithms(val *[]*string)
Tunnel1Phase1IntegrityAlgorithmsInput() *[]*string
Tunnel1Phase1LifetimeSeconds() *float64
SetTunnel1Phase1LifetimeSeconds(val *float64)
Tunnel1Phase1LifetimeSecondsInput() *float64
Tunnel1Phase2DhGroupNumbers() *[]*float64
SetTunnel1Phase2DhGroupNumbers(val *[]*float64)
Tunnel1Phase2DhGroupNumbersInput() *[]*float64
Tunnel1Phase2EncryptionAlgorithms() *[]*string
SetTunnel1Phase2EncryptionAlgorithms(val *[]*string)
Tunnel1Phase2EncryptionAlgorithmsInput() *[]*string
Tunnel1Phase2IntegrityAlgorithms() *[]*string
SetTunnel1Phase2IntegrityAlgorithms(val *[]*string)
Tunnel1Phase2IntegrityAlgorithmsInput() *[]*string
Tunnel1Phase2LifetimeSeconds() *float64
SetTunnel1Phase2LifetimeSeconds(val *float64)
Tunnel1Phase2LifetimeSecondsInput() *float64
Tunnel1RekeyFuzzPercentage() *float64
SetTunnel1RekeyFuzzPercentage(val *float64)
Tunnel1RekeyFuzzPercentageInput() *float64
Tunnel1RekeyMarginTimeSeconds() *float64
SetTunnel1RekeyMarginTimeSeconds(val *float64)
Tunnel1RekeyMarginTimeSecondsInput() *float64
Tunnel1ReplayWindowSize() *float64
SetTunnel1ReplayWindowSize(val *float64)
Tunnel1ReplayWindowSizeInput() *float64
Tunnel1StartupAction() *string
SetTunnel1StartupAction(val *string)
Tunnel1StartupActionInput() *string
Tunnel1VgwInsideAddress() *string
Tunnel2Address() *string
Tunnel2BgpAsn() *string
Tunnel2BgpHoldtime() *float64
Tunnel2CgwInsideAddress() *string
Tunnel2DpdTimeoutAction() *string
SetTunnel2DpdTimeoutAction(val *string)
Tunnel2DpdTimeoutActionInput() *string
Tunnel2DpdTimeoutSeconds() *float64
SetTunnel2DpdTimeoutSeconds(val *float64)
Tunnel2DpdTimeoutSecondsInput() *float64
Tunnel2EnableTunnelLifecycleControl() interface{}
SetTunnel2EnableTunnelLifecycleControl(val interface{})
Tunnel2EnableTunnelLifecycleControlInput() interface{}
Tunnel2IkeVersions() *[]*string
SetTunnel2IkeVersions(val *[]*string)
Tunnel2IkeVersionsInput() *[]*string
Tunnel2InsideCidr() *string
SetTunnel2InsideCidr(val *string)
Tunnel2InsideCidrInput() *string
Tunnel2InsideIpv6Cidr() *string
SetTunnel2InsideIpv6Cidr(val *string)
Tunnel2InsideIpv6CidrInput() *string
Tunnel2LogOptions() VpnConnectionTunnel2LogOptionsOutputReference
Tunnel2LogOptionsInput() *VpnConnectionTunnel2LogOptions
Tunnel2Phase1DhGroupNumbers() *[]*float64
SetTunnel2Phase1DhGroupNumbers(val *[]*float64)
Tunnel2Phase1DhGroupNumbersInput() *[]*float64
Tunnel2Phase1EncryptionAlgorithms() *[]*string
SetTunnel2Phase1EncryptionAlgorithms(val *[]*string)
Tunnel2Phase1EncryptionAlgorithmsInput() *[]*string
Tunnel2Phase1IntegrityAlgorithms() *[]*string
SetTunnel2Phase1IntegrityAlgorithms(val *[]*string)
Tunnel2Phase1IntegrityAlgorithmsInput() *[]*string
Tunnel2Phase1LifetimeSeconds() *float64
SetTunnel2Phase1LifetimeSeconds(val *float64)
Tunnel2Phase1LifetimeSecondsInput() *float64
Tunnel2Phase2DhGroupNumbers() *[]*float64
SetTunnel2Phase2DhGroupNumbers(val *[]*float64)
Tunnel2Phase2DhGroupNumbersInput() *[]*float64
Tunnel2Phase2EncryptionAlgorithms() *[]*string
SetTunnel2Phase2EncryptionAlgorithms(val *[]*string)
Tunnel2Phase2EncryptionAlgorithmsInput() *[]*string
Tunnel2Phase2IntegrityAlgorithms() *[]*string
SetTunnel2Phase2IntegrityAlgorithms(val *[]*string)
Tunnel2Phase2IntegrityAlgorithmsInput() *[]*string
Tunnel2Phase2LifetimeSeconds() *float64
SetTunnel2Phase2LifetimeSeconds(val *float64)
Tunnel2Phase2LifetimeSecondsInput() *float64
Tunnel2RekeyFuzzPercentage() *float64
SetTunnel2RekeyFuzzPercentage(val *float64)
Tunnel2RekeyFuzzPercentageInput() *float64
Tunnel2RekeyMarginTimeSeconds() *float64
SetTunnel2RekeyMarginTimeSeconds(val *float64)
Tunnel2RekeyMarginTimeSecondsInput() *float64
Tunnel2ReplayWindowSize() *float64
SetTunnel2ReplayWindowSize(val *float64)
Tunnel2ReplayWindowSizeInput() *float64
Tunnel2StartupAction() *string
SetTunnel2StartupAction(val *string)
Tunnel2StartupActionInput() *string
Tunnel2VgwInsideAddress() *string
TunnelInsideIpVersion() *string
SetTunnelInsideIpVersion(val *string)
TunnelInsideIpVersionInput() *string
Type() *string
SetType(val *string)
TypeInput() *string
VgwTelemetry() VpnConnectionVgwTelemetryList
VpnGatewayId() *string
SetVpnGatewayId(val *string)
VpnGatewayIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTunnel1LogOptions(value *VpnConnectionTunnel1LogOptions)
PutTunnel2LogOptions(value *VpnConnectionTunnel2LogOptions)
ResetEnableAcceleration()
ResetId()
ResetLocalIpv4NetworkCidr()
ResetLocalIpv6NetworkCidr()
ResetOutsideIpAddressType()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRemoteIpv4NetworkCidr()
ResetRemoteIpv6NetworkCidr()
ResetStaticRoutesOnly()
ResetTags()
ResetTagsAll()
ResetTransitGatewayId()
ResetTransportTransitGatewayAttachmentId()
ResetTunnel1DpdTimeoutAction()
ResetTunnel1DpdTimeoutSeconds()
ResetTunnel1EnableTunnelLifecycleControl()
ResetTunnel1IkeVersions()
ResetTunnel1InsideCidr()
ResetTunnel1InsideIpv6Cidr()
ResetTunnel1LogOptions()
ResetTunnel1Phase1DhGroupNumbers()
ResetTunnel1Phase1EncryptionAlgorithms()
ResetTunnel1Phase1IntegrityAlgorithms()
ResetTunnel1Phase1LifetimeSeconds()
ResetTunnel1Phase2DhGroupNumbers()
ResetTunnel1Phase2EncryptionAlgorithms()
ResetTunnel1Phase2IntegrityAlgorithms()
ResetTunnel1Phase2LifetimeSeconds()
ResetTunnel1RekeyFuzzPercentage()
ResetTunnel1RekeyMarginTimeSeconds()
ResetTunnel1ReplayWindowSize()
ResetTunnel1StartupAction()
ResetTunnel2DpdTimeoutAction()
ResetTunnel2DpdTimeoutSeconds()
ResetTunnel2EnableTunnelLifecycleControl()
ResetTunnel2IkeVersions()
ResetTunnel2InsideCidr()
ResetTunnel2InsideIpv6Cidr()
ResetTunnel2LogOptions()
ResetTunnel2Phase1DhGroupNumbers()
ResetTunnel2Phase1EncryptionAlgorithms()
ResetTunnel2Phase1IntegrityAlgorithms()
ResetTunnel2Phase1LifetimeSeconds()
ResetTunnel2Phase2DhGroupNumbers()
ResetTunnel2Phase2EncryptionAlgorithms()
ResetTunnel2Phase2IntegrityAlgorithms()
ResetTunnel2Phase2LifetimeSeconds()
ResetTunnel2RekeyFuzzPercentage()
ResetTunnel2RekeyMarginTimeSeconds()
ResetTunnel2ReplayWindowSize()
ResetTunnel2StartupAction()
ResetTunnelInsideIpVersion()
ResetVpnGatewayId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection aws_vpn_connection}.
func NewVpnConnection ¶
func NewVpnConnection(scope constructs.Construct, id *string, config *VpnConnectionConfig) VpnConnection
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection aws_vpn_connection} Resource.
type VpnConnectionConfig ¶
type VpnConnectionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#customer_gateway_id VpnConnection#customer_gateway_id}.
CustomerGatewayId *string `field:"required" json:"customerGatewayId" yaml:"customerGatewayId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#type VpnConnection#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#enable_acceleration VpnConnection#enable_acceleration}.
EnableAcceleration interface{} `field:"optional" json:"enableAcceleration" yaml:"enableAcceleration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#id VpnConnection#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#local_ipv4_network_cidr VpnConnection#local_ipv4_network_cidr}.
LocalIpv4NetworkCidr *string `field:"optional" json:"localIpv4NetworkCidr" yaml:"localIpv4NetworkCidr"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#local_ipv6_network_cidr VpnConnection#local_ipv6_network_cidr}.
LocalIpv6NetworkCidr *string `field:"optional" json:"localIpv6NetworkCidr" yaml:"localIpv6NetworkCidr"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#outside_ip_address_type VpnConnection#outside_ip_address_type}.
OutsideIpAddressType *string `field:"optional" json:"outsideIpAddressType" yaml:"outsideIpAddressType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#remote_ipv4_network_cidr VpnConnection#remote_ipv4_network_cidr}.
RemoteIpv4NetworkCidr *string `field:"optional" json:"remoteIpv4NetworkCidr" yaml:"remoteIpv4NetworkCidr"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#remote_ipv6_network_cidr VpnConnection#remote_ipv6_network_cidr}.
RemoteIpv6NetworkCidr *string `field:"optional" json:"remoteIpv6NetworkCidr" yaml:"remoteIpv6NetworkCidr"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#static_routes_only VpnConnection#static_routes_only}.
StaticRoutesOnly interface{} `field:"optional" json:"staticRoutesOnly" yaml:"staticRoutesOnly"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tags VpnConnection#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tags_all VpnConnection#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#transit_gateway_id VpnConnection#transit_gateway_id}.
TransitGatewayId *string `field:"optional" json:"transitGatewayId" yaml:"transitGatewayId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#transport_transit_gateway_attachment_id VpnConnection#transport_transit_gateway_attachment_id}.
TransportTransitGatewayAttachmentId *string `field:"optional" json:"transportTransitGatewayAttachmentId" yaml:"transportTransitGatewayAttachmentId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel1_dpd_timeout_action VpnConnection#tunnel1_dpd_timeout_action}.
Tunnel1DpdTimeoutAction *string `field:"optional" json:"tunnel1DpdTimeoutAction" yaml:"tunnel1DpdTimeoutAction"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel1_dpd_timeout_seconds VpnConnection#tunnel1_dpd_timeout_seconds}.
Tunnel1DpdTimeoutSeconds *float64 `field:"optional" json:"tunnel1DpdTimeoutSeconds" yaml:"tunnel1DpdTimeoutSeconds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel1_enable_tunnel_lifecycle_control VpnConnection#tunnel1_enable_tunnel_lifecycle_control}.
Tunnel1EnableTunnelLifecycleControl interface{} `field:"optional" json:"tunnel1EnableTunnelLifecycleControl" yaml:"tunnel1EnableTunnelLifecycleControl"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel1_ike_versions VpnConnection#tunnel1_ike_versions}.
Tunnel1IkeVersions *[]*string `field:"optional" json:"tunnel1IkeVersions" yaml:"tunnel1IkeVersions"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel1_inside_cidr VpnConnection#tunnel1_inside_cidr}.
Tunnel1InsideCidr *string `field:"optional" json:"tunnel1InsideCidr" yaml:"tunnel1InsideCidr"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel1_inside_ipv6_cidr VpnConnection#tunnel1_inside_ipv6_cidr}.
Tunnel1InsideIpv6Cidr *string `field:"optional" json:"tunnel1InsideIpv6Cidr" yaml:"tunnel1InsideIpv6Cidr"`
// tunnel1_log_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel1_log_options VpnConnection#tunnel1_log_options}
Tunnel1LogOptions *VpnConnectionTunnel1LogOptions `field:"optional" json:"tunnel1LogOptions" yaml:"tunnel1LogOptions"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel1_phase1_dh_group_numbers VpnConnection#tunnel1_phase1_dh_group_numbers}.
Tunnel1Phase1DhGroupNumbers *[]*float64 `field:"optional" json:"tunnel1Phase1DhGroupNumbers" yaml:"tunnel1Phase1DhGroupNumbers"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel1_phase1_encryption_algorithms VpnConnection#tunnel1_phase1_encryption_algorithms}.
Tunnel1Phase1EncryptionAlgorithms *[]*string `field:"optional" json:"tunnel1Phase1EncryptionAlgorithms" yaml:"tunnel1Phase1EncryptionAlgorithms"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel1_phase1_integrity_algorithms VpnConnection#tunnel1_phase1_integrity_algorithms}.
Tunnel1Phase1IntegrityAlgorithms *[]*string `field:"optional" json:"tunnel1Phase1IntegrityAlgorithms" yaml:"tunnel1Phase1IntegrityAlgorithms"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel1_phase1_lifetime_seconds VpnConnection#tunnel1_phase1_lifetime_seconds}.
Tunnel1Phase1LifetimeSeconds *float64 `field:"optional" json:"tunnel1Phase1LifetimeSeconds" yaml:"tunnel1Phase1LifetimeSeconds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel1_phase2_dh_group_numbers VpnConnection#tunnel1_phase2_dh_group_numbers}.
Tunnel1Phase2DhGroupNumbers *[]*float64 `field:"optional" json:"tunnel1Phase2DhGroupNumbers" yaml:"tunnel1Phase2DhGroupNumbers"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel1_phase2_encryption_algorithms VpnConnection#tunnel1_phase2_encryption_algorithms}.
Tunnel1Phase2EncryptionAlgorithms *[]*string `field:"optional" json:"tunnel1Phase2EncryptionAlgorithms" yaml:"tunnel1Phase2EncryptionAlgorithms"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel1_phase2_integrity_algorithms VpnConnection#tunnel1_phase2_integrity_algorithms}.
Tunnel1Phase2IntegrityAlgorithms *[]*string `field:"optional" json:"tunnel1Phase2IntegrityAlgorithms" yaml:"tunnel1Phase2IntegrityAlgorithms"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel1_phase2_lifetime_seconds VpnConnection#tunnel1_phase2_lifetime_seconds}.
Tunnel1Phase2LifetimeSeconds *float64 `field:"optional" json:"tunnel1Phase2LifetimeSeconds" yaml:"tunnel1Phase2LifetimeSeconds"`
Tunnel1PresharedKey *string `field:"optional" json:"tunnel1PresharedKey" yaml:"tunnel1PresharedKey"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel1_rekey_fuzz_percentage VpnConnection#tunnel1_rekey_fuzz_percentage}.
Tunnel1RekeyFuzzPercentage *float64 `field:"optional" json:"tunnel1RekeyFuzzPercentage" yaml:"tunnel1RekeyFuzzPercentage"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel1_rekey_margin_time_seconds VpnConnection#tunnel1_rekey_margin_time_seconds}.
Tunnel1RekeyMarginTimeSeconds *float64 `field:"optional" json:"tunnel1RekeyMarginTimeSeconds" yaml:"tunnel1RekeyMarginTimeSeconds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel1_replay_window_size VpnConnection#tunnel1_replay_window_size}.
Tunnel1ReplayWindowSize *float64 `field:"optional" json:"tunnel1ReplayWindowSize" yaml:"tunnel1ReplayWindowSize"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel1_startup_action VpnConnection#tunnel1_startup_action}.
Tunnel1StartupAction *string `field:"optional" json:"tunnel1StartupAction" yaml:"tunnel1StartupAction"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel2_dpd_timeout_action VpnConnection#tunnel2_dpd_timeout_action}.
Tunnel2DpdTimeoutAction *string `field:"optional" json:"tunnel2DpdTimeoutAction" yaml:"tunnel2DpdTimeoutAction"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel2_dpd_timeout_seconds VpnConnection#tunnel2_dpd_timeout_seconds}.
Tunnel2DpdTimeoutSeconds *float64 `field:"optional" json:"tunnel2DpdTimeoutSeconds" yaml:"tunnel2DpdTimeoutSeconds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel2_enable_tunnel_lifecycle_control VpnConnection#tunnel2_enable_tunnel_lifecycle_control}.
Tunnel2EnableTunnelLifecycleControl interface{} `field:"optional" json:"tunnel2EnableTunnelLifecycleControl" yaml:"tunnel2EnableTunnelLifecycleControl"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel2_ike_versions VpnConnection#tunnel2_ike_versions}.
Tunnel2IkeVersions *[]*string `field:"optional" json:"tunnel2IkeVersions" yaml:"tunnel2IkeVersions"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel2_inside_cidr VpnConnection#tunnel2_inside_cidr}.
Tunnel2InsideCidr *string `field:"optional" json:"tunnel2InsideCidr" yaml:"tunnel2InsideCidr"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel2_inside_ipv6_cidr VpnConnection#tunnel2_inside_ipv6_cidr}.
Tunnel2InsideIpv6Cidr *string `field:"optional" json:"tunnel2InsideIpv6Cidr" yaml:"tunnel2InsideIpv6Cidr"`
// tunnel2_log_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel2_log_options VpnConnection#tunnel2_log_options}
Tunnel2LogOptions *VpnConnectionTunnel2LogOptions `field:"optional" json:"tunnel2LogOptions" yaml:"tunnel2LogOptions"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel2_phase1_dh_group_numbers VpnConnection#tunnel2_phase1_dh_group_numbers}.
Tunnel2Phase1DhGroupNumbers *[]*float64 `field:"optional" json:"tunnel2Phase1DhGroupNumbers" yaml:"tunnel2Phase1DhGroupNumbers"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel2_phase1_encryption_algorithms VpnConnection#tunnel2_phase1_encryption_algorithms}.
Tunnel2Phase1EncryptionAlgorithms *[]*string `field:"optional" json:"tunnel2Phase1EncryptionAlgorithms" yaml:"tunnel2Phase1EncryptionAlgorithms"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel2_phase1_integrity_algorithms VpnConnection#tunnel2_phase1_integrity_algorithms}.
Tunnel2Phase1IntegrityAlgorithms *[]*string `field:"optional" json:"tunnel2Phase1IntegrityAlgorithms" yaml:"tunnel2Phase1IntegrityAlgorithms"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel2_phase1_lifetime_seconds VpnConnection#tunnel2_phase1_lifetime_seconds}.
Tunnel2Phase1LifetimeSeconds *float64 `field:"optional" json:"tunnel2Phase1LifetimeSeconds" yaml:"tunnel2Phase1LifetimeSeconds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel2_phase2_dh_group_numbers VpnConnection#tunnel2_phase2_dh_group_numbers}.
Tunnel2Phase2DhGroupNumbers *[]*float64 `field:"optional" json:"tunnel2Phase2DhGroupNumbers" yaml:"tunnel2Phase2DhGroupNumbers"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel2_phase2_encryption_algorithms VpnConnection#tunnel2_phase2_encryption_algorithms}.
Tunnel2Phase2EncryptionAlgorithms *[]*string `field:"optional" json:"tunnel2Phase2EncryptionAlgorithms" yaml:"tunnel2Phase2EncryptionAlgorithms"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel2_phase2_integrity_algorithms VpnConnection#tunnel2_phase2_integrity_algorithms}.
Tunnel2Phase2IntegrityAlgorithms *[]*string `field:"optional" json:"tunnel2Phase2IntegrityAlgorithms" yaml:"tunnel2Phase2IntegrityAlgorithms"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel2_phase2_lifetime_seconds VpnConnection#tunnel2_phase2_lifetime_seconds}.
Tunnel2Phase2LifetimeSeconds *float64 `field:"optional" json:"tunnel2Phase2LifetimeSeconds" yaml:"tunnel2Phase2LifetimeSeconds"`
Tunnel2PresharedKey *string `field:"optional" json:"tunnel2PresharedKey" yaml:"tunnel2PresharedKey"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel2_rekey_fuzz_percentage VpnConnection#tunnel2_rekey_fuzz_percentage}.
Tunnel2RekeyFuzzPercentage *float64 `field:"optional" json:"tunnel2RekeyFuzzPercentage" yaml:"tunnel2RekeyFuzzPercentage"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel2_rekey_margin_time_seconds VpnConnection#tunnel2_rekey_margin_time_seconds}.
Tunnel2RekeyMarginTimeSeconds *float64 `field:"optional" json:"tunnel2RekeyMarginTimeSeconds" yaml:"tunnel2RekeyMarginTimeSeconds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel2_replay_window_size VpnConnection#tunnel2_replay_window_size}.
Tunnel2ReplayWindowSize *float64 `field:"optional" json:"tunnel2ReplayWindowSize" yaml:"tunnel2ReplayWindowSize"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel2_startup_action VpnConnection#tunnel2_startup_action}.
Tunnel2StartupAction *string `field:"optional" json:"tunnel2StartupAction" yaml:"tunnel2StartupAction"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#tunnel_inside_ip_version VpnConnection#tunnel_inside_ip_version}.
TunnelInsideIpVersion *string `field:"optional" json:"tunnelInsideIpVersion" yaml:"tunnelInsideIpVersion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#vpn_gateway_id VpnConnection#vpn_gateway_id}.
VpnGatewayId *string `field:"optional" json:"vpnGatewayId" yaml:"vpnGatewayId"`
}
type VpnConnectionRoutes ¶
type VpnConnectionRoutes struct {
}
type VpnConnectionRoutesList ¶
type VpnConnectionRoutesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) VpnConnectionRoutesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpnConnectionRoutesList ¶
func NewVpnConnectionRoutesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) VpnConnectionRoutesList
type VpnConnectionRoutesOutputReference ¶
type VpnConnectionRoutesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DestinationCidrBlock() *string
// Experimental.
Fqn() *string
InternalValue() *VpnConnectionRoutes
SetInternalValue(val *VpnConnectionRoutes)
Source() *string
State() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpnConnectionRoutesOutputReference ¶
func NewVpnConnectionRoutesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) VpnConnectionRoutesOutputReference
type VpnConnectionTunnel1LogOptions ¶
type VpnConnectionTunnel1LogOptions struct {
// cloudwatch_log_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#cloudwatch_log_options VpnConnection#cloudwatch_log_options}
CloudwatchLogOptions *VpnConnectionTunnel1LogOptionsCloudwatchLogOptions `field:"optional" json:"cloudwatchLogOptions" yaml:"cloudwatchLogOptions"`
}
type VpnConnectionTunnel1LogOptionsCloudwatchLogOptions ¶
type VpnConnectionTunnel1LogOptionsCloudwatchLogOptions struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#log_enabled VpnConnection#log_enabled}.
LogEnabled interface{} `field:"optional" json:"logEnabled" yaml:"logEnabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#log_group_arn VpnConnection#log_group_arn}.
LogGroupArn *string `field:"optional" json:"logGroupArn" yaml:"logGroupArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#log_output_format VpnConnection#log_output_format}.
LogOutputFormat *string `field:"optional" json:"logOutputFormat" yaml:"logOutputFormat"`
}
type VpnConnectionTunnel1LogOptionsCloudwatchLogOptionsOutputReference ¶
type VpnConnectionTunnel1LogOptionsCloudwatchLogOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *VpnConnectionTunnel1LogOptionsCloudwatchLogOptions
SetInternalValue(val *VpnConnectionTunnel1LogOptionsCloudwatchLogOptions)
LogEnabled() interface{}
SetLogEnabled(val interface{})
LogEnabledInput() interface{}
LogGroupArn() *string
SetLogGroupArn(val *string)
LogGroupArnInput() *string
LogOutputFormat() *string
SetLogOutputFormat(val *string)
LogOutputFormatInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetLogEnabled()
ResetLogGroupArn()
ResetLogOutputFormat()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpnConnectionTunnel1LogOptionsCloudwatchLogOptionsOutputReference ¶
func NewVpnConnectionTunnel1LogOptionsCloudwatchLogOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VpnConnectionTunnel1LogOptionsCloudwatchLogOptionsOutputReference
type VpnConnectionTunnel1LogOptionsOutputReference ¶
type VpnConnectionTunnel1LogOptionsOutputReference interface {
cdktf.ComplexObject
CloudwatchLogOptions() VpnConnectionTunnel1LogOptionsCloudwatchLogOptionsOutputReference
CloudwatchLogOptionsInput() *VpnConnectionTunnel1LogOptionsCloudwatchLogOptions
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *VpnConnectionTunnel1LogOptions
SetInternalValue(val *VpnConnectionTunnel1LogOptions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutCloudwatchLogOptions(value *VpnConnectionTunnel1LogOptionsCloudwatchLogOptions)
ResetCloudwatchLogOptions()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpnConnectionTunnel1LogOptionsOutputReference ¶
func NewVpnConnectionTunnel1LogOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VpnConnectionTunnel1LogOptionsOutputReference
type VpnConnectionTunnel2LogOptions ¶
type VpnConnectionTunnel2LogOptions struct {
// cloudwatch_log_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#cloudwatch_log_options VpnConnection#cloudwatch_log_options}
CloudwatchLogOptions *VpnConnectionTunnel2LogOptionsCloudwatchLogOptions `field:"optional" json:"cloudwatchLogOptions" yaml:"cloudwatchLogOptions"`
}
type VpnConnectionTunnel2LogOptionsCloudwatchLogOptions ¶
type VpnConnectionTunnel2LogOptionsCloudwatchLogOptions struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#log_enabled VpnConnection#log_enabled}.
LogEnabled interface{} `field:"optional" json:"logEnabled" yaml:"logEnabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#log_group_arn VpnConnection#log_group_arn}.
LogGroupArn *string `field:"optional" json:"logGroupArn" yaml:"logGroupArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.66.1/docs/resources/vpn_connection#log_output_format VpnConnection#log_output_format}.
LogOutputFormat *string `field:"optional" json:"logOutputFormat" yaml:"logOutputFormat"`
}
type VpnConnectionTunnel2LogOptionsCloudwatchLogOptionsOutputReference ¶
type VpnConnectionTunnel2LogOptionsCloudwatchLogOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *VpnConnectionTunnel2LogOptionsCloudwatchLogOptions
SetInternalValue(val *VpnConnectionTunnel2LogOptionsCloudwatchLogOptions)
LogEnabled() interface{}
SetLogEnabled(val interface{})
LogEnabledInput() interface{}
LogGroupArn() *string
SetLogGroupArn(val *string)
LogGroupArnInput() *string
LogOutputFormat() *string
SetLogOutputFormat(val *string)
LogOutputFormatInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetLogEnabled()
ResetLogGroupArn()
ResetLogOutputFormat()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpnConnectionTunnel2LogOptionsCloudwatchLogOptionsOutputReference ¶
func NewVpnConnectionTunnel2LogOptionsCloudwatchLogOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VpnConnectionTunnel2LogOptionsCloudwatchLogOptionsOutputReference
type VpnConnectionTunnel2LogOptionsOutputReference ¶
type VpnConnectionTunnel2LogOptionsOutputReference interface {
cdktf.ComplexObject
CloudwatchLogOptions() VpnConnectionTunnel2LogOptionsCloudwatchLogOptionsOutputReference
CloudwatchLogOptionsInput() *VpnConnectionTunnel2LogOptionsCloudwatchLogOptions
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *VpnConnectionTunnel2LogOptions
SetInternalValue(val *VpnConnectionTunnel2LogOptions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutCloudwatchLogOptions(value *VpnConnectionTunnel2LogOptionsCloudwatchLogOptions)
ResetCloudwatchLogOptions()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpnConnectionTunnel2LogOptionsOutputReference ¶
func NewVpnConnectionTunnel2LogOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) VpnConnectionTunnel2LogOptionsOutputReference
type VpnConnectionVgwTelemetry ¶
type VpnConnectionVgwTelemetry struct {
}
type VpnConnectionVgwTelemetryList ¶
type VpnConnectionVgwTelemetryList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) VpnConnectionVgwTelemetryOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpnConnectionVgwTelemetryList ¶
func NewVpnConnectionVgwTelemetryList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) VpnConnectionVgwTelemetryList
type VpnConnectionVgwTelemetryOutputReference ¶
type VpnConnectionVgwTelemetryOutputReference interface {
cdktf.ComplexObject
AcceptedRouteCount() *float64
CertificateArn() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *VpnConnectionVgwTelemetry
SetInternalValue(val *VpnConnectionVgwTelemetry)
LastStatusChange() *string
OutsideIpAddress() *string
Status() *string
StatusMessage() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewVpnConnectionVgwTelemetryOutputReference ¶
func NewVpnConnectionVgwTelemetryOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) VpnConnectionVgwTelemetryOutputReference
Source Files
¶
- VpnConnection.go
- VpnConnectionConfig.go
- VpnConnectionRoutes.go
- VpnConnectionRoutesList.go
- VpnConnectionRoutesList__checks.go
- VpnConnectionRoutesOutputReference.go
- VpnConnectionRoutesOutputReference__checks.go
- VpnConnectionTunnel1LogOptions.go
- VpnConnectionTunnel1LogOptionsCloudwatchLogOptions.go
- VpnConnectionTunnel1LogOptionsCloudwatchLogOptionsOutputReference.go
- VpnConnectionTunnel1LogOptionsCloudwatchLogOptionsOutputReference__checks.go
- VpnConnectionTunnel1LogOptionsOutputReference.go
- VpnConnectionTunnel1LogOptionsOutputReference__checks.go
- VpnConnectionTunnel2LogOptions.go
- VpnConnectionTunnel2LogOptionsCloudwatchLogOptions.go
- VpnConnectionTunnel2LogOptionsCloudwatchLogOptionsOutputReference.go
- VpnConnectionTunnel2LogOptionsCloudwatchLogOptionsOutputReference__checks.go
- VpnConnectionTunnel2LogOptionsOutputReference.go
- VpnConnectionTunnel2LogOptionsOutputReference__checks.go
- VpnConnectionVgwTelemetry.go
- VpnConnectionVgwTelemetryList.go
- VpnConnectionVgwTelemetryList__checks.go
- VpnConnectionVgwTelemetryOutputReference.go
- VpnConnectionVgwTelemetryOutputReference__checks.go
- VpnConnection__checks.go
- main.go