Documentation
¶
Index ¶
- func AccountPrimaryContact_IsConstruct(x interface{}) *bool
- func AccountPrimaryContact_IsTerraformElement(x interface{}) *bool
- func AccountPrimaryContact_IsTerraformResource(x interface{}) *bool
- func AccountPrimaryContact_TfResourceType() *string
- func NewAccountPrimaryContact_Override(a AccountPrimaryContact, scope constructs.Construct, id *string, ...)
- type AccountPrimaryContact
- type AccountPrimaryContactConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AccountPrimaryContact_IsConstruct ¶
func AccountPrimaryContact_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AccountPrimaryContact_IsTerraformElement ¶
func AccountPrimaryContact_IsTerraformElement(x interface{}) *bool
Experimental.
func AccountPrimaryContact_IsTerraformResource ¶
func AccountPrimaryContact_IsTerraformResource(x interface{}) *bool
Experimental.
func AccountPrimaryContact_TfResourceType ¶
func AccountPrimaryContact_TfResourceType() *string
func NewAccountPrimaryContact_Override ¶
func NewAccountPrimaryContact_Override(a AccountPrimaryContact, scope constructs.Construct, id *string, config *AccountPrimaryContactConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/account_primary_contact aws_account_primary_contact} Resource.
Types ¶
type AccountPrimaryContact ¶
type AccountPrimaryContact interface {
cdktf.TerraformResource
AccountId() *string
SetAccountId(val *string)
AccountIdInput() *string
AddressLine1() *string
SetAddressLine1(val *string)
AddressLine1Input() *string
AddressLine2() *string
SetAddressLine2(val *string)
AddressLine2Input() *string
AddressLine3() *string
SetAddressLine3(val *string)
AddressLine3Input() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
City() *string
SetCity(val *string)
CityInput() *string
CompanyName() *string
SetCompanyName(val *string)
CompanyNameInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CountryCode() *string
SetCountryCode(val *string)
CountryCodeInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DistrictOrCounty() *string
SetDistrictOrCounty(val *string)
DistrictOrCountyInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
FullName() *string
SetFullName(val *string)
FullNameInput() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
PhoneNumber() *string
SetPhoneNumber(val *string)
PhoneNumberInput() *string
PostalCode() *string
SetPostalCode(val *string)
PostalCodeInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
StateOrRegion() *string
SetStateOrRegion(val *string)
StateOrRegionInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
WebsiteUrl() *string
SetWebsiteUrl(val *string)
WebsiteUrlInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetAccountId()
ResetAddressLine2()
ResetAddressLine3()
ResetCompanyName()
ResetDistrictOrCounty()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetStateOrRegion()
ResetWebsiteUrl()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/account_primary_contact aws_account_primary_contact}.
func NewAccountPrimaryContact ¶
func NewAccountPrimaryContact(scope constructs.Construct, id *string, config *AccountPrimaryContactConfig) AccountPrimaryContact
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/account_primary_contact aws_account_primary_contact} Resource.
type AccountPrimaryContactConfig ¶
type AccountPrimaryContactConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/account_primary_contact#address_line_1 AccountPrimaryContact#address_line_1}.
AddressLine1 *string `field:"required" json:"addressLine1" yaml:"addressLine1"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/account_primary_contact#city AccountPrimaryContact#city}.
City *string `field:"required" json:"city" yaml:"city"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/account_primary_contact#country_code AccountPrimaryContact#country_code}.
CountryCode *string `field:"required" json:"countryCode" yaml:"countryCode"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/account_primary_contact#full_name AccountPrimaryContact#full_name}.
FullName *string `field:"required" json:"fullName" yaml:"fullName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/account_primary_contact#phone_number AccountPrimaryContact#phone_number}.
PhoneNumber *string `field:"required" json:"phoneNumber" yaml:"phoneNumber"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/account_primary_contact#postal_code AccountPrimaryContact#postal_code}.
PostalCode *string `field:"required" json:"postalCode" yaml:"postalCode"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/account_primary_contact#account_id AccountPrimaryContact#account_id}.
AccountId *string `field:"optional" json:"accountId" yaml:"accountId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/account_primary_contact#address_line_2 AccountPrimaryContact#address_line_2}.
AddressLine2 *string `field:"optional" json:"addressLine2" yaml:"addressLine2"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/account_primary_contact#address_line_3 AccountPrimaryContact#address_line_3}.
AddressLine3 *string `field:"optional" json:"addressLine3" yaml:"addressLine3"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/account_primary_contact#company_name AccountPrimaryContact#company_name}.
CompanyName *string `field:"optional" json:"companyName" yaml:"companyName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/account_primary_contact#district_or_county AccountPrimaryContact#district_or_county}.
DistrictOrCounty *string `field:"optional" json:"districtOrCounty" yaml:"districtOrCounty"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/account_primary_contact#id AccountPrimaryContact#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/account_primary_contact#state_or_region AccountPrimaryContact#state_or_region}.
StateOrRegion *string `field:"optional" json:"stateOrRegion" yaml:"stateOrRegion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/account_primary_contact#website_url AccountPrimaryContact#website_url}.
WebsiteUrl *string `field:"optional" json:"websiteUrl" yaml:"websiteUrl"`
}