Documentation
¶
Index ¶
- func AcmCertificate_IsConstruct(x interface{}) *bool
- func AcmCertificate_IsTerraformElement(x interface{}) *bool
- func AcmCertificate_IsTerraformResource(x interface{}) *bool
- func AcmCertificate_TfResourceType() *string
- func NewAcmCertificateDomainValidationOptionsList_Override(a AcmCertificateDomainValidationOptionsList, ...)
- func NewAcmCertificateDomainValidationOptionsOutputReference_Override(a AcmCertificateDomainValidationOptionsOutputReference, ...)
- func NewAcmCertificateOptionsOutputReference_Override(a AcmCertificateOptionsOutputReference, ...)
- func NewAcmCertificateRenewalSummaryList_Override(a AcmCertificateRenewalSummaryList, ...)
- func NewAcmCertificateRenewalSummaryOutputReference_Override(a AcmCertificateRenewalSummaryOutputReference, ...)
- func NewAcmCertificateValidationOptionList_Override(a AcmCertificateValidationOptionList, ...)
- func NewAcmCertificateValidationOptionOutputReference_Override(a AcmCertificateValidationOptionOutputReference, ...)
- func NewAcmCertificate_Override(a AcmCertificate, scope constructs.Construct, id *string, ...)
- type AcmCertificate
- type AcmCertificateConfig
- type AcmCertificateDomainValidationOptions
- type AcmCertificateDomainValidationOptionsList
- type AcmCertificateDomainValidationOptionsOutputReference
- type AcmCertificateOptions
- type AcmCertificateOptionsOutputReference
- type AcmCertificateRenewalSummary
- type AcmCertificateRenewalSummaryList
- type AcmCertificateRenewalSummaryOutputReference
- type AcmCertificateValidationOption
- type AcmCertificateValidationOptionList
- type AcmCertificateValidationOptionOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AcmCertificate_IsConstruct ¶
func AcmCertificate_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AcmCertificate_IsTerraformElement ¶
func AcmCertificate_IsTerraformElement(x interface{}) *bool
Experimental.
func AcmCertificate_IsTerraformResource ¶
func AcmCertificate_IsTerraformResource(x interface{}) *bool
Experimental.
func AcmCertificate_TfResourceType ¶
func AcmCertificate_TfResourceType() *string
func NewAcmCertificateDomainValidationOptionsList_Override ¶
func NewAcmCertificateDomainValidationOptionsList_Override(a AcmCertificateDomainValidationOptionsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAcmCertificateDomainValidationOptionsOutputReference_Override ¶
func NewAcmCertificateDomainValidationOptionsOutputReference_Override(a AcmCertificateDomainValidationOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAcmCertificateOptionsOutputReference_Override ¶
func NewAcmCertificateOptionsOutputReference_Override(a AcmCertificateOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAcmCertificateRenewalSummaryList_Override ¶
func NewAcmCertificateRenewalSummaryList_Override(a AcmCertificateRenewalSummaryList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAcmCertificateRenewalSummaryOutputReference_Override ¶
func NewAcmCertificateRenewalSummaryOutputReference_Override(a AcmCertificateRenewalSummaryOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAcmCertificateValidationOptionList_Override ¶
func NewAcmCertificateValidationOptionList_Override(a AcmCertificateValidationOptionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAcmCertificateValidationOptionOutputReference_Override ¶
func NewAcmCertificateValidationOptionOutputReference_Override(a AcmCertificateValidationOptionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAcmCertificate_Override ¶
func NewAcmCertificate_Override(a AcmCertificate, scope constructs.Construct, id *string, config *AcmCertificateConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate aws_acm_certificate} Resource.
Types ¶
type AcmCertificate ¶
type AcmCertificate interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CertificateAuthorityArn() *string
SetCertificateAuthorityArn(val *string)
CertificateAuthorityArnInput() *string
CertificateBody() *string
SetCertificateBody(val *string)
CertificateBodyInput() *string
CertificateChain() *string
SetCertificateChain(val *string)
CertificateChainInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DomainName() *string
SetDomainName(val *string)
DomainNameInput() *string
DomainValidationOptions() AcmCertificateDomainValidationOptionsList
EarlyRenewalDuration() *string
SetEarlyRenewalDuration(val *string)
EarlyRenewalDurationInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
KeyAlgorithm() *string
SetKeyAlgorithm(val *string)
KeyAlgorithmInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
NotAfter() *string
NotBefore() *string
Options() AcmCertificateOptionsOutputReference
OptionsInput() *AcmCertificateOptions
PendingRenewal() cdktf.IResolvable
PrivateKey() *string
SetPrivateKey(val *string)
PrivateKeyInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RenewalEligibility() *string
RenewalSummary() AcmCertificateRenewalSummaryList
Status() *string
SubjectAlternativeNames() *[]*string
SetSubjectAlternativeNames(val *[]*string)
SubjectAlternativeNamesInput() *[]*string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Type() *string
ValidationEmails() *[]*string
ValidationMethod() *string
SetValidationMethod(val *string)
ValidationMethodInput() *string
ValidationOption() AcmCertificateValidationOptionList
ValidationOptionInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutOptions(value *AcmCertificateOptions)
PutValidationOption(value interface{})
ResetCertificateAuthorityArn()
ResetCertificateBody()
ResetCertificateChain()
ResetDomainName()
ResetEarlyRenewalDuration()
ResetId()
ResetKeyAlgorithm()
ResetOptions()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPrivateKey()
ResetSubjectAlternativeNames()
ResetTags()
ResetTagsAll()
ResetValidationMethod()
ResetValidationOption()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate aws_acm_certificate}.
func NewAcmCertificate ¶
func NewAcmCertificate(scope constructs.Construct, id *string, config *AcmCertificateConfig) AcmCertificate
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate aws_acm_certificate} Resource.
type AcmCertificateConfig ¶
type AcmCertificateConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate#certificate_authority_arn AcmCertificate#certificate_authority_arn}.
CertificateAuthorityArn *string `field:"optional" json:"certificateAuthorityArn" yaml:"certificateAuthorityArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate#certificate_body AcmCertificate#certificate_body}.
CertificateBody *string `field:"optional" json:"certificateBody" yaml:"certificateBody"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate#certificate_chain AcmCertificate#certificate_chain}.
CertificateChain *string `field:"optional" json:"certificateChain" yaml:"certificateChain"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate#domain_name AcmCertificate#domain_name}.
DomainName *string `field:"optional" json:"domainName" yaml:"domainName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate#early_renewal_duration AcmCertificate#early_renewal_duration}.
EarlyRenewalDuration *string `field:"optional" json:"earlyRenewalDuration" yaml:"earlyRenewalDuration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate#id AcmCertificate#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate#key_algorithm AcmCertificate#key_algorithm}.
KeyAlgorithm *string `field:"optional" json:"keyAlgorithm" yaml:"keyAlgorithm"`
// options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate#options AcmCertificate#options}
Options *AcmCertificateOptions `field:"optional" json:"options" yaml:"options"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate#private_key AcmCertificate#private_key}.
PrivateKey *string `field:"optional" json:"privateKey" yaml:"privateKey"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate#subject_alternative_names AcmCertificate#subject_alternative_names}.
SubjectAlternativeNames *[]*string `field:"optional" json:"subjectAlternativeNames" yaml:"subjectAlternativeNames"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate#tags AcmCertificate#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate#tags_all AcmCertificate#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate#validation_method AcmCertificate#validation_method}.
ValidationMethod *string `field:"optional" json:"validationMethod" yaml:"validationMethod"`
// validation_option block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate#validation_option AcmCertificate#validation_option}
ValidationOption interface{} `field:"optional" json:"validationOption" yaml:"validationOption"`
}
type AcmCertificateDomainValidationOptions ¶
type AcmCertificateDomainValidationOptions struct {
}
type AcmCertificateDomainValidationOptionsList ¶
type AcmCertificateDomainValidationOptionsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) AcmCertificateDomainValidationOptionsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAcmCertificateDomainValidationOptionsList ¶
func NewAcmCertificateDomainValidationOptionsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AcmCertificateDomainValidationOptionsList
type AcmCertificateDomainValidationOptionsOutputReference ¶
type AcmCertificateDomainValidationOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DomainName() *string
// Experimental.
Fqn() *string
InternalValue() *AcmCertificateDomainValidationOptions
SetInternalValue(val *AcmCertificateDomainValidationOptions)
ResourceRecordName() *string
ResourceRecordType() *string
ResourceRecordValue() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAcmCertificateDomainValidationOptionsOutputReference ¶
func NewAcmCertificateDomainValidationOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AcmCertificateDomainValidationOptionsOutputReference
type AcmCertificateOptions ¶
type AcmCertificateOptions struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate#certificate_transparency_logging_preference AcmCertificate#certificate_transparency_logging_preference}.
CertificateTransparencyLoggingPreference *string `field:"optional" json:"certificateTransparencyLoggingPreference" yaml:"certificateTransparencyLoggingPreference"`
}
type AcmCertificateOptionsOutputReference ¶
type AcmCertificateOptionsOutputReference interface {
cdktf.ComplexObject
CertificateTransparencyLoggingPreference() *string
SetCertificateTransparencyLoggingPreference(val *string)
CertificateTransparencyLoggingPreferenceInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AcmCertificateOptions
SetInternalValue(val *AcmCertificateOptions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCertificateTransparencyLoggingPreference()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAcmCertificateOptionsOutputReference ¶
func NewAcmCertificateOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AcmCertificateOptionsOutputReference
type AcmCertificateRenewalSummary ¶
type AcmCertificateRenewalSummary struct {
}
type AcmCertificateRenewalSummaryList ¶
type AcmCertificateRenewalSummaryList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) AcmCertificateRenewalSummaryOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAcmCertificateRenewalSummaryList ¶
func NewAcmCertificateRenewalSummaryList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AcmCertificateRenewalSummaryList
type AcmCertificateRenewalSummaryOutputReference ¶
type AcmCertificateRenewalSummaryOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AcmCertificateRenewalSummary
SetInternalValue(val *AcmCertificateRenewalSummary)
RenewalStatus() *string
RenewalStatusReason() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UpdatedAt() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAcmCertificateRenewalSummaryOutputReference ¶
func NewAcmCertificateRenewalSummaryOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AcmCertificateRenewalSummaryOutputReference
type AcmCertificateValidationOption ¶
type AcmCertificateValidationOption struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate#domain_name AcmCertificate#domain_name}.
DomainName *string `field:"required" json:"domainName" yaml:"domainName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/acm_certificate#validation_domain AcmCertificate#validation_domain}.
ValidationDomain *string `field:"required" json:"validationDomain" yaml:"validationDomain"`
}
type AcmCertificateValidationOptionList ¶
type AcmCertificateValidationOptionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) AcmCertificateValidationOptionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAcmCertificateValidationOptionList ¶
func NewAcmCertificateValidationOptionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AcmCertificateValidationOptionList
type AcmCertificateValidationOptionOutputReference ¶
type AcmCertificateValidationOptionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DomainName() *string
SetDomainName(val *string)
DomainNameInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ValidationDomain() *string
SetValidationDomain(val *string)
ValidationDomainInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAcmCertificateValidationOptionOutputReference ¶
func NewAcmCertificateValidationOptionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AcmCertificateValidationOptionOutputReference
Source Files
¶
- AcmCertificate.go
- AcmCertificateConfig.go
- AcmCertificateDomainValidationOptions.go
- AcmCertificateDomainValidationOptionsList.go
- AcmCertificateDomainValidationOptionsList__checks.go
- AcmCertificateDomainValidationOptionsOutputReference.go
- AcmCertificateDomainValidationOptionsOutputReference__checks.go
- AcmCertificateOptions.go
- AcmCertificateOptionsOutputReference.go
- AcmCertificateOptionsOutputReference__checks.go
- AcmCertificateRenewalSummary.go
- AcmCertificateRenewalSummaryList.go
- AcmCertificateRenewalSummaryList__checks.go
- AcmCertificateRenewalSummaryOutputReference.go
- AcmCertificateRenewalSummaryOutputReference__checks.go
- AcmCertificateValidationOption.go
- AcmCertificateValidationOptionList.go
- AcmCertificateValidationOptionList__checks.go
- AcmCertificateValidationOptionOutputReference.go
- AcmCertificateValidationOptionOutputReference__checks.go
- AcmCertificate__checks.go
- main.go