Documentation
¶
Index ¶
- func AlbListener_IsConstruct(x interface{}) *bool
- func AlbListener_IsTerraformElement(x interface{}) *bool
- func AlbListener_IsTerraformResource(x interface{}) *bool
- func AlbListener_TfResourceType() *string
- func NewAlbListenerDefaultActionAuthenticateCognitoOutputReference_Override(a AlbListenerDefaultActionAuthenticateCognitoOutputReference, ...)
- func NewAlbListenerDefaultActionAuthenticateOidcOutputReference_Override(a AlbListenerDefaultActionAuthenticateOidcOutputReference, ...)
- func NewAlbListenerDefaultActionFixedResponseOutputReference_Override(a AlbListenerDefaultActionFixedResponseOutputReference, ...)
- func NewAlbListenerDefaultActionForwardOutputReference_Override(a AlbListenerDefaultActionForwardOutputReference, ...)
- func NewAlbListenerDefaultActionForwardStickinessOutputReference_Override(a AlbListenerDefaultActionForwardStickinessOutputReference, ...)
- func NewAlbListenerDefaultActionForwardTargetGroupList_Override(a AlbListenerDefaultActionForwardTargetGroupList, ...)
- func NewAlbListenerDefaultActionForwardTargetGroupOutputReference_Override(a AlbListenerDefaultActionForwardTargetGroupOutputReference, ...)
- func NewAlbListenerDefaultActionList_Override(a AlbListenerDefaultActionList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewAlbListenerDefaultActionOutputReference_Override(a AlbListenerDefaultActionOutputReference, ...)
- func NewAlbListenerDefaultActionRedirectOutputReference_Override(a AlbListenerDefaultActionRedirectOutputReference, ...)
- func NewAlbListenerTimeoutsOutputReference_Override(a AlbListenerTimeoutsOutputReference, ...)
- func NewAlbListener_Override(a AlbListener, scope constructs.Construct, id *string, ...)
- type AlbListener
- type AlbListenerConfig
- type AlbListenerDefaultAction
- type AlbListenerDefaultActionAuthenticateCognito
- type AlbListenerDefaultActionAuthenticateCognitoOutputReference
- type AlbListenerDefaultActionAuthenticateOidc
- type AlbListenerDefaultActionAuthenticateOidcOutputReference
- type AlbListenerDefaultActionFixedResponse
- type AlbListenerDefaultActionFixedResponseOutputReference
- type AlbListenerDefaultActionForward
- type AlbListenerDefaultActionForwardOutputReference
- type AlbListenerDefaultActionForwardStickiness
- type AlbListenerDefaultActionForwardStickinessOutputReference
- type AlbListenerDefaultActionForwardTargetGroup
- type AlbListenerDefaultActionForwardTargetGroupList
- type AlbListenerDefaultActionForwardTargetGroupOutputReference
- type AlbListenerDefaultActionList
- type AlbListenerDefaultActionOutputReference
- type AlbListenerDefaultActionRedirect
- type AlbListenerDefaultActionRedirectOutputReference
- type AlbListenerTimeouts
- type AlbListenerTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AlbListener_IsConstruct ¶
func AlbListener_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AlbListener_IsTerraformElement ¶
func AlbListener_IsTerraformElement(x interface{}) *bool
Experimental.
func AlbListener_IsTerraformResource ¶
func AlbListener_IsTerraformResource(x interface{}) *bool
Experimental.
func AlbListener_TfResourceType ¶
func AlbListener_TfResourceType() *string
func NewAlbListenerDefaultActionAuthenticateCognitoOutputReference_Override ¶
func NewAlbListenerDefaultActionAuthenticateCognitoOutputReference_Override(a AlbListenerDefaultActionAuthenticateCognitoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAlbListenerDefaultActionAuthenticateOidcOutputReference_Override ¶
func NewAlbListenerDefaultActionAuthenticateOidcOutputReference_Override(a AlbListenerDefaultActionAuthenticateOidcOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAlbListenerDefaultActionFixedResponseOutputReference_Override ¶
func NewAlbListenerDefaultActionFixedResponseOutputReference_Override(a AlbListenerDefaultActionFixedResponseOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAlbListenerDefaultActionForwardOutputReference_Override ¶
func NewAlbListenerDefaultActionForwardOutputReference_Override(a AlbListenerDefaultActionForwardOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAlbListenerDefaultActionForwardStickinessOutputReference_Override ¶
func NewAlbListenerDefaultActionForwardStickinessOutputReference_Override(a AlbListenerDefaultActionForwardStickinessOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAlbListenerDefaultActionForwardTargetGroupList_Override ¶
func NewAlbListenerDefaultActionForwardTargetGroupList_Override(a AlbListenerDefaultActionForwardTargetGroupList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAlbListenerDefaultActionForwardTargetGroupOutputReference_Override ¶
func NewAlbListenerDefaultActionForwardTargetGroupOutputReference_Override(a AlbListenerDefaultActionForwardTargetGroupOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAlbListenerDefaultActionList_Override ¶
func NewAlbListenerDefaultActionList_Override(a AlbListenerDefaultActionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAlbListenerDefaultActionOutputReference_Override ¶
func NewAlbListenerDefaultActionOutputReference_Override(a AlbListenerDefaultActionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAlbListenerDefaultActionRedirectOutputReference_Override ¶
func NewAlbListenerDefaultActionRedirectOutputReference_Override(a AlbListenerDefaultActionRedirectOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAlbListenerTimeoutsOutputReference_Override ¶
func NewAlbListenerTimeoutsOutputReference_Override(a AlbListenerTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAlbListener_Override ¶
func NewAlbListener_Override(a AlbListener, scope constructs.Construct, id *string, config *AlbListenerConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener aws_alb_listener} Resource.
Types ¶
type AlbListener ¶
type AlbListener interface {
cdktf.TerraformResource
AlpnPolicy() *string
SetAlpnPolicy(val *string)
AlpnPolicyInput() *string
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CertificateArn() *string
SetCertificateArn(val *string)
CertificateArnInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DefaultAction() AlbListenerDefaultActionList
DefaultActionInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LoadBalancerArn() *string
SetLoadBalancerArn(val *string)
LoadBalancerArnInput() *string
// The tree node.
Node() constructs.Node
Port() *float64
SetPort(val *float64)
PortInput() *float64
Protocol() *string
SetProtocol(val *string)
ProtocolInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SslPolicy() *string
SetSslPolicy(val *string)
SslPolicyInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() AlbListenerTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDefaultAction(value interface{})
PutTimeouts(value *AlbListenerTimeouts)
ResetAlpnPolicy()
ResetCertificateArn()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPort()
ResetProtocol()
ResetSslPolicy()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener aws_alb_listener}.
func NewAlbListener ¶
func NewAlbListener(scope constructs.Construct, id *string, config *AlbListenerConfig) AlbListener
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener aws_alb_listener} Resource.
type AlbListenerConfig ¶
type AlbListenerConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// default_action block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#default_action AlbListener#default_action}
DefaultAction interface{} `field:"required" json:"defaultAction" yaml:"defaultAction"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#load_balancer_arn AlbListener#load_balancer_arn}.
LoadBalancerArn *string `field:"required" json:"loadBalancerArn" yaml:"loadBalancerArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#alpn_policy AlbListener#alpn_policy}.
AlpnPolicy *string `field:"optional" json:"alpnPolicy" yaml:"alpnPolicy"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#certificate_arn AlbListener#certificate_arn}.
CertificateArn *string `field:"optional" json:"certificateArn" yaml:"certificateArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#id AlbListener#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#port AlbListener#port}.
Port *float64 `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#protocol AlbListener#protocol}.
Protocol *string `field:"optional" json:"protocol" yaml:"protocol"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#ssl_policy AlbListener#ssl_policy}.
SslPolicy *string `field:"optional" json:"sslPolicy" yaml:"sslPolicy"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#tags AlbListener#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#tags_all AlbListener#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#timeouts AlbListener#timeouts}
Timeouts *AlbListenerTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type AlbListenerDefaultAction ¶
type AlbListenerDefaultAction struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#type AlbListener#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// authenticate_cognito block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#authenticate_cognito AlbListener#authenticate_cognito}
AuthenticateCognito *AlbListenerDefaultActionAuthenticateCognito `field:"optional" json:"authenticateCognito" yaml:"authenticateCognito"`
// authenticate_oidc block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#authenticate_oidc AlbListener#authenticate_oidc}
AuthenticateOidc *AlbListenerDefaultActionAuthenticateOidc `field:"optional" json:"authenticateOidc" yaml:"authenticateOidc"`
// fixed_response block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#fixed_response AlbListener#fixed_response}
FixedResponse *AlbListenerDefaultActionFixedResponse `field:"optional" json:"fixedResponse" yaml:"fixedResponse"`
// forward block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#forward AlbListener#forward}
Forward *AlbListenerDefaultActionForward `field:"optional" json:"forward" yaml:"forward"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#order AlbListener#order}.
Order *float64 `field:"optional" json:"order" yaml:"order"`
// redirect block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#redirect AlbListener#redirect}
Redirect *AlbListenerDefaultActionRedirect `field:"optional" json:"redirect" yaml:"redirect"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#target_group_arn AlbListener#target_group_arn}.
TargetGroupArn *string `field:"optional" json:"targetGroupArn" yaml:"targetGroupArn"`
}
type AlbListenerDefaultActionAuthenticateCognito ¶
type AlbListenerDefaultActionAuthenticateCognito struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#user_pool_arn AlbListener#user_pool_arn}.
UserPoolArn *string `field:"required" json:"userPoolArn" yaml:"userPoolArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#user_pool_client_id AlbListener#user_pool_client_id}.
UserPoolClientId *string `field:"required" json:"userPoolClientId" yaml:"userPoolClientId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#user_pool_domain AlbListener#user_pool_domain}.
UserPoolDomain *string `field:"required" json:"userPoolDomain" yaml:"userPoolDomain"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#authentication_request_extra_params AlbListener#authentication_request_extra_params}.
AuthenticationRequestExtraParams *map[string]*string `field:"optional" json:"authenticationRequestExtraParams" yaml:"authenticationRequestExtraParams"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#on_unauthenticated_request AlbListener#on_unauthenticated_request}.
OnUnauthenticatedRequest *string `field:"optional" json:"onUnauthenticatedRequest" yaml:"onUnauthenticatedRequest"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#scope AlbListener#scope}.
Scope *string `field:"optional" json:"scope" yaml:"scope"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#session_cookie_name AlbListener#session_cookie_name}.
SessionCookieName *string `field:"optional" json:"sessionCookieName" yaml:"sessionCookieName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#session_timeout AlbListener#session_timeout}.
SessionTimeout *float64 `field:"optional" json:"sessionTimeout" yaml:"sessionTimeout"`
}
type AlbListenerDefaultActionAuthenticateCognitoOutputReference ¶
type AlbListenerDefaultActionAuthenticateCognitoOutputReference interface {
cdktf.ComplexObject
AuthenticationRequestExtraParams() *map[string]*string
SetAuthenticationRequestExtraParams(val *map[string]*string)
AuthenticationRequestExtraParamsInput() *map[string]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AlbListenerDefaultActionAuthenticateCognito
SetInternalValue(val *AlbListenerDefaultActionAuthenticateCognito)
OnUnauthenticatedRequest() *string
SetOnUnauthenticatedRequest(val *string)
OnUnauthenticatedRequestInput() *string
Scope() *string
SetScope(val *string)
ScopeInput() *string
SessionCookieName() *string
SetSessionCookieName(val *string)
SessionCookieNameInput() *string
SessionTimeout() *float64
SetSessionTimeout(val *float64)
SessionTimeoutInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UserPoolArn() *string
SetUserPoolArn(val *string)
UserPoolArnInput() *string
UserPoolClientId() *string
SetUserPoolClientId(val *string)
UserPoolClientIdInput() *string
UserPoolDomain() *string
SetUserPoolDomain(val *string)
UserPoolDomainInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAuthenticationRequestExtraParams()
ResetOnUnauthenticatedRequest()
ResetScope()
ResetSessionCookieName()
ResetSessionTimeout()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlbListenerDefaultActionAuthenticateCognitoOutputReference ¶
func NewAlbListenerDefaultActionAuthenticateCognitoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AlbListenerDefaultActionAuthenticateCognitoOutputReference
type AlbListenerDefaultActionAuthenticateOidc ¶
type AlbListenerDefaultActionAuthenticateOidc struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#authorization_endpoint AlbListener#authorization_endpoint}.
AuthorizationEndpoint *string `field:"required" json:"authorizationEndpoint" yaml:"authorizationEndpoint"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#client_id AlbListener#client_id}.
ClientId *string `field:"required" json:"clientId" yaml:"clientId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#client_secret AlbListener#client_secret}.
ClientSecret *string `field:"required" json:"clientSecret" yaml:"clientSecret"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#issuer AlbListener#issuer}.
Issuer *string `field:"required" json:"issuer" yaml:"issuer"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#token_endpoint AlbListener#token_endpoint}.
TokenEndpoint *string `field:"required" json:"tokenEndpoint" yaml:"tokenEndpoint"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#user_info_endpoint AlbListener#user_info_endpoint}.
UserInfoEndpoint *string `field:"required" json:"userInfoEndpoint" yaml:"userInfoEndpoint"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#authentication_request_extra_params AlbListener#authentication_request_extra_params}.
AuthenticationRequestExtraParams *map[string]*string `field:"optional" json:"authenticationRequestExtraParams" yaml:"authenticationRequestExtraParams"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#on_unauthenticated_request AlbListener#on_unauthenticated_request}.
OnUnauthenticatedRequest *string `field:"optional" json:"onUnauthenticatedRequest" yaml:"onUnauthenticatedRequest"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#scope AlbListener#scope}.
Scope *string `field:"optional" json:"scope" yaml:"scope"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#session_cookie_name AlbListener#session_cookie_name}.
SessionCookieName *string `field:"optional" json:"sessionCookieName" yaml:"sessionCookieName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#session_timeout AlbListener#session_timeout}.
SessionTimeout *float64 `field:"optional" json:"sessionTimeout" yaml:"sessionTimeout"`
}
type AlbListenerDefaultActionAuthenticateOidcOutputReference ¶
type AlbListenerDefaultActionAuthenticateOidcOutputReference interface {
cdktf.ComplexObject
AuthenticationRequestExtraParams() *map[string]*string
SetAuthenticationRequestExtraParams(val *map[string]*string)
AuthenticationRequestExtraParamsInput() *map[string]*string
AuthorizationEndpoint() *string
SetAuthorizationEndpoint(val *string)
AuthorizationEndpointInput() *string
ClientId() *string
SetClientId(val *string)
ClientIdInput() *string
ClientSecret() *string
SetClientSecret(val *string)
ClientSecretInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AlbListenerDefaultActionAuthenticateOidc
SetInternalValue(val *AlbListenerDefaultActionAuthenticateOidc)
Issuer() *string
SetIssuer(val *string)
IssuerInput() *string
OnUnauthenticatedRequest() *string
SetOnUnauthenticatedRequest(val *string)
OnUnauthenticatedRequestInput() *string
Scope() *string
SetScope(val *string)
ScopeInput() *string
SessionCookieName() *string
SetSessionCookieName(val *string)
SessionCookieNameInput() *string
SessionTimeout() *float64
SetSessionTimeout(val *float64)
SessionTimeoutInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TokenEndpoint() *string
SetTokenEndpoint(val *string)
TokenEndpointInput() *string
UserInfoEndpoint() *string
SetUserInfoEndpoint(val *string)
UserInfoEndpointInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAuthenticationRequestExtraParams()
ResetOnUnauthenticatedRequest()
ResetScope()
ResetSessionCookieName()
ResetSessionTimeout()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlbListenerDefaultActionAuthenticateOidcOutputReference ¶
func NewAlbListenerDefaultActionAuthenticateOidcOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AlbListenerDefaultActionAuthenticateOidcOutputReference
type AlbListenerDefaultActionFixedResponse ¶
type AlbListenerDefaultActionFixedResponse struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#content_type AlbListener#content_type}.
ContentType *string `field:"required" json:"contentType" yaml:"contentType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#message_body AlbListener#message_body}.
MessageBody *string `field:"optional" json:"messageBody" yaml:"messageBody"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#status_code AlbListener#status_code}.
StatusCode *string `field:"optional" json:"statusCode" yaml:"statusCode"`
}
type AlbListenerDefaultActionFixedResponseOutputReference ¶
type AlbListenerDefaultActionFixedResponseOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ContentType() *string
SetContentType(val *string)
ContentTypeInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AlbListenerDefaultActionFixedResponse
SetInternalValue(val *AlbListenerDefaultActionFixedResponse)
MessageBody() *string
SetMessageBody(val *string)
MessageBodyInput() *string
StatusCode() *string
SetStatusCode(val *string)
StatusCodeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetMessageBody()
ResetStatusCode()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlbListenerDefaultActionFixedResponseOutputReference ¶
func NewAlbListenerDefaultActionFixedResponseOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AlbListenerDefaultActionFixedResponseOutputReference
type AlbListenerDefaultActionForward ¶
type AlbListenerDefaultActionForward struct {
// target_group block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#target_group AlbListener#target_group}
TargetGroup interface{} `field:"required" json:"targetGroup" yaml:"targetGroup"`
// stickiness block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#stickiness AlbListener#stickiness}
Stickiness *AlbListenerDefaultActionForwardStickiness `field:"optional" json:"stickiness" yaml:"stickiness"`
}
type AlbListenerDefaultActionForwardOutputReference ¶
type AlbListenerDefaultActionForwardOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AlbListenerDefaultActionForward
SetInternalValue(val *AlbListenerDefaultActionForward)
Stickiness() AlbListenerDefaultActionForwardStickinessOutputReference
StickinessInput() *AlbListenerDefaultActionForwardStickiness
TargetGroup() AlbListenerDefaultActionForwardTargetGroupList
TargetGroupInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutStickiness(value *AlbListenerDefaultActionForwardStickiness)
PutTargetGroup(value interface{})
ResetStickiness()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlbListenerDefaultActionForwardOutputReference ¶
func NewAlbListenerDefaultActionForwardOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AlbListenerDefaultActionForwardOutputReference
type AlbListenerDefaultActionForwardStickiness ¶
type AlbListenerDefaultActionForwardStickiness struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#duration AlbListener#duration}.
Duration *float64 `field:"required" json:"duration" yaml:"duration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#enabled AlbListener#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
}
type AlbListenerDefaultActionForwardStickinessOutputReference ¶
type AlbListenerDefaultActionForwardStickinessOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Duration() *float64
SetDuration(val *float64)
DurationInput() *float64
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *AlbListenerDefaultActionForwardStickiness
SetInternalValue(val *AlbListenerDefaultActionForwardStickiness)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnabled()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlbListenerDefaultActionForwardStickinessOutputReference ¶
func NewAlbListenerDefaultActionForwardStickinessOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AlbListenerDefaultActionForwardStickinessOutputReference
type AlbListenerDefaultActionForwardTargetGroup ¶
type AlbListenerDefaultActionForwardTargetGroup struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#arn AlbListener#arn}.
Arn *string `field:"required" json:"arn" yaml:"arn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#weight AlbListener#weight}.
Weight *float64 `field:"optional" json:"weight" yaml:"weight"`
}
type AlbListenerDefaultActionForwardTargetGroupList ¶
type AlbListenerDefaultActionForwardTargetGroupList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) AlbListenerDefaultActionForwardTargetGroupOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlbListenerDefaultActionForwardTargetGroupList ¶
func NewAlbListenerDefaultActionForwardTargetGroupList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AlbListenerDefaultActionForwardTargetGroupList
type AlbListenerDefaultActionForwardTargetGroupOutputReference ¶
type AlbListenerDefaultActionForwardTargetGroupOutputReference interface {
cdktf.ComplexObject
Arn() *string
SetArn(val *string)
ArnInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Weight() *float64
SetWeight(val *float64)
WeightInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetWeight()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlbListenerDefaultActionForwardTargetGroupOutputReference ¶
func NewAlbListenerDefaultActionForwardTargetGroupOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AlbListenerDefaultActionForwardTargetGroupOutputReference
type AlbListenerDefaultActionList ¶
type AlbListenerDefaultActionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) AlbListenerDefaultActionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlbListenerDefaultActionList ¶
func NewAlbListenerDefaultActionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AlbListenerDefaultActionList
type AlbListenerDefaultActionOutputReference ¶
type AlbListenerDefaultActionOutputReference interface {
cdktf.ComplexObject
AuthenticateCognito() AlbListenerDefaultActionAuthenticateCognitoOutputReference
AuthenticateCognitoInput() *AlbListenerDefaultActionAuthenticateCognito
AuthenticateOidc() AlbListenerDefaultActionAuthenticateOidcOutputReference
AuthenticateOidcInput() *AlbListenerDefaultActionAuthenticateOidc
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FixedResponse() AlbListenerDefaultActionFixedResponseOutputReference
FixedResponseInput() *AlbListenerDefaultActionFixedResponse
Forward() AlbListenerDefaultActionForwardOutputReference
ForwardInput() *AlbListenerDefaultActionForward
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Order() *float64
SetOrder(val *float64)
OrderInput() *float64
Redirect() AlbListenerDefaultActionRedirectOutputReference
RedirectInput() *AlbListenerDefaultActionRedirect
TargetGroupArn() *string
SetTargetGroupArn(val *string)
TargetGroupArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAuthenticateCognito(value *AlbListenerDefaultActionAuthenticateCognito)
PutAuthenticateOidc(value *AlbListenerDefaultActionAuthenticateOidc)
PutFixedResponse(value *AlbListenerDefaultActionFixedResponse)
PutForward(value *AlbListenerDefaultActionForward)
PutRedirect(value *AlbListenerDefaultActionRedirect)
ResetAuthenticateCognito()
ResetAuthenticateOidc()
ResetFixedResponse()
ResetForward()
ResetOrder()
ResetRedirect()
ResetTargetGroupArn()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlbListenerDefaultActionOutputReference ¶
func NewAlbListenerDefaultActionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AlbListenerDefaultActionOutputReference
type AlbListenerDefaultActionRedirect ¶
type AlbListenerDefaultActionRedirect struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#status_code AlbListener#status_code}.
StatusCode *string `field:"required" json:"statusCode" yaml:"statusCode"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#host AlbListener#host}.
Host *string `field:"optional" json:"host" yaml:"host"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#path AlbListener#path}.
Path *string `field:"optional" json:"path" yaml:"path"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#port AlbListener#port}.
Port *string `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#protocol AlbListener#protocol}.
Protocol *string `field:"optional" json:"protocol" yaml:"protocol"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#query AlbListener#query}.
Query *string `field:"optional" json:"query" yaml:"query"`
}
type AlbListenerDefaultActionRedirectOutputReference ¶
type AlbListenerDefaultActionRedirectOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Host() *string
SetHost(val *string)
HostInput() *string
InternalValue() *AlbListenerDefaultActionRedirect
SetInternalValue(val *AlbListenerDefaultActionRedirect)
Path() *string
SetPath(val *string)
PathInput() *string
Port() *string
SetPort(val *string)
PortInput() *string
Protocol() *string
SetProtocol(val *string)
ProtocolInput() *string
Query() *string
SetQuery(val *string)
QueryInput() *string
StatusCode() *string
SetStatusCode(val *string)
StatusCodeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetHost()
ResetPath()
ResetPort()
ResetProtocol()
ResetQuery()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlbListenerDefaultActionRedirectOutputReference ¶
func NewAlbListenerDefaultActionRedirectOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AlbListenerDefaultActionRedirectOutputReference
type AlbListenerTimeouts ¶
type AlbListenerTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/alb_listener#read AlbListener#read}.
Read *string `field:"optional" json:"read" yaml:"read"`
}
type AlbListenerTimeoutsOutputReference ¶
type AlbListenerTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Read() *string
SetRead(val *string)
ReadInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetRead()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAlbListenerTimeoutsOutputReference ¶
func NewAlbListenerTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AlbListenerTimeoutsOutputReference
Source Files
¶
- AlbListener.go
- AlbListenerConfig.go
- AlbListenerDefaultAction.go
- AlbListenerDefaultActionAuthenticateCognito.go
- AlbListenerDefaultActionAuthenticateCognitoOutputReference.go
- AlbListenerDefaultActionAuthenticateCognitoOutputReference__checks.go
- AlbListenerDefaultActionAuthenticateOidc.go
- AlbListenerDefaultActionAuthenticateOidcOutputReference.go
- AlbListenerDefaultActionAuthenticateOidcOutputReference__checks.go
- AlbListenerDefaultActionFixedResponse.go
- AlbListenerDefaultActionFixedResponseOutputReference.go
- AlbListenerDefaultActionFixedResponseOutputReference__checks.go
- AlbListenerDefaultActionForward.go
- AlbListenerDefaultActionForwardOutputReference.go
- AlbListenerDefaultActionForwardOutputReference__checks.go
- AlbListenerDefaultActionForwardStickiness.go
- AlbListenerDefaultActionForwardStickinessOutputReference.go
- AlbListenerDefaultActionForwardStickinessOutputReference__checks.go
- AlbListenerDefaultActionForwardTargetGroup.go
- AlbListenerDefaultActionForwardTargetGroupList.go
- AlbListenerDefaultActionForwardTargetGroupList__checks.go
- AlbListenerDefaultActionForwardTargetGroupOutputReference.go
- AlbListenerDefaultActionForwardTargetGroupOutputReference__checks.go
- AlbListenerDefaultActionList.go
- AlbListenerDefaultActionList__checks.go
- AlbListenerDefaultActionOutputReference.go
- AlbListenerDefaultActionOutputReference__checks.go
- AlbListenerDefaultActionRedirect.go
- AlbListenerDefaultActionRedirectOutputReference.go
- AlbListenerDefaultActionRedirectOutputReference__checks.go
- AlbListenerTimeouts.go
- AlbListenerTimeoutsOutputReference.go
- AlbListenerTimeoutsOutputReference__checks.go
- AlbListener__checks.go
- main.go