Documentation
¶
Index ¶
- func AmplifyApp_IsConstruct(x interface{}) *bool
- func AmplifyApp_IsTerraformElement(x interface{}) *bool
- func AmplifyApp_IsTerraformResource(x interface{}) *bool
- func AmplifyApp_TfResourceType() *string
- func NewAmplifyAppAutoBranchCreationConfigOutputReference_Override(a AmplifyAppAutoBranchCreationConfigOutputReference, ...)
- func NewAmplifyAppCustomRuleList_Override(a AmplifyAppCustomRuleList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewAmplifyAppCustomRuleOutputReference_Override(a AmplifyAppCustomRuleOutputReference, ...)
- func NewAmplifyAppProductionBranchList_Override(a AmplifyAppProductionBranchList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewAmplifyAppProductionBranchOutputReference_Override(a AmplifyAppProductionBranchOutputReference, ...)
- func NewAmplifyApp_Override(a AmplifyApp, scope constructs.Construct, id *string, config *AmplifyAppConfig)
- type AmplifyApp
- type AmplifyAppAutoBranchCreationConfig
- type AmplifyAppAutoBranchCreationConfigOutputReference
- type AmplifyAppConfig
- type AmplifyAppCustomRule
- type AmplifyAppCustomRuleList
- type AmplifyAppCustomRuleOutputReference
- type AmplifyAppProductionBranch
- type AmplifyAppProductionBranchList
- type AmplifyAppProductionBranchOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AmplifyApp_IsConstruct ¶
func AmplifyApp_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AmplifyApp_IsTerraformElement ¶
func AmplifyApp_IsTerraformElement(x interface{}) *bool
Experimental.
func AmplifyApp_IsTerraformResource ¶
func AmplifyApp_IsTerraformResource(x interface{}) *bool
Experimental.
func AmplifyApp_TfResourceType ¶
func AmplifyApp_TfResourceType() *string
func NewAmplifyAppAutoBranchCreationConfigOutputReference_Override ¶
func NewAmplifyAppAutoBranchCreationConfigOutputReference_Override(a AmplifyAppAutoBranchCreationConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAmplifyAppCustomRuleList_Override ¶
func NewAmplifyAppCustomRuleList_Override(a AmplifyAppCustomRuleList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAmplifyAppCustomRuleOutputReference_Override ¶
func NewAmplifyAppCustomRuleOutputReference_Override(a AmplifyAppCustomRuleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAmplifyAppProductionBranchList_Override ¶
func NewAmplifyAppProductionBranchList_Override(a AmplifyAppProductionBranchList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewAmplifyAppProductionBranchOutputReference_Override ¶
func NewAmplifyAppProductionBranchOutputReference_Override(a AmplifyAppProductionBranchOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewAmplifyApp_Override ¶
func NewAmplifyApp_Override(a AmplifyApp, scope constructs.Construct, id *string, config *AmplifyAppConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app aws_amplify_app} Resource.
Types ¶
type AmplifyApp ¶
type AmplifyApp interface {
cdktf.TerraformResource
AccessToken() *string
SetAccessToken(val *string)
AccessTokenInput() *string
Arn() *string
AutoBranchCreationConfig() AmplifyAppAutoBranchCreationConfigOutputReference
AutoBranchCreationConfigInput() *AmplifyAppAutoBranchCreationConfig
AutoBranchCreationPatterns() *[]*string
SetAutoBranchCreationPatterns(val *[]*string)
AutoBranchCreationPatternsInput() *[]*string
BasicAuthCredentials() *string
SetBasicAuthCredentials(val *string)
BasicAuthCredentialsInput() *string
BuildSpec() *string
SetBuildSpec(val *string)
BuildSpecInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CustomRule() AmplifyAppCustomRuleList
CustomRuleInput() interface{}
DefaultDomain() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
EnableAutoBranchCreation() interface{}
SetEnableAutoBranchCreation(val interface{})
EnableAutoBranchCreationInput() interface{}
EnableBasicAuth() interface{}
SetEnableBasicAuth(val interface{})
EnableBasicAuthInput() interface{}
EnableBranchAutoBuild() interface{}
SetEnableBranchAutoBuild(val interface{})
EnableBranchAutoBuildInput() interface{}
EnableBranchAutoDeletion() interface{}
SetEnableBranchAutoDeletion(val interface{})
EnableBranchAutoDeletionInput() interface{}
EnvironmentVariables() *map[string]*string
SetEnvironmentVariables(val *map[string]*string)
EnvironmentVariablesInput() *map[string]*string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
IamServiceRoleArn() *string
SetIamServiceRoleArn(val *string)
IamServiceRoleArnInput() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
OauthToken() *string
SetOauthToken(val *string)
OauthTokenInput() *string
Platform() *string
SetPlatform(val *string)
PlatformInput() *string
ProductionBranch() AmplifyAppProductionBranchList
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Repository() *string
SetRepository(val *string)
RepositoryInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAutoBranchCreationConfig(value *AmplifyAppAutoBranchCreationConfig)
PutCustomRule(value interface{})
ResetAccessToken()
ResetAutoBranchCreationConfig()
ResetAutoBranchCreationPatterns()
ResetBasicAuthCredentials()
ResetBuildSpec()
ResetCustomRule()
ResetDescription()
ResetEnableAutoBranchCreation()
ResetEnableBasicAuth()
ResetEnableBranchAutoBuild()
ResetEnableBranchAutoDeletion()
ResetEnvironmentVariables()
ResetIamServiceRoleArn()
ResetId()
ResetOauthToken()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPlatform()
ResetRepository()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app aws_amplify_app}.
func NewAmplifyApp ¶
func NewAmplifyApp(scope constructs.Construct, id *string, config *AmplifyAppConfig) AmplifyApp
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app aws_amplify_app} Resource.
type AmplifyAppAutoBranchCreationConfig ¶
type AmplifyAppAutoBranchCreationConfig struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#basic_auth_credentials AmplifyApp#basic_auth_credentials}.
BasicAuthCredentials *string `field:"optional" json:"basicAuthCredentials" yaml:"basicAuthCredentials"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#build_spec AmplifyApp#build_spec}.
BuildSpec *string `field:"optional" json:"buildSpec" yaml:"buildSpec"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#enable_auto_build AmplifyApp#enable_auto_build}.
EnableAutoBuild interface{} `field:"optional" json:"enableAutoBuild" yaml:"enableAutoBuild"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#enable_basic_auth AmplifyApp#enable_basic_auth}.
EnableBasicAuth interface{} `field:"optional" json:"enableBasicAuth" yaml:"enableBasicAuth"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#enable_performance_mode AmplifyApp#enable_performance_mode}.
EnablePerformanceMode interface{} `field:"optional" json:"enablePerformanceMode" yaml:"enablePerformanceMode"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#enable_pull_request_preview AmplifyApp#enable_pull_request_preview}.
EnablePullRequestPreview interface{} `field:"optional" json:"enablePullRequestPreview" yaml:"enablePullRequestPreview"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#environment_variables AmplifyApp#environment_variables}.
EnvironmentVariables *map[string]*string `field:"optional" json:"environmentVariables" yaml:"environmentVariables"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#framework AmplifyApp#framework}.
Framework *string `field:"optional" json:"framework" yaml:"framework"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#pull_request_environment_name AmplifyApp#pull_request_environment_name}.
PullRequestEnvironmentName *string `field:"optional" json:"pullRequestEnvironmentName" yaml:"pullRequestEnvironmentName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#stage AmplifyApp#stage}.
Stage *string `field:"optional" json:"stage" yaml:"stage"`
}
type AmplifyAppAutoBranchCreationConfigOutputReference ¶
type AmplifyAppAutoBranchCreationConfigOutputReference interface {
cdktf.ComplexObject
BasicAuthCredentials() *string
SetBasicAuthCredentials(val *string)
BasicAuthCredentialsInput() *string
BuildSpec() *string
SetBuildSpec(val *string)
BuildSpecInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EnableAutoBuild() interface{}
SetEnableAutoBuild(val interface{})
EnableAutoBuildInput() interface{}
EnableBasicAuth() interface{}
SetEnableBasicAuth(val interface{})
EnableBasicAuthInput() interface{}
EnablePerformanceMode() interface{}
SetEnablePerformanceMode(val interface{})
EnablePerformanceModeInput() interface{}
EnablePullRequestPreview() interface{}
SetEnablePullRequestPreview(val interface{})
EnablePullRequestPreviewInput() interface{}
EnvironmentVariables() *map[string]*string
SetEnvironmentVariables(val *map[string]*string)
EnvironmentVariablesInput() *map[string]*string
// Experimental.
Fqn() *string
Framework() *string
SetFramework(val *string)
FrameworkInput() *string
InternalValue() *AmplifyAppAutoBranchCreationConfig
SetInternalValue(val *AmplifyAppAutoBranchCreationConfig)
PullRequestEnvironmentName() *string
SetPullRequestEnvironmentName(val *string)
PullRequestEnvironmentNameInput() *string
Stage() *string
SetStage(val *string)
StageInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBasicAuthCredentials()
ResetBuildSpec()
ResetEnableAutoBuild()
ResetEnableBasicAuth()
ResetEnablePerformanceMode()
ResetEnablePullRequestPreview()
ResetEnvironmentVariables()
ResetFramework()
ResetPullRequestEnvironmentName()
ResetStage()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAmplifyAppAutoBranchCreationConfigOutputReference ¶
func NewAmplifyAppAutoBranchCreationConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AmplifyAppAutoBranchCreationConfigOutputReference
type AmplifyAppConfig ¶
type AmplifyAppConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#name AmplifyApp#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#access_token AmplifyApp#access_token}.
AccessToken *string `field:"optional" json:"accessToken" yaml:"accessToken"`
// auto_branch_creation_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#auto_branch_creation_config AmplifyApp#auto_branch_creation_config}
AutoBranchCreationConfig *AmplifyAppAutoBranchCreationConfig `field:"optional" json:"autoBranchCreationConfig" yaml:"autoBranchCreationConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#auto_branch_creation_patterns AmplifyApp#auto_branch_creation_patterns}.
AutoBranchCreationPatterns *[]*string `field:"optional" json:"autoBranchCreationPatterns" yaml:"autoBranchCreationPatterns"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#basic_auth_credentials AmplifyApp#basic_auth_credentials}.
BasicAuthCredentials *string `field:"optional" json:"basicAuthCredentials" yaml:"basicAuthCredentials"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#build_spec AmplifyApp#build_spec}.
BuildSpec *string `field:"optional" json:"buildSpec" yaml:"buildSpec"`
// custom_rule block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#custom_rule AmplifyApp#custom_rule}
CustomRule interface{} `field:"optional" json:"customRule" yaml:"customRule"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#description AmplifyApp#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#enable_auto_branch_creation AmplifyApp#enable_auto_branch_creation}.
EnableAutoBranchCreation interface{} `field:"optional" json:"enableAutoBranchCreation" yaml:"enableAutoBranchCreation"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#enable_basic_auth AmplifyApp#enable_basic_auth}.
EnableBasicAuth interface{} `field:"optional" json:"enableBasicAuth" yaml:"enableBasicAuth"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#enable_branch_auto_build AmplifyApp#enable_branch_auto_build}.
EnableBranchAutoBuild interface{} `field:"optional" json:"enableBranchAutoBuild" yaml:"enableBranchAutoBuild"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#enable_branch_auto_deletion AmplifyApp#enable_branch_auto_deletion}.
EnableBranchAutoDeletion interface{} `field:"optional" json:"enableBranchAutoDeletion" yaml:"enableBranchAutoDeletion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#environment_variables AmplifyApp#environment_variables}.
EnvironmentVariables *map[string]*string `field:"optional" json:"environmentVariables" yaml:"environmentVariables"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#iam_service_role_arn AmplifyApp#iam_service_role_arn}.
IamServiceRoleArn *string `field:"optional" json:"iamServiceRoleArn" yaml:"iamServiceRoleArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#id AmplifyApp#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#oauth_token AmplifyApp#oauth_token}.
OauthToken *string `field:"optional" json:"oauthToken" yaml:"oauthToken"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#platform AmplifyApp#platform}.
Platform *string `field:"optional" json:"platform" yaml:"platform"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#repository AmplifyApp#repository}.
Repository *string `field:"optional" json:"repository" yaml:"repository"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#tags AmplifyApp#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#tags_all AmplifyApp#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type AmplifyAppCustomRule ¶
type AmplifyAppCustomRule struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#source AmplifyApp#source}.
Source *string `field:"required" json:"source" yaml:"source"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#target AmplifyApp#target}.
Target *string `field:"required" json:"target" yaml:"target"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#condition AmplifyApp#condition}.
Condition *string `field:"optional" json:"condition" yaml:"condition"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/amplify_app#status AmplifyApp#status}.
Status *string `field:"optional" json:"status" yaml:"status"`
}
type AmplifyAppCustomRuleList ¶
type AmplifyAppCustomRuleList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) AmplifyAppCustomRuleOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAmplifyAppCustomRuleList ¶
func NewAmplifyAppCustomRuleList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AmplifyAppCustomRuleList
type AmplifyAppCustomRuleOutputReference ¶
type AmplifyAppCustomRuleOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Condition() *string
SetCondition(val *string)
ConditionInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Source() *string
SetSource(val *string)
SourceInput() *string
Status() *string
SetStatus(val *string)
StatusInput() *string
Target() *string
SetTarget(val *string)
TargetInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCondition()
ResetStatus()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAmplifyAppCustomRuleOutputReference ¶
func NewAmplifyAppCustomRuleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AmplifyAppCustomRuleOutputReference
type AmplifyAppProductionBranch ¶
type AmplifyAppProductionBranch struct {
}
type AmplifyAppProductionBranchList ¶
type AmplifyAppProductionBranchList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) AmplifyAppProductionBranchOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAmplifyAppProductionBranchList ¶
func NewAmplifyAppProductionBranchList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) AmplifyAppProductionBranchList
type AmplifyAppProductionBranchOutputReference ¶
type AmplifyAppProductionBranchOutputReference interface {
cdktf.ComplexObject
BranchName() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AmplifyAppProductionBranch
SetInternalValue(val *AmplifyAppProductionBranch)
LastDeployTime() *string
Status() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ThumbnailUrl() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAmplifyAppProductionBranchOutputReference ¶
func NewAmplifyAppProductionBranchOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) AmplifyAppProductionBranchOutputReference
Source Files
¶
- AmplifyApp.go
- AmplifyAppAutoBranchCreationConfig.go
- AmplifyAppAutoBranchCreationConfigOutputReference.go
- AmplifyAppAutoBranchCreationConfigOutputReference__checks.go
- AmplifyAppConfig.go
- AmplifyAppCustomRule.go
- AmplifyAppCustomRuleList.go
- AmplifyAppCustomRuleList__checks.go
- AmplifyAppCustomRuleOutputReference.go
- AmplifyAppCustomRuleOutputReference__checks.go
- AmplifyAppProductionBranch.go
- AmplifyAppProductionBranchList.go
- AmplifyAppProductionBranchList__checks.go
- AmplifyAppProductionBranchOutputReference.go
- AmplifyAppProductionBranchOutputReference__checks.go
- AmplifyApp__checks.go
- main.go