Documentation
¶
Index ¶
- func Apigatewayv2Api_IsConstruct(x interface{}) *bool
- func Apigatewayv2Api_IsTerraformElement(x interface{}) *bool
- func Apigatewayv2Api_IsTerraformResource(x interface{}) *bool
- func Apigatewayv2Api_TfResourceType() *string
- func NewApigatewayv2ApiCorsConfigurationOutputReference_Override(a Apigatewayv2ApiCorsConfigurationOutputReference, ...)
- func NewApigatewayv2Api_Override(a Apigatewayv2Api, scope constructs.Construct, id *string, ...)
- type Apigatewayv2Api
- type Apigatewayv2ApiConfig
- type Apigatewayv2ApiCorsConfiguration
- type Apigatewayv2ApiCorsConfigurationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Apigatewayv2Api_IsConstruct ¶
func Apigatewayv2Api_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func Apigatewayv2Api_IsTerraformElement ¶
func Apigatewayv2Api_IsTerraformElement(x interface{}) *bool
Experimental.
func Apigatewayv2Api_IsTerraformResource ¶
func Apigatewayv2Api_IsTerraformResource(x interface{}) *bool
Experimental.
func Apigatewayv2Api_TfResourceType ¶
func Apigatewayv2Api_TfResourceType() *string
func NewApigatewayv2ApiCorsConfigurationOutputReference_Override ¶
func NewApigatewayv2ApiCorsConfigurationOutputReference_Override(a Apigatewayv2ApiCorsConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewApigatewayv2Api_Override ¶
func NewApigatewayv2Api_Override(a Apigatewayv2Api, scope constructs.Construct, id *string, config *Apigatewayv2ApiConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api aws_apigatewayv2_api} Resource.
Types ¶
type Apigatewayv2Api ¶
type Apigatewayv2Api interface {
cdktf.TerraformResource
ApiEndpoint() *string
ApiKeySelectionExpression() *string
SetApiKeySelectionExpression(val *string)
ApiKeySelectionExpressionInput() *string
Arn() *string
Body() *string
SetBody(val *string)
BodyInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
CorsConfiguration() Apigatewayv2ApiCorsConfigurationOutputReference
CorsConfigurationInput() *Apigatewayv2ApiCorsConfiguration
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CredentialsArn() *string
SetCredentialsArn(val *string)
CredentialsArnInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DisableExecuteApiEndpoint() interface{}
SetDisableExecuteApiEndpoint(val interface{})
DisableExecuteApiEndpointInput() interface{}
ExecutionArn() *string
FailOnWarnings() interface{}
SetFailOnWarnings(val interface{})
FailOnWarningsInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
ProtocolType() *string
SetProtocolType(val *string)
ProtocolTypeInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RouteKey() *string
SetRouteKey(val *string)
RouteKeyInput() *string
RouteSelectionExpression() *string
SetRouteSelectionExpression(val *string)
RouteSelectionExpressionInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
Target() *string
SetTarget(val *string)
TargetInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Version() *string
SetVersion(val *string)
VersionInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCorsConfiguration(value *Apigatewayv2ApiCorsConfiguration)
ResetApiKeySelectionExpression()
ResetBody()
ResetCorsConfiguration()
ResetCredentialsArn()
ResetDescription()
ResetDisableExecuteApiEndpoint()
ResetFailOnWarnings()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRouteKey()
ResetRouteSelectionExpression()
ResetTags()
ResetTagsAll()
ResetTarget()
ResetVersion()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api aws_apigatewayv2_api}.
func NewApigatewayv2Api ¶
func NewApigatewayv2Api(scope constructs.Construct, id *string, config *Apigatewayv2ApiConfig) Apigatewayv2Api
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api aws_apigatewayv2_api} Resource.
type Apigatewayv2ApiConfig ¶
type Apigatewayv2ApiConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#name Apigatewayv2Api#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#protocol_type Apigatewayv2Api#protocol_type}.
ProtocolType *string `field:"required" json:"protocolType" yaml:"protocolType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#api_key_selection_expression Apigatewayv2Api#api_key_selection_expression}.
ApiKeySelectionExpression *string `field:"optional" json:"apiKeySelectionExpression" yaml:"apiKeySelectionExpression"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#body Apigatewayv2Api#body}.
Body *string `field:"optional" json:"body" yaml:"body"`
// cors_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#cors_configuration Apigatewayv2Api#cors_configuration}
CorsConfiguration *Apigatewayv2ApiCorsConfiguration `field:"optional" json:"corsConfiguration" yaml:"corsConfiguration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#credentials_arn Apigatewayv2Api#credentials_arn}.
CredentialsArn *string `field:"optional" json:"credentialsArn" yaml:"credentialsArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#description Apigatewayv2Api#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#disable_execute_api_endpoint Apigatewayv2Api#disable_execute_api_endpoint}.
DisableExecuteApiEndpoint interface{} `field:"optional" json:"disableExecuteApiEndpoint" yaml:"disableExecuteApiEndpoint"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#fail_on_warnings Apigatewayv2Api#fail_on_warnings}.
FailOnWarnings interface{} `field:"optional" json:"failOnWarnings" yaml:"failOnWarnings"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#id Apigatewayv2Api#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#route_key Apigatewayv2Api#route_key}.
RouteKey *string `field:"optional" json:"routeKey" yaml:"routeKey"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#route_selection_expression Apigatewayv2Api#route_selection_expression}.
RouteSelectionExpression *string `field:"optional" json:"routeSelectionExpression" yaml:"routeSelectionExpression"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#tags Apigatewayv2Api#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#tags_all Apigatewayv2Api#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#target Apigatewayv2Api#target}.
Target *string `field:"optional" json:"target" yaml:"target"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#version Apigatewayv2Api#version}.
Version *string `field:"optional" json:"version" yaml:"version"`
}
type Apigatewayv2ApiCorsConfiguration ¶
type Apigatewayv2ApiCorsConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#allow_credentials Apigatewayv2Api#allow_credentials}.
AllowCredentials interface{} `field:"optional" json:"allowCredentials" yaml:"allowCredentials"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#allow_headers Apigatewayv2Api#allow_headers}.
AllowHeaders *[]*string `field:"optional" json:"allowHeaders" yaml:"allowHeaders"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#allow_methods Apigatewayv2Api#allow_methods}.
AllowMethods *[]*string `field:"optional" json:"allowMethods" yaml:"allowMethods"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#allow_origins Apigatewayv2Api#allow_origins}.
AllowOrigins *[]*string `field:"optional" json:"allowOrigins" yaml:"allowOrigins"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#expose_headers Apigatewayv2Api#expose_headers}.
ExposeHeaders *[]*string `field:"optional" json:"exposeHeaders" yaml:"exposeHeaders"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_api#max_age Apigatewayv2Api#max_age}.
MaxAge *float64 `field:"optional" json:"maxAge" yaml:"maxAge"`
}
type Apigatewayv2ApiCorsConfigurationOutputReference ¶
type Apigatewayv2ApiCorsConfigurationOutputReference interface {
cdktf.ComplexObject
AllowCredentials() interface{}
SetAllowCredentials(val interface{})
AllowCredentialsInput() interface{}
AllowHeaders() *[]*string
SetAllowHeaders(val *[]*string)
AllowHeadersInput() *[]*string
AllowMethods() *[]*string
SetAllowMethods(val *[]*string)
AllowMethodsInput() *[]*string
AllowOrigins() *[]*string
SetAllowOrigins(val *[]*string)
AllowOriginsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
ExposeHeaders() *[]*string
SetExposeHeaders(val *[]*string)
ExposeHeadersInput() *[]*string
// Experimental.
Fqn() *string
InternalValue() *Apigatewayv2ApiCorsConfiguration
SetInternalValue(val *Apigatewayv2ApiCorsConfiguration)
MaxAge() *float64
SetMaxAge(val *float64)
MaxAgeInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAllowCredentials()
ResetAllowHeaders()
ResetAllowMethods()
ResetAllowOrigins()
ResetExposeHeaders()
ResetMaxAge()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApigatewayv2ApiCorsConfigurationOutputReference ¶
func NewApigatewayv2ApiCorsConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) Apigatewayv2ApiCorsConfigurationOutputReference