Documentation
¶
Index ¶
- func Apigatewayv2Route_IsConstruct(x interface{}) *bool
- func Apigatewayv2Route_IsTerraformElement(x interface{}) *bool
- func Apigatewayv2Route_IsTerraformResource(x interface{}) *bool
- func Apigatewayv2Route_TfResourceType() *string
- func NewApigatewayv2RouteRequestParameterList_Override(a Apigatewayv2RouteRequestParameterList, ...)
- func NewApigatewayv2RouteRequestParameterOutputReference_Override(a Apigatewayv2RouteRequestParameterOutputReference, ...)
- func NewApigatewayv2Route_Override(a Apigatewayv2Route, scope constructs.Construct, id *string, ...)
- type Apigatewayv2Route
- type Apigatewayv2RouteConfig
- type Apigatewayv2RouteRequestParameter
- type Apigatewayv2RouteRequestParameterList
- type Apigatewayv2RouteRequestParameterOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Apigatewayv2Route_IsConstruct ¶
func Apigatewayv2Route_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func Apigatewayv2Route_IsTerraformElement ¶
func Apigatewayv2Route_IsTerraformElement(x interface{}) *bool
Experimental.
func Apigatewayv2Route_IsTerraformResource ¶
func Apigatewayv2Route_IsTerraformResource(x interface{}) *bool
Experimental.
func Apigatewayv2Route_TfResourceType ¶
func Apigatewayv2Route_TfResourceType() *string
func NewApigatewayv2RouteRequestParameterList_Override ¶
func NewApigatewayv2RouteRequestParameterList_Override(a Apigatewayv2RouteRequestParameterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewApigatewayv2RouteRequestParameterOutputReference_Override ¶
func NewApigatewayv2RouteRequestParameterOutputReference_Override(a Apigatewayv2RouteRequestParameterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewApigatewayv2Route_Override ¶
func NewApigatewayv2Route_Override(a Apigatewayv2Route, scope constructs.Construct, id *string, config *Apigatewayv2RouteConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_route aws_apigatewayv2_route} Resource.
Types ¶
type Apigatewayv2Route ¶
type Apigatewayv2Route interface {
cdktf.TerraformResource
ApiId() *string
SetApiId(val *string)
ApiIdInput() *string
ApiKeyRequired() interface{}
SetApiKeyRequired(val interface{})
ApiKeyRequiredInput() interface{}
AuthorizationScopes() *[]*string
SetAuthorizationScopes(val *[]*string)
AuthorizationScopesInput() *[]*string
AuthorizationType() *string
SetAuthorizationType(val *string)
AuthorizationTypeInput() *string
AuthorizerId() *string
SetAuthorizerId(val *string)
AuthorizerIdInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
ModelSelectionExpression() *string
SetModelSelectionExpression(val *string)
ModelSelectionExpressionInput() *string
// The tree node.
Node() constructs.Node
OperationName() *string
SetOperationName(val *string)
OperationNameInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RequestModels() *map[string]*string
SetRequestModels(val *map[string]*string)
RequestModelsInput() *map[string]*string
RequestParameter() Apigatewayv2RouteRequestParameterList
RequestParameterInput() interface{}
RouteKey() *string
SetRouteKey(val *string)
RouteKeyInput() *string
RouteResponseSelectionExpression() *string
SetRouteResponseSelectionExpression(val *string)
RouteResponseSelectionExpressionInput() *string
Target() *string
SetTarget(val *string)
TargetInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutRequestParameter(value interface{})
ResetApiKeyRequired()
ResetAuthorizationScopes()
ResetAuthorizationType()
ResetAuthorizerId()
ResetId()
ResetModelSelectionExpression()
ResetOperationName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetRequestModels()
ResetRequestParameter()
ResetRouteResponseSelectionExpression()
ResetTarget()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_route aws_apigatewayv2_route}.
func NewApigatewayv2Route ¶
func NewApigatewayv2Route(scope constructs.Construct, id *string, config *Apigatewayv2RouteConfig) Apigatewayv2Route
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_route aws_apigatewayv2_route} Resource.
type Apigatewayv2RouteConfig ¶
type Apigatewayv2RouteConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_route#api_id Apigatewayv2Route#api_id}.
ApiId *string `field:"required" json:"apiId" yaml:"apiId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_route#route_key Apigatewayv2Route#route_key}.
RouteKey *string `field:"required" json:"routeKey" yaml:"routeKey"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_route#api_key_required Apigatewayv2Route#api_key_required}.
ApiKeyRequired interface{} `field:"optional" json:"apiKeyRequired" yaml:"apiKeyRequired"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_route#authorization_scopes Apigatewayv2Route#authorization_scopes}.
AuthorizationScopes *[]*string `field:"optional" json:"authorizationScopes" yaml:"authorizationScopes"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_route#authorization_type Apigatewayv2Route#authorization_type}.
AuthorizationType *string `field:"optional" json:"authorizationType" yaml:"authorizationType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_route#authorizer_id Apigatewayv2Route#authorizer_id}.
AuthorizerId *string `field:"optional" json:"authorizerId" yaml:"authorizerId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_route#id Apigatewayv2Route#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_route#model_selection_expression Apigatewayv2Route#model_selection_expression}.
ModelSelectionExpression *string `field:"optional" json:"modelSelectionExpression" yaml:"modelSelectionExpression"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_route#operation_name Apigatewayv2Route#operation_name}.
OperationName *string `field:"optional" json:"operationName" yaml:"operationName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_route#request_models Apigatewayv2Route#request_models}.
RequestModels *map[string]*string `field:"optional" json:"requestModels" yaml:"requestModels"`
// request_parameter block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_route#request_parameter Apigatewayv2Route#request_parameter}
RequestParameter interface{} `field:"optional" json:"requestParameter" yaml:"requestParameter"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_route#route_response_selection_expression Apigatewayv2Route#route_response_selection_expression}.
RouteResponseSelectionExpression *string `field:"optional" json:"routeResponseSelectionExpression" yaml:"routeResponseSelectionExpression"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_route#target Apigatewayv2Route#target}.
Target *string `field:"optional" json:"target" yaml:"target"`
}
type Apigatewayv2RouteRequestParameter ¶
type Apigatewayv2RouteRequestParameter struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_route#request_parameter_key Apigatewayv2Route#request_parameter_key}.
RequestParameterKey *string `field:"required" json:"requestParameterKey" yaml:"requestParameterKey"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/apigatewayv2_route#required Apigatewayv2Route#required}.
Required interface{} `field:"required" json:"required" yaml:"required"`
}
type Apigatewayv2RouteRequestParameterList ¶
type Apigatewayv2RouteRequestParameterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) Apigatewayv2RouteRequestParameterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApigatewayv2RouteRequestParameterList ¶
func NewApigatewayv2RouteRequestParameterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) Apigatewayv2RouteRequestParameterList
type Apigatewayv2RouteRequestParameterOutputReference ¶
type Apigatewayv2RouteRequestParameterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
RequestParameterKey() *string
SetRequestParameterKey(val *string)
RequestParameterKeyInput() *string
Required() interface{}
SetRequired(val interface{})
RequiredInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewApigatewayv2RouteRequestParameterOutputReference ¶
func NewApigatewayv2RouteRequestParameterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) Apigatewayv2RouteRequestParameterOutputReference
Source Files
¶
- Apigatewayv2Route.go
- Apigatewayv2RouteConfig.go
- Apigatewayv2RouteRequestParameter.go
- Apigatewayv2RouteRequestParameterList.go
- Apigatewayv2RouteRequestParameterList__checks.go
- Apigatewayv2RouteRequestParameterOutputReference.go
- Apigatewayv2RouteRequestParameterOutputReference__checks.go
- Apigatewayv2Route__checks.go
- main.go