Documentation
¶
Index ¶
- func AthenaDatabase_IsConstruct(x interface{}) *bool
- func AthenaDatabase_IsTerraformElement(x interface{}) *bool
- func AthenaDatabase_IsTerraformResource(x interface{}) *bool
- func AthenaDatabase_TfResourceType() *string
- func NewAthenaDatabaseAclConfigurationOutputReference_Override(a AthenaDatabaseAclConfigurationOutputReference, ...)
- func NewAthenaDatabaseEncryptionConfigurationOutputReference_Override(a AthenaDatabaseEncryptionConfigurationOutputReference, ...)
- func NewAthenaDatabase_Override(a AthenaDatabase, scope constructs.Construct, id *string, ...)
- type AthenaDatabase
- type AthenaDatabaseAclConfiguration
- type AthenaDatabaseAclConfigurationOutputReference
- type AthenaDatabaseConfig
- type AthenaDatabaseEncryptionConfiguration
- type AthenaDatabaseEncryptionConfigurationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AthenaDatabase_IsConstruct ¶
func AthenaDatabase_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func AthenaDatabase_IsTerraformElement ¶
func AthenaDatabase_IsTerraformElement(x interface{}) *bool
Experimental.
func AthenaDatabase_IsTerraformResource ¶
func AthenaDatabase_IsTerraformResource(x interface{}) *bool
Experimental.
func AthenaDatabase_TfResourceType ¶
func AthenaDatabase_TfResourceType() *string
func NewAthenaDatabaseAclConfigurationOutputReference_Override ¶
func NewAthenaDatabaseAclConfigurationOutputReference_Override(a AthenaDatabaseAclConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAthenaDatabaseEncryptionConfigurationOutputReference_Override ¶
func NewAthenaDatabaseEncryptionConfigurationOutputReference_Override(a AthenaDatabaseEncryptionConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewAthenaDatabase_Override ¶
func NewAthenaDatabase_Override(a AthenaDatabase, scope constructs.Construct, id *string, config *AthenaDatabaseConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/athena_database aws_athena_database} Resource.
Types ¶
type AthenaDatabase ¶
type AthenaDatabase interface {
cdktf.TerraformResource
AclConfiguration() AthenaDatabaseAclConfigurationOutputReference
AclConfigurationInput() *AthenaDatabaseAclConfiguration
Bucket() *string
SetBucket(val *string)
BucketInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
Comment() *string
SetComment(val *string)
CommentInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EncryptionConfiguration() AthenaDatabaseEncryptionConfigurationOutputReference
EncryptionConfigurationInput() *AthenaDatabaseEncryptionConfiguration
ExpectedBucketOwner() *string
SetExpectedBucketOwner(val *string)
ExpectedBucketOwnerInput() *string
ForceDestroy() interface{}
SetForceDestroy(val interface{})
ForceDestroyInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Properties() *map[string]*string
SetProperties(val *map[string]*string)
PropertiesInput() *map[string]*string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAclConfiguration(value *AthenaDatabaseAclConfiguration)
PutEncryptionConfiguration(value *AthenaDatabaseEncryptionConfiguration)
ResetAclConfiguration()
ResetBucket()
ResetComment()
ResetEncryptionConfiguration()
ResetExpectedBucketOwner()
ResetForceDestroy()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProperties()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/athena_database aws_athena_database}.
func NewAthenaDatabase ¶
func NewAthenaDatabase(scope constructs.Construct, id *string, config *AthenaDatabaseConfig) AthenaDatabase
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/athena_database aws_athena_database} Resource.
type AthenaDatabaseAclConfiguration ¶
type AthenaDatabaseAclConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/athena_database#s3_acl_option AthenaDatabase#s3_acl_option}.
S3AclOption *string `field:"required" json:"s3AclOption" yaml:"s3AclOption"`
}
type AthenaDatabaseAclConfigurationOutputReference ¶
type AthenaDatabaseAclConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *AthenaDatabaseAclConfiguration
SetInternalValue(val *AthenaDatabaseAclConfiguration)
S3AclOption() *string
SetS3AclOption(val *string)
S3AclOptionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAthenaDatabaseAclConfigurationOutputReference ¶
func NewAthenaDatabaseAclConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AthenaDatabaseAclConfigurationOutputReference
type AthenaDatabaseConfig ¶
type AthenaDatabaseConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/athena_database#name AthenaDatabase#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// acl_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/athena_database#acl_configuration AthenaDatabase#acl_configuration}
AclConfiguration *AthenaDatabaseAclConfiguration `field:"optional" json:"aclConfiguration" yaml:"aclConfiguration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/athena_database#bucket AthenaDatabase#bucket}.
Bucket *string `field:"optional" json:"bucket" yaml:"bucket"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/athena_database#comment AthenaDatabase#comment}.
Comment *string `field:"optional" json:"comment" yaml:"comment"`
// encryption_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/athena_database#encryption_configuration AthenaDatabase#encryption_configuration}
EncryptionConfiguration *AthenaDatabaseEncryptionConfiguration `field:"optional" json:"encryptionConfiguration" yaml:"encryptionConfiguration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/athena_database#expected_bucket_owner AthenaDatabase#expected_bucket_owner}.
ExpectedBucketOwner *string `field:"optional" json:"expectedBucketOwner" yaml:"expectedBucketOwner"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/athena_database#force_destroy AthenaDatabase#force_destroy}.
ForceDestroy interface{} `field:"optional" json:"forceDestroy" yaml:"forceDestroy"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/athena_database#id AthenaDatabase#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/athena_database#properties AthenaDatabase#properties}.
Properties *map[string]*string `field:"optional" json:"properties" yaml:"properties"`
}
type AthenaDatabaseEncryptionConfiguration ¶
type AthenaDatabaseEncryptionConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/athena_database#encryption_option AthenaDatabase#encryption_option}.
EncryptionOption *string `field:"required" json:"encryptionOption" yaml:"encryptionOption"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/athena_database#kms_key AthenaDatabase#kms_key}.
KmsKey *string `field:"optional" json:"kmsKey" yaml:"kmsKey"`
}
type AthenaDatabaseEncryptionConfigurationOutputReference ¶
type AthenaDatabaseEncryptionConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EncryptionOption() *string
SetEncryptionOption(val *string)
EncryptionOptionInput() *string
// Experimental.
Fqn() *string
InternalValue() *AthenaDatabaseEncryptionConfiguration
SetInternalValue(val *AthenaDatabaseEncryptionConfiguration)
KmsKey() *string
SetKmsKey(val *string)
KmsKeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetKmsKey()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewAthenaDatabaseEncryptionConfigurationOutputReference ¶
func NewAthenaDatabaseEncryptionConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) AthenaDatabaseEncryptionConfigurationOutputReference
Source Files
¶
- AthenaDatabase.go
- AthenaDatabaseAclConfiguration.go
- AthenaDatabaseAclConfigurationOutputReference.go
- AthenaDatabaseAclConfigurationOutputReference__checks.go
- AthenaDatabaseConfig.go
- AthenaDatabaseEncryptionConfiguration.go
- AthenaDatabaseEncryptionConfigurationOutputReference.go
- AthenaDatabaseEncryptionConfigurationOutputReference__checks.go
- AthenaDatabase__checks.go
- main.go