Documentation
¶
Index ¶
- func BackupPlan_IsConstruct(x interface{}) *bool
- func BackupPlan_IsTerraformElement(x interface{}) *bool
- func BackupPlan_IsTerraformResource(x interface{}) *bool
- func BackupPlan_TfResourceType() *string
- func NewBackupPlanAdvancedBackupSettingList_Override(b BackupPlanAdvancedBackupSettingList, ...)
- func NewBackupPlanAdvancedBackupSettingOutputReference_Override(b BackupPlanAdvancedBackupSettingOutputReference, ...)
- func NewBackupPlanRuleCopyActionLifecycleOutputReference_Override(b BackupPlanRuleCopyActionLifecycleOutputReference, ...)
- func NewBackupPlanRuleCopyActionList_Override(b BackupPlanRuleCopyActionList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewBackupPlanRuleCopyActionOutputReference_Override(b BackupPlanRuleCopyActionOutputReference, ...)
- func NewBackupPlanRuleLifecycleOutputReference_Override(b BackupPlanRuleLifecycleOutputReference, ...)
- func NewBackupPlanRuleList_Override(b BackupPlanRuleList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewBackupPlanRuleOutputReference_Override(b BackupPlanRuleOutputReference, terraformResource cdktf.IInterpolatingParent, ...)
- func NewBackupPlan_Override(b BackupPlan, scope constructs.Construct, id *string, config *BackupPlanConfig)
- type BackupPlan
- type BackupPlanAdvancedBackupSetting
- type BackupPlanAdvancedBackupSettingList
- type BackupPlanAdvancedBackupSettingOutputReference
- type BackupPlanConfig
- type BackupPlanRule
- type BackupPlanRuleCopyAction
- type BackupPlanRuleCopyActionLifecycle
- type BackupPlanRuleCopyActionLifecycleOutputReference
- type BackupPlanRuleCopyActionList
- type BackupPlanRuleCopyActionOutputReference
- type BackupPlanRuleLifecycle
- type BackupPlanRuleLifecycleOutputReference
- type BackupPlanRuleList
- type BackupPlanRuleOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BackupPlan_IsConstruct ¶
func BackupPlan_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func BackupPlan_IsTerraformElement ¶
func BackupPlan_IsTerraformElement(x interface{}) *bool
Experimental.
func BackupPlan_IsTerraformResource ¶
func BackupPlan_IsTerraformResource(x interface{}) *bool
Experimental.
func BackupPlan_TfResourceType ¶
func BackupPlan_TfResourceType() *string
func NewBackupPlanAdvancedBackupSettingList_Override ¶
func NewBackupPlanAdvancedBackupSettingList_Override(b BackupPlanAdvancedBackupSettingList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewBackupPlanAdvancedBackupSettingOutputReference_Override ¶
func NewBackupPlanAdvancedBackupSettingOutputReference_Override(b BackupPlanAdvancedBackupSettingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewBackupPlanRuleCopyActionLifecycleOutputReference_Override ¶
func NewBackupPlanRuleCopyActionLifecycleOutputReference_Override(b BackupPlanRuleCopyActionLifecycleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBackupPlanRuleCopyActionList_Override ¶
func NewBackupPlanRuleCopyActionList_Override(b BackupPlanRuleCopyActionList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewBackupPlanRuleCopyActionOutputReference_Override ¶
func NewBackupPlanRuleCopyActionOutputReference_Override(b BackupPlanRuleCopyActionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewBackupPlanRuleLifecycleOutputReference_Override ¶
func NewBackupPlanRuleLifecycleOutputReference_Override(b BackupPlanRuleLifecycleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewBackupPlanRuleList_Override ¶
func NewBackupPlanRuleList_Override(b BackupPlanRuleList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewBackupPlanRuleOutputReference_Override ¶
func NewBackupPlanRuleOutputReference_Override(b BackupPlanRuleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewBackupPlan_Override ¶
func NewBackupPlan_Override(b BackupPlan, scope constructs.Construct, id *string, config *BackupPlanConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan aws_backup_plan} Resource.
Types ¶
type BackupPlan ¶
type BackupPlan interface {
cdktf.TerraformResource
AdvancedBackupSetting() BackupPlanAdvancedBackupSettingList
AdvancedBackupSettingInput() interface{}
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Rule() BackupPlanRuleList
RuleInput() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Version() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAdvancedBackupSetting(value interface{})
PutRule(value interface{})
ResetAdvancedBackupSetting()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan aws_backup_plan}.
func NewBackupPlan ¶
func NewBackupPlan(scope constructs.Construct, id *string, config *BackupPlanConfig) BackupPlan
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan aws_backup_plan} Resource.
type BackupPlanAdvancedBackupSetting ¶
type BackupPlanAdvancedBackupSetting struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#backup_options BackupPlan#backup_options}.
BackupOptions *map[string]*string `field:"required" json:"backupOptions" yaml:"backupOptions"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#resource_type BackupPlan#resource_type}.
ResourceType *string `field:"required" json:"resourceType" yaml:"resourceType"`
}
type BackupPlanAdvancedBackupSettingList ¶
type BackupPlanAdvancedBackupSettingList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) BackupPlanAdvancedBackupSettingOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupPlanAdvancedBackupSettingList ¶
func NewBackupPlanAdvancedBackupSettingList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) BackupPlanAdvancedBackupSettingList
type BackupPlanAdvancedBackupSettingOutputReference ¶
type BackupPlanAdvancedBackupSettingOutputReference interface {
cdktf.ComplexObject
BackupOptions() *map[string]*string
SetBackupOptions(val *map[string]*string)
BackupOptionsInput() *map[string]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
ResourceType() *string
SetResourceType(val *string)
ResourceTypeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupPlanAdvancedBackupSettingOutputReference ¶
func NewBackupPlanAdvancedBackupSettingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) BackupPlanAdvancedBackupSettingOutputReference
type BackupPlanConfig ¶
type BackupPlanConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#name BackupPlan#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// rule block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#rule BackupPlan#rule}
Rule interface{} `field:"required" json:"rule" yaml:"rule"`
// advanced_backup_setting block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#advanced_backup_setting BackupPlan#advanced_backup_setting}
AdvancedBackupSetting interface{} `field:"optional" json:"advancedBackupSetting" yaml:"advancedBackupSetting"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#id BackupPlan#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#tags BackupPlan#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#tags_all BackupPlan#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
}
type BackupPlanRule ¶
type BackupPlanRule struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#rule_name BackupPlan#rule_name}.
RuleName *string `field:"required" json:"ruleName" yaml:"ruleName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#target_vault_name BackupPlan#target_vault_name}.
TargetVaultName *string `field:"required" json:"targetVaultName" yaml:"targetVaultName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#completion_window BackupPlan#completion_window}.
CompletionWindow *float64 `field:"optional" json:"completionWindow" yaml:"completionWindow"`
// copy_action block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#copy_action BackupPlan#copy_action}
CopyAction interface{} `field:"optional" json:"copyAction" yaml:"copyAction"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#enable_continuous_backup BackupPlan#enable_continuous_backup}.
EnableContinuousBackup interface{} `field:"optional" json:"enableContinuousBackup" yaml:"enableContinuousBackup"`
// lifecycle block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#lifecycle BackupPlan#lifecycle}
Lifecycle *BackupPlanRuleLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#recovery_point_tags BackupPlan#recovery_point_tags}.
RecoveryPointTags *map[string]*string `field:"optional" json:"recoveryPointTags" yaml:"recoveryPointTags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#schedule BackupPlan#schedule}.
Schedule *string `field:"optional" json:"schedule" yaml:"schedule"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#start_window BackupPlan#start_window}.
StartWindow *float64 `field:"optional" json:"startWindow" yaml:"startWindow"`
}
type BackupPlanRuleCopyAction ¶
type BackupPlanRuleCopyAction struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#destination_vault_arn BackupPlan#destination_vault_arn}.
DestinationVaultArn *string `field:"required" json:"destinationVaultArn" yaml:"destinationVaultArn"`
// lifecycle block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#lifecycle BackupPlan#lifecycle}
Lifecycle *BackupPlanRuleCopyActionLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
}
type BackupPlanRuleCopyActionLifecycle ¶
type BackupPlanRuleCopyActionLifecycle struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#cold_storage_after BackupPlan#cold_storage_after}.
ColdStorageAfter *float64 `field:"optional" json:"coldStorageAfter" yaml:"coldStorageAfter"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#delete_after BackupPlan#delete_after}.
DeleteAfter *float64 `field:"optional" json:"deleteAfter" yaml:"deleteAfter"`
}
type BackupPlanRuleCopyActionLifecycleOutputReference ¶
type BackupPlanRuleCopyActionLifecycleOutputReference interface {
cdktf.ComplexObject
ColdStorageAfter() *float64
SetColdStorageAfter(val *float64)
ColdStorageAfterInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeleteAfter() *float64
SetDeleteAfter(val *float64)
DeleteAfterInput() *float64
// Experimental.
Fqn() *string
InternalValue() *BackupPlanRuleCopyActionLifecycle
SetInternalValue(val *BackupPlanRuleCopyActionLifecycle)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetColdStorageAfter()
ResetDeleteAfter()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupPlanRuleCopyActionLifecycleOutputReference ¶
func NewBackupPlanRuleCopyActionLifecycleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BackupPlanRuleCopyActionLifecycleOutputReference
type BackupPlanRuleCopyActionList ¶
type BackupPlanRuleCopyActionList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) BackupPlanRuleCopyActionOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupPlanRuleCopyActionList ¶
func NewBackupPlanRuleCopyActionList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) BackupPlanRuleCopyActionList
type BackupPlanRuleCopyActionOutputReference ¶
type BackupPlanRuleCopyActionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DestinationVaultArn() *string
SetDestinationVaultArn(val *string)
DestinationVaultArnInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Lifecycle() BackupPlanRuleCopyActionLifecycleOutputReference
LifecycleInput() *BackupPlanRuleCopyActionLifecycle
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutLifecycle(value *BackupPlanRuleCopyActionLifecycle)
ResetLifecycle()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupPlanRuleCopyActionOutputReference ¶
func NewBackupPlanRuleCopyActionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) BackupPlanRuleCopyActionOutputReference
type BackupPlanRuleLifecycle ¶
type BackupPlanRuleLifecycle struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#cold_storage_after BackupPlan#cold_storage_after}.
ColdStorageAfter *float64 `field:"optional" json:"coldStorageAfter" yaml:"coldStorageAfter"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/backup_plan#delete_after BackupPlan#delete_after}.
DeleteAfter *float64 `field:"optional" json:"deleteAfter" yaml:"deleteAfter"`
}
type BackupPlanRuleLifecycleOutputReference ¶
type BackupPlanRuleLifecycleOutputReference interface {
cdktf.ComplexObject
ColdStorageAfter() *float64
SetColdStorageAfter(val *float64)
ColdStorageAfterInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeleteAfter() *float64
SetDeleteAfter(val *float64)
DeleteAfterInput() *float64
// Experimental.
Fqn() *string
InternalValue() *BackupPlanRuleLifecycle
SetInternalValue(val *BackupPlanRuleLifecycle)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetColdStorageAfter()
ResetDeleteAfter()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupPlanRuleLifecycleOutputReference ¶
func NewBackupPlanRuleLifecycleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) BackupPlanRuleLifecycleOutputReference
type BackupPlanRuleList ¶
type BackupPlanRuleList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) BackupPlanRuleOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupPlanRuleList ¶
func NewBackupPlanRuleList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) BackupPlanRuleList
type BackupPlanRuleOutputReference ¶
type BackupPlanRuleOutputReference interface {
cdktf.ComplexObject
CompletionWindow() *float64
SetCompletionWindow(val *float64)
CompletionWindowInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CopyAction() BackupPlanRuleCopyActionList
CopyActionInput() interface{}
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EnableContinuousBackup() interface{}
SetEnableContinuousBackup(val interface{})
EnableContinuousBackupInput() interface{}
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Lifecycle() BackupPlanRuleLifecycleOutputReference
LifecycleInput() *BackupPlanRuleLifecycle
RecoveryPointTags() *map[string]*string
SetRecoveryPointTags(val *map[string]*string)
RecoveryPointTagsInput() *map[string]*string
RuleName() *string
SetRuleName(val *string)
RuleNameInput() *string
Schedule() *string
SetSchedule(val *string)
ScheduleInput() *string
StartWindow() *float64
SetStartWindow(val *float64)
StartWindowInput() *float64
TargetVaultName() *string
SetTargetVaultName(val *string)
TargetVaultNameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutCopyAction(value interface{})
PutLifecycle(value *BackupPlanRuleLifecycle)
ResetCompletionWindow()
ResetCopyAction()
ResetEnableContinuousBackup()
ResetLifecycle()
ResetRecoveryPointTags()
ResetSchedule()
ResetStartWindow()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewBackupPlanRuleOutputReference ¶
func NewBackupPlanRuleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) BackupPlanRuleOutputReference
Source Files
¶
- BackupPlan.go
- BackupPlanAdvancedBackupSetting.go
- BackupPlanAdvancedBackupSettingList.go
- BackupPlanAdvancedBackupSettingList__checks.go
- BackupPlanAdvancedBackupSettingOutputReference.go
- BackupPlanAdvancedBackupSettingOutputReference__checks.go
- BackupPlanConfig.go
- BackupPlanRule.go
- BackupPlanRuleCopyAction.go
- BackupPlanRuleCopyActionLifecycle.go
- BackupPlanRuleCopyActionLifecycleOutputReference.go
- BackupPlanRuleCopyActionLifecycleOutputReference__checks.go
- BackupPlanRuleCopyActionList.go
- BackupPlanRuleCopyActionList__checks.go
- BackupPlanRuleCopyActionOutputReference.go
- BackupPlanRuleCopyActionOutputReference__checks.go
- BackupPlanRuleLifecycle.go
- BackupPlanRuleLifecycleOutputReference.go
- BackupPlanRuleLifecycleOutputReference__checks.go
- BackupPlanRuleList.go
- BackupPlanRuleList__checks.go
- BackupPlanRuleOutputReference.go
- BackupPlanRuleOutputReference__checks.go
- BackupPlan__checks.go
- main.go