Documentation
¶
Index ¶
- func ChimesdkvoiceVoiceProfileDomain_IsConstruct(x interface{}) *bool
- func ChimesdkvoiceVoiceProfileDomain_IsTerraformElement(x interface{}) *bool
- func ChimesdkvoiceVoiceProfileDomain_IsTerraformResource(x interface{}) *bool
- func ChimesdkvoiceVoiceProfileDomain_TfResourceType() *string
- func NewChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfigurationOutputReference_Override(...)
- func NewChimesdkvoiceVoiceProfileDomainTimeoutsOutputReference_Override(c ChimesdkvoiceVoiceProfileDomainTimeoutsOutputReference, ...)
- func NewChimesdkvoiceVoiceProfileDomain_Override(c ChimesdkvoiceVoiceProfileDomain, scope constructs.Construct, id *string, ...)
- type ChimesdkvoiceVoiceProfileDomain
- type ChimesdkvoiceVoiceProfileDomainConfig
- type ChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfiguration
- type ChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfigurationOutputReference
- type ChimesdkvoiceVoiceProfileDomainTimeouts
- type ChimesdkvoiceVoiceProfileDomainTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ChimesdkvoiceVoiceProfileDomain_IsConstruct ¶
func ChimesdkvoiceVoiceProfileDomain_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ChimesdkvoiceVoiceProfileDomain_IsTerraformElement ¶
func ChimesdkvoiceVoiceProfileDomain_IsTerraformElement(x interface{}) *bool
Experimental.
func ChimesdkvoiceVoiceProfileDomain_IsTerraformResource ¶
func ChimesdkvoiceVoiceProfileDomain_IsTerraformResource(x interface{}) *bool
Experimental.
func ChimesdkvoiceVoiceProfileDomain_TfResourceType ¶
func ChimesdkvoiceVoiceProfileDomain_TfResourceType() *string
func NewChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfigurationOutputReference_Override ¶
func NewChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfigurationOutputReference_Override(c ChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewChimesdkvoiceVoiceProfileDomainTimeoutsOutputReference_Override ¶
func NewChimesdkvoiceVoiceProfileDomainTimeoutsOutputReference_Override(c ChimesdkvoiceVoiceProfileDomainTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewChimesdkvoiceVoiceProfileDomain_Override ¶
func NewChimesdkvoiceVoiceProfileDomain_Override(c ChimesdkvoiceVoiceProfileDomain, scope constructs.Construct, id *string, config *ChimesdkvoiceVoiceProfileDomainConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chimesdkvoice_voice_profile_domain aws_chimesdkvoice_voice_profile_domain} Resource.
Types ¶
type ChimesdkvoiceVoiceProfileDomain ¶
type ChimesdkvoiceVoiceProfileDomain interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ServerSideEncryptionConfiguration() ChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfigurationOutputReference
ServerSideEncryptionConfigurationInput() *ChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfiguration
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() ChimesdkvoiceVoiceProfileDomainTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutServerSideEncryptionConfiguration(value *ChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfiguration)
PutTimeouts(value *ChimesdkvoiceVoiceProfileDomainTimeouts)
ResetDescription()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chimesdkvoice_voice_profile_domain aws_chimesdkvoice_voice_profile_domain}.
func NewChimesdkvoiceVoiceProfileDomain ¶
func NewChimesdkvoiceVoiceProfileDomain(scope constructs.Construct, id *string, config *ChimesdkvoiceVoiceProfileDomainConfig) ChimesdkvoiceVoiceProfileDomain
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chimesdkvoice_voice_profile_domain aws_chimesdkvoice_voice_profile_domain} Resource.
type ChimesdkvoiceVoiceProfileDomainConfig ¶
type ChimesdkvoiceVoiceProfileDomainConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chimesdkvoice_voice_profile_domain#name ChimesdkvoiceVoiceProfileDomain#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// server_side_encryption_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chimesdkvoice_voice_profile_domain#server_side_encryption_configuration ChimesdkvoiceVoiceProfileDomain#server_side_encryption_configuration}
ServerSideEncryptionConfiguration *ChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfiguration `field:"required" json:"serverSideEncryptionConfiguration" yaml:"serverSideEncryptionConfiguration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chimesdkvoice_voice_profile_domain#description ChimesdkvoiceVoiceProfileDomain#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chimesdkvoice_voice_profile_domain#tags ChimesdkvoiceVoiceProfileDomain#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chimesdkvoice_voice_profile_domain#tags_all ChimesdkvoiceVoiceProfileDomain#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chimesdkvoice_voice_profile_domain#timeouts ChimesdkvoiceVoiceProfileDomain#timeouts}
Timeouts *ChimesdkvoiceVoiceProfileDomainTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type ChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfiguration ¶
type ChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chimesdkvoice_voice_profile_domain#kms_key_arn ChimesdkvoiceVoiceProfileDomain#kms_key_arn}.
KmsKeyArn *string `field:"required" json:"kmsKeyArn" yaml:"kmsKeyArn"`
}
type ChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfigurationOutputReference ¶
type ChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfiguration
SetInternalValue(val *ChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfiguration)
KmsKeyArn() *string
SetKmsKeyArn(val *string)
KmsKeyArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfigurationOutputReference ¶
func NewChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfigurationOutputReference
type ChimesdkvoiceVoiceProfileDomainTimeouts ¶
type ChimesdkvoiceVoiceProfileDomainTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chimesdkvoice_voice_profile_domain#create ChimesdkvoiceVoiceProfileDomain#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chimesdkvoice_voice_profile_domain#delete ChimesdkvoiceVoiceProfileDomain#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chimesdkvoice_voice_profile_domain#update ChimesdkvoiceVoiceProfileDomain#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type ChimesdkvoiceVoiceProfileDomainTimeoutsOutputReference ¶
type ChimesdkvoiceVoiceProfileDomainTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewChimesdkvoiceVoiceProfileDomainTimeoutsOutputReference ¶
func NewChimesdkvoiceVoiceProfileDomainTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ChimesdkvoiceVoiceProfileDomainTimeoutsOutputReference
Source Files
¶
- ChimesdkvoiceVoiceProfileDomain.go
- ChimesdkvoiceVoiceProfileDomainConfig.go
- ChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfiguration.go
- ChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfigurationOutputReference.go
- ChimesdkvoiceVoiceProfileDomainServerSideEncryptionConfigurationOutputReference__checks.go
- ChimesdkvoiceVoiceProfileDomainTimeouts.go
- ChimesdkvoiceVoiceProfileDomainTimeoutsOutputReference.go
- ChimesdkvoiceVoiceProfileDomainTimeoutsOutputReference__checks.go
- ChimesdkvoiceVoiceProfileDomain__checks.go
- main.go