Documentation
¶
Index ¶
- func ChimeVoiceConnectorStreaming_IsConstruct(x interface{}) *bool
- func ChimeVoiceConnectorStreaming_IsTerraformElement(x interface{}) *bool
- func ChimeVoiceConnectorStreaming_IsTerraformResource(x interface{}) *bool
- func ChimeVoiceConnectorStreaming_TfResourceType() *string
- func NewChimeVoiceConnectorStreamingMediaInsightsConfigurationOutputReference_Override(c ChimeVoiceConnectorStreamingMediaInsightsConfigurationOutputReference, ...)
- func NewChimeVoiceConnectorStreaming_Override(c ChimeVoiceConnectorStreaming, scope constructs.Construct, id *string, ...)
- type ChimeVoiceConnectorStreaming
- type ChimeVoiceConnectorStreamingConfig
- type ChimeVoiceConnectorStreamingMediaInsightsConfiguration
- type ChimeVoiceConnectorStreamingMediaInsightsConfigurationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ChimeVoiceConnectorStreaming_IsConstruct ¶
func ChimeVoiceConnectorStreaming_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ChimeVoiceConnectorStreaming_IsTerraformElement ¶
func ChimeVoiceConnectorStreaming_IsTerraformElement(x interface{}) *bool
Experimental.
func ChimeVoiceConnectorStreaming_IsTerraformResource ¶
func ChimeVoiceConnectorStreaming_IsTerraformResource(x interface{}) *bool
Experimental.
func ChimeVoiceConnectorStreaming_TfResourceType ¶
func ChimeVoiceConnectorStreaming_TfResourceType() *string
func NewChimeVoiceConnectorStreamingMediaInsightsConfigurationOutputReference_Override ¶
func NewChimeVoiceConnectorStreamingMediaInsightsConfigurationOutputReference_Override(c ChimeVoiceConnectorStreamingMediaInsightsConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewChimeVoiceConnectorStreaming_Override ¶
func NewChimeVoiceConnectorStreaming_Override(c ChimeVoiceConnectorStreaming, scope constructs.Construct, id *string, config *ChimeVoiceConnectorStreamingConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chime_voice_connector_streaming aws_chime_voice_connector_streaming} Resource.
Types ¶
type ChimeVoiceConnectorStreaming ¶
type ChimeVoiceConnectorStreaming interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DataRetention() *float64
SetDataRetention(val *float64)
DataRetentionInput() *float64
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Disabled() interface{}
SetDisabled(val interface{})
DisabledInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MediaInsightsConfiguration() ChimeVoiceConnectorStreamingMediaInsightsConfigurationOutputReference
MediaInsightsConfigurationInput() *ChimeVoiceConnectorStreamingMediaInsightsConfiguration
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
StreamingNotificationTargets() *[]*string
SetStreamingNotificationTargets(val *[]*string)
StreamingNotificationTargetsInput() *[]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
VoiceConnectorId() *string
SetVoiceConnectorId(val *string)
VoiceConnectorIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutMediaInsightsConfiguration(value *ChimeVoiceConnectorStreamingMediaInsightsConfiguration)
ResetDisabled()
ResetId()
ResetMediaInsightsConfiguration()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetStreamingNotificationTargets()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chime_voice_connector_streaming aws_chime_voice_connector_streaming}.
func NewChimeVoiceConnectorStreaming ¶
func NewChimeVoiceConnectorStreaming(scope constructs.Construct, id *string, config *ChimeVoiceConnectorStreamingConfig) ChimeVoiceConnectorStreaming
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chime_voice_connector_streaming aws_chime_voice_connector_streaming} Resource.
type ChimeVoiceConnectorStreamingConfig ¶
type ChimeVoiceConnectorStreamingConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chime_voice_connector_streaming#data_retention ChimeVoiceConnectorStreaming#data_retention}.
DataRetention *float64 `field:"required" json:"dataRetention" yaml:"dataRetention"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chime_voice_connector_streaming#voice_connector_id ChimeVoiceConnectorStreaming#voice_connector_id}.
VoiceConnectorId *string `field:"required" json:"voiceConnectorId" yaml:"voiceConnectorId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chime_voice_connector_streaming#disabled ChimeVoiceConnectorStreaming#disabled}.
Disabled interface{} `field:"optional" json:"disabled" yaml:"disabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chime_voice_connector_streaming#id ChimeVoiceConnectorStreaming#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// media_insights_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chime_voice_connector_streaming#media_insights_configuration ChimeVoiceConnectorStreaming#media_insights_configuration}
MediaInsightsConfiguration *ChimeVoiceConnectorStreamingMediaInsightsConfiguration `field:"optional" json:"mediaInsightsConfiguration" yaml:"mediaInsightsConfiguration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chime_voice_connector_streaming#streaming_notification_targets ChimeVoiceConnectorStreaming#streaming_notification_targets}.
StreamingNotificationTargets *[]*string `field:"optional" json:"streamingNotificationTargets" yaml:"streamingNotificationTargets"`
}
type ChimeVoiceConnectorStreamingMediaInsightsConfiguration ¶
type ChimeVoiceConnectorStreamingMediaInsightsConfiguration struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chime_voice_connector_streaming#configuration_arn ChimeVoiceConnectorStreaming#configuration_arn}.
ConfigurationArn *string `field:"optional" json:"configurationArn" yaml:"configurationArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/chime_voice_connector_streaming#disabled ChimeVoiceConnectorStreaming#disabled}.
Disabled interface{} `field:"optional" json:"disabled" yaml:"disabled"`
}
type ChimeVoiceConnectorStreamingMediaInsightsConfigurationOutputReference ¶
type ChimeVoiceConnectorStreamingMediaInsightsConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ConfigurationArn() *string
SetConfigurationArn(val *string)
ConfigurationArnInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Disabled() interface{}
SetDisabled(val interface{})
DisabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *ChimeVoiceConnectorStreamingMediaInsightsConfiguration
SetInternalValue(val *ChimeVoiceConnectorStreamingMediaInsightsConfiguration)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetConfigurationArn()
ResetDisabled()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewChimeVoiceConnectorStreamingMediaInsightsConfigurationOutputReference ¶
func NewChimeVoiceConnectorStreamingMediaInsightsConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ChimeVoiceConnectorStreamingMediaInsightsConfigurationOutputReference
Source Files
¶
- ChimeVoiceConnectorStreaming.go
- ChimeVoiceConnectorStreamingConfig.go
- ChimeVoiceConnectorStreamingMediaInsightsConfiguration.go
- ChimeVoiceConnectorStreamingMediaInsightsConfigurationOutputReference.go
- ChimeVoiceConnectorStreamingMediaInsightsConfigurationOutputReference__checks.go
- ChimeVoiceConnectorStreaming__checks.go
- main.go