Documentation
¶
Index ¶
- func CloudformationType_IsConstruct(x interface{}) *bool
- func CloudformationType_IsTerraformElement(x interface{}) *bool
- func CloudformationType_IsTerraformResource(x interface{}) *bool
- func CloudformationType_TfResourceType() *string
- func NewCloudformationTypeLoggingConfigOutputReference_Override(c CloudformationTypeLoggingConfigOutputReference, ...)
- func NewCloudformationType_Override(c CloudformationType, scope constructs.Construct, id *string, ...)
- type CloudformationType
- type CloudformationTypeConfig
- type CloudformationTypeLoggingConfig
- type CloudformationTypeLoggingConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CloudformationType_IsConstruct ¶
func CloudformationType_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func CloudformationType_IsTerraformElement ¶
func CloudformationType_IsTerraformElement(x interface{}) *bool
Experimental.
func CloudformationType_IsTerraformResource ¶
func CloudformationType_IsTerraformResource(x interface{}) *bool
Experimental.
func CloudformationType_TfResourceType ¶
func CloudformationType_TfResourceType() *string
func NewCloudformationTypeLoggingConfigOutputReference_Override ¶
func NewCloudformationTypeLoggingConfigOutputReference_Override(c CloudformationTypeLoggingConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewCloudformationType_Override ¶
func NewCloudformationType_Override(c CloudformationType, scope constructs.Construct, id *string, config *CloudformationTypeConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/cloudformation_type aws_cloudformation_type} Resource.
Types ¶
type CloudformationType ¶
type CloudformationType interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DefaultVersionId() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeprecatedStatus() *string
Description() *string
DocumentationUrl() *string
ExecutionRoleArn() *string
SetExecutionRoleArn(val *string)
ExecutionRoleArnInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IsDefaultVersion() cdktf.IResolvable
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LoggingConfig() CloudformationTypeLoggingConfigOutputReference
LoggingConfigInput() *CloudformationTypeLoggingConfig
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
ProvisioningType() *string
// Experimental.
RawOverrides() interface{}
Schema() *string
SchemaHandlerPackage() *string
SetSchemaHandlerPackage(val *string)
SchemaHandlerPackageInput() *string
SourceUrl() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Type() *string
SetType(val *string)
TypeArn() *string
TypeInput() *string
TypeName() *string
SetTypeName(val *string)
TypeNameInput() *string
VersionId() *string
Visibility() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutLoggingConfig(value *CloudformationTypeLoggingConfig)
ResetExecutionRoleArn()
ResetId()
ResetLoggingConfig()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetType()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/cloudformation_type aws_cloudformation_type}.
func NewCloudformationType ¶
func NewCloudformationType(scope constructs.Construct, id *string, config *CloudformationTypeConfig) CloudformationType
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/cloudformation_type aws_cloudformation_type} Resource.
type CloudformationTypeConfig ¶
type CloudformationTypeConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/cloudformation_type#schema_handler_package CloudformationType#schema_handler_package}.
SchemaHandlerPackage *string `field:"required" json:"schemaHandlerPackage" yaml:"schemaHandlerPackage"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/cloudformation_type#type_name CloudformationType#type_name}.
TypeName *string `field:"required" json:"typeName" yaml:"typeName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/cloudformation_type#execution_role_arn CloudformationType#execution_role_arn}.
ExecutionRoleArn *string `field:"optional" json:"executionRoleArn" yaml:"executionRoleArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/cloudformation_type#id CloudformationType#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// logging_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/cloudformation_type#logging_config CloudformationType#logging_config}
LoggingConfig *CloudformationTypeLoggingConfig `field:"optional" json:"loggingConfig" yaml:"loggingConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/cloudformation_type#type CloudformationType#type}.
Type *string `field:"optional" json:"type" yaml:"type"`
}
type CloudformationTypeLoggingConfig ¶
type CloudformationTypeLoggingConfig struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/cloudformation_type#log_group_name CloudformationType#log_group_name}.
LogGroupName *string `field:"required" json:"logGroupName" yaml:"logGroupName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/cloudformation_type#log_role_arn CloudformationType#log_role_arn}.
LogRoleArn *string `field:"required" json:"logRoleArn" yaml:"logRoleArn"`
}
type CloudformationTypeLoggingConfigOutputReference ¶
type CloudformationTypeLoggingConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *CloudformationTypeLoggingConfig
SetInternalValue(val *CloudformationTypeLoggingConfig)
LogGroupName() *string
SetLogGroupName(val *string)
LogGroupNameInput() *string
LogRoleArn() *string
SetLogRoleArn(val *string)
LogRoleArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewCloudformationTypeLoggingConfigOutputReference ¶
func NewCloudformationTypeLoggingConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) CloudformationTypeLoggingConfigOutputReference