Documentation
¶
Index ¶
- func DaxCluster_IsConstruct(x interface{}) *bool
- func DaxCluster_IsTerraformElement(x interface{}) *bool
- func DaxCluster_IsTerraformResource(x interface{}) *bool
- func DaxCluster_TfResourceType() *string
- func NewDaxClusterNodesList_Override(d DaxClusterNodesList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewDaxClusterNodesOutputReference_Override(d DaxClusterNodesOutputReference, terraformResource cdktf.IInterpolatingParent, ...)
- func NewDaxClusterServerSideEncryptionOutputReference_Override(d DaxClusterServerSideEncryptionOutputReference, ...)
- func NewDaxClusterTimeoutsOutputReference_Override(d DaxClusterTimeoutsOutputReference, ...)
- func NewDaxCluster_Override(d DaxCluster, scope constructs.Construct, id *string, config *DaxClusterConfig)
- type DaxCluster
- type DaxClusterConfig
- type DaxClusterNodes
- type DaxClusterNodesList
- type DaxClusterNodesOutputReference
- type DaxClusterServerSideEncryption
- type DaxClusterServerSideEncryptionOutputReference
- type DaxClusterTimeouts
- type DaxClusterTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DaxCluster_IsConstruct ¶
func DaxCluster_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DaxCluster_IsTerraformElement ¶
func DaxCluster_IsTerraformElement(x interface{}) *bool
Experimental.
func DaxCluster_IsTerraformResource ¶
func DaxCluster_IsTerraformResource(x interface{}) *bool
Experimental.
func DaxCluster_TfResourceType ¶
func DaxCluster_TfResourceType() *string
func NewDaxClusterNodesList_Override ¶
func NewDaxClusterNodesList_Override(d DaxClusterNodesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDaxClusterNodesOutputReference_Override ¶
func NewDaxClusterNodesOutputReference_Override(d DaxClusterNodesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDaxClusterServerSideEncryptionOutputReference_Override ¶
func NewDaxClusterServerSideEncryptionOutputReference_Override(d DaxClusterServerSideEncryptionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDaxClusterTimeoutsOutputReference_Override ¶
func NewDaxClusterTimeoutsOutputReference_Override(d DaxClusterTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewDaxCluster_Override ¶
func NewDaxCluster_Override(d DaxCluster, scope constructs.Construct, id *string, config *DaxClusterConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster aws_dax_cluster} Resource.
Types ¶
type DaxCluster ¶
type DaxCluster interface {
cdktf.TerraformResource
Arn() *string
AvailabilityZones() *[]*string
SetAvailabilityZones(val *[]*string)
AvailabilityZonesInput() *[]*string
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterAddress() *string
ClusterEndpointEncryptionType() *string
SetClusterEndpointEncryptionType(val *string)
ClusterEndpointEncryptionTypeInput() *string
ClusterName() *string
SetClusterName(val *string)
ClusterNameInput() *string
ConfigurationEndpoint() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
IamRoleArn() *string
SetIamRoleArn(val *string)
IamRoleArnInput() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaintenanceWindow() *string
SetMaintenanceWindow(val *string)
MaintenanceWindowInput() *string
// The tree node.
Node() constructs.Node
Nodes() DaxClusterNodesList
NodeType() *string
SetNodeType(val *string)
NodeTypeInput() *string
NotificationTopicArn() *string
SetNotificationTopicArn(val *string)
NotificationTopicArnInput() *string
ParameterGroupName() *string
SetParameterGroupName(val *string)
ParameterGroupNameInput() *string
Port() *float64
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ReplicationFactor() *float64
SetReplicationFactor(val *float64)
ReplicationFactorInput() *float64
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
ServerSideEncryption() DaxClusterServerSideEncryptionOutputReference
ServerSideEncryptionInput() *DaxClusterServerSideEncryption
SubnetGroupName() *string
SetSubnetGroupName(val *string)
SubnetGroupNameInput() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() DaxClusterTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutServerSideEncryption(value *DaxClusterServerSideEncryption)
PutTimeouts(value *DaxClusterTimeouts)
ResetAvailabilityZones()
ResetClusterEndpointEncryptionType()
ResetDescription()
ResetId()
ResetMaintenanceWindow()
ResetNotificationTopicArn()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetParameterGroupName()
ResetSecurityGroupIds()
ResetServerSideEncryption()
ResetSubnetGroupName()
ResetTags()
ResetTagsAll()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster aws_dax_cluster}.
func NewDaxCluster ¶
func NewDaxCluster(scope constructs.Construct, id *string, config *DaxClusterConfig) DaxCluster
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster aws_dax_cluster} Resource.
type DaxClusterConfig ¶
type DaxClusterConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#cluster_name DaxCluster#cluster_name}.
ClusterName *string `field:"required" json:"clusterName" yaml:"clusterName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#iam_role_arn DaxCluster#iam_role_arn}.
IamRoleArn *string `field:"required" json:"iamRoleArn" yaml:"iamRoleArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#node_type DaxCluster#node_type}.
NodeType *string `field:"required" json:"nodeType" yaml:"nodeType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#replication_factor DaxCluster#replication_factor}.
ReplicationFactor *float64 `field:"required" json:"replicationFactor" yaml:"replicationFactor"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#availability_zones DaxCluster#availability_zones}.
AvailabilityZones *[]*string `field:"optional" json:"availabilityZones" yaml:"availabilityZones"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#cluster_endpoint_encryption_type DaxCluster#cluster_endpoint_encryption_type}.
ClusterEndpointEncryptionType *string `field:"optional" json:"clusterEndpointEncryptionType" yaml:"clusterEndpointEncryptionType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#description DaxCluster#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#id DaxCluster#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#maintenance_window DaxCluster#maintenance_window}.
MaintenanceWindow *string `field:"optional" json:"maintenanceWindow" yaml:"maintenanceWindow"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#notification_topic_arn DaxCluster#notification_topic_arn}.
NotificationTopicArn *string `field:"optional" json:"notificationTopicArn" yaml:"notificationTopicArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#parameter_group_name DaxCluster#parameter_group_name}.
ParameterGroupName *string `field:"optional" json:"parameterGroupName" yaml:"parameterGroupName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#security_group_ids DaxCluster#security_group_ids}.
SecurityGroupIds *[]*string `field:"optional" json:"securityGroupIds" yaml:"securityGroupIds"`
// server_side_encryption block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#server_side_encryption DaxCluster#server_side_encryption}
ServerSideEncryption *DaxClusterServerSideEncryption `field:"optional" json:"serverSideEncryption" yaml:"serverSideEncryption"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#subnet_group_name DaxCluster#subnet_group_name}.
SubnetGroupName *string `field:"optional" json:"subnetGroupName" yaml:"subnetGroupName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#tags DaxCluster#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#tags_all DaxCluster#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#timeouts DaxCluster#timeouts}
Timeouts *DaxClusterTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type DaxClusterNodes ¶
type DaxClusterNodes struct {
}
type DaxClusterNodesList ¶
type DaxClusterNodesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DaxClusterNodesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDaxClusterNodesList ¶
func NewDaxClusterNodesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DaxClusterNodesList
type DaxClusterNodesOutputReference ¶
type DaxClusterNodesOutputReference interface {
cdktf.ComplexObject
Address() *string
AvailabilityZone() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *DaxClusterNodes
SetInternalValue(val *DaxClusterNodes)
Port() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDaxClusterNodesOutputReference ¶
func NewDaxClusterNodesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DaxClusterNodesOutputReference
type DaxClusterServerSideEncryption ¶
type DaxClusterServerSideEncryption struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#enabled DaxCluster#enabled}.
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
}
type DaxClusterServerSideEncryptionOutputReference ¶
type DaxClusterServerSideEncryptionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *DaxClusterServerSideEncryption
SetInternalValue(val *DaxClusterServerSideEncryption)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnabled()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDaxClusterServerSideEncryptionOutputReference ¶
func NewDaxClusterServerSideEncryptionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DaxClusterServerSideEncryptionOutputReference
type DaxClusterTimeouts ¶
type DaxClusterTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#create DaxCluster#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#delete DaxCluster#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/dax_cluster#update DaxCluster#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type DaxClusterTimeoutsOutputReference ¶
type DaxClusterTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDaxClusterTimeoutsOutputReference ¶
func NewDaxClusterTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) DaxClusterTimeoutsOutputReference
Source Files
¶
- DaxCluster.go
- DaxClusterConfig.go
- DaxClusterNodes.go
- DaxClusterNodesList.go
- DaxClusterNodesList__checks.go
- DaxClusterNodesOutputReference.go
- DaxClusterNodesOutputReference__checks.go
- DaxClusterServerSideEncryption.go
- DaxClusterServerSideEncryptionOutputReference.go
- DaxClusterServerSideEncryptionOutputReference__checks.go
- DaxClusterTimeouts.go
- DaxClusterTimeoutsOutputReference.go
- DaxClusterTimeoutsOutputReference__checks.go
- DaxCluster__checks.go
- main.go