Documentation
¶
Index ¶
- func EmrInstanceFleet_IsConstruct(x interface{}) *bool
- func EmrInstanceFleet_IsTerraformElement(x interface{}) *bool
- func EmrInstanceFleet_IsTerraformResource(x interface{}) *bool
- func EmrInstanceFleet_TfResourceType() *string
- func NewEmrInstanceFleetInstanceTypeConfigsConfigurationsList_Override(e EmrInstanceFleetInstanceTypeConfigsConfigurationsList, ...)
- func NewEmrInstanceFleetInstanceTypeConfigsConfigurationsOutputReference_Override(e EmrInstanceFleetInstanceTypeConfigsConfigurationsOutputReference, ...)
- func NewEmrInstanceFleetInstanceTypeConfigsEbsConfigList_Override(e EmrInstanceFleetInstanceTypeConfigsEbsConfigList, ...)
- func NewEmrInstanceFleetInstanceTypeConfigsEbsConfigOutputReference_Override(e EmrInstanceFleetInstanceTypeConfigsEbsConfigOutputReference, ...)
- func NewEmrInstanceFleetInstanceTypeConfigsList_Override(e EmrInstanceFleetInstanceTypeConfigsList, ...)
- func NewEmrInstanceFleetInstanceTypeConfigsOutputReference_Override(e EmrInstanceFleetInstanceTypeConfigsOutputReference, ...)
- func NewEmrInstanceFleetLaunchSpecificationsOnDemandSpecificationList_Override(e EmrInstanceFleetLaunchSpecificationsOnDemandSpecificationList, ...)
- func NewEmrInstanceFleetLaunchSpecificationsOnDemandSpecificationOutputReference_Override(e EmrInstanceFleetLaunchSpecificationsOnDemandSpecificationOutputReference, ...)
- func NewEmrInstanceFleetLaunchSpecificationsOutputReference_Override(e EmrInstanceFleetLaunchSpecificationsOutputReference, ...)
- func NewEmrInstanceFleetLaunchSpecificationsSpotSpecificationList_Override(e EmrInstanceFleetLaunchSpecificationsSpotSpecificationList, ...)
- func NewEmrInstanceFleetLaunchSpecificationsSpotSpecificationOutputReference_Override(e EmrInstanceFleetLaunchSpecificationsSpotSpecificationOutputReference, ...)
- func NewEmrInstanceFleet_Override(e EmrInstanceFleet, scope constructs.Construct, id *string, ...)
- type EmrInstanceFleet
- type EmrInstanceFleetConfig
- type EmrInstanceFleetInstanceTypeConfigs
- type EmrInstanceFleetInstanceTypeConfigsConfigurations
- type EmrInstanceFleetInstanceTypeConfigsConfigurationsList
- type EmrInstanceFleetInstanceTypeConfigsConfigurationsOutputReference
- type EmrInstanceFleetInstanceTypeConfigsEbsConfig
- type EmrInstanceFleetInstanceTypeConfigsEbsConfigList
- type EmrInstanceFleetInstanceTypeConfigsEbsConfigOutputReference
- type EmrInstanceFleetInstanceTypeConfigsList
- type EmrInstanceFleetInstanceTypeConfigsOutputReference
- type EmrInstanceFleetLaunchSpecifications
- type EmrInstanceFleetLaunchSpecificationsOnDemandSpecification
- type EmrInstanceFleetLaunchSpecificationsOnDemandSpecificationList
- type EmrInstanceFleetLaunchSpecificationsOnDemandSpecificationOutputReference
- type EmrInstanceFleetLaunchSpecificationsOutputReference
- type EmrInstanceFleetLaunchSpecificationsSpotSpecification
- type EmrInstanceFleetLaunchSpecificationsSpotSpecificationList
- type EmrInstanceFleetLaunchSpecificationsSpotSpecificationOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EmrInstanceFleet_IsConstruct ¶
func EmrInstanceFleet_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func EmrInstanceFleet_IsTerraformElement ¶
func EmrInstanceFleet_IsTerraformElement(x interface{}) *bool
Experimental.
func EmrInstanceFleet_IsTerraformResource ¶
func EmrInstanceFleet_IsTerraformResource(x interface{}) *bool
Experimental.
func EmrInstanceFleet_TfResourceType ¶
func EmrInstanceFleet_TfResourceType() *string
func NewEmrInstanceFleetInstanceTypeConfigsConfigurationsList_Override ¶
func NewEmrInstanceFleetInstanceTypeConfigsConfigurationsList_Override(e EmrInstanceFleetInstanceTypeConfigsConfigurationsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEmrInstanceFleetInstanceTypeConfigsConfigurationsOutputReference_Override ¶
func NewEmrInstanceFleetInstanceTypeConfigsConfigurationsOutputReference_Override(e EmrInstanceFleetInstanceTypeConfigsConfigurationsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEmrInstanceFleetInstanceTypeConfigsEbsConfigList_Override ¶
func NewEmrInstanceFleetInstanceTypeConfigsEbsConfigList_Override(e EmrInstanceFleetInstanceTypeConfigsEbsConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEmrInstanceFleetInstanceTypeConfigsEbsConfigOutputReference_Override ¶
func NewEmrInstanceFleetInstanceTypeConfigsEbsConfigOutputReference_Override(e EmrInstanceFleetInstanceTypeConfigsEbsConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEmrInstanceFleetInstanceTypeConfigsList_Override ¶
func NewEmrInstanceFleetInstanceTypeConfigsList_Override(e EmrInstanceFleetInstanceTypeConfigsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEmrInstanceFleetInstanceTypeConfigsOutputReference_Override ¶
func NewEmrInstanceFleetInstanceTypeConfigsOutputReference_Override(e EmrInstanceFleetInstanceTypeConfigsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEmrInstanceFleetLaunchSpecificationsOnDemandSpecificationList_Override ¶
func NewEmrInstanceFleetLaunchSpecificationsOnDemandSpecificationList_Override(e EmrInstanceFleetLaunchSpecificationsOnDemandSpecificationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEmrInstanceFleetLaunchSpecificationsOnDemandSpecificationOutputReference_Override ¶
func NewEmrInstanceFleetLaunchSpecificationsOnDemandSpecificationOutputReference_Override(e EmrInstanceFleetLaunchSpecificationsOnDemandSpecificationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEmrInstanceFleetLaunchSpecificationsOutputReference_Override ¶
func NewEmrInstanceFleetLaunchSpecificationsOutputReference_Override(e EmrInstanceFleetLaunchSpecificationsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewEmrInstanceFleetLaunchSpecificationsSpotSpecificationList_Override ¶
func NewEmrInstanceFleetLaunchSpecificationsSpotSpecificationList_Override(e EmrInstanceFleetLaunchSpecificationsSpotSpecificationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewEmrInstanceFleetLaunchSpecificationsSpotSpecificationOutputReference_Override ¶
func NewEmrInstanceFleetLaunchSpecificationsSpotSpecificationOutputReference_Override(e EmrInstanceFleetLaunchSpecificationsSpotSpecificationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewEmrInstanceFleet_Override ¶
func NewEmrInstanceFleet_Override(e EmrInstanceFleet, scope constructs.Construct, id *string, config *EmrInstanceFleetConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet aws_emr_instance_fleet} Resource.
Types ¶
type EmrInstanceFleet ¶
type EmrInstanceFleet interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
ClusterId() *string
SetClusterId(val *string)
ClusterIdInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InstanceTypeConfigs() EmrInstanceFleetInstanceTypeConfigsList
InstanceTypeConfigsInput() interface{}
LaunchSpecifications() EmrInstanceFleetLaunchSpecificationsOutputReference
LaunchSpecificationsInput() *EmrInstanceFleetLaunchSpecifications
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
ProvisionedOnDemandCapacity() *float64
ProvisionedSpotCapacity() *float64
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
TargetOnDemandCapacity() *float64
SetTargetOnDemandCapacity(val *float64)
TargetOnDemandCapacityInput() *float64
TargetSpotCapacity() *float64
SetTargetSpotCapacity(val *float64)
TargetSpotCapacityInput() *float64
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutInstanceTypeConfigs(value interface{})
PutLaunchSpecifications(value *EmrInstanceFleetLaunchSpecifications)
ResetId()
ResetInstanceTypeConfigs()
ResetLaunchSpecifications()
ResetName()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTargetOnDemandCapacity()
ResetTargetSpotCapacity()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet aws_emr_instance_fleet}.
func NewEmrInstanceFleet ¶
func NewEmrInstanceFleet(scope constructs.Construct, id *string, config *EmrInstanceFleetConfig) EmrInstanceFleet
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet aws_emr_instance_fleet} Resource.
type EmrInstanceFleetConfig ¶
type EmrInstanceFleetConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#cluster_id EmrInstanceFleet#cluster_id}.
ClusterId *string `field:"required" json:"clusterId" yaml:"clusterId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#id EmrInstanceFleet#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// instance_type_configs block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#instance_type_configs EmrInstanceFleet#instance_type_configs}
InstanceTypeConfigs interface{} `field:"optional" json:"instanceTypeConfigs" yaml:"instanceTypeConfigs"`
// launch_specifications block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#launch_specifications EmrInstanceFleet#launch_specifications}
LaunchSpecifications *EmrInstanceFleetLaunchSpecifications `field:"optional" json:"launchSpecifications" yaml:"launchSpecifications"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#name EmrInstanceFleet#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#target_on_demand_capacity EmrInstanceFleet#target_on_demand_capacity}.
TargetOnDemandCapacity *float64 `field:"optional" json:"targetOnDemandCapacity" yaml:"targetOnDemandCapacity"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#target_spot_capacity EmrInstanceFleet#target_spot_capacity}.
TargetSpotCapacity *float64 `field:"optional" json:"targetSpotCapacity" yaml:"targetSpotCapacity"`
}
type EmrInstanceFleetInstanceTypeConfigs ¶
type EmrInstanceFleetInstanceTypeConfigs struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#instance_type EmrInstanceFleet#instance_type}.
InstanceType *string `field:"required" json:"instanceType" yaml:"instanceType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#bid_price EmrInstanceFleet#bid_price}.
BidPrice *string `field:"optional" json:"bidPrice" yaml:"bidPrice"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#bid_price_as_percentage_of_on_demand_price EmrInstanceFleet#bid_price_as_percentage_of_on_demand_price}.
BidPriceAsPercentageOfOnDemandPrice *float64 `field:"optional" json:"bidPriceAsPercentageOfOnDemandPrice" yaml:"bidPriceAsPercentageOfOnDemandPrice"`
// configurations block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#configurations EmrInstanceFleet#configurations}
Configurations interface{} `field:"optional" json:"configurations" yaml:"configurations"`
// ebs_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#ebs_config EmrInstanceFleet#ebs_config}
EbsConfig interface{} `field:"optional" json:"ebsConfig" yaml:"ebsConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#weighted_capacity EmrInstanceFleet#weighted_capacity}.
WeightedCapacity *float64 `field:"optional" json:"weightedCapacity" yaml:"weightedCapacity"`
}
type EmrInstanceFleetInstanceTypeConfigsConfigurations ¶
type EmrInstanceFleetInstanceTypeConfigsConfigurations struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#classification EmrInstanceFleet#classification}.
Classification *string `field:"optional" json:"classification" yaml:"classification"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#properties EmrInstanceFleet#properties}.
Properties *map[string]*string `field:"optional" json:"properties" yaml:"properties"`
}
type EmrInstanceFleetInstanceTypeConfigsConfigurationsList ¶
type EmrInstanceFleetInstanceTypeConfigsConfigurationsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EmrInstanceFleetInstanceTypeConfigsConfigurationsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrInstanceFleetInstanceTypeConfigsConfigurationsList ¶
func NewEmrInstanceFleetInstanceTypeConfigsConfigurationsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EmrInstanceFleetInstanceTypeConfigsConfigurationsList
type EmrInstanceFleetInstanceTypeConfigsConfigurationsOutputReference ¶
type EmrInstanceFleetInstanceTypeConfigsConfigurationsOutputReference interface {
cdktf.ComplexObject
Classification() *string
SetClassification(val *string)
ClassificationInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Properties() *map[string]*string
SetProperties(val *map[string]*string)
PropertiesInput() *map[string]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetClassification()
ResetProperties()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrInstanceFleetInstanceTypeConfigsConfigurationsOutputReference ¶
func NewEmrInstanceFleetInstanceTypeConfigsConfigurationsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EmrInstanceFleetInstanceTypeConfigsConfigurationsOutputReference
type EmrInstanceFleetInstanceTypeConfigsEbsConfig ¶
type EmrInstanceFleetInstanceTypeConfigsEbsConfig struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#size EmrInstanceFleet#size}.
Size *float64 `field:"required" json:"size" yaml:"size"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#type EmrInstanceFleet#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#iops EmrInstanceFleet#iops}.
Iops *float64 `field:"optional" json:"iops" yaml:"iops"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#volumes_per_instance EmrInstanceFleet#volumes_per_instance}.
VolumesPerInstance *float64 `field:"optional" json:"volumesPerInstance" yaml:"volumesPerInstance"`
}
type EmrInstanceFleetInstanceTypeConfigsEbsConfigList ¶
type EmrInstanceFleetInstanceTypeConfigsEbsConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EmrInstanceFleetInstanceTypeConfigsEbsConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrInstanceFleetInstanceTypeConfigsEbsConfigList ¶
func NewEmrInstanceFleetInstanceTypeConfigsEbsConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EmrInstanceFleetInstanceTypeConfigsEbsConfigList
type EmrInstanceFleetInstanceTypeConfigsEbsConfigOutputReference ¶
type EmrInstanceFleetInstanceTypeConfigsEbsConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Iops() *float64
SetIops(val *float64)
IopsInput() *float64
Size() *float64
SetSize(val *float64)
SizeInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
VolumesPerInstance() *float64
SetVolumesPerInstance(val *float64)
VolumesPerInstanceInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetIops()
ResetVolumesPerInstance()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrInstanceFleetInstanceTypeConfigsEbsConfigOutputReference ¶
func NewEmrInstanceFleetInstanceTypeConfigsEbsConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EmrInstanceFleetInstanceTypeConfigsEbsConfigOutputReference
type EmrInstanceFleetInstanceTypeConfigsList ¶
type EmrInstanceFleetInstanceTypeConfigsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EmrInstanceFleetInstanceTypeConfigsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrInstanceFleetInstanceTypeConfigsList ¶
func NewEmrInstanceFleetInstanceTypeConfigsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EmrInstanceFleetInstanceTypeConfigsList
type EmrInstanceFleetInstanceTypeConfigsOutputReference ¶
type EmrInstanceFleetInstanceTypeConfigsOutputReference interface {
cdktf.ComplexObject
BidPrice() *string
SetBidPrice(val *string)
BidPriceAsPercentageOfOnDemandPrice() *float64
SetBidPriceAsPercentageOfOnDemandPrice(val *float64)
BidPriceAsPercentageOfOnDemandPriceInput() *float64
BidPriceInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Configurations() EmrInstanceFleetInstanceTypeConfigsConfigurationsList
ConfigurationsInput() interface{}
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EbsConfig() EmrInstanceFleetInstanceTypeConfigsEbsConfigList
EbsConfigInput() interface{}
// Experimental.
Fqn() *string
InstanceType() *string
SetInstanceType(val *string)
InstanceTypeInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
WeightedCapacity() *float64
SetWeightedCapacity(val *float64)
WeightedCapacityInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutConfigurations(value interface{})
PutEbsConfig(value interface{})
ResetBidPrice()
ResetBidPriceAsPercentageOfOnDemandPrice()
ResetConfigurations()
ResetEbsConfig()
ResetWeightedCapacity()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrInstanceFleetInstanceTypeConfigsOutputReference ¶
func NewEmrInstanceFleetInstanceTypeConfigsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EmrInstanceFleetInstanceTypeConfigsOutputReference
type EmrInstanceFleetLaunchSpecifications ¶
type EmrInstanceFleetLaunchSpecifications struct {
// on_demand_specification block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#on_demand_specification EmrInstanceFleet#on_demand_specification}
OnDemandSpecification interface{} `field:"optional" json:"onDemandSpecification" yaml:"onDemandSpecification"`
// spot_specification block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#spot_specification EmrInstanceFleet#spot_specification}
SpotSpecification interface{} `field:"optional" json:"spotSpecification" yaml:"spotSpecification"`
}
type EmrInstanceFleetLaunchSpecificationsOnDemandSpecification ¶
type EmrInstanceFleetLaunchSpecificationsOnDemandSpecification struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#allocation_strategy EmrInstanceFleet#allocation_strategy}.
AllocationStrategy *string `field:"required" json:"allocationStrategy" yaml:"allocationStrategy"`
}
type EmrInstanceFleetLaunchSpecificationsOnDemandSpecificationList ¶
type EmrInstanceFleetLaunchSpecificationsOnDemandSpecificationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EmrInstanceFleetLaunchSpecificationsOnDemandSpecificationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrInstanceFleetLaunchSpecificationsOnDemandSpecificationList ¶
func NewEmrInstanceFleetLaunchSpecificationsOnDemandSpecificationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EmrInstanceFleetLaunchSpecificationsOnDemandSpecificationList
type EmrInstanceFleetLaunchSpecificationsOnDemandSpecificationOutputReference ¶
type EmrInstanceFleetLaunchSpecificationsOnDemandSpecificationOutputReference interface {
cdktf.ComplexObject
AllocationStrategy() *string
SetAllocationStrategy(val *string)
AllocationStrategyInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrInstanceFleetLaunchSpecificationsOnDemandSpecificationOutputReference ¶
func NewEmrInstanceFleetLaunchSpecificationsOnDemandSpecificationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EmrInstanceFleetLaunchSpecificationsOnDemandSpecificationOutputReference
type EmrInstanceFleetLaunchSpecificationsOutputReference ¶
type EmrInstanceFleetLaunchSpecificationsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *EmrInstanceFleetLaunchSpecifications
SetInternalValue(val *EmrInstanceFleetLaunchSpecifications)
OnDemandSpecification() EmrInstanceFleetLaunchSpecificationsOnDemandSpecificationList
OnDemandSpecificationInput() interface{}
SpotSpecification() EmrInstanceFleetLaunchSpecificationsSpotSpecificationList
SpotSpecificationInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutOnDemandSpecification(value interface{})
PutSpotSpecification(value interface{})
ResetOnDemandSpecification()
ResetSpotSpecification()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrInstanceFleetLaunchSpecificationsOutputReference ¶
func NewEmrInstanceFleetLaunchSpecificationsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) EmrInstanceFleetLaunchSpecificationsOutputReference
type EmrInstanceFleetLaunchSpecificationsSpotSpecification ¶
type EmrInstanceFleetLaunchSpecificationsSpotSpecification struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#allocation_strategy EmrInstanceFleet#allocation_strategy}.
AllocationStrategy *string `field:"required" json:"allocationStrategy" yaml:"allocationStrategy"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#timeout_action EmrInstanceFleet#timeout_action}.
TimeoutAction *string `field:"required" json:"timeoutAction" yaml:"timeoutAction"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#timeout_duration_minutes EmrInstanceFleet#timeout_duration_minutes}.
TimeoutDurationMinutes *float64 `field:"required" json:"timeoutDurationMinutes" yaml:"timeoutDurationMinutes"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/emr_instance_fleet#block_duration_minutes EmrInstanceFleet#block_duration_minutes}.
BlockDurationMinutes *float64 `field:"optional" json:"blockDurationMinutes" yaml:"blockDurationMinutes"`
}
type EmrInstanceFleetLaunchSpecificationsSpotSpecificationList ¶
type EmrInstanceFleetLaunchSpecificationsSpotSpecificationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) EmrInstanceFleetLaunchSpecificationsSpotSpecificationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrInstanceFleetLaunchSpecificationsSpotSpecificationList ¶
func NewEmrInstanceFleetLaunchSpecificationsSpotSpecificationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) EmrInstanceFleetLaunchSpecificationsSpotSpecificationList
type EmrInstanceFleetLaunchSpecificationsSpotSpecificationOutputReference ¶
type EmrInstanceFleetLaunchSpecificationsSpotSpecificationOutputReference interface {
cdktf.ComplexObject
AllocationStrategy() *string
SetAllocationStrategy(val *string)
AllocationStrategyInput() *string
BlockDurationMinutes() *float64
SetBlockDurationMinutes(val *float64)
BlockDurationMinutesInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TimeoutAction() *string
SetTimeoutAction(val *string)
TimeoutActionInput() *string
TimeoutDurationMinutes() *float64
SetTimeoutDurationMinutes(val *float64)
TimeoutDurationMinutesInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBlockDurationMinutes()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewEmrInstanceFleetLaunchSpecificationsSpotSpecificationOutputReference ¶
func NewEmrInstanceFleetLaunchSpecificationsSpotSpecificationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) EmrInstanceFleetLaunchSpecificationsSpotSpecificationOutputReference
Source Files
¶
- EmrInstanceFleet.go
- EmrInstanceFleetConfig.go
- EmrInstanceFleetInstanceTypeConfigs.go
- EmrInstanceFleetInstanceTypeConfigsConfigurations.go
- EmrInstanceFleetInstanceTypeConfigsConfigurationsList.go
- EmrInstanceFleetInstanceTypeConfigsConfigurationsList__checks.go
- EmrInstanceFleetInstanceTypeConfigsConfigurationsOutputReference.go
- EmrInstanceFleetInstanceTypeConfigsConfigurationsOutputReference__checks.go
- EmrInstanceFleetInstanceTypeConfigsEbsConfig.go
- EmrInstanceFleetInstanceTypeConfigsEbsConfigList.go
- EmrInstanceFleetInstanceTypeConfigsEbsConfigList__checks.go
- EmrInstanceFleetInstanceTypeConfigsEbsConfigOutputReference.go
- EmrInstanceFleetInstanceTypeConfigsEbsConfigOutputReference__checks.go
- EmrInstanceFleetInstanceTypeConfigsList.go
- EmrInstanceFleetInstanceTypeConfigsList__checks.go
- EmrInstanceFleetInstanceTypeConfigsOutputReference.go
- EmrInstanceFleetInstanceTypeConfigsOutputReference__checks.go
- EmrInstanceFleetLaunchSpecifications.go
- EmrInstanceFleetLaunchSpecificationsOnDemandSpecification.go
- EmrInstanceFleetLaunchSpecificationsOnDemandSpecificationList.go
- EmrInstanceFleetLaunchSpecificationsOnDemandSpecificationList__checks.go
- EmrInstanceFleetLaunchSpecificationsOnDemandSpecificationOutputReference.go
- EmrInstanceFleetLaunchSpecificationsOnDemandSpecificationOutputReference__checks.go
- EmrInstanceFleetLaunchSpecificationsOutputReference.go
- EmrInstanceFleetLaunchSpecificationsOutputReference__checks.go
- EmrInstanceFleetLaunchSpecificationsSpotSpecification.go
- EmrInstanceFleetLaunchSpecificationsSpotSpecificationList.go
- EmrInstanceFleetLaunchSpecificationsSpotSpecificationList__checks.go
- EmrInstanceFleetLaunchSpecificationsSpotSpecificationOutputReference.go
- EmrInstanceFleetLaunchSpecificationsSpotSpecificationOutputReference__checks.go
- EmrInstanceFleet__checks.go
- main.go