Documentation
¶
Index ¶
- func LaunchConfiguration_IsConstruct(x interface{}) *bool
- func LaunchConfiguration_IsTerraformElement(x interface{}) *bool
- func LaunchConfiguration_IsTerraformResource(x interface{}) *bool
- func LaunchConfiguration_TfResourceType() *string
- func NewLaunchConfigurationEbsBlockDeviceList_Override(l LaunchConfigurationEbsBlockDeviceList, ...)
- func NewLaunchConfigurationEbsBlockDeviceOutputReference_Override(l LaunchConfigurationEbsBlockDeviceOutputReference, ...)
- func NewLaunchConfigurationEphemeralBlockDeviceList_Override(l LaunchConfigurationEphemeralBlockDeviceList, ...)
- func NewLaunchConfigurationEphemeralBlockDeviceOutputReference_Override(l LaunchConfigurationEphemeralBlockDeviceOutputReference, ...)
- func NewLaunchConfigurationMetadataOptionsOutputReference_Override(l LaunchConfigurationMetadataOptionsOutputReference, ...)
- func NewLaunchConfigurationRootBlockDeviceOutputReference_Override(l LaunchConfigurationRootBlockDeviceOutputReference, ...)
- func NewLaunchConfiguration_Override(l LaunchConfiguration, scope constructs.Construct, id *string, ...)
- type LaunchConfiguration
- type LaunchConfigurationConfig
- type LaunchConfigurationEbsBlockDevice
- type LaunchConfigurationEbsBlockDeviceList
- type LaunchConfigurationEbsBlockDeviceOutputReference
- type LaunchConfigurationEphemeralBlockDevice
- type LaunchConfigurationEphemeralBlockDeviceList
- type LaunchConfigurationEphemeralBlockDeviceOutputReference
- type LaunchConfigurationMetadataOptions
- type LaunchConfigurationMetadataOptionsOutputReference
- type LaunchConfigurationRootBlockDevice
- type LaunchConfigurationRootBlockDeviceOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LaunchConfiguration_IsConstruct ¶
func LaunchConfiguration_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func LaunchConfiguration_IsTerraformElement ¶
func LaunchConfiguration_IsTerraformElement(x interface{}) *bool
Experimental.
func LaunchConfiguration_IsTerraformResource ¶
func LaunchConfiguration_IsTerraformResource(x interface{}) *bool
Experimental.
func LaunchConfiguration_TfResourceType ¶
func LaunchConfiguration_TfResourceType() *string
func NewLaunchConfigurationEbsBlockDeviceList_Override ¶
func NewLaunchConfigurationEbsBlockDeviceList_Override(l LaunchConfigurationEbsBlockDeviceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewLaunchConfigurationEbsBlockDeviceOutputReference_Override ¶
func NewLaunchConfigurationEbsBlockDeviceOutputReference_Override(l LaunchConfigurationEbsBlockDeviceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewLaunchConfigurationEphemeralBlockDeviceList_Override ¶
func NewLaunchConfigurationEphemeralBlockDeviceList_Override(l LaunchConfigurationEphemeralBlockDeviceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewLaunchConfigurationEphemeralBlockDeviceOutputReference_Override ¶
func NewLaunchConfigurationEphemeralBlockDeviceOutputReference_Override(l LaunchConfigurationEphemeralBlockDeviceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewLaunchConfigurationMetadataOptionsOutputReference_Override ¶
func NewLaunchConfigurationMetadataOptionsOutputReference_Override(l LaunchConfigurationMetadataOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLaunchConfigurationRootBlockDeviceOutputReference_Override ¶
func NewLaunchConfigurationRootBlockDeviceOutputReference_Override(l LaunchConfigurationRootBlockDeviceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLaunchConfiguration_Override ¶
func NewLaunchConfiguration_Override(l LaunchConfiguration, scope constructs.Construct, id *string, config *LaunchConfigurationConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration aws_launch_configuration} Resource.
Types ¶
type LaunchConfiguration ¶
type LaunchConfiguration interface {
cdktf.TerraformResource
Arn() *string
AssociatePublicIpAddress() interface{}
SetAssociatePublicIpAddress(val interface{})
AssociatePublicIpAddressInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EbsBlockDevice() LaunchConfigurationEbsBlockDeviceList
EbsBlockDeviceInput() interface{}
EbsOptimized() interface{}
SetEbsOptimized(val interface{})
EbsOptimizedInput() interface{}
EnableMonitoring() interface{}
SetEnableMonitoring(val interface{})
EnableMonitoringInput() interface{}
EphemeralBlockDevice() LaunchConfigurationEphemeralBlockDeviceList
EphemeralBlockDeviceInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
IamInstanceProfile() *string
SetIamInstanceProfile(val *string)
IamInstanceProfileInput() *string
Id() *string
SetId(val *string)
IdInput() *string
ImageId() *string
SetImageId(val *string)
ImageIdInput() *string
InstanceType() *string
SetInstanceType(val *string)
InstanceTypeInput() *string
KeyName() *string
SetKeyName(val *string)
KeyNameInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MetadataOptions() LaunchConfigurationMetadataOptionsOutputReference
MetadataOptionsInput() *LaunchConfigurationMetadataOptions
Name() *string
SetName(val *string)
NameInput() *string
NamePrefix() *string
SetNamePrefix(val *string)
NamePrefixInput() *string
// The tree node.
Node() constructs.Node
PlacementTenancy() *string
SetPlacementTenancy(val *string)
PlacementTenancyInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RootBlockDevice() LaunchConfigurationRootBlockDeviceOutputReference
RootBlockDeviceInput() *LaunchConfigurationRootBlockDevice
SecurityGroups() *[]*string
SetSecurityGroups(val *[]*string)
SecurityGroupsInput() *[]*string
SpotPrice() *string
SetSpotPrice(val *string)
SpotPriceInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
UserData() *string
SetUserData(val *string)
UserDataBase64() *string
SetUserDataBase64(val *string)
UserDataBase64Input() *string
UserDataInput() *string
VpcClassicLinkId() *string
SetVpcClassicLinkId(val *string)
VpcClassicLinkIdInput() *string
VpcClassicLinkSecurityGroups() *[]*string
SetVpcClassicLinkSecurityGroups(val *[]*string)
VpcClassicLinkSecurityGroupsInput() *[]*string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutEbsBlockDevice(value interface{})
PutEphemeralBlockDevice(value interface{})
PutMetadataOptions(value *LaunchConfigurationMetadataOptions)
PutRootBlockDevice(value *LaunchConfigurationRootBlockDevice)
ResetAssociatePublicIpAddress()
ResetEbsBlockDevice()
ResetEbsOptimized()
ResetEnableMonitoring()
ResetEphemeralBlockDevice()
ResetIamInstanceProfile()
ResetId()
ResetKeyName()
ResetMetadataOptions()
ResetName()
ResetNamePrefix()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPlacementTenancy()
ResetRootBlockDevice()
ResetSecurityGroups()
ResetSpotPrice()
ResetUserData()
ResetUserDataBase64()
ResetVpcClassicLinkId()
ResetVpcClassicLinkSecurityGroups()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration aws_launch_configuration}.
func NewLaunchConfiguration ¶
func NewLaunchConfiguration(scope constructs.Construct, id *string, config *LaunchConfigurationConfig) LaunchConfiguration
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration aws_launch_configuration} Resource.
type LaunchConfigurationConfig ¶
type LaunchConfigurationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#image_id LaunchConfiguration#image_id}.
ImageId *string `field:"required" json:"imageId" yaml:"imageId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#instance_type LaunchConfiguration#instance_type}.
InstanceType *string `field:"required" json:"instanceType" yaml:"instanceType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#associate_public_ip_address LaunchConfiguration#associate_public_ip_address}.
AssociatePublicIpAddress interface{} `field:"optional" json:"associatePublicIpAddress" yaml:"associatePublicIpAddress"`
// ebs_block_device block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#ebs_block_device LaunchConfiguration#ebs_block_device}
EbsBlockDevice interface{} `field:"optional" json:"ebsBlockDevice" yaml:"ebsBlockDevice"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#ebs_optimized LaunchConfiguration#ebs_optimized}.
EbsOptimized interface{} `field:"optional" json:"ebsOptimized" yaml:"ebsOptimized"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#enable_monitoring LaunchConfiguration#enable_monitoring}.
EnableMonitoring interface{} `field:"optional" json:"enableMonitoring" yaml:"enableMonitoring"`
// ephemeral_block_device block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#ephemeral_block_device LaunchConfiguration#ephemeral_block_device}
EphemeralBlockDevice interface{} `field:"optional" json:"ephemeralBlockDevice" yaml:"ephemeralBlockDevice"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#iam_instance_profile LaunchConfiguration#iam_instance_profile}.
IamInstanceProfile *string `field:"optional" json:"iamInstanceProfile" yaml:"iamInstanceProfile"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#id LaunchConfiguration#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#key_name LaunchConfiguration#key_name}.
KeyName *string `field:"optional" json:"keyName" yaml:"keyName"`
// metadata_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#metadata_options LaunchConfiguration#metadata_options}
MetadataOptions *LaunchConfigurationMetadataOptions `field:"optional" json:"metadataOptions" yaml:"metadataOptions"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#name LaunchConfiguration#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#name_prefix LaunchConfiguration#name_prefix}.
NamePrefix *string `field:"optional" json:"namePrefix" yaml:"namePrefix"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#placement_tenancy LaunchConfiguration#placement_tenancy}.
PlacementTenancy *string `field:"optional" json:"placementTenancy" yaml:"placementTenancy"`
// root_block_device block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#root_block_device LaunchConfiguration#root_block_device}
RootBlockDevice *LaunchConfigurationRootBlockDevice `field:"optional" json:"rootBlockDevice" yaml:"rootBlockDevice"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#security_groups LaunchConfiguration#security_groups}.
SecurityGroups *[]*string `field:"optional" json:"securityGroups" yaml:"securityGroups"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#spot_price LaunchConfiguration#spot_price}.
SpotPrice *string `field:"optional" json:"spotPrice" yaml:"spotPrice"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#user_data LaunchConfiguration#user_data}.
UserData *string `field:"optional" json:"userData" yaml:"userData"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#user_data_base64 LaunchConfiguration#user_data_base64}.
UserDataBase64 *string `field:"optional" json:"userDataBase64" yaml:"userDataBase64"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#vpc_classic_link_id LaunchConfiguration#vpc_classic_link_id}.
VpcClassicLinkId *string `field:"optional" json:"vpcClassicLinkId" yaml:"vpcClassicLinkId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#vpc_classic_link_security_groups LaunchConfiguration#vpc_classic_link_security_groups}.
VpcClassicLinkSecurityGroups *[]*string `field:"optional" json:"vpcClassicLinkSecurityGroups" yaml:"vpcClassicLinkSecurityGroups"`
}
type LaunchConfigurationEbsBlockDevice ¶
type LaunchConfigurationEbsBlockDevice struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#device_name LaunchConfiguration#device_name}.
DeviceName *string `field:"required" json:"deviceName" yaml:"deviceName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#delete_on_termination LaunchConfiguration#delete_on_termination}.
DeleteOnTermination interface{} `field:"optional" json:"deleteOnTermination" yaml:"deleteOnTermination"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#encrypted LaunchConfiguration#encrypted}.
Encrypted interface{} `field:"optional" json:"encrypted" yaml:"encrypted"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#iops LaunchConfiguration#iops}.
Iops *float64 `field:"optional" json:"iops" yaml:"iops"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#no_device LaunchConfiguration#no_device}.
NoDevice interface{} `field:"optional" json:"noDevice" yaml:"noDevice"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#snapshot_id LaunchConfiguration#snapshot_id}.
SnapshotId *string `field:"optional" json:"snapshotId" yaml:"snapshotId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#throughput LaunchConfiguration#throughput}.
Throughput *float64 `field:"optional" json:"throughput" yaml:"throughput"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#volume_size LaunchConfiguration#volume_size}.
VolumeSize *float64 `field:"optional" json:"volumeSize" yaml:"volumeSize"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#volume_type LaunchConfiguration#volume_type}.
VolumeType *string `field:"optional" json:"volumeType" yaml:"volumeType"`
}
type LaunchConfigurationEbsBlockDeviceList ¶
type LaunchConfigurationEbsBlockDeviceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) LaunchConfigurationEbsBlockDeviceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLaunchConfigurationEbsBlockDeviceList ¶
func NewLaunchConfigurationEbsBlockDeviceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) LaunchConfigurationEbsBlockDeviceList
type LaunchConfigurationEbsBlockDeviceOutputReference ¶
type LaunchConfigurationEbsBlockDeviceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeleteOnTermination() interface{}
SetDeleteOnTermination(val interface{})
DeleteOnTerminationInput() interface{}
DeviceName() *string
SetDeviceName(val *string)
DeviceNameInput() *string
Encrypted() interface{}
SetEncrypted(val interface{})
EncryptedInput() interface{}
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Iops() *float64
SetIops(val *float64)
IopsInput() *float64
NoDevice() interface{}
SetNoDevice(val interface{})
NoDeviceInput() interface{}
SnapshotId() *string
SetSnapshotId(val *string)
SnapshotIdInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Throughput() *float64
SetThroughput(val *float64)
ThroughputInput() *float64
VolumeSize() *float64
SetVolumeSize(val *float64)
VolumeSizeInput() *float64
VolumeType() *string
SetVolumeType(val *string)
VolumeTypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDeleteOnTermination()
ResetEncrypted()
ResetIops()
ResetNoDevice()
ResetSnapshotId()
ResetThroughput()
ResetVolumeSize()
ResetVolumeType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLaunchConfigurationEbsBlockDeviceOutputReference ¶
func NewLaunchConfigurationEbsBlockDeviceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) LaunchConfigurationEbsBlockDeviceOutputReference
type LaunchConfigurationEphemeralBlockDevice ¶
type LaunchConfigurationEphemeralBlockDevice struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#device_name LaunchConfiguration#device_name}.
DeviceName *string `field:"required" json:"deviceName" yaml:"deviceName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#no_device LaunchConfiguration#no_device}.
NoDevice interface{} `field:"optional" json:"noDevice" yaml:"noDevice"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#virtual_name LaunchConfiguration#virtual_name}.
VirtualName *string `field:"optional" json:"virtualName" yaml:"virtualName"`
}
type LaunchConfigurationEphemeralBlockDeviceList ¶
type LaunchConfigurationEphemeralBlockDeviceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) LaunchConfigurationEphemeralBlockDeviceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLaunchConfigurationEphemeralBlockDeviceList ¶
func NewLaunchConfigurationEphemeralBlockDeviceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) LaunchConfigurationEphemeralBlockDeviceList
type LaunchConfigurationEphemeralBlockDeviceOutputReference ¶
type LaunchConfigurationEphemeralBlockDeviceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeviceName() *string
SetDeviceName(val *string)
DeviceNameInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
NoDevice() interface{}
SetNoDevice(val interface{})
NoDeviceInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VirtualName() *string
SetVirtualName(val *string)
VirtualNameInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetNoDevice()
ResetVirtualName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLaunchConfigurationEphemeralBlockDeviceOutputReference ¶
func NewLaunchConfigurationEphemeralBlockDeviceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) LaunchConfigurationEphemeralBlockDeviceOutputReference
type LaunchConfigurationMetadataOptions ¶
type LaunchConfigurationMetadataOptions struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#http_endpoint LaunchConfiguration#http_endpoint}.
HttpEndpoint *string `field:"optional" json:"httpEndpoint" yaml:"httpEndpoint"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#http_put_response_hop_limit LaunchConfiguration#http_put_response_hop_limit}.
HttpPutResponseHopLimit *float64 `field:"optional" json:"httpPutResponseHopLimit" yaml:"httpPutResponseHopLimit"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#http_tokens LaunchConfiguration#http_tokens}.
HttpTokens *string `field:"optional" json:"httpTokens" yaml:"httpTokens"`
}
type LaunchConfigurationMetadataOptionsOutputReference ¶
type LaunchConfigurationMetadataOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HttpEndpoint() *string
SetHttpEndpoint(val *string)
HttpEndpointInput() *string
HttpPutResponseHopLimit() *float64
SetHttpPutResponseHopLimit(val *float64)
HttpPutResponseHopLimitInput() *float64
HttpTokens() *string
SetHttpTokens(val *string)
HttpTokensInput() *string
InternalValue() *LaunchConfigurationMetadataOptions
SetInternalValue(val *LaunchConfigurationMetadataOptions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetHttpEndpoint()
ResetHttpPutResponseHopLimit()
ResetHttpTokens()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLaunchConfigurationMetadataOptionsOutputReference ¶
func NewLaunchConfigurationMetadataOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LaunchConfigurationMetadataOptionsOutputReference
type LaunchConfigurationRootBlockDevice ¶
type LaunchConfigurationRootBlockDevice struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#delete_on_termination LaunchConfiguration#delete_on_termination}.
DeleteOnTermination interface{} `field:"optional" json:"deleteOnTermination" yaml:"deleteOnTermination"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#encrypted LaunchConfiguration#encrypted}.
Encrypted interface{} `field:"optional" json:"encrypted" yaml:"encrypted"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#iops LaunchConfiguration#iops}.
Iops *float64 `field:"optional" json:"iops" yaml:"iops"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#throughput LaunchConfiguration#throughput}.
Throughput *float64 `field:"optional" json:"throughput" yaml:"throughput"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#volume_size LaunchConfiguration#volume_size}.
VolumeSize *float64 `field:"optional" json:"volumeSize" yaml:"volumeSize"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/4.67.0/docs/resources/launch_configuration#volume_type LaunchConfiguration#volume_type}.
VolumeType *string `field:"optional" json:"volumeType" yaml:"volumeType"`
}
type LaunchConfigurationRootBlockDeviceOutputReference ¶
type LaunchConfigurationRootBlockDeviceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DeleteOnTermination() interface{}
SetDeleteOnTermination(val interface{})
DeleteOnTerminationInput() interface{}
Encrypted() interface{}
SetEncrypted(val interface{})
EncryptedInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *LaunchConfigurationRootBlockDevice
SetInternalValue(val *LaunchConfigurationRootBlockDevice)
Iops() *float64
SetIops(val *float64)
IopsInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Throughput() *float64
SetThroughput(val *float64)
ThroughputInput() *float64
VolumeSize() *float64
SetVolumeSize(val *float64)
VolumeSizeInput() *float64
VolumeType() *string
SetVolumeType(val *string)
VolumeTypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDeleteOnTermination()
ResetEncrypted()
ResetIops()
ResetThroughput()
ResetVolumeSize()
ResetVolumeType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLaunchConfigurationRootBlockDeviceOutputReference ¶
func NewLaunchConfigurationRootBlockDeviceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LaunchConfigurationRootBlockDeviceOutputReference
Source Files
¶
- LaunchConfiguration.go
- LaunchConfigurationConfig.go
- LaunchConfigurationEbsBlockDevice.go
- LaunchConfigurationEbsBlockDeviceList.go
- LaunchConfigurationEbsBlockDeviceList__checks.go
- LaunchConfigurationEbsBlockDeviceOutputReference.go
- LaunchConfigurationEbsBlockDeviceOutputReference__checks.go
- LaunchConfigurationEphemeralBlockDevice.go
- LaunchConfigurationEphemeralBlockDeviceList.go
- LaunchConfigurationEphemeralBlockDeviceList__checks.go
- LaunchConfigurationEphemeralBlockDeviceOutputReference.go
- LaunchConfigurationEphemeralBlockDeviceOutputReference__checks.go
- LaunchConfigurationMetadataOptions.go
- LaunchConfigurationMetadataOptionsOutputReference.go
- LaunchConfigurationMetadataOptionsOutputReference__checks.go
- LaunchConfigurationRootBlockDevice.go
- LaunchConfigurationRootBlockDeviceOutputReference.go
- LaunchConfigurationRootBlockDeviceOutputReference__checks.go
- LaunchConfiguration__checks.go
- main.go