Documentation
¶
Index ¶
- func ComprehendDocumentClassifier_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func ComprehendDocumentClassifier_IsConstruct(x interface{}) *bool
- func ComprehendDocumentClassifier_IsTerraformElement(x interface{}) *bool
- func ComprehendDocumentClassifier_IsTerraformResource(x interface{}) *bool
- func ComprehendDocumentClassifier_TfResourceType() *string
- func NewComprehendDocumentClassifierInputDataConfigAugmentedManifestsList_Override(c ComprehendDocumentClassifierInputDataConfigAugmentedManifestsList, ...)
- func NewComprehendDocumentClassifierInputDataConfigAugmentedManifestsOutputReference_Override(c ComprehendDocumentClassifierInputDataConfigAugmentedManifestsOutputReference, ...)
- func NewComprehendDocumentClassifierInputDataConfigOutputReference_Override(c ComprehendDocumentClassifierInputDataConfigOutputReference, ...)
- func NewComprehendDocumentClassifierOutputDataConfigOutputReference_Override(c ComprehendDocumentClassifierOutputDataConfigOutputReference, ...)
- func NewComprehendDocumentClassifierTimeoutsOutputReference_Override(c ComprehendDocumentClassifierTimeoutsOutputReference, ...)
- func NewComprehendDocumentClassifierVpcConfigOutputReference_Override(c ComprehendDocumentClassifierVpcConfigOutputReference, ...)
- func NewComprehendDocumentClassifier_Override(c ComprehendDocumentClassifier, scope constructs.Construct, id *string, ...)
- type ComprehendDocumentClassifier
- type ComprehendDocumentClassifierConfig
- type ComprehendDocumentClassifierInputDataConfig
- type ComprehendDocumentClassifierInputDataConfigAugmentedManifests
- type ComprehendDocumentClassifierInputDataConfigAugmentedManifestsList
- type ComprehendDocumentClassifierInputDataConfigAugmentedManifestsOutputReference
- type ComprehendDocumentClassifierInputDataConfigOutputReference
- type ComprehendDocumentClassifierOutputDataConfig
- type ComprehendDocumentClassifierOutputDataConfigOutputReference
- type ComprehendDocumentClassifierTimeouts
- type ComprehendDocumentClassifierTimeoutsOutputReference
- type ComprehendDocumentClassifierVpcConfig
- type ComprehendDocumentClassifierVpcConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ComprehendDocumentClassifier_GenerateConfigForImport ¶
func ComprehendDocumentClassifier_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a ComprehendDocumentClassifier resource upon running "cdktf plan <stack-name>".
func ComprehendDocumentClassifier_IsConstruct ¶
func ComprehendDocumentClassifier_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ComprehendDocumentClassifier_IsTerraformElement ¶
func ComprehendDocumentClassifier_IsTerraformElement(x interface{}) *bool
Experimental.
func ComprehendDocumentClassifier_IsTerraformResource ¶
func ComprehendDocumentClassifier_IsTerraformResource(x interface{}) *bool
Experimental.
func ComprehendDocumentClassifier_TfResourceType ¶
func ComprehendDocumentClassifier_TfResourceType() *string
func NewComprehendDocumentClassifierInputDataConfigAugmentedManifestsList_Override ¶
func NewComprehendDocumentClassifierInputDataConfigAugmentedManifestsList_Override(c ComprehendDocumentClassifierInputDataConfigAugmentedManifestsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewComprehendDocumentClassifierInputDataConfigAugmentedManifestsOutputReference_Override ¶
func NewComprehendDocumentClassifierInputDataConfigAugmentedManifestsOutputReference_Override(c ComprehendDocumentClassifierInputDataConfigAugmentedManifestsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewComprehendDocumentClassifierInputDataConfigOutputReference_Override ¶
func NewComprehendDocumentClassifierInputDataConfigOutputReference_Override(c ComprehendDocumentClassifierInputDataConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComprehendDocumentClassifierOutputDataConfigOutputReference_Override ¶
func NewComprehendDocumentClassifierOutputDataConfigOutputReference_Override(c ComprehendDocumentClassifierOutputDataConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComprehendDocumentClassifierTimeoutsOutputReference_Override ¶
func NewComprehendDocumentClassifierTimeoutsOutputReference_Override(c ComprehendDocumentClassifierTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComprehendDocumentClassifierVpcConfigOutputReference_Override ¶
func NewComprehendDocumentClassifierVpcConfigOutputReference_Override(c ComprehendDocumentClassifierVpcConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewComprehendDocumentClassifier_Override ¶
func NewComprehendDocumentClassifier_Override(c ComprehendDocumentClassifier, scope constructs.Construct, id *string, config *ComprehendDocumentClassifierConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier aws_comprehend_document_classifier} Resource.
Types ¶
type ComprehendDocumentClassifier ¶
type ComprehendDocumentClassifier interface {
cdktf.TerraformResource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DataAccessRoleArn() *string
SetDataAccessRoleArn(val *string)
DataAccessRoleArnInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InputDataConfig() ComprehendDocumentClassifierInputDataConfigOutputReference
InputDataConfigInput() *ComprehendDocumentClassifierInputDataConfig
LanguageCode() *string
SetLanguageCode(val *string)
LanguageCodeInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Mode() *string
SetMode(val *string)
ModeInput() *string
ModelKmsKeyId() *string
SetModelKmsKeyId(val *string)
ModelKmsKeyIdInput() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
OutputDataConfig() ComprehendDocumentClassifierOutputDataConfigOutputReference
OutputDataConfigInput() *ComprehendDocumentClassifierOutputDataConfig
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() ComprehendDocumentClassifierTimeoutsOutputReference
TimeoutsInput() interface{}
VersionName() *string
SetVersionName(val *string)
VersionNameInput() *string
VersionNamePrefix() *string
SetVersionNamePrefix(val *string)
VersionNamePrefixInput() *string
VolumeKmsKeyId() *string
SetVolumeKmsKeyId(val *string)
VolumeKmsKeyIdInput() *string
VpcConfig() ComprehendDocumentClassifierVpcConfigOutputReference
VpcConfigInput() *ComprehendDocumentClassifierVpcConfig
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutInputDataConfig(value *ComprehendDocumentClassifierInputDataConfig)
PutOutputDataConfig(value *ComprehendDocumentClassifierOutputDataConfig)
PutTimeouts(value *ComprehendDocumentClassifierTimeouts)
PutVpcConfig(value *ComprehendDocumentClassifierVpcConfig)
ResetId()
ResetMode()
ResetModelKmsKeyId()
ResetOutputDataConfig()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
ResetTagsAll()
ResetTimeouts()
ResetVersionName()
ResetVersionNamePrefix()
ResetVolumeKmsKeyId()
ResetVpcConfig()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier aws_comprehend_document_classifier}.
func NewComprehendDocumentClassifier ¶
func NewComprehendDocumentClassifier(scope constructs.Construct, id *string, config *ComprehendDocumentClassifierConfig) ComprehendDocumentClassifier
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier aws_comprehend_document_classifier} Resource.
type ComprehendDocumentClassifierConfig ¶
type ComprehendDocumentClassifierConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#data_access_role_arn ComprehendDocumentClassifier#data_access_role_arn}.
DataAccessRoleArn *string `field:"required" json:"dataAccessRoleArn" yaml:"dataAccessRoleArn"`
// input_data_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#input_data_config ComprehendDocumentClassifier#input_data_config}
InputDataConfig *ComprehendDocumentClassifierInputDataConfig `field:"required" json:"inputDataConfig" yaml:"inputDataConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#language_code ComprehendDocumentClassifier#language_code}.
LanguageCode *string `field:"required" json:"languageCode" yaml:"languageCode"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#name ComprehendDocumentClassifier#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#id ComprehendDocumentClassifier#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#mode ComprehendDocumentClassifier#mode}.
Mode *string `field:"optional" json:"mode" yaml:"mode"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#model_kms_key_id ComprehendDocumentClassifier#model_kms_key_id}.
ModelKmsKeyId *string `field:"optional" json:"modelKmsKeyId" yaml:"modelKmsKeyId"`
// output_data_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#output_data_config ComprehendDocumentClassifier#output_data_config}
OutputDataConfig *ComprehendDocumentClassifierOutputDataConfig `field:"optional" json:"outputDataConfig" yaml:"outputDataConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#tags ComprehendDocumentClassifier#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#tags_all ComprehendDocumentClassifier#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#timeouts ComprehendDocumentClassifier#timeouts}
Timeouts *ComprehendDocumentClassifierTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#version_name ComprehendDocumentClassifier#version_name}.
VersionName *string `field:"optional" json:"versionName" yaml:"versionName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#version_name_prefix ComprehendDocumentClassifier#version_name_prefix}.
VersionNamePrefix *string `field:"optional" json:"versionNamePrefix" yaml:"versionNamePrefix"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#volume_kms_key_id ComprehendDocumentClassifier#volume_kms_key_id}.
VolumeKmsKeyId *string `field:"optional" json:"volumeKmsKeyId" yaml:"volumeKmsKeyId"`
// vpc_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#vpc_config ComprehendDocumentClassifier#vpc_config}
VpcConfig *ComprehendDocumentClassifierVpcConfig `field:"optional" json:"vpcConfig" yaml:"vpcConfig"`
}
type ComprehendDocumentClassifierInputDataConfig ¶
type ComprehendDocumentClassifierInputDataConfig struct {
// augmented_manifests block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#augmented_manifests ComprehendDocumentClassifier#augmented_manifests}
AugmentedManifests interface{} `field:"optional" json:"augmentedManifests" yaml:"augmentedManifests"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#data_format ComprehendDocumentClassifier#data_format}.
DataFormat *string `field:"optional" json:"dataFormat" yaml:"dataFormat"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#label_delimiter ComprehendDocumentClassifier#label_delimiter}.
LabelDelimiter *string `field:"optional" json:"labelDelimiter" yaml:"labelDelimiter"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#s3_uri ComprehendDocumentClassifier#s3_uri}.
S3Uri *string `field:"optional" json:"s3Uri" yaml:"s3Uri"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#test_s3_uri ComprehendDocumentClassifier#test_s3_uri}.
TestS3Uri *string `field:"optional" json:"testS3Uri" yaml:"testS3Uri"`
}
type ComprehendDocumentClassifierInputDataConfigAugmentedManifests ¶
type ComprehendDocumentClassifierInputDataConfigAugmentedManifests struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#attribute_names ComprehendDocumentClassifier#attribute_names}.
AttributeNames *[]*string `field:"required" json:"attributeNames" yaml:"attributeNames"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#s3_uri ComprehendDocumentClassifier#s3_uri}.
S3Uri *string `field:"required" json:"s3Uri" yaml:"s3Uri"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#annotation_data_s3_uri ComprehendDocumentClassifier#annotation_data_s3_uri}.
AnnotationDataS3Uri *string `field:"optional" json:"annotationDataS3Uri" yaml:"annotationDataS3Uri"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#document_type ComprehendDocumentClassifier#document_type}.
DocumentType *string `field:"optional" json:"documentType" yaml:"documentType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#source_documents_s3_uri ComprehendDocumentClassifier#source_documents_s3_uri}.
SourceDocumentsS3Uri *string `field:"optional" json:"sourceDocumentsS3Uri" yaml:"sourceDocumentsS3Uri"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#split ComprehendDocumentClassifier#split}.
Split *string `field:"optional" json:"split" yaml:"split"`
}
type ComprehendDocumentClassifierInputDataConfigAugmentedManifestsList ¶
type ComprehendDocumentClassifierInputDataConfigAugmentedManifestsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) ComprehendDocumentClassifierInputDataConfigAugmentedManifestsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComprehendDocumentClassifierInputDataConfigAugmentedManifestsList ¶
func NewComprehendDocumentClassifierInputDataConfigAugmentedManifestsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) ComprehendDocumentClassifierInputDataConfigAugmentedManifestsList
type ComprehendDocumentClassifierInputDataConfigAugmentedManifestsOutputReference ¶
type ComprehendDocumentClassifierInputDataConfigAugmentedManifestsOutputReference interface {
cdktf.ComplexObject
AnnotationDataS3Uri() *string
SetAnnotationDataS3Uri(val *string)
AnnotationDataS3UriInput() *string
AttributeNames() *[]*string
SetAttributeNames(val *[]*string)
AttributeNamesInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DocumentType() *string
SetDocumentType(val *string)
DocumentTypeInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
S3Uri() *string
SetS3Uri(val *string)
S3UriInput() *string
SourceDocumentsS3Uri() *string
SetSourceDocumentsS3Uri(val *string)
SourceDocumentsS3UriInput() *string
Split() *string
SetSplit(val *string)
SplitInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAnnotationDataS3Uri()
ResetDocumentType()
ResetSourceDocumentsS3Uri()
ResetSplit()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComprehendDocumentClassifierInputDataConfigAugmentedManifestsOutputReference ¶
func NewComprehendDocumentClassifierInputDataConfigAugmentedManifestsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) ComprehendDocumentClassifierInputDataConfigAugmentedManifestsOutputReference
type ComprehendDocumentClassifierInputDataConfigOutputReference ¶
type ComprehendDocumentClassifierInputDataConfigOutputReference interface {
cdktf.ComplexObject
AugmentedManifests() ComprehendDocumentClassifierInputDataConfigAugmentedManifestsList
AugmentedManifestsInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DataFormat() *string
SetDataFormat(val *string)
DataFormatInput() *string
// Experimental.
Fqn() *string
InternalValue() *ComprehendDocumentClassifierInputDataConfig
SetInternalValue(val *ComprehendDocumentClassifierInputDataConfig)
LabelDelimiter() *string
SetLabelDelimiter(val *string)
LabelDelimiterInput() *string
S3Uri() *string
SetS3Uri(val *string)
S3UriInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TestS3Uri() *string
SetTestS3Uri(val *string)
TestS3UriInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAugmentedManifests(value interface{})
ResetAugmentedManifests()
ResetDataFormat()
ResetLabelDelimiter()
ResetS3Uri()
ResetTestS3Uri()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComprehendDocumentClassifierInputDataConfigOutputReference ¶
func NewComprehendDocumentClassifierInputDataConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComprehendDocumentClassifierInputDataConfigOutputReference
type ComprehendDocumentClassifierOutputDataConfig ¶
type ComprehendDocumentClassifierOutputDataConfig struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#s3_uri ComprehendDocumentClassifier#s3_uri}.
S3Uri *string `field:"required" json:"s3Uri" yaml:"s3Uri"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#kms_key_id ComprehendDocumentClassifier#kms_key_id}.
KmsKeyId *string `field:"optional" json:"kmsKeyId" yaml:"kmsKeyId"`
}
type ComprehendDocumentClassifierOutputDataConfigOutputReference ¶
type ComprehendDocumentClassifierOutputDataConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ComprehendDocumentClassifierOutputDataConfig
SetInternalValue(val *ComprehendDocumentClassifierOutputDataConfig)
KmsKeyId() *string
SetKmsKeyId(val *string)
KmsKeyIdInput() *string
OutputS3Uri() *string
S3Uri() *string
SetS3Uri(val *string)
S3UriInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetKmsKeyId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComprehendDocumentClassifierOutputDataConfigOutputReference ¶
func NewComprehendDocumentClassifierOutputDataConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComprehendDocumentClassifierOutputDataConfigOutputReference
type ComprehendDocumentClassifierTimeouts ¶
type ComprehendDocumentClassifierTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#create ComprehendDocumentClassifier#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#delete ComprehendDocumentClassifier#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#update ComprehendDocumentClassifier#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type ComprehendDocumentClassifierTimeoutsOutputReference ¶
type ComprehendDocumentClassifierTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComprehendDocumentClassifierTimeoutsOutputReference ¶
func NewComprehendDocumentClassifierTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComprehendDocumentClassifierTimeoutsOutputReference
type ComprehendDocumentClassifierVpcConfig ¶
type ComprehendDocumentClassifierVpcConfig struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#security_group_ids ComprehendDocumentClassifier#security_group_ids}.
SecurityGroupIds *[]*string `field:"required" json:"securityGroupIds" yaml:"securityGroupIds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.93.0/docs/resources/comprehend_document_classifier#subnets ComprehendDocumentClassifier#subnets}.
Subnets *[]*string `field:"required" json:"subnets" yaml:"subnets"`
}
type ComprehendDocumentClassifierVpcConfigOutputReference ¶
type ComprehendDocumentClassifierVpcConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *ComprehendDocumentClassifierVpcConfig
SetInternalValue(val *ComprehendDocumentClassifierVpcConfig)
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
Subnets() *[]*string
SetSubnets(val *[]*string)
SubnetsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewComprehendDocumentClassifierVpcConfigOutputReference ¶
func NewComprehendDocumentClassifierVpcConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) ComprehendDocumentClassifierVpcConfigOutputReference
Source Files
¶
- ComprehendDocumentClassifier.go
- ComprehendDocumentClassifierConfig.go
- ComprehendDocumentClassifierInputDataConfig.go
- ComprehendDocumentClassifierInputDataConfigAugmentedManifests.go
- ComprehendDocumentClassifierInputDataConfigAugmentedManifestsList.go
- ComprehendDocumentClassifierInputDataConfigAugmentedManifestsList__checks.go
- ComprehendDocumentClassifierInputDataConfigAugmentedManifestsOutputReference.go
- ComprehendDocumentClassifierInputDataConfigAugmentedManifestsOutputReference__checks.go
- ComprehendDocumentClassifierInputDataConfigOutputReference.go
- ComprehendDocumentClassifierInputDataConfigOutputReference__checks.go
- ComprehendDocumentClassifierOutputDataConfig.go
- ComprehendDocumentClassifierOutputDataConfigOutputReference.go
- ComprehendDocumentClassifierOutputDataConfigOutputReference__checks.go
- ComprehendDocumentClassifierTimeouts.go
- ComprehendDocumentClassifierTimeoutsOutputReference.go
- ComprehendDocumentClassifierTimeoutsOutputReference__checks.go
- ComprehendDocumentClassifierVpcConfig.go
- ComprehendDocumentClassifierVpcConfigOutputReference.go
- ComprehendDocumentClassifierVpcConfigOutputReference__checks.go
- ComprehendDocumentClassifier__checks.go
- main.go