Documentation
¶
Index ¶
- func DataAwsAppmeshVirtualService_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func DataAwsAppmeshVirtualService_IsConstruct(x interface{}) *bool
- func DataAwsAppmeshVirtualService_IsTerraformDataSource(x interface{}) *bool
- func DataAwsAppmeshVirtualService_IsTerraformElement(x interface{}) *bool
- func DataAwsAppmeshVirtualService_TfResourceType() *string
- func NewDataAwsAppmeshVirtualServiceSpecList_Override(d DataAwsAppmeshVirtualServiceSpecList, ...)
- func NewDataAwsAppmeshVirtualServiceSpecOutputReference_Override(d DataAwsAppmeshVirtualServiceSpecOutputReference, ...)
- func NewDataAwsAppmeshVirtualServiceSpecProviderList_Override(d DataAwsAppmeshVirtualServiceSpecProviderList, ...)
- func NewDataAwsAppmeshVirtualServiceSpecProviderOutputReference_Override(d DataAwsAppmeshVirtualServiceSpecProviderOutputReference, ...)
- func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualNodeList_Override(d DataAwsAppmeshVirtualServiceSpecProviderVirtualNodeList, ...)
- func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualNodeOutputReference_Override(d DataAwsAppmeshVirtualServiceSpecProviderVirtualNodeOutputReference, ...)
- func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualRouterList_Override(d DataAwsAppmeshVirtualServiceSpecProviderVirtualRouterList, ...)
- func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualRouterOutputReference_Override(d DataAwsAppmeshVirtualServiceSpecProviderVirtualRouterOutputReference, ...)
- func NewDataAwsAppmeshVirtualService_Override(d DataAwsAppmeshVirtualService, scope constructs.Construct, id *string, ...)
- type DataAwsAppmeshVirtualService
- type DataAwsAppmeshVirtualServiceConfig
- type DataAwsAppmeshVirtualServiceSpec
- type DataAwsAppmeshVirtualServiceSpecList
- type DataAwsAppmeshVirtualServiceSpecOutputReference
- type DataAwsAppmeshVirtualServiceSpecProvider
- type DataAwsAppmeshVirtualServiceSpecProviderList
- type DataAwsAppmeshVirtualServiceSpecProviderOutputReference
- type DataAwsAppmeshVirtualServiceSpecProviderVirtualNode
- type DataAwsAppmeshVirtualServiceSpecProviderVirtualNodeList
- type DataAwsAppmeshVirtualServiceSpecProviderVirtualNodeOutputReference
- type DataAwsAppmeshVirtualServiceSpecProviderVirtualRouter
- type DataAwsAppmeshVirtualServiceSpecProviderVirtualRouterList
- type DataAwsAppmeshVirtualServiceSpecProviderVirtualRouterOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsAppmeshVirtualService_GenerateConfigForImport ¶
func DataAwsAppmeshVirtualService_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a DataAwsAppmeshVirtualService resource upon running "cdktf plan <stack-name>".
func DataAwsAppmeshVirtualService_IsConstruct ¶
func DataAwsAppmeshVirtualService_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsAppmeshVirtualService_IsTerraformDataSource ¶
func DataAwsAppmeshVirtualService_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsAppmeshVirtualService_IsTerraformElement ¶
func DataAwsAppmeshVirtualService_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsAppmeshVirtualService_TfResourceType ¶
func DataAwsAppmeshVirtualService_TfResourceType() *string
func NewDataAwsAppmeshVirtualServiceSpecList_Override ¶
func NewDataAwsAppmeshVirtualServiceSpecList_Override(d DataAwsAppmeshVirtualServiceSpecList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsAppmeshVirtualServiceSpecOutputReference_Override ¶
func NewDataAwsAppmeshVirtualServiceSpecOutputReference_Override(d DataAwsAppmeshVirtualServiceSpecOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsAppmeshVirtualServiceSpecProviderList_Override ¶
func NewDataAwsAppmeshVirtualServiceSpecProviderList_Override(d DataAwsAppmeshVirtualServiceSpecProviderList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsAppmeshVirtualServiceSpecProviderOutputReference_Override ¶
func NewDataAwsAppmeshVirtualServiceSpecProviderOutputReference_Override(d DataAwsAppmeshVirtualServiceSpecProviderOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualNodeList_Override ¶
func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualNodeList_Override(d DataAwsAppmeshVirtualServiceSpecProviderVirtualNodeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualNodeOutputReference_Override ¶
func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualNodeOutputReference_Override(d DataAwsAppmeshVirtualServiceSpecProviderVirtualNodeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualRouterList_Override ¶
func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualRouterList_Override(d DataAwsAppmeshVirtualServiceSpecProviderVirtualRouterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualRouterOutputReference_Override ¶
func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualRouterOutputReference_Override(d DataAwsAppmeshVirtualServiceSpecProviderVirtualRouterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsAppmeshVirtualService_Override ¶
func NewDataAwsAppmeshVirtualService_Override(d DataAwsAppmeshVirtualService, scope constructs.Construct, id *string, config *DataAwsAppmeshVirtualServiceConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/5.90.1/docs/data-sources/appmesh_virtual_service aws_appmesh_virtual_service} Data Source.
Types ¶
type DataAwsAppmeshVirtualService ¶
type DataAwsAppmeshVirtualService interface {
cdktf.TerraformDataSource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreatedDate() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
LastUpdatedDate() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MeshName() *string
SetMeshName(val *string)
MeshNameInput() *string
MeshOwner() *string
SetMeshOwner(val *string)
MeshOwnerInput() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
ResourceOwner() *string
Spec() DataAwsAppmeshVirtualServiceSpecList
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
ResetMeshOwner()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Adds this resource to the terraform JSON output.
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/5.90.1/docs/data-sources/appmesh_virtual_service aws_appmesh_virtual_service}.
func NewDataAwsAppmeshVirtualService ¶
func NewDataAwsAppmeshVirtualService(scope constructs.Construct, id *string, config *DataAwsAppmeshVirtualServiceConfig) DataAwsAppmeshVirtualService
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/5.90.1/docs/data-sources/appmesh_virtual_service aws_appmesh_virtual_service} Data Source.
type DataAwsAppmeshVirtualServiceConfig ¶
type DataAwsAppmeshVirtualServiceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.90.1/docs/data-sources/appmesh_virtual_service#mesh_name DataAwsAppmeshVirtualService#mesh_name}.
MeshName *string `field:"required" json:"meshName" yaml:"meshName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.90.1/docs/data-sources/appmesh_virtual_service#name DataAwsAppmeshVirtualService#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.90.1/docs/data-sources/appmesh_virtual_service#id DataAwsAppmeshVirtualService#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.90.1/docs/data-sources/appmesh_virtual_service#mesh_owner DataAwsAppmeshVirtualService#mesh_owner}.
MeshOwner *string `field:"optional" json:"meshOwner" yaml:"meshOwner"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.90.1/docs/data-sources/appmesh_virtual_service#tags DataAwsAppmeshVirtualService#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsAppmeshVirtualServiceSpec ¶
type DataAwsAppmeshVirtualServiceSpec struct {
}
type DataAwsAppmeshVirtualServiceSpecList ¶
type DataAwsAppmeshVirtualServiceSpecList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsAppmeshVirtualServiceSpecOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAppmeshVirtualServiceSpecList ¶
func NewDataAwsAppmeshVirtualServiceSpecList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsAppmeshVirtualServiceSpecList
type DataAwsAppmeshVirtualServiceSpecOutputReference ¶
type DataAwsAppmeshVirtualServiceSpecOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsAppmeshVirtualServiceSpec
SetInternalValue(val *DataAwsAppmeshVirtualServiceSpec)
Provider() DataAwsAppmeshVirtualServiceSpecProviderList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAppmeshVirtualServiceSpecOutputReference ¶
func NewDataAwsAppmeshVirtualServiceSpecOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsAppmeshVirtualServiceSpecOutputReference
type DataAwsAppmeshVirtualServiceSpecProvider ¶
type DataAwsAppmeshVirtualServiceSpecProvider struct {
}
type DataAwsAppmeshVirtualServiceSpecProviderList ¶
type DataAwsAppmeshVirtualServiceSpecProviderList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsAppmeshVirtualServiceSpecProviderOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAppmeshVirtualServiceSpecProviderList ¶
func NewDataAwsAppmeshVirtualServiceSpecProviderList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsAppmeshVirtualServiceSpecProviderList
type DataAwsAppmeshVirtualServiceSpecProviderOutputReference ¶
type DataAwsAppmeshVirtualServiceSpecProviderOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsAppmeshVirtualServiceSpecProvider
SetInternalValue(val *DataAwsAppmeshVirtualServiceSpecProvider)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VirtualNode() DataAwsAppmeshVirtualServiceSpecProviderVirtualNodeList
VirtualRouter() DataAwsAppmeshVirtualServiceSpecProviderVirtualRouterList
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAppmeshVirtualServiceSpecProviderOutputReference ¶
func NewDataAwsAppmeshVirtualServiceSpecProviderOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsAppmeshVirtualServiceSpecProviderOutputReference
type DataAwsAppmeshVirtualServiceSpecProviderVirtualNode ¶
type DataAwsAppmeshVirtualServiceSpecProviderVirtualNode struct {
}
type DataAwsAppmeshVirtualServiceSpecProviderVirtualNodeList ¶
type DataAwsAppmeshVirtualServiceSpecProviderVirtualNodeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsAppmeshVirtualServiceSpecProviderVirtualNodeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualNodeList ¶
func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualNodeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsAppmeshVirtualServiceSpecProviderVirtualNodeList
type DataAwsAppmeshVirtualServiceSpecProviderVirtualNodeOutputReference ¶
type DataAwsAppmeshVirtualServiceSpecProviderVirtualNodeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsAppmeshVirtualServiceSpecProviderVirtualNode
SetInternalValue(val *DataAwsAppmeshVirtualServiceSpecProviderVirtualNode)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VirtualNodeName() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualNodeOutputReference ¶
func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualNodeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsAppmeshVirtualServiceSpecProviderVirtualNodeOutputReference
type DataAwsAppmeshVirtualServiceSpecProviderVirtualRouter ¶
type DataAwsAppmeshVirtualServiceSpecProviderVirtualRouter struct {
}
type DataAwsAppmeshVirtualServiceSpecProviderVirtualRouterList ¶
type DataAwsAppmeshVirtualServiceSpecProviderVirtualRouterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsAppmeshVirtualServiceSpecProviderVirtualRouterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualRouterList ¶
func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualRouterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsAppmeshVirtualServiceSpecProviderVirtualRouterList
type DataAwsAppmeshVirtualServiceSpecProviderVirtualRouterOutputReference ¶
type DataAwsAppmeshVirtualServiceSpecProviderVirtualRouterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsAppmeshVirtualServiceSpecProviderVirtualRouter
SetInternalValue(val *DataAwsAppmeshVirtualServiceSpecProviderVirtualRouter)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VirtualRouterName() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualRouterOutputReference ¶
func NewDataAwsAppmeshVirtualServiceSpecProviderVirtualRouterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsAppmeshVirtualServiceSpecProviderVirtualRouterOutputReference
Source Files
¶
- DataAwsAppmeshVirtualService.go
- DataAwsAppmeshVirtualServiceConfig.go
- DataAwsAppmeshVirtualServiceSpec.go
- DataAwsAppmeshVirtualServiceSpecList.go
- DataAwsAppmeshVirtualServiceSpecList__checks.go
- DataAwsAppmeshVirtualServiceSpecOutputReference.go
- DataAwsAppmeshVirtualServiceSpecOutputReference__checks.go
- DataAwsAppmeshVirtualServiceSpecProvider.go
- DataAwsAppmeshVirtualServiceSpecProviderList.go
- DataAwsAppmeshVirtualServiceSpecProviderList__checks.go
- DataAwsAppmeshVirtualServiceSpecProviderOutputReference.go
- DataAwsAppmeshVirtualServiceSpecProviderOutputReference__checks.go
- DataAwsAppmeshVirtualServiceSpecProviderVirtualNode.go
- DataAwsAppmeshVirtualServiceSpecProviderVirtualNodeList.go
- DataAwsAppmeshVirtualServiceSpecProviderVirtualNodeList__checks.go
- DataAwsAppmeshVirtualServiceSpecProviderVirtualNodeOutputReference.go
- DataAwsAppmeshVirtualServiceSpecProviderVirtualNodeOutputReference__checks.go
- DataAwsAppmeshVirtualServiceSpecProviderVirtualRouter.go
- DataAwsAppmeshVirtualServiceSpecProviderVirtualRouterList.go
- DataAwsAppmeshVirtualServiceSpecProviderVirtualRouterList__checks.go
- DataAwsAppmeshVirtualServiceSpecProviderVirtualRouterOutputReference.go
- DataAwsAppmeshVirtualServiceSpecProviderVirtualRouterOutputReference__checks.go
- DataAwsAppmeshVirtualService__checks.go
- main.go