Documentation
¶
Index ¶
- func DataAwsCloudformationType_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func DataAwsCloudformationType_IsConstruct(x interface{}) *bool
- func DataAwsCloudformationType_IsTerraformDataSource(x interface{}) *bool
- func DataAwsCloudformationType_IsTerraformElement(x interface{}) *bool
- func DataAwsCloudformationType_TfResourceType() *string
- func NewDataAwsCloudformationTypeLoggingConfigList_Override(d DataAwsCloudformationTypeLoggingConfigList, ...)
- func NewDataAwsCloudformationTypeLoggingConfigOutputReference_Override(d DataAwsCloudformationTypeLoggingConfigOutputReference, ...)
- func NewDataAwsCloudformationType_Override(d DataAwsCloudformationType, scope constructs.Construct, id *string, ...)
- type DataAwsCloudformationType
- type DataAwsCloudformationTypeConfig
- type DataAwsCloudformationTypeLoggingConfig
- type DataAwsCloudformationTypeLoggingConfigList
- type DataAwsCloudformationTypeLoggingConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsCloudformationType_GenerateConfigForImport ¶
func DataAwsCloudformationType_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a DataAwsCloudformationType resource upon running "cdktf plan <stack-name>".
func DataAwsCloudformationType_IsConstruct ¶
func DataAwsCloudformationType_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsCloudformationType_IsTerraformDataSource ¶
func DataAwsCloudformationType_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsCloudformationType_IsTerraformElement ¶
func DataAwsCloudformationType_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsCloudformationType_TfResourceType ¶
func DataAwsCloudformationType_TfResourceType() *string
func NewDataAwsCloudformationTypeLoggingConfigList_Override ¶
func NewDataAwsCloudformationTypeLoggingConfigList_Override(d DataAwsCloudformationTypeLoggingConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsCloudformationTypeLoggingConfigOutputReference_Override ¶
func NewDataAwsCloudformationTypeLoggingConfigOutputReference_Override(d DataAwsCloudformationTypeLoggingConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsCloudformationType_Override ¶
func NewDataAwsCloudformationType_Override(d DataAwsCloudformationType, scope constructs.Construct, id *string, config *DataAwsCloudformationTypeConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/5.88.0/docs/data-sources/cloudformation_type aws_cloudformation_type} Data Source.
Types ¶
type DataAwsCloudformationType ¶
type DataAwsCloudformationType interface {
cdktf.TerraformDataSource
Arn() *string
SetArn(val *string)
ArnInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DefaultVersionId() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeprecatedStatus() *string
Description() *string
DocumentationUrl() *string
ExecutionRoleArn() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IsDefaultVersion() cdktf.IResolvable
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LoggingConfig() DataAwsCloudformationTypeLoggingConfigList
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
ProvisioningType() *string
// Experimental.
RawOverrides() interface{}
Schema() *string
SourceUrl() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Type() *string
SetType(val *string)
TypeArn() *string
TypeInput() *string
TypeName() *string
SetTypeName(val *string)
TypeNameInput() *string
VersionId() *string
SetVersionId(val *string)
VersionIdInput() *string
Visibility() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetArn()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetType()
ResetTypeName()
ResetVersionId()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Adds this resource to the terraform JSON output.
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/5.88.0/docs/data-sources/cloudformation_type aws_cloudformation_type}.
func NewDataAwsCloudformationType ¶
func NewDataAwsCloudformationType(scope constructs.Construct, id *string, config *DataAwsCloudformationTypeConfig) DataAwsCloudformationType
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/5.88.0/docs/data-sources/cloudformation_type aws_cloudformation_type} Data Source.
type DataAwsCloudformationTypeConfig ¶
type DataAwsCloudformationTypeConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.88.0/docs/data-sources/cloudformation_type#arn DataAwsCloudformationType#arn}.
Arn *string `field:"optional" json:"arn" yaml:"arn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.88.0/docs/data-sources/cloudformation_type#id DataAwsCloudformationType#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.88.0/docs/data-sources/cloudformation_type#type DataAwsCloudformationType#type}.
Type *string `field:"optional" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.88.0/docs/data-sources/cloudformation_type#type_name DataAwsCloudformationType#type_name}.
TypeName *string `field:"optional" json:"typeName" yaml:"typeName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.88.0/docs/data-sources/cloudformation_type#version_id DataAwsCloudformationType#version_id}.
VersionId *string `field:"optional" json:"versionId" yaml:"versionId"`
}
type DataAwsCloudformationTypeLoggingConfig ¶
type DataAwsCloudformationTypeLoggingConfig struct {
}
type DataAwsCloudformationTypeLoggingConfigList ¶
type DataAwsCloudformationTypeLoggingConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsCloudformationTypeLoggingConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsCloudformationTypeLoggingConfigList ¶
func NewDataAwsCloudformationTypeLoggingConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsCloudformationTypeLoggingConfigList
type DataAwsCloudformationTypeLoggingConfigOutputReference ¶
type DataAwsCloudformationTypeLoggingConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataAwsCloudformationTypeLoggingConfig
SetInternalValue(val *DataAwsCloudformationTypeLoggingConfig)
LogGroupName() *string
LogRoleArn() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsCloudformationTypeLoggingConfigOutputReference ¶
func NewDataAwsCloudformationTypeLoggingConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsCloudformationTypeLoggingConfigOutputReference
Source Files
¶
- DataAwsCloudformationType.go
- DataAwsCloudformationTypeConfig.go
- DataAwsCloudformationTypeLoggingConfig.go
- DataAwsCloudformationTypeLoggingConfigList.go
- DataAwsCloudformationTypeLoggingConfigList__checks.go
- DataAwsCloudformationTypeLoggingConfigOutputReference.go
- DataAwsCloudformationTypeLoggingConfigOutputReference__checks.go
- DataAwsCloudformationType__checks.go
- main.go