Documentation
¶
Index ¶
- func DatazoneEnvironmentProfile_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func DatazoneEnvironmentProfile_IsConstruct(x interface{}) *bool
- func DatazoneEnvironmentProfile_IsTerraformElement(x interface{}) *bool
- func DatazoneEnvironmentProfile_IsTerraformResource(x interface{}) *bool
- func DatazoneEnvironmentProfile_TfResourceType() *string
- func NewDatazoneEnvironmentProfileUserParametersList_Override(d DatazoneEnvironmentProfileUserParametersList, ...)
- func NewDatazoneEnvironmentProfileUserParametersOutputReference_Override(d DatazoneEnvironmentProfileUserParametersOutputReference, ...)
- func NewDatazoneEnvironmentProfile_Override(d DatazoneEnvironmentProfile, scope constructs.Construct, id *string, ...)
- type DatazoneEnvironmentProfile
- type DatazoneEnvironmentProfileConfig
- type DatazoneEnvironmentProfileUserParameters
- type DatazoneEnvironmentProfileUserParametersList
- type DatazoneEnvironmentProfileUserParametersOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DatazoneEnvironmentProfile_GenerateConfigForImport ¶
func DatazoneEnvironmentProfile_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a DatazoneEnvironmentProfile resource upon running "cdktf plan <stack-name>".
func DatazoneEnvironmentProfile_IsConstruct ¶
func DatazoneEnvironmentProfile_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DatazoneEnvironmentProfile_IsTerraformElement ¶
func DatazoneEnvironmentProfile_IsTerraformElement(x interface{}) *bool
Experimental.
func DatazoneEnvironmentProfile_IsTerraformResource ¶
func DatazoneEnvironmentProfile_IsTerraformResource(x interface{}) *bool
Experimental.
func DatazoneEnvironmentProfile_TfResourceType ¶
func DatazoneEnvironmentProfile_TfResourceType() *string
func NewDatazoneEnvironmentProfileUserParametersList_Override ¶
func NewDatazoneEnvironmentProfileUserParametersList_Override(d DatazoneEnvironmentProfileUserParametersList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDatazoneEnvironmentProfileUserParametersOutputReference_Override ¶
func NewDatazoneEnvironmentProfileUserParametersOutputReference_Override(d DatazoneEnvironmentProfileUserParametersOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDatazoneEnvironmentProfile_Override ¶
func NewDatazoneEnvironmentProfile_Override(d DatazoneEnvironmentProfile, scope constructs.Construct, id *string, config *DatazoneEnvironmentProfileConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/5.81.0/docs/resources/datazone_environment_profile aws_datazone_environment_profile} Resource.
Types ¶
type DatazoneEnvironmentProfile ¶
type DatazoneEnvironmentProfile interface {
cdktf.TerraformResource
AwsAccountId() *string
SetAwsAccountId(val *string)
AwsAccountIdInput() *string
AwsAccountRegion() *string
SetAwsAccountRegion(val *string)
AwsAccountRegionInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreatedAt() *string
CreatedBy() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DomainIdentifier() *string
SetDomainIdentifier(val *string)
DomainIdentifierInput() *string
EnvironmentBlueprintIdentifier() *string
SetEnvironmentBlueprintIdentifier(val *string)
EnvironmentBlueprintIdentifierInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
ProjectIdentifier() *string
SetProjectIdentifier(val *string)
ProjectIdentifierInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
UpdatedAt() *string
UserParameters() DatazoneEnvironmentProfileUserParametersList
UserParametersInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutUserParameters(value interface{})
ResetAwsAccountId()
ResetDescription()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetUserParameters()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/5.81.0/docs/resources/datazone_environment_profile aws_datazone_environment_profile}.
func NewDatazoneEnvironmentProfile ¶
func NewDatazoneEnvironmentProfile(scope constructs.Construct, id *string, config *DatazoneEnvironmentProfileConfig) DatazoneEnvironmentProfile
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/5.81.0/docs/resources/datazone_environment_profile aws_datazone_environment_profile} Resource.
type DatazoneEnvironmentProfileConfig ¶
type DatazoneEnvironmentProfileConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.81.0/docs/resources/datazone_environment_profile#aws_account_region DatazoneEnvironmentProfile#aws_account_region}.
AwsAccountRegion *string `field:"required" json:"awsAccountRegion" yaml:"awsAccountRegion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.81.0/docs/resources/datazone_environment_profile#domain_identifier DatazoneEnvironmentProfile#domain_identifier}.
DomainIdentifier *string `field:"required" json:"domainIdentifier" yaml:"domainIdentifier"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.81.0/docs/resources/datazone_environment_profile#environment_blueprint_identifier DatazoneEnvironmentProfile#environment_blueprint_identifier}.
EnvironmentBlueprintIdentifier *string `field:"required" json:"environmentBlueprintIdentifier" yaml:"environmentBlueprintIdentifier"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.81.0/docs/resources/datazone_environment_profile#name DatazoneEnvironmentProfile#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.81.0/docs/resources/datazone_environment_profile#project_identifier DatazoneEnvironmentProfile#project_identifier}.
ProjectIdentifier *string `field:"required" json:"projectIdentifier" yaml:"projectIdentifier"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.81.0/docs/resources/datazone_environment_profile#aws_account_id DatazoneEnvironmentProfile#aws_account_id}.
AwsAccountId *string `field:"optional" json:"awsAccountId" yaml:"awsAccountId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.81.0/docs/resources/datazone_environment_profile#description DatazoneEnvironmentProfile#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// user_parameters block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.81.0/docs/resources/datazone_environment_profile#user_parameters DatazoneEnvironmentProfile#user_parameters}
UserParameters interface{} `field:"optional" json:"userParameters" yaml:"userParameters"`
}
type DatazoneEnvironmentProfileUserParameters ¶
type DatazoneEnvironmentProfileUserParameters struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.81.0/docs/resources/datazone_environment_profile#name DatazoneEnvironmentProfile#name}.
Name *string `field:"optional" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.81.0/docs/resources/datazone_environment_profile#value DatazoneEnvironmentProfile#value}.
Value *string `field:"optional" json:"value" yaml:"value"`
}
type DatazoneEnvironmentProfileUserParametersList ¶
type DatazoneEnvironmentProfileUserParametersList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DatazoneEnvironmentProfileUserParametersOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDatazoneEnvironmentProfileUserParametersList ¶
func NewDatazoneEnvironmentProfileUserParametersList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DatazoneEnvironmentProfileUserParametersList
type DatazoneEnvironmentProfileUserParametersOutputReference ¶
type DatazoneEnvironmentProfileUserParametersOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetName()
ResetValue()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDatazoneEnvironmentProfileUserParametersOutputReference ¶
func NewDatazoneEnvironmentProfileUserParametersOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DatazoneEnvironmentProfileUserParametersOutputReference
Source Files
¶
- DatazoneEnvironmentProfile.go
- DatazoneEnvironmentProfileConfig.go
- DatazoneEnvironmentProfileUserParameters.go
- DatazoneEnvironmentProfileUserParametersList.go
- DatazoneEnvironmentProfileUserParametersList__checks.go
- DatazoneEnvironmentProfileUserParametersOutputReference.go
- DatazoneEnvironmentProfileUserParametersOutputReference__checks.go
- DatazoneEnvironmentProfile__checks.go
- main.go