Documentation
¶
Index ¶
- func DataAwsEc2NetworkInsightsPath_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func DataAwsEc2NetworkInsightsPath_IsConstruct(x interface{}) *bool
- func DataAwsEc2NetworkInsightsPath_IsTerraformDataSource(x interface{}) *bool
- func DataAwsEc2NetworkInsightsPath_IsTerraformElement(x interface{}) *bool
- func DataAwsEc2NetworkInsightsPath_TfResourceType() *string
- func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeList_Override(d DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeList, ...)
- func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeOutputReference_Override(...)
- func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationList_Override(d DataAwsEc2NetworkInsightsPathFilterAtDestinationList, ...)
- func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationOutputReference_Override(d DataAwsEc2NetworkInsightsPathFilterAtDestinationOutputReference, ...)
- func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeList_Override(d DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeList, ...)
- func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeOutputReference_Override(...)
- func NewDataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeList_Override(d DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeList, ...)
- func NewDataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeOutputReference_Override(...)
- func NewDataAwsEc2NetworkInsightsPathFilterAtSourceList_Override(d DataAwsEc2NetworkInsightsPathFilterAtSourceList, ...)
- func NewDataAwsEc2NetworkInsightsPathFilterAtSourceOutputReference_Override(d DataAwsEc2NetworkInsightsPathFilterAtSourceOutputReference, ...)
- func NewDataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeList_Override(d DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeList, ...)
- func NewDataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeOutputReference_Override(d DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeOutputReference, ...)
- func NewDataAwsEc2NetworkInsightsPathFilterList_Override(d DataAwsEc2NetworkInsightsPathFilterList, ...)
- func NewDataAwsEc2NetworkInsightsPathFilterOutputReference_Override(d DataAwsEc2NetworkInsightsPathFilterOutputReference, ...)
- func NewDataAwsEc2NetworkInsightsPath_Override(d DataAwsEc2NetworkInsightsPath, scope constructs.Construct, id *string, ...)
- type DataAwsEc2NetworkInsightsPath
- type DataAwsEc2NetworkInsightsPathConfig
- type DataAwsEc2NetworkInsightsPathFilter
- type DataAwsEc2NetworkInsightsPathFilterAtDestination
- type DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRange
- type DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeList
- type DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeOutputReference
- type DataAwsEc2NetworkInsightsPathFilterAtDestinationList
- type DataAwsEc2NetworkInsightsPathFilterAtDestinationOutputReference
- type DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRange
- type DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeList
- type DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeOutputReference
- type DataAwsEc2NetworkInsightsPathFilterAtSource
- type DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRange
- type DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeList
- type DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeOutputReference
- type DataAwsEc2NetworkInsightsPathFilterAtSourceList
- type DataAwsEc2NetworkInsightsPathFilterAtSourceOutputReference
- type DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRange
- type DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeList
- type DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeOutputReference
- type DataAwsEc2NetworkInsightsPathFilterList
- type DataAwsEc2NetworkInsightsPathFilterOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataAwsEc2NetworkInsightsPath_GenerateConfigForImport ¶
func DataAwsEc2NetworkInsightsPath_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a DataAwsEc2NetworkInsightsPath resource upon running "cdktf plan <stack-name>".
func DataAwsEc2NetworkInsightsPath_IsConstruct ¶
func DataAwsEc2NetworkInsightsPath_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataAwsEc2NetworkInsightsPath_IsTerraformDataSource ¶
func DataAwsEc2NetworkInsightsPath_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataAwsEc2NetworkInsightsPath_IsTerraformElement ¶
func DataAwsEc2NetworkInsightsPath_IsTerraformElement(x interface{}) *bool
Experimental.
func DataAwsEc2NetworkInsightsPath_TfResourceType ¶
func DataAwsEc2NetworkInsightsPath_TfResourceType() *string
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeList_Override ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeList_Override(d DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeOutputReference_Override ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeOutputReference_Override(d DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationList_Override ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationList_Override(d DataAwsEc2NetworkInsightsPathFilterAtDestinationList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationOutputReference_Override ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationOutputReference_Override(d DataAwsEc2NetworkInsightsPathFilterAtDestinationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeList_Override ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeList_Override(d DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeOutputReference_Override ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeOutputReference_Override(d DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeList_Override ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeList_Override(d DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeOutputReference_Override ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeOutputReference_Override(d DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceList_Override ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceList_Override(d DataAwsEc2NetworkInsightsPathFilterAtSourceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceOutputReference_Override ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceOutputReference_Override(d DataAwsEc2NetworkInsightsPathFilterAtSourceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeList_Override ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeList_Override(d DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeOutputReference_Override ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeOutputReference_Override(d DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEc2NetworkInsightsPathFilterList_Override ¶
func NewDataAwsEc2NetworkInsightsPathFilterList_Override(d DataAwsEc2NetworkInsightsPathFilterList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataAwsEc2NetworkInsightsPathFilterOutputReference_Override ¶
func NewDataAwsEc2NetworkInsightsPathFilterOutputReference_Override(d DataAwsEc2NetworkInsightsPathFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataAwsEc2NetworkInsightsPath_Override ¶
func NewDataAwsEc2NetworkInsightsPath_Override(d DataAwsEc2NetworkInsightsPath, scope constructs.Construct, id *string, config *DataAwsEc2NetworkInsightsPathConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/data-sources/ec2_network_insights_path aws_ec2_network_insights_path} Data Source.
Types ¶
type DataAwsEc2NetworkInsightsPath ¶
type DataAwsEc2NetworkInsightsPath interface {
cdktf.TerraformDataSource
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Destination() *string
DestinationArn() *string
DestinationIp() *string
DestinationPort() *float64
Filter() DataAwsEc2NetworkInsightsPathFilterList
FilterAtDestination() DataAwsEc2NetworkInsightsPathFilterAtDestinationList
FilterAtSource() DataAwsEc2NetworkInsightsPathFilterAtSourceList
FilterInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
NetworkInsightsPathId() *string
SetNetworkInsightsPathId(val *string)
NetworkInsightsPathIdInput() *string
// The tree node.
Node() constructs.Node
Protocol() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Source() *string
SourceArn() *string
SourceIp() *string
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutFilter(value interface{})
ResetFilter()
ResetId()
ResetNetworkInsightsPathId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTags()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Adds this resource to the terraform JSON output.
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/data-sources/ec2_network_insights_path aws_ec2_network_insights_path}.
func NewDataAwsEc2NetworkInsightsPath ¶
func NewDataAwsEc2NetworkInsightsPath(scope constructs.Construct, id *string, config *DataAwsEc2NetworkInsightsPathConfig) DataAwsEc2NetworkInsightsPath
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/data-sources/ec2_network_insights_path aws_ec2_network_insights_path} Data Source.
type DataAwsEc2NetworkInsightsPathConfig ¶
type DataAwsEc2NetworkInsightsPathConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// filter block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/data-sources/ec2_network_insights_path#filter DataAwsEc2NetworkInsightsPath#filter}
Filter interface{} `field:"optional" json:"filter" yaml:"filter"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/data-sources/ec2_network_insights_path#id DataAwsEc2NetworkInsightsPath#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/data-sources/ec2_network_insights_path#network_insights_path_id DataAwsEc2NetworkInsightsPath#network_insights_path_id}.
NetworkInsightsPathId *string `field:"optional" json:"networkInsightsPathId" yaml:"networkInsightsPathId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/data-sources/ec2_network_insights_path#tags DataAwsEc2NetworkInsightsPath#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
}
type DataAwsEc2NetworkInsightsPathFilter ¶
type DataAwsEc2NetworkInsightsPathFilter struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/data-sources/ec2_network_insights_path#name DataAwsEc2NetworkInsightsPath#name}.
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/data-sources/ec2_network_insights_path#values DataAwsEc2NetworkInsightsPath#values}.
Values *[]*string `field:"required" json:"values" yaml:"values"`
}
type DataAwsEc2NetworkInsightsPathFilterAtDestination ¶
type DataAwsEc2NetworkInsightsPathFilterAtDestination struct {
}
type DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRange ¶
type DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRange struct {
}
type DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeList ¶
type DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeList ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeList
type DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeOutputReference ¶
type DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
FromPort() *float64
InternalValue() *DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRange
SetInternalValue(val *DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRange)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ToPort() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeOutputReference ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeOutputReference
type DataAwsEc2NetworkInsightsPathFilterAtDestinationList ¶
type DataAwsEc2NetworkInsightsPathFilterAtDestinationList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEc2NetworkInsightsPathFilterAtDestinationOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationList ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEc2NetworkInsightsPathFilterAtDestinationList
type DataAwsEc2NetworkInsightsPathFilterAtDestinationOutputReference ¶
type DataAwsEc2NetworkInsightsPathFilterAtDestinationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DestinationAddress() *string
DestinationPortRange() DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeList
// Experimental.
Fqn() *string
InternalValue() *DataAwsEc2NetworkInsightsPathFilterAtDestination
SetInternalValue(val *DataAwsEc2NetworkInsightsPathFilterAtDestination)
SourceAddress() *string
SourcePortRange() DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationOutputReference ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEc2NetworkInsightsPathFilterAtDestinationOutputReference
type DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRange ¶
type DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRange struct {
}
type DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeList ¶
type DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeList ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeList
type DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeOutputReference ¶
type DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
FromPort() *float64
InternalValue() *DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRange
SetInternalValue(val *DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRange)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ToPort() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeOutputReference ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeOutputReference
type DataAwsEc2NetworkInsightsPathFilterAtSource ¶
type DataAwsEc2NetworkInsightsPathFilterAtSource struct {
}
type DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRange ¶
type DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRange struct {
}
type DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeList ¶
type DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeList ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeList
type DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeOutputReference ¶
type DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
FromPort() *float64
InternalValue() *DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRange
SetInternalValue(val *DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRange)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ToPort() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeOutputReference ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeOutputReference
type DataAwsEc2NetworkInsightsPathFilterAtSourceList ¶
type DataAwsEc2NetworkInsightsPathFilterAtSourceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEc2NetworkInsightsPathFilterAtSourceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceList ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEc2NetworkInsightsPathFilterAtSourceList
type DataAwsEc2NetworkInsightsPathFilterAtSourceOutputReference ¶
type DataAwsEc2NetworkInsightsPathFilterAtSourceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DestinationAddress() *string
DestinationPortRange() DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeList
// Experimental.
Fqn() *string
InternalValue() *DataAwsEc2NetworkInsightsPathFilterAtSource
SetInternalValue(val *DataAwsEc2NetworkInsightsPathFilterAtSource)
SourceAddress() *string
SourcePortRange() DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceOutputReference ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEc2NetworkInsightsPathFilterAtSourceOutputReference
type DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRange ¶
type DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRange struct {
}
type DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeList ¶
type DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeList ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeList
type DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeOutputReference ¶
type DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
FromPort() *float64
InternalValue() *DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRange
SetInternalValue(val *DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRange)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
ToPort() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeOutputReference ¶
func NewDataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeOutputReference
type DataAwsEc2NetworkInsightsPathFilterList ¶
type DataAwsEc2NetworkInsightsPathFilterList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataAwsEc2NetworkInsightsPathFilterOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2NetworkInsightsPathFilterList ¶
func NewDataAwsEc2NetworkInsightsPathFilterList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataAwsEc2NetworkInsightsPathFilterList
type DataAwsEc2NetworkInsightsPathFilterOutputReference ¶
type DataAwsEc2NetworkInsightsPathFilterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
SetValues(val *[]*string)
ValuesInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataAwsEc2NetworkInsightsPathFilterOutputReference ¶
func NewDataAwsEc2NetworkInsightsPathFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataAwsEc2NetworkInsightsPathFilterOutputReference
Source Files
¶
- DataAwsEc2NetworkInsightsPath.go
- DataAwsEc2NetworkInsightsPathConfig.go
- DataAwsEc2NetworkInsightsPathFilter.go
- DataAwsEc2NetworkInsightsPathFilterAtDestination.go
- DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRange.go
- DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeList.go
- DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeList__checks.go
- DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeOutputReference.go
- DataAwsEc2NetworkInsightsPathFilterAtDestinationDestinationPortRangeOutputReference__checks.go
- DataAwsEc2NetworkInsightsPathFilterAtDestinationList.go
- DataAwsEc2NetworkInsightsPathFilterAtDestinationList__checks.go
- DataAwsEc2NetworkInsightsPathFilterAtDestinationOutputReference.go
- DataAwsEc2NetworkInsightsPathFilterAtDestinationOutputReference__checks.go
- DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRange.go
- DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeList.go
- DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeList__checks.go
- DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeOutputReference.go
- DataAwsEc2NetworkInsightsPathFilterAtDestinationSourcePortRangeOutputReference__checks.go
- DataAwsEc2NetworkInsightsPathFilterAtSource.go
- DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRange.go
- DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeList.go
- DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeList__checks.go
- DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeOutputReference.go
- DataAwsEc2NetworkInsightsPathFilterAtSourceDestinationPortRangeOutputReference__checks.go
- DataAwsEc2NetworkInsightsPathFilterAtSourceList.go
- DataAwsEc2NetworkInsightsPathFilterAtSourceList__checks.go
- DataAwsEc2NetworkInsightsPathFilterAtSourceOutputReference.go
- DataAwsEc2NetworkInsightsPathFilterAtSourceOutputReference__checks.go
- DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRange.go
- DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeList.go
- DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeList__checks.go
- DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeOutputReference.go
- DataAwsEc2NetworkInsightsPathFilterAtSourceSourcePortRangeOutputReference__checks.go
- DataAwsEc2NetworkInsightsPathFilterList.go
- DataAwsEc2NetworkInsightsPathFilterList__checks.go
- DataAwsEc2NetworkInsightsPathFilterOutputReference.go
- DataAwsEc2NetworkInsightsPathFilterOutputReference__checks.go
- DataAwsEc2NetworkInsightsPath__checks.go
- main.go