Documentation
¶
Index ¶
- func LambdaFunction_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func LambdaFunction_IsConstruct(x interface{}) *bool
- func LambdaFunction_IsTerraformElement(x interface{}) *bool
- func LambdaFunction_IsTerraformResource(x interface{}) *bool
- func LambdaFunction_TfResourceType() *string
- func NewLambdaFunctionDeadLetterConfigOutputReference_Override(l LambdaFunctionDeadLetterConfigOutputReference, ...)
- func NewLambdaFunctionEnvironmentOutputReference_Override(l LambdaFunctionEnvironmentOutputReference, ...)
- func NewLambdaFunctionEphemeralStorageOutputReference_Override(l LambdaFunctionEphemeralStorageOutputReference, ...)
- func NewLambdaFunctionFileSystemConfigOutputReference_Override(l LambdaFunctionFileSystemConfigOutputReference, ...)
- func NewLambdaFunctionImageConfigOutputReference_Override(l LambdaFunctionImageConfigOutputReference, ...)
- func NewLambdaFunctionLoggingConfigOutputReference_Override(l LambdaFunctionLoggingConfigOutputReference, ...)
- func NewLambdaFunctionSnapStartOutputReference_Override(l LambdaFunctionSnapStartOutputReference, ...)
- func NewLambdaFunctionTimeoutsOutputReference_Override(l LambdaFunctionTimeoutsOutputReference, ...)
- func NewLambdaFunctionTracingConfigOutputReference_Override(l LambdaFunctionTracingConfigOutputReference, ...)
- func NewLambdaFunctionVpcConfigOutputReference_Override(l LambdaFunctionVpcConfigOutputReference, ...)
- func NewLambdaFunction_Override(l LambdaFunction, scope constructs.Construct, id *string, ...)
- type LambdaFunction
- type LambdaFunctionConfig
- type LambdaFunctionDeadLetterConfig
- type LambdaFunctionDeadLetterConfigOutputReference
- type LambdaFunctionEnvironment
- type LambdaFunctionEnvironmentOutputReference
- type LambdaFunctionEphemeralStorage
- type LambdaFunctionEphemeralStorageOutputReference
- type LambdaFunctionFileSystemConfig
- type LambdaFunctionFileSystemConfigOutputReference
- type LambdaFunctionImageConfig
- type LambdaFunctionImageConfigOutputReference
- type LambdaFunctionLoggingConfig
- type LambdaFunctionLoggingConfigOutputReference
- type LambdaFunctionSnapStart
- type LambdaFunctionSnapStartOutputReference
- type LambdaFunctionTimeouts
- type LambdaFunctionTimeoutsOutputReference
- type LambdaFunctionTracingConfig
- type LambdaFunctionTracingConfigOutputReference
- type LambdaFunctionVpcConfig
- type LambdaFunctionVpcConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LambdaFunction_GenerateConfigForImport ¶
func LambdaFunction_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a LambdaFunction resource upon running "cdktf plan <stack-name>".
func LambdaFunction_IsConstruct ¶
func LambdaFunction_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func LambdaFunction_IsTerraformElement ¶
func LambdaFunction_IsTerraformElement(x interface{}) *bool
Experimental.
func LambdaFunction_IsTerraformResource ¶
func LambdaFunction_IsTerraformResource(x interface{}) *bool
Experimental.
func LambdaFunction_TfResourceType ¶
func LambdaFunction_TfResourceType() *string
func NewLambdaFunctionDeadLetterConfigOutputReference_Override ¶
func NewLambdaFunctionDeadLetterConfigOutputReference_Override(l LambdaFunctionDeadLetterConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLambdaFunctionEnvironmentOutputReference_Override ¶
func NewLambdaFunctionEnvironmentOutputReference_Override(l LambdaFunctionEnvironmentOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLambdaFunctionEphemeralStorageOutputReference_Override ¶
func NewLambdaFunctionEphemeralStorageOutputReference_Override(l LambdaFunctionEphemeralStorageOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLambdaFunctionFileSystemConfigOutputReference_Override ¶
func NewLambdaFunctionFileSystemConfigOutputReference_Override(l LambdaFunctionFileSystemConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLambdaFunctionImageConfigOutputReference_Override ¶
func NewLambdaFunctionImageConfigOutputReference_Override(l LambdaFunctionImageConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLambdaFunctionLoggingConfigOutputReference_Override ¶
func NewLambdaFunctionLoggingConfigOutputReference_Override(l LambdaFunctionLoggingConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLambdaFunctionSnapStartOutputReference_Override ¶
func NewLambdaFunctionSnapStartOutputReference_Override(l LambdaFunctionSnapStartOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLambdaFunctionTimeoutsOutputReference_Override ¶
func NewLambdaFunctionTimeoutsOutputReference_Override(l LambdaFunctionTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLambdaFunctionTracingConfigOutputReference_Override ¶
func NewLambdaFunctionTracingConfigOutputReference_Override(l LambdaFunctionTracingConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLambdaFunctionVpcConfigOutputReference_Override ¶
func NewLambdaFunctionVpcConfigOutputReference_Override(l LambdaFunctionVpcConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewLambdaFunction_Override ¶
func NewLambdaFunction_Override(l LambdaFunction, scope constructs.Construct, id *string, config *LambdaFunctionConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function aws_lambda_function} Resource.
Types ¶
type LambdaFunction ¶
type LambdaFunction interface {
cdktf.TerraformResource
Architectures() *[]*string
SetArchitectures(val *[]*string)
ArchitecturesInput() *[]*string
Arn() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CodeSha256() *string
CodeSigningConfigArn() *string
SetCodeSigningConfigArn(val *string)
CodeSigningConfigArnInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DeadLetterConfig() LambdaFunctionDeadLetterConfigOutputReference
DeadLetterConfigInput() *LambdaFunctionDeadLetterConfig
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Environment() LambdaFunctionEnvironmentOutputReference
EnvironmentInput() *LambdaFunctionEnvironment
EphemeralStorage() LambdaFunctionEphemeralStorageOutputReference
EphemeralStorageInput() *LambdaFunctionEphemeralStorage
Filename() *string
SetFilename(val *string)
FilenameInput() *string
FileSystemConfig() LambdaFunctionFileSystemConfigOutputReference
FileSystemConfigInput() *LambdaFunctionFileSystemConfig
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
FunctionName() *string
SetFunctionName(val *string)
FunctionNameInput() *string
Handler() *string
SetHandler(val *string)
HandlerInput() *string
Id() *string
SetId(val *string)
IdInput() *string
ImageConfig() LambdaFunctionImageConfigOutputReference
ImageConfigInput() *LambdaFunctionImageConfig
ImageUri() *string
SetImageUri(val *string)
ImageUriInput() *string
InvokeArn() *string
KmsKeyArn() *string
SetKmsKeyArn(val *string)
KmsKeyArnInput() *string
LastModified() *string
Layers() *[]*string
SetLayers(val *[]*string)
LayersInput() *[]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LoggingConfig() LambdaFunctionLoggingConfigOutputReference
LoggingConfigInput() *LambdaFunctionLoggingConfig
MemorySize() *float64
SetMemorySize(val *float64)
MemorySizeInput() *float64
// The tree node.
Node() constructs.Node
PackageType() *string
SetPackageType(val *string)
PackageTypeInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
Publish() interface{}
SetPublish(val interface{})
PublishInput() interface{}
QualifiedArn() *string
QualifiedInvokeArn() *string
// Experimental.
RawOverrides() interface{}
ReplacementSecurityGroupIds() *[]*string
SetReplacementSecurityGroupIds(val *[]*string)
ReplacementSecurityGroupIdsInput() *[]*string
ReplaceSecurityGroupsOnDestroy() interface{}
SetReplaceSecurityGroupsOnDestroy(val interface{})
ReplaceSecurityGroupsOnDestroyInput() interface{}
ReservedConcurrentExecutions() *float64
SetReservedConcurrentExecutions(val *float64)
ReservedConcurrentExecutionsInput() *float64
Role() *string
SetRole(val *string)
RoleInput() *string
Runtime() *string
SetRuntime(val *string)
RuntimeInput() *string
S3Bucket() *string
SetS3Bucket(val *string)
S3BucketInput() *string
S3Key() *string
SetS3Key(val *string)
S3KeyInput() *string
S3ObjectVersion() *string
SetS3ObjectVersion(val *string)
S3ObjectVersionInput() *string
SigningJobArn() *string
SigningProfileVersionArn() *string
SkipDestroy() interface{}
SetSkipDestroy(val interface{})
SkipDestroyInput() interface{}
SnapStart() LambdaFunctionSnapStartOutputReference
SnapStartInput() *LambdaFunctionSnapStart
SourceCodeHash() *string
SetSourceCodeHash(val *string)
SourceCodeHashInput() *string
SourceCodeSize() *float64
Tags() *map[string]*string
SetTags(val *map[string]*string)
TagsAll() *map[string]*string
SetTagsAll(val *map[string]*string)
TagsAllInput() *map[string]*string
TagsInput() *map[string]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeout() *float64
SetTimeout(val *float64)
TimeoutInput() *float64
Timeouts() LambdaFunctionTimeoutsOutputReference
TimeoutsInput() interface{}
TracingConfig() LambdaFunctionTracingConfigOutputReference
TracingConfigInput() *LambdaFunctionTracingConfig
Version() *string
VpcConfig() LambdaFunctionVpcConfigOutputReference
VpcConfigInput() *LambdaFunctionVpcConfig
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDeadLetterConfig(value *LambdaFunctionDeadLetterConfig)
PutEnvironment(value *LambdaFunctionEnvironment)
PutEphemeralStorage(value *LambdaFunctionEphemeralStorage)
PutFileSystemConfig(value *LambdaFunctionFileSystemConfig)
PutImageConfig(value *LambdaFunctionImageConfig)
PutLoggingConfig(value *LambdaFunctionLoggingConfig)
PutSnapStart(value *LambdaFunctionSnapStart)
PutTimeouts(value *LambdaFunctionTimeouts)
PutTracingConfig(value *LambdaFunctionTracingConfig)
PutVpcConfig(value *LambdaFunctionVpcConfig)
ResetArchitectures()
ResetCodeSigningConfigArn()
ResetDeadLetterConfig()
ResetDescription()
ResetEnvironment()
ResetEphemeralStorage()
ResetFilename()
ResetFileSystemConfig()
ResetHandler()
ResetId()
ResetImageConfig()
ResetImageUri()
ResetKmsKeyArn()
ResetLayers()
ResetLoggingConfig()
ResetMemorySize()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPackageType()
ResetPublish()
ResetReplacementSecurityGroupIds()
ResetReplaceSecurityGroupsOnDestroy()
ResetReservedConcurrentExecutions()
ResetRuntime()
ResetS3Bucket()
ResetS3Key()
ResetS3ObjectVersion()
ResetSkipDestroy()
ResetSnapStart()
ResetSourceCodeHash()
ResetTags()
ResetTagsAll()
ResetTimeout()
ResetTimeouts()
ResetTracingConfig()
ResetVpcConfig()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function aws_lambda_function}.
func NewLambdaFunction ¶
func NewLambdaFunction(scope constructs.Construct, id *string, config *LambdaFunctionConfig) LambdaFunction
Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function aws_lambda_function} Resource.
type LambdaFunctionConfig ¶
type LambdaFunctionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#function_name LambdaFunction#function_name}.
FunctionName *string `field:"required" json:"functionName" yaml:"functionName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#role LambdaFunction#role}.
Role *string `field:"required" json:"role" yaml:"role"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#architectures LambdaFunction#architectures}.
Architectures *[]*string `field:"optional" json:"architectures" yaml:"architectures"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#code_signing_config_arn LambdaFunction#code_signing_config_arn}.
CodeSigningConfigArn *string `field:"optional" json:"codeSigningConfigArn" yaml:"codeSigningConfigArn"`
// dead_letter_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#dead_letter_config LambdaFunction#dead_letter_config}
DeadLetterConfig *LambdaFunctionDeadLetterConfig `field:"optional" json:"deadLetterConfig" yaml:"deadLetterConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#description LambdaFunction#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
// environment block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#environment LambdaFunction#environment}
Environment *LambdaFunctionEnvironment `field:"optional" json:"environment" yaml:"environment"`
// ephemeral_storage block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#ephemeral_storage LambdaFunction#ephemeral_storage}
EphemeralStorage *LambdaFunctionEphemeralStorage `field:"optional" json:"ephemeralStorage" yaml:"ephemeralStorage"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#filename LambdaFunction#filename}.
Filename *string `field:"optional" json:"filename" yaml:"filename"`
// file_system_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#file_system_config LambdaFunction#file_system_config}
FileSystemConfig *LambdaFunctionFileSystemConfig `field:"optional" json:"fileSystemConfig" yaml:"fileSystemConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#handler LambdaFunction#handler}.
Handler *string `field:"optional" json:"handler" yaml:"handler"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#id LambdaFunction#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// image_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#image_config LambdaFunction#image_config}
ImageConfig *LambdaFunctionImageConfig `field:"optional" json:"imageConfig" yaml:"imageConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#image_uri LambdaFunction#image_uri}.
ImageUri *string `field:"optional" json:"imageUri" yaml:"imageUri"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#kms_key_arn LambdaFunction#kms_key_arn}.
KmsKeyArn *string `field:"optional" json:"kmsKeyArn" yaml:"kmsKeyArn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#layers LambdaFunction#layers}.
Layers *[]*string `field:"optional" json:"layers" yaml:"layers"`
// logging_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#logging_config LambdaFunction#logging_config}
LoggingConfig *LambdaFunctionLoggingConfig `field:"optional" json:"loggingConfig" yaml:"loggingConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#memory_size LambdaFunction#memory_size}.
MemorySize *float64 `field:"optional" json:"memorySize" yaml:"memorySize"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#package_type LambdaFunction#package_type}.
PackageType *string `field:"optional" json:"packageType" yaml:"packageType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#publish LambdaFunction#publish}.
Publish interface{} `field:"optional" json:"publish" yaml:"publish"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#replacement_security_group_ids LambdaFunction#replacement_security_group_ids}.
ReplacementSecurityGroupIds *[]*string `field:"optional" json:"replacementSecurityGroupIds" yaml:"replacementSecurityGroupIds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#replace_security_groups_on_destroy LambdaFunction#replace_security_groups_on_destroy}.
ReplaceSecurityGroupsOnDestroy interface{} `field:"optional" json:"replaceSecurityGroupsOnDestroy" yaml:"replaceSecurityGroupsOnDestroy"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#reserved_concurrent_executions LambdaFunction#reserved_concurrent_executions}.
ReservedConcurrentExecutions *float64 `field:"optional" json:"reservedConcurrentExecutions" yaml:"reservedConcurrentExecutions"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#runtime LambdaFunction#runtime}.
Runtime *string `field:"optional" json:"runtime" yaml:"runtime"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#s3_bucket LambdaFunction#s3_bucket}.
S3Bucket *string `field:"optional" json:"s3Bucket" yaml:"s3Bucket"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#s3_key LambdaFunction#s3_key}.
S3Key *string `field:"optional" json:"s3Key" yaml:"s3Key"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#s3_object_version LambdaFunction#s3_object_version}.
S3ObjectVersion *string `field:"optional" json:"s3ObjectVersion" yaml:"s3ObjectVersion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#skip_destroy LambdaFunction#skip_destroy}.
SkipDestroy interface{} `field:"optional" json:"skipDestroy" yaml:"skipDestroy"`
// snap_start block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#snap_start LambdaFunction#snap_start}
SnapStart *LambdaFunctionSnapStart `field:"optional" json:"snapStart" yaml:"snapStart"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#source_code_hash LambdaFunction#source_code_hash}.
SourceCodeHash *string `field:"optional" json:"sourceCodeHash" yaml:"sourceCodeHash"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#tags LambdaFunction#tags}.
Tags *map[string]*string `field:"optional" json:"tags" yaml:"tags"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#tags_all LambdaFunction#tags_all}.
TagsAll *map[string]*string `field:"optional" json:"tagsAll" yaml:"tagsAll"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#timeout LambdaFunction#timeout}.
Timeout *float64 `field:"optional" json:"timeout" yaml:"timeout"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#timeouts LambdaFunction#timeouts}
Timeouts *LambdaFunctionTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// tracing_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#tracing_config LambdaFunction#tracing_config}
TracingConfig *LambdaFunctionTracingConfig `field:"optional" json:"tracingConfig" yaml:"tracingConfig"`
// vpc_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#vpc_config LambdaFunction#vpc_config}
VpcConfig *LambdaFunctionVpcConfig `field:"optional" json:"vpcConfig" yaml:"vpcConfig"`
}
type LambdaFunctionDeadLetterConfig ¶
type LambdaFunctionDeadLetterConfig struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#target_arn LambdaFunction#target_arn}.
TargetArn *string `field:"required" json:"targetArn" yaml:"targetArn"`
}
type LambdaFunctionDeadLetterConfigOutputReference ¶
type LambdaFunctionDeadLetterConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LambdaFunctionDeadLetterConfig
SetInternalValue(val *LambdaFunctionDeadLetterConfig)
TargetArn() *string
SetTargetArn(val *string)
TargetArnInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLambdaFunctionDeadLetterConfigOutputReference ¶
func NewLambdaFunctionDeadLetterConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LambdaFunctionDeadLetterConfigOutputReference
type LambdaFunctionEnvironment ¶
type LambdaFunctionEnvironment struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#variables LambdaFunction#variables}.
Variables *map[string]*string `field:"optional" json:"variables" yaml:"variables"`
}
type LambdaFunctionEnvironmentOutputReference ¶
type LambdaFunctionEnvironmentOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LambdaFunctionEnvironment
SetInternalValue(val *LambdaFunctionEnvironment)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Variables() *map[string]*string
SetVariables(val *map[string]*string)
VariablesInput() *map[string]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetVariables()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLambdaFunctionEnvironmentOutputReference ¶
func NewLambdaFunctionEnvironmentOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LambdaFunctionEnvironmentOutputReference
type LambdaFunctionEphemeralStorage ¶
type LambdaFunctionEphemeralStorage struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#size LambdaFunction#size}.
Size *float64 `field:"optional" json:"size" yaml:"size"`
}
type LambdaFunctionEphemeralStorageOutputReference ¶
type LambdaFunctionEphemeralStorageOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LambdaFunctionEphemeralStorage
SetInternalValue(val *LambdaFunctionEphemeralStorage)
Size() *float64
SetSize(val *float64)
SizeInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetSize()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLambdaFunctionEphemeralStorageOutputReference ¶
func NewLambdaFunctionEphemeralStorageOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LambdaFunctionEphemeralStorageOutputReference
type LambdaFunctionFileSystemConfig ¶
type LambdaFunctionFileSystemConfig struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#arn LambdaFunction#arn}.
Arn *string `field:"required" json:"arn" yaml:"arn"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#local_mount_path LambdaFunction#local_mount_path}.
LocalMountPath *string `field:"required" json:"localMountPath" yaml:"localMountPath"`
}
type LambdaFunctionFileSystemConfigOutputReference ¶
type LambdaFunctionFileSystemConfigOutputReference interface {
cdktf.ComplexObject
Arn() *string
SetArn(val *string)
ArnInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LambdaFunctionFileSystemConfig
SetInternalValue(val *LambdaFunctionFileSystemConfig)
LocalMountPath() *string
SetLocalMountPath(val *string)
LocalMountPathInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLambdaFunctionFileSystemConfigOutputReference ¶
func NewLambdaFunctionFileSystemConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LambdaFunctionFileSystemConfigOutputReference
type LambdaFunctionImageConfig ¶
type LambdaFunctionImageConfig struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#command LambdaFunction#command}.
Command *[]*string `field:"optional" json:"command" yaml:"command"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#entry_point LambdaFunction#entry_point}.
EntryPoint *[]*string `field:"optional" json:"entryPoint" yaml:"entryPoint"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#working_directory LambdaFunction#working_directory}.
WorkingDirectory *string `field:"optional" json:"workingDirectory" yaml:"workingDirectory"`
}
type LambdaFunctionImageConfigOutputReference ¶
type LambdaFunctionImageConfigOutputReference interface {
cdktf.ComplexObject
Command() *[]*string
SetCommand(val *[]*string)
CommandInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EntryPoint() *[]*string
SetEntryPoint(val *[]*string)
EntryPointInput() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LambdaFunctionImageConfig
SetInternalValue(val *LambdaFunctionImageConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
WorkingDirectory() *string
SetWorkingDirectory(val *string)
WorkingDirectoryInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCommand()
ResetEntryPoint()
ResetWorkingDirectory()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLambdaFunctionImageConfigOutputReference ¶
func NewLambdaFunctionImageConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LambdaFunctionImageConfigOutputReference
type LambdaFunctionLoggingConfig ¶
type LambdaFunctionLoggingConfig struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#log_format LambdaFunction#log_format}.
LogFormat *string `field:"required" json:"logFormat" yaml:"logFormat"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#application_log_level LambdaFunction#application_log_level}.
ApplicationLogLevel *string `field:"optional" json:"applicationLogLevel" yaml:"applicationLogLevel"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#log_group LambdaFunction#log_group}.
LogGroup *string `field:"optional" json:"logGroup" yaml:"logGroup"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#system_log_level LambdaFunction#system_log_level}.
SystemLogLevel *string `field:"optional" json:"systemLogLevel" yaml:"systemLogLevel"`
}
type LambdaFunctionLoggingConfigOutputReference ¶
type LambdaFunctionLoggingConfigOutputReference interface {
cdktf.ComplexObject
ApplicationLogLevel() *string
SetApplicationLogLevel(val *string)
ApplicationLogLevelInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LambdaFunctionLoggingConfig
SetInternalValue(val *LambdaFunctionLoggingConfig)
LogFormat() *string
SetLogFormat(val *string)
LogFormatInput() *string
LogGroup() *string
SetLogGroup(val *string)
LogGroupInput() *string
SystemLogLevel() *string
SetSystemLogLevel(val *string)
SystemLogLevelInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetApplicationLogLevel()
ResetLogGroup()
ResetSystemLogLevel()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLambdaFunctionLoggingConfigOutputReference ¶
func NewLambdaFunctionLoggingConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LambdaFunctionLoggingConfigOutputReference
type LambdaFunctionSnapStart ¶
type LambdaFunctionSnapStart struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#apply_on LambdaFunction#apply_on}.
ApplyOn *string `field:"required" json:"applyOn" yaml:"applyOn"`
}
type LambdaFunctionSnapStartOutputReference ¶
type LambdaFunctionSnapStartOutputReference interface {
cdktf.ComplexObject
ApplyOn() *string
SetApplyOn(val *string)
ApplyOnInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LambdaFunctionSnapStart
SetInternalValue(val *LambdaFunctionSnapStart)
OptimizationStatus() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLambdaFunctionSnapStartOutputReference ¶
func NewLambdaFunctionSnapStartOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LambdaFunctionSnapStartOutputReference
type LambdaFunctionTimeouts ¶
type LambdaFunctionTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#create LambdaFunction#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#delete LambdaFunction#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#update LambdaFunction#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type LambdaFunctionTimeoutsOutputReference ¶
type LambdaFunctionTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLambdaFunctionTimeoutsOutputReference ¶
func NewLambdaFunctionTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LambdaFunctionTimeoutsOutputReference
type LambdaFunctionTracingConfig ¶
type LambdaFunctionTracingConfig struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#mode LambdaFunction#mode}.
Mode *string `field:"required" json:"mode" yaml:"mode"`
}
type LambdaFunctionTracingConfigOutputReference ¶
type LambdaFunctionTracingConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LambdaFunctionTracingConfig
SetInternalValue(val *LambdaFunctionTracingConfig)
Mode() *string
SetMode(val *string)
ModeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLambdaFunctionTracingConfigOutputReference ¶
func NewLambdaFunctionTracingConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LambdaFunctionTracingConfigOutputReference
type LambdaFunctionVpcConfig ¶
type LambdaFunctionVpcConfig struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#security_group_ids LambdaFunction#security_group_ids}.
SecurityGroupIds *[]*string `field:"required" json:"securityGroupIds" yaml:"securityGroupIds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#subnet_ids LambdaFunction#subnet_ids}.
SubnetIds *[]*string `field:"required" json:"subnetIds" yaml:"subnetIds"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.100.0/docs/resources/lambda_function#ipv6_allowed_for_dual_stack LambdaFunction#ipv6_allowed_for_dual_stack}.
Ipv6AllowedForDualStack interface{} `field:"optional" json:"ipv6AllowedForDualStack" yaml:"ipv6AllowedForDualStack"`
}
type LambdaFunctionVpcConfigOutputReference ¶
type LambdaFunctionVpcConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *LambdaFunctionVpcConfig
SetInternalValue(val *LambdaFunctionVpcConfig)
Ipv6AllowedForDualStack() interface{}
SetIpv6AllowedForDualStack(val interface{})
Ipv6AllowedForDualStackInput() interface{}
SecurityGroupIds() *[]*string
SetSecurityGroupIds(val *[]*string)
SecurityGroupIdsInput() *[]*string
SubnetIds() *[]*string
SetSubnetIds(val *[]*string)
SubnetIdsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
VpcId() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetIpv6AllowedForDualStack()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewLambdaFunctionVpcConfigOutputReference ¶
func NewLambdaFunctionVpcConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) LambdaFunctionVpcConfigOutputReference
Source Files
¶
- LambdaFunction.go
- LambdaFunctionConfig.go
- LambdaFunctionDeadLetterConfig.go
- LambdaFunctionDeadLetterConfigOutputReference.go
- LambdaFunctionDeadLetterConfigOutputReference__checks.go
- LambdaFunctionEnvironment.go
- LambdaFunctionEnvironmentOutputReference.go
- LambdaFunctionEnvironmentOutputReference__checks.go
- LambdaFunctionEphemeralStorage.go
- LambdaFunctionEphemeralStorageOutputReference.go
- LambdaFunctionEphemeralStorageOutputReference__checks.go
- LambdaFunctionFileSystemConfig.go
- LambdaFunctionFileSystemConfigOutputReference.go
- LambdaFunctionFileSystemConfigOutputReference__checks.go
- LambdaFunctionImageConfig.go
- LambdaFunctionImageConfigOutputReference.go
- LambdaFunctionImageConfigOutputReference__checks.go
- LambdaFunctionLoggingConfig.go
- LambdaFunctionLoggingConfigOutputReference.go
- LambdaFunctionLoggingConfigOutputReference__checks.go
- LambdaFunctionSnapStart.go
- LambdaFunctionSnapStartOutputReference.go
- LambdaFunctionSnapStartOutputReference__checks.go
- LambdaFunctionTimeouts.go
- LambdaFunctionTimeoutsOutputReference.go
- LambdaFunctionTimeoutsOutputReference__checks.go
- LambdaFunctionTracingConfig.go
- LambdaFunctionTracingConfigOutputReference.go
- LambdaFunctionTracingConfigOutputReference__checks.go
- LambdaFunctionVpcConfig.go
- LambdaFunctionVpcConfigOutputReference.go
- LambdaFunctionVpcConfigOutputReference__checks.go
- LambdaFunction__checks.go
- main.go